All Classes and Interfaces

Class
Description
Abstract implementation of the HeaderFields type.
Abstract implementation of the HeaderFields type.
Implementation of the HttpRequest interface.
Implementation of the HttpResponse interface.
The Enum AuthType.
Provides an accessor for a AuthType property.
Provides a builder method for a AuthType property returning the builder for applying multiple build operations.
Provides a mutator for a AuthType property.
Provides a AuthType property.
The Interface AuthTypeCredentials.
The Class BadGatewayException.
Proprietary code and only used inside a REFCODES.ORG client not trespassing any networking border (the error is generated by the client for the client locally).
The Class BadRequestException.
Proprietary code and only used inside a REFCODES.ORG client not trespassing any networking border (the error is generated by the client for the client locally).
Provides an accessor for a base locator property.
Provides a builder method for a base locator property returning the builder for applying multiple build operations.
Provides a mutator for a base locator property.
Provides a base locator property.
Provides an accessor for a base URL (protocol, host, port, locator) property.
Provides a builder method for a base URL (protocol, host, port, path) property returning the builder for applying multiple build operations.
Provides a mutator for a base URL (protocol, host, port, locator) property.
Provides a base URL (protocol, host, port, path) property.
The BasicAuthCredentials defines a type for representing a Basic-Authentication credentials Header-Field.
Provides an accessor for a BasicAuthCredentials property.
Provides a builder method for a BasicAuthCredentials property returning the builder for applying multiple build operations.
Provides a mutator for a BasicAuthCredentials property.
Provides a BasicAuthCredentials property.
The BasicAuthCredentialsBuilder compares the secret (BasicAuthCredentials.getSecret()) case sensitive but the username ( BasicAuthCredentials.getIdentity()) case insensitive within the BasicAuthCredentials.equals(Object) method.
Thrown in case HTTP basic authorization failed, e.g. verifying BasicAuthCredentials failed.
An observable which notifies the registered BasicAuthObserver on incoming HTTP Basic-Authentication requests.
An observer being notified by incoming HTTP Basic-Authentication requests which might have been registered via BasicAuthObservable.onBasicAuthRequest(BasicAuthObserver) possibly using lambda syntax.
Defines a BasicAuthRequest describes a Baisc-Auth request as of HTTP.
Thrown in case HTTP basic authorization is required but no required HeaderField.WWW_AUTHENTICATE data was found, e.g.
The enumeration for a Basic-Auth response.
The BasicCredentials describes the attributes required by a Basic-Auth authentication over HTTP(S).
The BearerAuthCredentials defines a type for representing a Bearer-Authentication credentials Header-Field.
Provides an accessor for a BearerAuthCredentials property.
Provides a builder method for a BearerAuthCredentials property returning the builder for applying multiple build operations.
Provides a mutator for a BearerAuthCredentials property.
Provides a BearerAuthCredentials property.
The Class ConflictException.
ContentEncodings are specified an an HTTP Header-Fields HeaderField.ACCEPT_ENCODING or HeaderField.CONTENT_ENCODING and how to encode a HTTP body or how a HTTP body is encoded.
Concrete MimeType implementation optionally carrying parameters.
Builder for creating ContentType instances.
Provides an accessor for a Content-Type property.
Provides a builder method for a Content-Type property returning the builder for applying multiple build operations.
Provides a mutator for a Content-Type property.
Provides a Content-Type property.
A provider interface provides a "toSomething(?)"
The ContentTypeParameters class represents parameters associated with an HTTP content type or media type.
Builder for creating ContentTypeParameters instances.
Known or in this scope used MimeType parameters.
The Cookie represents a HTTP cookie.
The Enum CookieAttribute.
The Class ExpectationFailedException.
The Class FailedDependencyException.
The Class ForbiddenException.
The FormFields represent the URL's Query-String by the notation originally used by the GET request of the ancient web forms (see "https://en.wikipedia.org/wiki/Query_string#Web_forms").
Provides an accessor for a request Form-Fields property.
Provides a mutator for a request Form-Fields property.
Provides a mutator for a request Form-Fields property.
Provides a request Form-Fields property.
Implements the MediaTypeFactory for Media-Type "application/x-www-form-urlencoded" ( MediaType.APPLICATION_X_WWW_FORM_URLENCODED).
Provides an accessor for a fragment property.
Provides a mutator for an fragment property.
Provides a mutator for a fragment property.
Provides a fragment property.
The Class GatewayTimeoutException.
The Class GoneException.
The GrantType enumerations.
The Enum HeaderField.
Provides an accessor for a HeaderField property.
Provides a builder method for a HeaderField property returning the builder for applying multiple build operations.
Provides a mutator for a HeaderField property.
Provides a HeaderField property.
The HeaderFields reflect the structure of a HTTP header and may be used to represent a HTTP header.
Provides an accessor for an Header-Fields property.
Provides a mutator for an Header-Fields property.
Provides a mutator for an Header-Fields property.
Provides an Header-Fields property.
Provides an accessor for a host property.
Provides a mutator for an host property.
Provides a mutator for a host property.
Provides a host property.
Implements the MediaTypeFactory for Media-Type "application/YAML" ( MediaType.APPLICATION_YAML).
Provides an accessor for a HTTP body property.
Provides a builder body for a HTTP body property returning the builder for applying multiple build operations.
Provides a mutator for a HTTP body property.
Provides a HTTP body property.
A provider interface provides a "toSomething(?)"
The HttpBodyTable type is a "dynamic" type in terms of it's structure being represented by paths'.
This context describes all information required to open a client (HTTP or HTTPS).
Provides a builder for the HttpClientContext type.
The HttpClientInterceptable provides base functionality for working with HttpClientInterceptor instances using the PreHttpClientInterceptable as well as the PostHttpClientInterceptable definitions.
An HttpClientInterceptor definition for pre- as well as post-processing HttpClientRequest as well as HttpClientResponse instances.
Defines a HttpClientRequest being the request as produced by the client.
Defines a HttpClientResponse being the response as consumed by the client.
The Class HttpRuntimeException.
Various key/value "collections" we run across when we develop HTTP based applications may have more then one value for one key.
Provides an accessor for a HTTP InputStream body property.
Provides a builder body for a HTTP InputStream property returning the builder for applying multiple build operations.
Provides a mutator for a InputStream property.
Provides a HTTP InputStream property.
A provider interface provides a "toSomething(?)"
The HttpInterceptable provides base functionality for working with HttpInterceptor instances using the PreHttpInterceptable as well as the PostHttpInterceptable definitions.
An HttpInterceptor definition for pre- as well as post-processing HttpRequest as well as HttpResponse instances.
The HttpMediaType converts an implementing instance's state into an HTTP media type as used in HTTP Header-Fields.
Provides an accessor for a HTTP Media-Type property.
Provides a builder body for a HTTP Media-Type property returning the builder for applying multiple build operations.
Provides a mutator for a HTTP Media-Type property.
Provides a HTTP Media-Type property.
A provider interface provides a "toSomething(?)"
The Enum HttpMethod.
Provides an accessor for a HTTP-Method property.
Provides a builder method for a HTTP-Method property returning the builder for applying multiple build operations.
Provides a mutator for a HTTP-Method property.
Provides a HTTP-Method property.
Defines a HTTP-Request, being the HttpMethod, the Header-Fields and the locator representing, though without the request body.
The Interface HttpRequestBuilder.
Defines a HttpResponse being the response Header-Fields and the response body.
The Interface HttpResponseBuilder.
Thrown by a HTTP-Response handling system in case of some unexpected response.
An observable which notifies the registered HttpsConnectionRequestObserver on incoming HTTPS requests.
An observer being notified by incoming HTTPS requests which might have been registered via HttpsConnectionRequestObservable.onConnectionRequest(HttpsConnectionRequestObserver) possibly using lambda syntax.
This context describes all information required to open a server (HTTP or HTTPS) and bind a port.
Provides a builder for the HttpServerContext type.
The HttpServerInterceptable provides base functionality for working with HttpServerInterceptor instances using the PreHttpServerInterceptable as well as the PostHttpServerInterceptable definitions.
An HttpServerInterceptor definition for pre- as well as post-processing HttpServerRequest as well as HttpServerResponse instances.
Defines a HttpServerRequest being the request as consumed by the server.
Defines a HttpServerResponse as produced by the server.
The org.apache.commons.httpclient.HttpStatus constants as enumeration.
Provides access to a HTTP Status-Code property including all known HTTP HTTP Status-Codes (success as well as error codes) as of HttpStatusCode.
Provides a builder method for a HTTP Status-Code property returning the builder for applying multiple build operations.
Extends the HttpStatusCodeAccessor with a setter method.
Extends the HttpStatusCodeAccessor with a setter method.
Base HTTP exception, thrown in case of HTTP status code related exceptions (e.g. as of a HTTP response was of an erroneous status).
Only the Success 2xx codes as of (from) the HttpStatusCode enumeration.
Provides access to a HTTP success code property including just the 2xx HTTP success codes as of HttpSuccessCode excluding all HTTP error codes.
Provides a builder method for a HTTP success code property returning the builder for applying multiple build operations.
Extends the HttpSuccessCodeAccessor with a setter method.
Extends the HttpSuccessCodeAccessor with a setter method.
The Class HttpVersionNotSupportedException.
The Class InsufficientSpaceOnResourceException.
The Class InsufficientStorageException.
Proprietary code and only used inside a REFCODES.ORG client not trespassing any networking border (the error is generated by the client for the client locally).
The Class InternalServerErrorException.
Implements the MediaTypeFactory for Media-Type "application/json" ( MediaType.APPLICATION_JSON).
The Class LengthRequiredException.
Represents a link relation describing the semantic relationship between resources.
Some simple load balancing strategies.
Provides access to a load balancing strategy property as of LoadBalancingStrategy.
Provides a builder method for a load balancing strategy property returning the builder for applying multiple build operations.
Extends the LoadBalancingStrategyAccessor with a setter method.
Extends the LoadBalancingStrategyAccessor with a setter method.
Provides an accessor for a local address property.
Provides a builder method for a local address property returning the builder for applying multiple build operations.
Provides a mutator for a local address property.
Provides a local address property.
The Class LockedException.
Represents a media type describing the format of data exchanged between components, systems, or protocols.
Provides an accessor for a Media-Type property.
Provides a builder method for a Media-Type property returning the builder for applying multiple build operations.
Provides a mutator for a Media-Type property.
Provides a Media-Type property.
The MediaTypeFactory creates instances from an HTTP body and creates an HTTP body from given instances according to the MimeType (as of MediaTypesAccessor.getMediaTypes()) for which the MediaTypeFactory is responsible.
The Interface MediaTypeFactoryLookup.
Provides an accessor for a Media-Types property.
Provides a builder method for a Media-Types property returning the builder for applying multiple build operations.
Provides a mutator for a Media-Types property.
Provides a Media-Types property.
The Class MethodFailureException.
The Class MethodNotAllowedException.
Represents a media type describing the format of data exchanged between components, systems, or protocols.
The Class MovedPermanentlyException.
The Class MovedTemporarilyException.
The Class MultipleChoicesException.
The Class MultiStatusException.
The Class NoContentException.
The Class NonAuthoritativeInformationException.
The Class NotAcceptableException.
The Class NotFoundException.
The Class NotImplementedException.
The Class NotModifiedException.
The Enum OauthField.
An OAuth-Token contains all relevant information to access a protected resource and refresh the the access token.
Provides an accessor for a OAuth token property.
Provides a builder method for a OAuth token property returning the builder for applying multiple build operations.
Provides a mutator for a OAuth token property.
Provides a OAuth token property.
The Class PartialContentException.
The Class PaymentRequiredException.
The Class PermanentRedirectException.
An PostHttpClientInterceptor definition for post-processing HttpClientRequest as well as HttpClientResponse instances.
The PostHttpInterceptable provides base functionality for working with PostHttpInterceptor instances.
An PostHttpInterceptor definition for post-processing HttpRequest as well as HttpResponse instances.
An PostHttpServerInterceptor definition for post-processing HttpServerRequest as well as HttpServerResponse instances.
The Class PreconditionFailedException.
An PreHttpClientInterceptor definition for pre-processing HttpClientRequest as well as HttpClientResponse instances.
The PreHttpInterceptable provides base functionality for working with PreHttpInterceptor instances.
An PreHttpInterceptor definition for pre-processing HttpRequest as well as HttpResponse instances.
An PreHttpServerInterceptor definition for pre-processing HttpServerRequest as well as HttpServerResponse instances.
The Enum Proxy.
The Class ProxyAuthenticationRequiredException.
Provides an accessor for a request Query-Fields property.
Provides a mutator for a request Query-Fields property.
Provides a mutator for a request Query-Fields property.
Provides a request Query-Fields property.
Provides an accessor for a realm property.
Provides a builder method for a realm property returning the builder for applying multiple build operations.
Provides a mutator for a realm property.
Provides a realm property.
The Class ReauthenticationRequiredException.
Provides an accessor for a redirect depth property.
Provides a builder method for a redirect depth property returning the builder for applying multiple build operations.
Provides a mutator for a redirect depth property.
Provides a redirect depth property.
Provides an accessor for a remote address property.
Provides a builder method for a remote address property returning the builder for applying multiple build operations.
Provides a mutator for a remote address property.
Provides a remote address property.
The RequestCookie represents a request cookies: We use URL encoding / decoding for the cookie value (regarding RequestCookie.fromHttpCookie(String) and RequestCookie.toHttpCookie()) to make life easier and not fall into the trap of unescaped values.
The Class RequestedRangeNotSatisfiableException.
The RequestHeaderFields reflect the structure of a HTTP-Header and may be used to represent a HTTP-Header.
Provides an accessor for an request Header-Fields property.
Provides a mutator for an request Header-Fields property.
Provides a mutator for an request Header-Fields property.
Provides an request Header-Fields property.
The Class RequestTimeoutException.
The Class RequestTooLongException.
The Class RequestUriTooLongException.
The Class ResetContentException.
As of "HTTP cookies explained - NCZOnline": "...
The ResponseHeaderFields reflect the structure of a HTTP header and may be used to represent a HTTP header.
Provides an accessor for an response Header-Fields property.
Provides a mutator for an response Header-Fields property.
Provides a mutator for an response Header-Fields property.
Provides an response Header-Fields property.
Provides an accessor for a URL scheme.
Provides a builder method for a URL scheme returning the builder for applying multiple build operations.
Provides a mutator for a URL scheme.
Provides a URL scheme.
The Class SeeOtherException.
The Class ServiceUnavailableException.
The Class TemporaryRedirectException.
Implements the MediaTypeFactory for Media-Type "text/plain" ( MediaType.TEXT_PLAIN).
The Interface TokenCredentials.
The Enum TokenType.
The TopLevelType is the top-level part of a HTTP Media-Type.
Provides an accessor for a Media-Top-Level-Type property.
Provides a builder method for a Media-Top-Level-Type property returning the builder for applying multiple build operations.
Provides a mutator for a Media-Top-Level-Type property.
Provides a Media-Top-Level-Type property.
Transport Layer Security Protocols (TLS-Protocols) known by the herein contained libraries.
The Class UnassignedStatusCodeException.
The Class UnauthorizedException.
The Class UnavailableForLegalReasonsException.
The Class UnprocessableEntityException.
Thrown in case a Media-Type has been provied which is not supported.
The Url class represents an immutable URL: An URL looks something like this:
Provides an accessor for a Url property..
Provides a builder method for a Url property returning the builder for applying multiple build operations.
Provides a mutator for a Url property.
Provides a Url property.
The UrlBuilder extends an immutable Url with mutable functionality.
Declarative syntactic sugar which may be statically imported in order to allow declarative definitions for Url (UrlBuilder) creation and tweaking: import static org.refcodes.web.UrlSugar
The Class UseProxyException.
Provides an accessor for a user agent property.
Provides a builder method for a user agent property returning the builder for applying multiple build operations.
Provides a mutator for a user agent property.
Provides a user agent property.
The Class VersionNotSupportedException.
Provides an accessor for a virtual host property.
Provides a mutator for an virtual host property.
Provides a mutator for a virtual host property.
Provides a virtual host property.
The base runtime exception for networking related issues.
Implements the MediaTypeFactory for Media-Type "application/xml" ( MediaType.APPLICATION_XML).
Implements the MediaTypeFactory for Media-Type "application/YAML" ( MediaType.APPLICATION_YAML).