Module org.refcodes.web

  • Packages

    Exports
    Package Description
    org.refcodes.web
    Use the types and definitions of this artifact when you are tired of defining your own networking based basics, your own HTTP-status-code enumerations (HttpStatusCode or exceptions representing erroneous HTTP state, or if you are tired of cookie handling, Header-Field processing ... and so on: