Class BadInvocationException

All Implemented Interfaces:
Serializable, ErrorCodeAccessor, Trap, StatusCodeAccessor<HttpStatusCode>, UrlAccessor

public class BadInvocationException extends HttpResponseException
Proprietary code and only used inside a REFCODES.ORG client not trespassing any networking border (the error is generated by the client for the client locally). This code is used when a client signals a bad invocation of the client by business logic, e.g. by providing a malformed URL.
See Also: