Class BadInvocationRuntimeException
- All Implemented Interfaces:
Serializable, ErrorCodeAccessor, Trap, StatusCodeAccessor<HttpStatusCode>, UrlAccessor
Proprietary code and only used inside a REFCODES.ORG client not trespassing
any networking border (the error is generated by the client for the client
locally). This code is used when a client signals a bad invocation of the
client by business logic, e.g. by providing a malformed URL.
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from interface ErrorCodeAccessor
ErrorCodeAccessor.ErrorCodeBuilder<B>, ErrorCodeAccessor.ErrorCodeMutator, ErrorCodeAccessor.ErrorCodePropertyNested classes/interfaces inherited from interface StatusCodeAccessor
StatusCodeAccessor.StatusCodeBuilder<SC,B>, StatusCodeAccessor.StatusCodeMutator<SC>, StatusCodeAccessor.StatusCodeProperty<SC> Nested classes/interfaces inherited from interface UrlAccessor
UrlAccessor.UrlBuilder, UrlAccessor.UrlMutator, UrlAccessor.UrlProperty -
Field Summary
Fields inherited from class HttpStatusRuntimeException
_httpStatusCode -
Constructor Summary
ConstructorsConstructorDescriptionBadInvocationRuntimeException(String aMessage) Instantiates the classBadInvocationRuntimeException.BadInvocationRuntimeException(String aMessage, String aErrorCode) Instantiates the classBadInvocationRuntimeException.BadInvocationRuntimeException(String aMessage, Throwable aCause) Instantiates the classBadInvocationRuntimeException.BadInvocationRuntimeException(String aMessage, Throwable aCause, String aErrorCode) Instantiates the classBadInvocationRuntimeException.Instantiates the classBadInvocationRuntimeException.BadInvocationRuntimeException(Throwable aCause, String aErrorCode) Instantiates the classBadInvocationRuntimeException.BadInvocationRuntimeException(Url aUrl, String aMessage) Instantiates the classBadInvocationRuntimeException.BadInvocationRuntimeException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classBadInvocationRuntimeException.BadInvocationRuntimeException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classBadInvocationRuntimeException.BadInvocationRuntimeException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classBadInvocationRuntimeException.BadInvocationRuntimeException(Url aUrl, Throwable aCause) Instantiates the classBadInvocationRuntimeException.BadInvocationRuntimeException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classBadInvocationRuntimeException. -
Method Summary
Methods inherited from class HttpStatusRuntimeException
getPatternArguments, getStatusCode, getUrlMethods inherited from class AbstractRuntimeException
getErrorCode, getMessageMethods inherited from class Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface Trap
toLocalizedMessage, toMessage, toMessage, toMessage, toShortLocalizedMessage, toShortMessage
-
Constructor Details
-
BadInvocationRuntimeException
Instantiates the classBadInvocationRuntimeException.- See Also:
-
BadInvocationRuntimeException
Instantiates the classBadInvocationRuntimeException.- See Also:
-
BadInvocationRuntimeException
Instantiates the classBadInvocationRuntimeException.- See Also:
-
BadInvocationRuntimeException
Instantiates the classBadInvocationRuntimeException.- See Also:
-
BadInvocationRuntimeException
Instantiates the classBadInvocationRuntimeException.- See Also:
-
BadInvocationRuntimeException
Instantiates the classBadInvocationRuntimeException.- See Also:
-
BadInvocationRuntimeException
Instantiates the classBadInvocationRuntimeException.- See Also:
-
BadInvocationRuntimeException
public BadInvocationRuntimeException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classBadInvocationRuntimeException.- See Also:
-
BadInvocationRuntimeException
Instantiates the classBadInvocationRuntimeException.- See Also:
-
BadInvocationRuntimeException
Instantiates the classBadInvocationRuntimeException.- See Also:
-
BadInvocationRuntimeException
Instantiates the classBadInvocationRuntimeException.- See Also:
-
BadInvocationRuntimeException
Instantiates the classBadInvocationRuntimeException.- See Also:
-