Class BadResponseException
- All Implemented Interfaces:
Serializable, ErrorCodeAccessor, Trap, StatusCodeAccessor<HttpStatusCode>, UrlAccessor
Proprietary code and only used inside a REFCODES.ORG client not trespassing
any networking border (the error is generated by the client for the client
locally). This code is used when a client signals a bad response being
received by a server, e.g. the response cannot be processed by the client and
does not meet the client's expectations.
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from interface ErrorCodeAccessor
ErrorCodeAccessor.ErrorCodeBuilder<B>, ErrorCodeAccessor.ErrorCodeMutator, ErrorCodeAccessor.ErrorCodePropertyNested classes/interfaces inherited from interface StatusCodeAccessor
StatusCodeAccessor.StatusCodeBuilder<SC,B>, StatusCodeAccessor.StatusCodeMutator<SC>, StatusCodeAccessor.StatusCodeProperty<SC> Nested classes/interfaces inherited from interface UrlAccessor
UrlAccessor.UrlBuilder, UrlAccessor.UrlMutator, UrlAccessor.UrlProperty -
Field Summary
Fields inherited from class HttpStatusException
_httpStatusCode -
Constructor Summary
ConstructorsConstructorDescriptionBadResponseException(String aMessage) Instantiates the classBadResponseException.BadResponseException(String aMessage, String aErrorCode) Instantiates the classBadResponseException.BadResponseException(String aMessage, Throwable aCause) Instantiates the classBadResponseException.BadResponseException(String aMessage, Throwable aCause, String aErrorCode) Instantiates the classBadResponseException.BadResponseException(Throwable aCause) Instantiates the classBadResponseException.BadResponseException(Throwable aCause, String aErrorCode) Instantiates the classBadResponseException.BadResponseException(Url aUrl, String aMessage) Instantiates the classBadResponseException.BadResponseException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classBadResponseException.BadResponseException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classBadResponseException.BadResponseException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classBadResponseException.BadResponseException(Url aUrl, Throwable aCause) Instantiates the classBadResponseException.BadResponseException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classBadResponseException. -
Method Summary
Methods inherited from class HttpStatusException
getPatternArguments, getStatusCode, getUrlMethods inherited from class AbstractException
getErrorCode, getMessageMethods inherited from class Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface Trap
toLocalizedMessage, toMessage, toMessage, toMessage, toShortLocalizedMessage, toShortMessage
-
Constructor Details
-
BadResponseException
Instantiates the classBadResponseException.- See Also:
-
BadResponseException
Instantiates the classBadResponseException.- See Also:
-
BadResponseException
Instantiates the classBadResponseException.- See Also:
-
BadResponseException
-
BadResponseException
Instantiates the classBadResponseException.- See Also:
-
BadResponseException
Instantiates the classBadResponseException.- See Also:
-
BadResponseException
Instantiates the classBadResponseException.- See Also:
-
BadResponseException
Instantiates the classBadResponseException.- See Also:
-
BadResponseException
Instantiates the classBadResponseException.- See Also:
-
BadResponseException
Instantiates the classBadResponseException.- See Also:
-
BadResponseException
Instantiates the classBadResponseException.- See Also:
-
BadResponseException
Instantiates the classBadResponseException.- See Also:
-