Class BadResponseRuntimeException

All Implemented Interfaces:
Serializable, ErrorCodeAccessor, Trap, StatusCodeAccessor<HttpStatusCode>, UrlAccessor

public class BadResponseRuntimeException extends HttpResponseRuntimeException
Proprietary code and only used inside a REFCODES.ORG client not trespassing any networking border (the error is generated by the client for the client locally). This code is used when a client signals a bad response being received by a server, e.g. the response cannot be processed by the client and does not meet the client's expectations.
See Also: