Module org.refcodes.web
Package org.refcodes.web
Interface BaseUrlAccessor.BaseUrlBuilder<B extends BaseUrlAccessor.BaseUrlBuilder<B>>
- Type Parameters:
B- The builder to return in order to be able to apply multiple build operations.
- All Known Implementing Classes:
HttpClientContextBuilder
- Enclosing interface:
- BaseUrlAccessor
public static interface BaseUrlAccessor.BaseUrlBuilder<B extends BaseUrlAccessor.BaseUrlBuilder<B>>
Provides a builder method for a base URL (protocol, host, port, path)
property returning the builder for applying multiple build operations.
-
Method Summary
Modifier and TypeMethodDescriptiondefault BwithBaseUrl(String aBaseUrl) Same aswithBaseUrl(URL)except that aMalformedURLExceptionmay occur when creating theURLinstance from the givenString.default BwithBaseUrl(String aProtocol, String aHost) Same aswithBaseUrl(URL)except that aMalformedURLExceptionmay occur when creating theURLinstance from the given parameters.default BwithBaseUrl(String aProtocol, String aHost, int aPort) Builder method forBaseUrlAccessor.BaseUrlMutator.setBaseUrl(String, String, int).default BwithBaseUrl(String aProtocol, String aHost, int aPort, String aPath) Builder method forBaseUrlAccessor.BaseUrlMutator.setBaseUrl(String, String, int, String).default BwithBaseUrl(String aProtocol, String aHost, String aPath) Same aswithBaseUrl(URL)except that aMalformedURLExceptionmay occur when creating theURLinstance from the given parameters.withBaseUrl(URL aBaseURL) Sets the base URL (protocol, host, port, path) for the base URL (protocol, host, port, path) property.default BwithBaseUrl(org.refcodes.data.Scheme aScheme, String aHost) Same aswithBaseUrl(URL)except that aMalformedURLExceptionmay occur when creating theURLinstance from the given parameters.default BwithBaseUrl(org.refcodes.data.Scheme aScheme, String aHost, int aPort) Builder method forBaseUrlAccessor.BaseUrlMutator.setBaseUrl(Scheme, String, int).default BwithBaseUrl(org.refcodes.data.Scheme aScheme, String aHost, int aPort, String aPath) Builder method forBaseUrlAccessor.BaseUrlMutator.setBaseUrl(Scheme, String, int, String).default BwithBaseUrl(org.refcodes.data.Scheme aScheme, String aHost, String aPath) Same aswithBaseUrl(URL)except that aMalformedURLExceptionmay occur when creating theURLinstance from the given parameters.withBaseUrl(Url aBaseUrl) Sets the baseUrl(protocol, host, port, path) for the base URL (protocol, host, port, path) property.
-
Method Details
-
withBaseUrl
Sets the baseUrl(protocol, host, port, path) for the base URL (protocol, host, port, path) property.- Parameters:
aBaseUrl- The base URL (protocol, host, port, path) to be stored by the local address property.- Returns:
- The builder for applying multiple build operations.
-
withBaseUrl
Sets the base URL (protocol, host, port, path) for the base URL (protocol, host, port, path) property.- Parameters:
aBaseURL- The base URL (protocol, host, port, path) to be stored by the local address property.- Returns:
- The builder for applying multiple build operations.
-
withBaseUrl
Same aswithBaseUrl(URL)except that aMalformedURLExceptionmay occur when creating theURLinstance from the givenString.- Parameters:
aBaseUrl- TheStringrepresenting theURL.- Returns:
- The builder for applying multiple build operations.
- Throws:
MalformedURLException- in case theStringcannot be converted to a valid (accepted)URL.
-
withBaseUrl
Same aswithBaseUrl(URL)except that aMalformedURLExceptionmay occur when creating theURLinstance from the given parameters.- Parameters:
aProtocol- The protocol (e.g. HTTP or HTTPS) to be used for the baseURL.aHost- The host to which the baseURLis to point to.- Returns:
- The builder for applying multiple build operations.
- Throws:
MalformedURLException- in case the parameters cannot be converted to a valid (accepted)URL.
-
withBaseUrl
Same aswithBaseUrl(URL)except that aMalformedURLExceptionmay occur when creating theURLinstance from the given parameters.- Parameters:
aScheme- TheScheme(e.g.Scheme.HTTPorScheme.HTTPS) to be used for the baseURL.aHost- The host to which the baseURLis to point to.- Returns:
- The builder for applying multiple build operations.
- Throws:
MalformedURLException- in case the parameters cannot be converted to a valid (accepted)URL.
-
withBaseUrl
Same aswithBaseUrl(URL)except that aMalformedURLExceptionmay occur when creating theURLinstance from the given parameters.- Parameters:
aProtocol- The protocol (e.g. HTTP or HTTPS) to be used for the baseURL.aHost- The host to which the baseURLis to point to.aPath- The path on the host to which the baseURLis to point to.- Returns:
- The builder for applying multiple build operations.
- Throws:
MalformedURLException- in case the parameters cannot be converted to a valid (accepted)URL.
-
withBaseUrl
default B withBaseUrl(org.refcodes.data.Scheme aScheme, String aHost, String aPath) throws MalformedURLException Same aswithBaseUrl(URL)except that aMalformedURLExceptionmay occur when creating theURLinstance from the given parameters.- Parameters:
aScheme- TheScheme(e.g.Scheme.HTTPorScheme.HTTPS) to be used for the baseURL.aHost- The host to which the baseURLis to point to.aPath- The path on the host to which the baseURLis to point to.- Returns:
- The builder for applying multiple build operations.
- Throws:
MalformedURLException- in case the parameters cannot be converted to a valid (accepted)URL.
-
withBaseUrl
Builder method forBaseUrlAccessor.BaseUrlMutator.setBaseUrl(String, String, int).- Parameters:
aProtocol- The protocol (e.g. HTTP or HTTPS) to be used for the baseURL.aHost- The host to which the baseURLis to point to.aPort- The port to be used when connecting to the host.- Returns:
- The builder for applying multiple build operations.
- Throws:
MalformedURLException- in case the parameters cannot be converted to a valid (accepted)URL.
-
withBaseUrl
default B withBaseUrl(org.refcodes.data.Scheme aScheme, String aHost, int aPort) throws MalformedURLException Builder method forBaseUrlAccessor.BaseUrlMutator.setBaseUrl(Scheme, String, int).- Parameters:
aScheme- TheScheme(e.g.Scheme.HTTPorScheme.HTTPS) to be used for the baseURL.aHost- The host to which the baseURLis to point to.aPort- The port to be used when connecting to the host.- Returns:
- The builder for applying multiple build operations.
- Throws:
MalformedURLException- in case the parameters cannot be converted to a valid (accepted)URL.
-
withBaseUrl
default B withBaseUrl(String aProtocol, String aHost, int aPort, String aPath) throws MalformedURLException Builder method forBaseUrlAccessor.BaseUrlMutator.setBaseUrl(String, String, int, String).- Parameters:
aProtocol- The protocol (e.g. HTTP or HTTPS) to be used for the baseURL.aHost- The host to which the baseURLis to point to.aPort- The port to be used when connecting to the host.aPath- The path on the host to which the baseURLis to point to.- Returns:
- The builder for applying multiple build operations.
- Throws:
MalformedURLException- in case the parameters cannot be converted to a valid (accepted)URL.
-
withBaseUrl
default B withBaseUrl(org.refcodes.data.Scheme aScheme, String aHost, int aPort, String aPath) throws MalformedURLException Builder method forBaseUrlAccessor.BaseUrlMutator.setBaseUrl(Scheme, String, int, String).- Parameters:
aScheme- TheScheme(e.g.Scheme.HTTPorScheme.HTTPS) to be used for the baseURL.aHost- The host to which the baseURLis to point to.aPort- The port to be used when connecting to the host.aPath- The path on the host to which the baseURLis to point to.- Returns:
- The builder for applying multiple build operations.
- Throws:
MalformedURLException- in case the parameters cannot be converted to a valid (accepted)URL.
-