- All Known Subinterfaces:
BaseUrlAccessor.BaseUrlProperty
- All Known Implementing Classes:
HttpClientContextBuilder
- Enclosing interface:
- BaseUrlAccessor
public static interface BaseUrlAccessor.BaseUrlMutator
Provides a mutator for a base URL (protocol, host, port, locator)
property.
-
Method Summary
Modifier and TypeMethodDescriptiondefault voidsetBaseUrl(String aBaseUrl) Same assetBaseUrl(URL)except that aMalformedURLExceptionmay occur when creating theURLinstance from the givenString.default voidsetBaseUrl(String aProtocol, String aHost) Same assetBaseUrl(URL)except that aMalformedURLExceptionmay occur when creating theURLinstance from the given parameters.default voidsetBaseUrl(String aProtocol, String aHost, int aPort) Same assetBaseUrl(URL)except that aMalformedURLExceptionmay occur when creating theURLinstance from the given parameters.default voidsetBaseUrl(String aProtocol, String aHost, int aPort, String aPath) Same assetBaseUrl(URL)except that aMalformedURLExceptionmay occur when creating theURLinstance from the given parameters.default voidsetBaseUrl(String aProtocol, String aHost, String aPath) Same assetBaseUrl(URL)except that aMalformedURLExceptionmay occur when creating theURLinstance from the given parameters.voidsetBaseUrl(URL aBaseUrl) Sets the base URL (protocol, host, port, path) for the base URL (protocol, host, port, path) property.default voidsetBaseUrl(org.refcodes.data.Scheme aScheme, String aHost) Same assetBaseUrl(URL)except that aMalformedURLExceptionmay occur when creating theURLinstance from the given parameters.default voidsetBaseUrl(org.refcodes.data.Scheme aScheme, String aHost, int aPort) Same assetBaseUrl(URL)except that aMalformedURLExceptionmay occur when creating theURLinstance from the given parameters.default voidsetBaseUrl(org.refcodes.data.Scheme aScheme, String aHost, int aPort, String aPath) Same assetBaseUrl(URL)except that aMalformedURLExceptionmay occur when creating theURLinstance from the given parameters.default voidsetBaseUrl(org.refcodes.data.Scheme aScheme, String aHost, String aPath) Same assetBaseUrl(URL)except that aMalformedURLExceptionmay occur when creating theURLinstance from the given parameters.voidsetBaseUrl(Url aBaseUrl) Sets the baseUrl(protocol, host, port, path) for the base URL (protocol, host, port, path) property.
-
Method Details
-
setBaseUrl
Sets the baseUrl(protocol, host, port, path) for the base URL (protocol, host, port, path) property.- Parameters:
aBaseUrl- The base URL (protocol, host, port, path) to be stored by the local address property.
-
setBaseUrl
Sets the base URL (protocol, host, port, path) for the base URL (protocol, host, port, path) property.- Parameters:
aBaseUrl- The base URL (protocol, host, port, path) to be stored by the local address property.
-
setBaseUrl
Same assetBaseUrl(URL)except that aMalformedURLExceptionmay occur when creating theURLinstance from the givenString.- Parameters:
aBaseUrl- TheStringrepresenting theURL.- Throws:
MalformedURLException- in case theStringcannot be converted to a valid (accepted)URL.
-
setBaseUrl
Same assetBaseUrl(URL)except that aMalformedURLExceptionmay occur when creating theURLinstance from the given parameters.- Parameters:
aProtocol- The protocol (e.g. HTTP or HTTPS) to be used for the baseURL.aHost- The host to which the baseURLis to point to.- Throws:
MalformedURLException- in case the parameters cannot be converted to a valid (accepted)URL.
-
setBaseUrl
Same assetBaseUrl(URL)except that aMalformedURLExceptionmay occur when creating theURLinstance from the given parameters.- Parameters:
aProtocol- The protocol (e.g. HTTP or HTTPS) to be used for the baseURL.aHost- The host to which the baseURLis to point to.aPort- The port to be used when connecting to the host.- Throws:
MalformedURLException- in case the parameters cannot be converted to a valid (accepted)URL.
-
setBaseUrl
default void setBaseUrl(org.refcodes.data.Scheme aScheme, String aHost) throws MalformedURLException Same assetBaseUrl(URL)except that aMalformedURLExceptionmay occur when creating theURLinstance from the given parameters.- Parameters:
aScheme- TheScheme(e.g.Scheme.HTTPorScheme.HTTPS) to be used for the baseURL.aHost- The host to which the baseURLis to point to.- Throws:
MalformedURLException- in case the parameters cannot be converted to a valid (accepted)URL.
-
setBaseUrl
default void setBaseUrl(org.refcodes.data.Scheme aScheme, String aHost, int aPort) throws MalformedURLException Same assetBaseUrl(URL)except that aMalformedURLExceptionmay occur when creating theURLinstance from the given parameters.- Parameters:
aScheme- TheScheme(e.g.Scheme.HTTPorScheme.HTTPS) to be used for the baseURL.aHost- The host to which the baseURLis to point to.aPort- The port to be used when connecting to the host.- Throws:
MalformedURLException- in case the parameters cannot be converted to a valid (accepted)URL.
-
setBaseUrl
Same assetBaseUrl(URL)except that aMalformedURLExceptionmay occur when creating theURLinstance from the given parameters.- Parameters:
aProtocol- The protocol (e.g. HTTP or HTTPS) to be used for the baseURL.aHost- The host to which the baseURLis to point to.aPath- The path on the host to which the baseURLis to point to.- Throws:
MalformedURLException- in case the parameters cannot be converted to a valid (accepted)URL.
-
setBaseUrl
default void setBaseUrl(String aProtocol, String aHost, int aPort, String aPath) throws MalformedURLException Same assetBaseUrl(URL)except that aMalformedURLExceptionmay occur when creating theURLinstance from the given parameters.- Parameters:
aProtocol- The protocol (e.g. HTTP or HTTPS) to be used for the baseURL.aHost- The host to which the baseURLis to point to.aPort- The port to be used when connecting to the host.aPath- The path on the host to which the baseURLis to point to.- Throws:
MalformedURLException- in case the parameters cannot be converted to a valid (accepted)URL.
-
setBaseUrl
default void setBaseUrl(org.refcodes.data.Scheme aScheme, String aHost, String aPath) throws MalformedURLException Same assetBaseUrl(URL)except that aMalformedURLExceptionmay occur when creating theURLinstance from the given parameters.- Parameters:
aScheme- TheScheme(e.g.Scheme.HTTPorScheme.HTTPS) to be used for the baseURL.aHost- The host to which the baseURLis to point to.aPath- The path on the host to which the baseURLis to point to.- Throws:
MalformedURLException- in case the parameters cannot be converted to a valid (accepted)URL.
-
setBaseUrl
default void setBaseUrl(org.refcodes.data.Scheme aScheme, String aHost, int aPort, String aPath) throws MalformedURLException Same assetBaseUrl(URL)except that aMalformedURLExceptionmay occur when creating theURLinstance from the given parameters.- Parameters:
aScheme- TheScheme(e.g.Scheme.HTTPorScheme.HTTPS) to be used for the baseURL.aHost- The host to which the baseURLis to point to.aPort- The port to be used when connecting to the host.aPath- The path on the host to which the baseURLis to point to.- Throws:
MalformedURLException- in case the parameters cannot be converted to a valid (accepted)URL.
-