Interface BaseUrlAccessor.BaseUrlProperty
- All Superinterfaces:
BaseUrlAccessor,BaseUrlAccessor.BaseUrlMutator
- All Known Implementing Classes:
HttpClientContextBuilder
- Enclosing interface:
BaseUrlAccessor
public static interface BaseUrlAccessor.BaseUrlProperty
extends BaseUrlAccessor, BaseUrlAccessor.BaseUrlMutator
Provides a base URL (protocol, host, port, path) property.
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.web.BaseUrlAccessor
BaseUrlAccessor.BaseUrlBuilder<B extends BaseUrlAccessor.BaseUrlBuilder<B>>, BaseUrlAccessor.BaseUrlMutator, BaseUrlAccessor.BaseUrlProperty -
Method Summary
Modifier and TypeMethodDescriptiondefault StringletBaseUrl(String aBaseUrl) This method stores and passes through the given argument, which is very useful for builder APIs.default UrlletBaseUrl(String aProtocol, String aHost) This method stores and passes through (being produced to anURL) the given arguments, which is very useful for builder APIs.default UrlletBaseUrl(String aProtocol, String aHost, int aPort) This method stores and passes through (being produced to anURL) the given arguments, which is very useful for builder APIs.default UrlletBaseUrl(String aProtocol, String aHost, int aPort, String aPath) This method stores and passes through (being produced to anURL) the given arguments, which is very useful for builder APIs.default UrlletBaseUrl(String aProtocol, String aHost, String aPath) This method stores and passes through (being produced to anURL) the given arguments, which is very useful for builder APIs.default URLletBaseUrl(URL aBaseUrl) This method stores and passes through the given arguments, which is very useful for builder APIs.default UrlletBaseUrl(org.refcodes.data.Scheme aScheme, String aHost) This method stores and passes through (being produced to anUrl) the given arguments, which is very useful for builder APIs.default UrlletBaseUrl(org.refcodes.data.Scheme aScheme, String aHost, int aPort) This method stores and passes through (being produced to anUrl) the given arguments, which is very useful for builder APIs.default UrlletBaseUrl(org.refcodes.data.Scheme aScheme, String aHost, int aPort, String aPath) This method stores and passes through (being produced to anURL) the given arguments, which is very useful for builder APIs.default UrlletBaseUrl(org.refcodes.data.Scheme aScheme, String aHost, String aPath) This method stores and passes through (being produced to anUrl) the given arguments, which is very useful for builder APIs.default UrlletBaseUrl(Url aBaseUrl) This method stores and passes through the given argument, which is very useful for builder APIs.Methods inherited from interface org.refcodes.web.BaseUrlAccessor
getBaseUrlMethods inherited from interface org.refcodes.web.BaseUrlAccessor.BaseUrlMutator
setBaseUrl, setBaseUrl, setBaseUrl, setBaseUrl, setBaseUrl, setBaseUrl, setBaseUrl, setBaseUrl, setBaseUrl, setBaseUrl, setBaseUrl
-
Method Details
-
letBaseUrl
This method stores and passes through (being produced to anUrl) the given arguments, which is very useful for builder APIs.- Parameters:
aScheme- TheScheme(e.g.Scheme.HTTPorScheme.HTTPS) to be used for the baseURL.aHost- The host to which the baseURLis to point to.- Returns:
- The produced value to be used in conclusive processing steps.
- Throws:
MalformedURLException- in case the parameters cannot beMalformedURLException- in case the parameters cannot be converted to a valid (accepted)URL.
-
letBaseUrl
default Url letBaseUrl(org.refcodes.data.Scheme aScheme, String aHost, int aPort) throws MalformedURLException This method stores and passes through (being produced to anUrl) the given arguments, which is very useful for builder APIs.- Parameters:
aScheme- TheScheme(e.g.Scheme.HTTPorScheme.HTTPS) to be used for the baseURL.aHost- The host to which the baseURLis to point to.aPort- The port to be used when connecting to the host.- Returns:
- The produced value to be used in conclusive processing steps.
- Throws:
MalformedURLException- in case the parameters cannot be converted to a valid (accepted)URL.
-
letBaseUrl
This method stores and passes through the given argument, which is very useful for builder APIs.- Parameters:
aBaseUrl- TheStringrepresenting theURL.- Returns:
- The value to be used in conclusive processing steps.
- Throws:
MalformedURLException- in case the parameters cannot be converted to a valid (accepted)URL.
-
letBaseUrl
default Url letBaseUrl(org.refcodes.data.Scheme aScheme, String aHost, String aPath) throws MalformedURLException This method stores and passes through (being produced to anUrl) the given arguments, which is very useful for builder APIs.- Parameters:
aScheme- TheScheme(e.g.Scheme.HTTPorScheme.HTTPS) to be used for the baseURL.aHost- The host to which the baseURLis to point to.aPath- The path on the host to which the baseURLis to point to.- Returns:
- The produced value to be used in conclusive processing steps.
- Throws:
MalformedURLException- in case the parameters cannot be converted to a valid (accepted)URL.
-
letBaseUrl
This method stores and passes through the given argument, which is very useful for builder APIs.- Parameters:
aBaseUrl- The base URL (protocol, host, port, path) to be stored by the local address property.- Returns:
- The value to be used in conclusive processing steps.
- Throws:
MalformedURLException- in case the parameters cannot be converted to a valid (accepted)URL.
-
letBaseUrl
This method stores and passes through the given arguments, which is very useful for builder APIs.- Parameters:
aBaseUrl- The base URL (protocol, host, port, path) to be stored by the local address property.- Returns:
- The passed value to be used in conclusive processing steps.
- Throws:
MalformedURLException- in case the parameters cannot be converted to a valid (accepted)URL.
-
letBaseUrl
This method stores and passes through (being produced to anURL) the given arguments, which is very useful for builder APIs.- Parameters:
aProtocol- The protocol (e.g. HTTP or HTTPS) to be used for the baseURL.aHost- The host to which the baseURLis to point to.- Returns:
- The produced value to be used in conclusive processing steps.
- Throws:
MalformedURLException- in case the parameters cannot be converted to a valid (accepted)URL.
-
letBaseUrl
This method stores and passes through (being produced to anURL) the given arguments, which is very useful for builder APIs.- Parameters:
aProtocol- The protocol (e.g. HTTP or HTTPS) to be used for the baseURL.aHost- The host to which the baseURLis to point to.aPort- The port to be used when connecting to the host.- Returns:
- The produced value to be used in conclusive processing steps.
- Throws:
MalformedURLException- in case the parameters cannot be converted to a valid (accepted)URL.
-
letBaseUrl
This method stores and passes through (being produced to anURL) the given arguments, which is very useful for builder APIs.- Parameters:
aProtocol- The protocol (e.g. HTTP or HTTPS) to be used for the baseURL.aHost- The host to which the baseURLis to point to.aPath- The path on the host to which the baseURLis to point to.- Returns:
- The produced value to be used in conclusive processing steps.
- Throws:
MalformedURLException- in case the parameters cannot be converted to a valid (accepted)URL.
-
letBaseUrl
default Url letBaseUrl(String aProtocol, String aHost, int aPort, String aPath) throws MalformedURLException This method stores and passes through (being produced to anURL) the given arguments, which is very useful for builder APIs.- Parameters:
aProtocol- The protocol (e.g. HTTP or HTTPS) to be used for the baseURL.aHost- The host to which the baseURLis to point to.aPort- The port to be used when connecting to the host.aPath- The path on the host to which the baseURLis to point to.- Returns:
- The produced value to be used in conclusive processing steps.
- Throws:
MalformedURLException- in case the parameters cannot be converted to a valid (accepted)URL.
-
letBaseUrl
default Url letBaseUrl(org.refcodes.data.Scheme aScheme, String aHost, int aPort, String aPath) throws MalformedURLException This method stores and passes through (being produced to anURL) the given arguments, which is very useful for builder APIs.- Parameters:
aScheme- TheScheme(e.g.Scheme.HTTPorScheme.HTTPS) to be used for the baseURL.aHost- The host to which the baseURLis to point to.aPort- The port to be used when connecting to the host.aPath- The path on the host to which the baseURLis to point to.- Returns:
- The produced value to be used in conclusive processing steps.
- Throws:
MalformedURLException- in case the parameters cannot be converted to a valid (accepted)URL.
-