-
- All Known Subinterfaces:
BasicAuthCredentialsAccessor.BasicAuthCredentialsProperty
- All Known Implementing Classes:
BasicAuthRequest
public interface BasicAuthCredentialsAccessorProvides an accessor for aBasicAuthCredentialsproperty.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceBasicAuthCredentialsAccessor.BasicAuthCredentialsBuilder<B extends BasicAuthCredentialsAccessor.BasicAuthCredentialsBuilder<B>>Provides a builder method for aBasicAuthCredentialsproperty returning the builder for applying multiple build operations.static interfaceBasicAuthCredentialsAccessor.BasicAuthCredentialsMutatorProvides a mutator for aBasicAuthCredentialsproperty.static interfaceBasicAuthCredentialsAccessor.BasicAuthCredentialsPropertyProvides aBasicAuthCredentialsproperty.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description BasicAuthCredentialsgetBasicAuthCredentials()Retrieves theBasicAuthCredentialsfrom the Basic-Authentication credentials property (or null if there are none such credentials).
-
-
-
Method Detail
-
getBasicAuthCredentials
BasicAuthCredentials getBasicAuthCredentials()
Retrieves theBasicAuthCredentialsfrom the Basic-Authentication credentials property (or null if there are none such credentials).- Returns:
- The
BasicAuthCredentialsstored by the basic authentication credentials property (or null if there are none such credentials).
-
-