Module org.refcodes.web
Package org.refcodes.web
Interface BasicAuthCredentialsAccessor.BasicAuthCredentialsMutator
- All Known Subinterfaces:
BasicAuthCredentialsAccessor.BasicAuthCredentialsProperty
- Enclosing interface:
- BasicAuthCredentialsAccessor
public static interface BasicAuthCredentialsAccessor.BasicAuthCredentialsMutator
Provides a mutator for a
BasicAuthCredentials property.-
Method Summary
Modifier and TypeMethodDescriptiondefault voidsetBasicAuthCredentials(String aUserName, String aSecret) Sets theBasicAuthCredentialsfrom the user name and the secret for the Basic-Authentication credentials property.voidsetBasicAuthCredentials(BasicAuthCredentials aBasicAuthCredentials) Sets theBasicAuthCredentialsfor the Basic-Authentication credentials property.
-
Method Details
-
setBasicAuthCredentials
Sets theBasicAuthCredentialsfor the Basic-Authentication credentials property.- Parameters:
aBasicAuthCredentials- TheBasicAuthCredentialsto be stored by theBasicAuthCredentialsproperty.
-
setBasicAuthCredentials
Sets theBasicAuthCredentialsfrom the user name and the secret for the Basic-Authentication credentials property.- Parameters:
aUserName- The user name to be stored by theBasicAuthCredentialsproperty.aSecret- The password to be stored by theBasicAuthCredentialsproperty.
-