Module org.refcodes.web
Package org.refcodes.web
Interface BasicAuthObservable<B extends BasicAuthObservable<B>>
-
- Type Parameters:
B- the generic type
public interface BasicAuthObservable<B extends BasicAuthObservable<B>>An observable which notifies the registeredBasicAuthObserveron incoming HTTP Basic-Authentication requests. Possible extension (idea): Provide means to add multipleBasicAuthObserverinstances and invoke them as of their locator pattern (provide an additional locator argument and an "BasicAuthEndpoint" class).
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description BonBasicAuthRequest(BasicAuthObserver aObserver)Registers theBasicAuthObserverto handle incoming HTTP basic authentication requests.
-
-
-
Method Detail
-
onBasicAuthRequest
B onBasicAuthRequest(BasicAuthObserver aObserver)
Registers theBasicAuthObserverto handle incoming HTTP basic authentication requests.- Parameters:
aObserver- The observer to handle incoming HTTP basic authentication requests.- Returns:
- the implementing instance as of the builder pattern
-
-