-
- All Known Subinterfaces:
BearerAuthCredentialsAccessor.BearerAuthCredentialsProperty
public interface BearerAuthCredentialsAccessorProvides an accessor for aBearerAuthCredentialsproperty.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceBearerAuthCredentialsAccessor.BearerAuthCredentialsBuilder<B extends BearerAuthCredentialsAccessor.BearerAuthCredentialsBuilder<B>>Provides a builder method for aBearerAuthCredentialsproperty returning the builder for applying multiple build operations.static interfaceBearerAuthCredentialsAccessor.BearerAuthCredentialsMutatorProvides a mutator for aBearerAuthCredentialsproperty.static interfaceBearerAuthCredentialsAccessor.BearerAuthCredentialsPropertyProvides aBearerAuthCredentialsproperty.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description BearerAuthCredentialsgetBearerAuthCredentials()Retrieves theBearerAuthCredentialsfrom the bearer auth credentials property (or null if there are none such credentials).
-
-
-
Method Detail
-
getBearerAuthCredentials
BearerAuthCredentials getBearerAuthCredentials()
Retrieves theBearerAuthCredentialsfrom the bearer auth credentials property (or null if there are none such credentials).- Returns:
- The
BearerAuthCredentialsstored by the bearer auth credentials property (or null if there are none such credentials).
-
-