Enum Class ContentEncoding
- All Implemented Interfaces:
Serializable,Comparable<ContentEncoding>,Constable,org.refcodes.mixin.NameAccessor
public enum ContentEncoding
extends Enum<ContentEncoding>
implements org.refcodes.mixin.NameAccessor
ContentEncodings are specified an an HTTP Header-Fields
HeaderField.ACCEPT_ENCODING or HeaderField.CONTENT_ENCODING
and how to encode a HTTP body or how a HTTP body is encoded.- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>>Nested classes/interfaces inherited from interface org.refcodes.mixin.NameAccessor
org.refcodes.mixin.NameAccessor.NameBuilder<B extends org.refcodes.mixin.NameAccessor.NameBuilder<B>>, org.refcodes.mixin.NameAccessor.NameMutator, org.refcodes.mixin.NameAccessor.NameProperty -
Enum Constant Summary
Enum Constants -
Method Summary
Modifier and TypeMethodDescriptionstatic ContentEncodingfromHttpEncoding(String aHttpEncoding) Returns thatContentEncodingrepresented by the given HTTP header's encoding.getName()Gets the name.static ContentEncodingReturns the enum constant of this class with the specified name.static ContentEncoding[]values()Returns an array containing the constants of this enum class, in the order they are declared.
-
Enum Constant Details
-
GZIP
-
COMPRESS
-
DEFLATE
-
IDENTITY
-
BR
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-
getName
Gets the name.- Specified by:
getNamein interfaceorg.refcodes.mixin.NameAccessor- Returns:
- the name
-
fromHttpEncoding
Returns thatContentEncodingrepresented by the given HTTP header's encoding.- Parameters:
aHttpEncoding- The HTTP header encoding for which to determine theContentEncoding.- Returns:
- The determined
ContentEncodingor null if none was determinable.
-