Class FormFields

java.lang.Object
All Implemented Interfaces:
Serializable, Cloneable, Map<String,List<String>>, HttpFields<FormFields>

public class FormFields extends AbstractHttpFields<FormFields>
The FormFields represent the URL's Query-String by the notation originally used by the GET request of the ancient web forms (see "https://en.wikipedia.org/wiki/Query_string#Web_forms"). Therefore the name FormFields, as them web forms provided fields with values (see "https://en.wikipedia.org/wiki/Form_(HTML)")
See Also: