- All Implemented Interfaces:
Serializable,Cloneable,Map<String,List<String>>,FormFields,HttpFields<FormFields>
public class FormFieldsImpl extends AbstractHttpFields<FormFields> implements FormFields
The Class FormFieldsImpl.
- Author:
- steiner
- See Also:
- Serialized Form
-
Nested Class Summary
Nested classes/interfaces inherited from class java.util.AbstractMap
AbstractMap.SimpleEntry<K extends Object,V extends Object>, AbstractMap.SimpleImmutableEntry<K extends Object,V extends Object> -
Constructor Summary
Constructors Constructor Description FormFieldsImpl()Instantiates a new form fields impl.FormFieldsImpl(String aHttpFormFields)Initializes the instance with the fields provided by the given HTTP Form-Fields (HTTP Query-String).FormFieldsImpl(Map<String,List<String>> aHttpFields)Initializes the instance with the fields provided by the givenMap. -
Method Summary
Methods inherited from class org.refcodes.web.AbstractHttpFields
copyHttpFieldsMethods inherited from class java.util.HashMap
clear, clone, compute, computeIfAbsent, computeIfPresent, containsKey, containsValue, entrySet, forEach, get, getOrDefault, isEmpty, keySet, merge, put, putAll, putIfAbsent, remove, remove, replace, replace, replaceAll, size, valuesMethods inherited from class java.util.AbstractMap
equals, hashCode, toStringMethods inherited from class java.lang.Object
finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.web.FormFields
fromBodyFormFields, fromUrl, fromUrlQueryString, toBodyFormFields, toContentLength, toUrlQueryStringMethods inherited from interface org.refcodes.web.HttpFields
addTo, addTo, addTo, addTo, addTo, addTo, getFirst, getFirst, put, put, put, put, toField, toField, withAddTo, withAddTo, withAddTo, withAddTo, withAddTo, withAddTo, withPut, withPut, withPut, withPut, withPut, withPutMethods inherited from interface java.util.Map
clear, compute, computeIfAbsent, computeIfPresent, containsKey, containsValue, entrySet, equals, forEach, get, getOrDefault, hashCode, isEmpty, keySet, merge, put, putAll, putIfAbsent, remove, remove, replace, replace, replaceAll, size, values
-
Constructor Details
-
FormFieldsImpl
public FormFieldsImpl()Instantiates a new form fields impl. -
FormFieldsImpl
Initializes the instance with the fields provided by the givenMap.- Parameters:
aHttpFields- TheMapfrom which to get the keys and values for initializing this instance.
-
FormFieldsImpl
Initializes the instance with the fields provided by the given HTTP Form-Fields (HTTP Query-String).- Parameters:
aHttpFormFields- TheStringfrom which to parse the keys and values for initializing this instance.
-