-
- All Known Subinterfaces:
FragmentAccessor.FragmentProperty
- All Known Implementing Classes:
Url,UrlBuilder
public interface FragmentAccessorProvides an accessor for a fragment property. A fragment is the hash ("#") separated suffix of anUrl.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceFragmentAccessor.FragmentBuilder<B extends FragmentAccessor.FragmentBuilder<?>>Provides a mutator for an fragment property.static interfaceFragmentAccessor.FragmentMutatorProvides a mutator for a fragment property.static interfaceFragmentAccessor.FragmentPropertyProvides a fragment property.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description StringgetFragment()Retrieves the fragment from the fragment property.
-
-
-
Method Detail
-
getFragment
String getFragment()
Retrieves the fragment from the fragment property.- Returns:
- The fragment stored by the fragment property.
-
-