-
- All Known Subinterfaces:
HostAccessor.HostProperty
- All Known Implementing Classes:
Url,UrlBuilder
public interface HostAccessorProvides an accessor for a host property.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceHostAccessor.HostBuilder<B extends HostAccessor.HostBuilder<?>>Provides a mutator for an host property.static interfaceHostAccessor.HostMutatorProvides a mutator for a host property.static interfaceHostAccessor.HostPropertyProvides a host property.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description StringgetHost()Retrieves the host from the host property.
-
-
-
Method Detail
-
getHost
String getHost()
Retrieves the host from the host property.- Returns:
- The host stored by the host property.
-
-