-
- All Known Subinterfaces:
HostAccessor.HostProperty
- All Known Implementing Classes:
UrlBuilder
- Enclosing interface:
- HostAccessor
public static interface HostAccessor.HostMutatorProvides a mutator for a host property.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description voidsetHost(String aHost)Sets the host for the host property.
-
-
-
Method Detail
-
setHost
void setHost(String aHost)
Sets the host for the host property.- Parameters:
aHost- The host to be stored by the host property.
-
-