- All Known Subinterfaces:
HttpBodyAccessor.HttpBodyProperty,HttpClientResponse,HttpServerRequest
- All Known Implementing Classes:
HttpClientResponseImpl,HttpServerRequestImpl
public interface HttpBodyAccessor
Provides an accessor for a HTTP body property.
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceHttpBodyAccessor.HttpBodyBuilder<B extends HttpBodyAccessor.HttpBodyBuilder<B>>Provides a builder body for a HTTP body property returning the builder for applying multiple build operations.static interfaceHttpBodyAccessor.HttpBodyMutatorProvides a mutator for a HTTP body property.static interfaceHttpBodyAccessor.HttpBodyPropertyProvides a HTTP body property.static interfaceHttpBodyAccessor.HttpBodyProvider<EXC extends Exception>A provider interface provides a "toSomething(?)" -
Method Summary
Modifier and Type Method Description StringgetHttpBody()Retrieves the HTTP body from the HTTP body property.
-
Method Details
-
getHttpBody
String getHttpBody()Retrieves the HTTP body from the HTTP body property.- Returns:
- The HTTP body stored by the HTTP body property.
-