Interface HttpBodyAccessor.HttpBodyProvider<EXC extends Exception>

Type Parameters:
EXC - The exception type which may be thrown upon converting to the desired type.
All Known Implementing Classes:
HttpClientRequest, HttpServerResponse
Enclosing interface:
HttpBodyAccessor

public static interface HttpBodyAccessor.HttpBodyProvider<EXC extends Exception>
A provider interface provides a "toSomething(?)" method which converts a given instance into something else. The ContentTypeAccessor.ContentTypeProvider converts an implementing instance's state into a ContentType instance.