Class HttpBodyTable
java.lang.Object
org.refcodes.struct.MapPathTable<String>
org.refcodes.struct.MapCanonicalTable
org.refcodes.web.HttpBodyTable
- All Implemented Interfaces:
Serializable, Map<String,String>, AnnotatorAccessor, Clearable, DelimiterAccessor, EmptyAccessor, TypeAccessor<String>, CanonicalTable, Containable, ImmutableCanonicalTable, ImmutableCanonicalTable.MutableCanonicalTable, ImmutableInterOperableTable<String>, ImmutableInterOperableTable.MutableInterOperableTable<String>, ImmutablePathTable<String>, ImmutablePathTable.MutablePathTable<String>, ImmutableTable<String, String>, ImmutableTable.MutableTable<String, String>, InterOperableTable<String>, Keys<String, String>, Keys.MutableKeys<String, String>, Keys.MutableValues<String, String>, PathTable<String>, Table<String, String, PathTable<String>>
The
HttpBodyTable type is a "dynamic" type in terms of it's structure
being represented by paths'. When a data structure is parsed e.g. from JSON
or XML, then the data structure's internal structure and values are reflected
by according paths's and values in the HttpBodyTable. The
HttpBodyTable is actually a https://www.metacodes.proization of the
ImmutablePathTable using String objects as values and a slash
("/") as path delimiter. Using the HttpBodyTable it is convenient to
navigate or address elements from unknown or dynamic data structures. The
other way round the HttpBodyTable may be used to construct dynamic
data types by adding the according paths's and values for marshaling into
e.g. JSON or XML. Think of an HttpBodyTable as a flattened JSON or
XML structure. The HttpClientResponse, HttpServerRequest,
HttpServerResponse as well as the HttpClientResponse
implementations directly support the HttpBodyTable, given that the
MediaTypeFactory being used supports marshaling and unmarshaling from
and to nested Map instances. The HttpBodyTable acts as a view
of the nested Map structures, which are somehow inconvenient to
navigate through. The HttpClientRequest.setRequest(Object)
implementation supports the HttpBodyTable to marshal an
HttpBodyTable into an HTTP Request-Body. The
HttpClientResponse.getResponse(Class) implementation supports the
HttpBodyTable to unmarshal an HTTP Response-Body into an
HttpBodyTable. The HttpServerRequest.getRequest(Class)
implementation supports the HttpBodyTable to unmarshal an HTTP
Request-Body into an HttpBodyTable. The
HttpServerResponse.setResponse(Object) implementation supports the
HttpBodyTable to marshal an HttpBodyTable into an HTTP
Request-Body.- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from interface AnnotatorAccessor
AnnotatorAccessor.AnnotatorBuilder<B>, AnnotatorAccessor.AnnotatorMutator, AnnotatorAccessor.AnnotatorPropertyNested classes/interfaces inherited from interface DelimiterAccessor
DelimiterAccessor.DelimiterBuilder<B>, DelimiterAccessor.DelimiterMutator, DelimiterAccessor.DelimiterPropertyNested classes/interfaces inherited from interface EmptyAccessor
EmptyAccessor.EmptyBuilder<B>, EmptyAccessor.EmptyMutator, EmptyAccessor.EmptyPropertyNested classes/interfaces inherited from interface ImmutableCanonicalTable
ImmutableCanonicalTable.MutableCanonicalTableNested classes/interfaces inherited from interface ImmutableInterOperableTable
ImmutableInterOperableTable.MutableInterOperableTable<T>Nested classes/interfaces inherited from interface ImmutablePathTable
ImmutablePathTable.MutablePathTable<T>Nested classes/interfaces inherited from interface ImmutableTable
ImmutableTable.MutableTable<K,V> Nested classes/interfaces inherited from interface Keys
Keys.MutableKeys<K,V>, Keys.MutableValues<K, V> Nested classes/interfaces inherited from interface TypeAccessor
TypeAccessor.TypeBuilder<T,B>, TypeAccessor.TypeMutator<T>, TypeAccessor.TypeProperty<T> -
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final Stringstatic final Stringstatic final Stringstatic final Stringstatic final StringFields inherited from class MapPathTable
_backingMapFields inherited from interface ImmutablePathTable
ANNOTATOR, DELIMITER -
Constructor Summary
ConstructorsConstructorDescriptionCreate an emptyHttpBodyTableinstance using the public path delimiter "/" (Delimiter.PATH) for the path declarations.HttpBodyTable(Object aObj) Create aHttpBodyTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the public path delimiter "/" (Delimiter.PATH) for the path declarations.HttpBodyTable(Object aObj, String aFromPath) Creates aHttpBodyTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the public path delimiter "/" (Delimiter.PATH) for the path declarations.HttpBodyTable(String aToPath, Object aObj) Create aHttpBodyTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the public path delimiter "/" (Delimiter.PATH) for the path declarations.HttpBodyTable(String aToPath, Object aObj, String aFromPath) Creates aHttpBodyTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the public path delimiter "/" (Delimiter.PATHfor the path declarations. -
Method Summary
Modifier and TypeMethodDescriptiongetDirAt(int aIndex) Retrieves the public path's ("status/alias") status alias.Retrieves the public path's ("status/code") status code.Class<?> Retrieves the public path's ("status/exception") status exception.Retrieves the public path's ("status/aMessage") status aMessage.Retrieves the public path's ("status/Time-Stamp") status Time-Stamp.booleanDetermines whether a public path's ("status/alias") status alias exists.booleanDetermines whether a public path's ("status/code") status code exists.booleanDetermines whether a public path's ("status/exception") status exception exists.booleanDetermines whether a public path's ("status/aMessage") status aMessage exists.booleanDetermines whether a public path's ("status/Time-Stamp") status Time-Stamp in milliseconds exists.putDirAt(int aIndex, ImmutablePathTable<String> aDir) putDirAt(Object[] aPathElements, int aIndex, ImmutablePathTable<String> aDir) putDirAt(Object aPath, int aIndex, ImmutablePathTable<String> aDir) putDirAt(String[] aPathElements, int aIndex, ImmutablePathTable<String> aDir) putDirAt(String aPath, int aIndex, ImmutablePathTable<String> aDir) putDirAt(Collection<?> aPathElements, int aIndex, Object aDir) putDirAt(Collection<?> aPathElements, int aIndex, ImmutablePathTable<String> aDir) putStatusAlias(String aStatusAlias) Puts a public path's ("status/alias") status alias.putStatusAlias(HttpStatusCode aStatusCode) Puts a public path's ("status/alias") status alias.putStatusCode(int aStatusCode) Puts a public path's ("status/code") status code.putStatusCode(HttpStatusCode aStatusCode) Puts a public path's ("status/code") status code.putStatusException(Class<Exception> aStatusException) Puts a public path's ("status/exception") status exception.putStatusException(Exception aStatusException) Puts a public path's ("status/exception") status exception.putStatusMessage(String aStatusMessage) Puts a public path's ("status/aMessage") status aMessage.Puts a public path's ("status/Time-Stamp") status Time-Stamp to the current time in milliseconds as ofSystem.currentTimeMillis()putStatusTimeStamp(long aStatusTimeStamp) Puts a public path's ("status/Time-Stamp") status Time-Stamp in milliseconds.query(Collection<?> aQueryElements) queryBetween(Object[] aFromPath, Object[] aPathQuery, Object[] aToPath) queryBetween(Object aFromPath, Object aPathQuery, Object aToPath) queryBetween(String[] aFromPath, String[] aPathQuery, String[] aToPath) queryBetween(String aFromPath, String aPathQuery, String aToPath) queryBetween(String aFromPath, Pattern aRegExp, String aToPath) queryBetween(Collection<?> aFromPath, Collection<?> aPathQuery, Collection<?> aToPath) queryFrom(Collection<?> aPathQuery, Collection<?> aFromPath) queryTo(Collection<?> aPathQuery, String aToPath) removeAll(Collection<?> aPathQueryElements) removeDirAt(int aIndex) removeDirAt(Object[] aPathElements, int aIndex) removeDirAt(Object aPath, int aIndex) removeDirAt(String[] aPathElements, int aIndex) removeDirAt(String aPath, int aIndex) removeFrom(Object aPath) removeFrom(Object... aPathElements) removeFrom(String aPath) removeFrom(String... aPathElements) removePaths(String... aPaths) removePaths(Collection<?> aPaths) retrieveBetween(Object[] aFromPath, Object[] aToPath) retrieveBetween(Object aFromPath, Object aToPath) retrieveBetween(String[] aFromPath, String[] aToPath) retrieveBetween(String aFromPath, String aToPath) retrieveBetween(Collection<?> aFromPath, Collection<?> aToPath) retrieveFrom(Object aParentPath) retrieveFrom(Object... aPathElements) retrieveFrom(String aFromPath) retrieveFrom(String... aPathElements) retrieveFrom(Collection<?> aPathElements) retrieveTo(Object aToPath) retrieveTo(Object... aToPathElements) retrieveTo(String aToPath) retrieveTo(String... aToPathElements) retrieveTo(Collection<?> aToPathElements) withInsert(Object aObj) withInsert(ImmutablePathTable<String> aFrom) withInsertBetween(Object[] aToPathElements, Object aFrom, Object[] aFromPathElements) withInsertBetween(Object[] aToPathElements, ImmutablePathTable<String> aFrom, Object[] aFromPathElements) withInsertBetween(Object aToPath, Object aFrom, Object aFromPath) withInsertBetween(Object aToPath, ImmutablePathTable<String> aFrom, Object aFromPath) withInsertBetween(String[] aToPathElements, Object aFrom, String[] aFromPathElements) withInsertBetween(String[] aToPathElements, ImmutablePathTable<String> aFrom, String[] aFromPathElements) withInsertBetween(String aToPath, Object aFrom, String aFromPath) withInsertBetween(String aToPath, ImmutablePathTable<String> aFrom, String aFromPath) withInsertBetween(Collection<?> aToPathElements, Object aFrom, Collection<?> aFromPathElements) withInsertBetween(Collection<?> aToPathElements, ImmutablePathTable<String> aFrom, Collection<?> aFromPathElements) withInsertFrom(Object aFrom, Object aFromPath) withInsertFrom(Object aFrom, Object... aFromPathElements) withInsertFrom(Object aFrom, String aFromPath) withInsertFrom(Object aFrom, String... aFromPathElements) withInsertFrom(Object aFrom, Collection<?> aFromPathElements) withInsertFrom(ImmutablePathTable<String> aFrom, Object aFromPath) withInsertFrom(ImmutablePathTable<String> aFrom, Object... aFromPathElements) withInsertFrom(ImmutablePathTable<String> aFrom, String aFromPath) withInsertFrom(ImmutablePathTable<String> aFrom, String... aFromPathElements) withInsertFrom(ImmutablePathTable<String> aFrom, Collection<?> aFromPathElements) withInsertTo(Object[] aToPathElements, Object aFrom) withInsertTo(Object[] aToPathElements, ImmutablePathTable<String> aFrom) withInsertTo(Object aToPath, Object aFrom) withInsertTo(Object aToPath, ImmutablePathTable<String> aFrom) withInsertTo(String[] aToPathElements, Object aFrom) withInsertTo(String[] aToPathElements, ImmutablePathTable<String> aFrom) withInsertTo(String aToPath, Object aFrom) withInsertTo(String aToPath, ImmutablePathTable<String> aFrom) withInsertTo(Collection<?> aToPathElements, Object aFrom) withInsertTo(Collection<?> aToPathElements, ImmutablePathTable<String> aFrom) withMerge(ImmutablePathTable<String> aFrom) withMergeBetween(Object[] aToPathElements, Object aFrom, Object[] aFromPathElements) withMergeBetween(Object[] aToPathElements, ImmutablePathTable<String> aFrom, Object[] aFromPathElements) withMergeBetween(Object aToPath, Object aFrom, Object aFromPath) withMergeBetween(Object aToPath, ImmutablePathTable<String> aFrom, Object aFromPath) withMergeBetween(String[] aToPathElements, Object aFrom, String[] aFromPathElements) withMergeBetween(String[] aToPathElements, ImmutablePathTable<String> aFrom, String[] aFromPathElements) withMergeBetween(String aToPath, Object aFrom, String aFromPath) withMergeBetween(String aToPath, ImmutablePathTable<String> aFrom, String aFromPath) withMergeBetween(Collection<?> aToPathElements, Object aFrom, Collection<?> aFromPathElements) withMergeBetween(Collection<?> aToPathElements, ImmutablePathTable<String> aFrom, Collection<?> aFromPathElements) withMergeFrom(Object aFrom, Object aFromPath) withMergeFrom(Object aFrom, Object... aFromPathElements) withMergeFrom(Object aFrom, String aFromPath) withMergeFrom(Object aFrom, String... aFromPathElements) withMergeFrom(Object aFrom, Collection<?> aFromPathElements) withMergeFrom(ImmutablePathTable<String> aFrom, Object aFromPath) withMergeFrom(ImmutablePathTable<String> aFrom, Object... aFromPathElements) withMergeFrom(ImmutablePathTable<String> aFrom, String aFromPath) withMergeFrom(ImmutablePathTable<String> aFrom, String... aFromPathElements) withMergeFrom(ImmutablePathTable<String> aFrom, Collection<?> aFromPathElements) withMergeTo(Object[] aToPathElements, Object aFrom) withMergeTo(Object[] aToPathElements, ImmutablePathTable<String> aFrom) withMergeTo(Object aToPath, Object aFrom) withMergeTo(Object aToPath, ImmutablePathTable<String> aFrom) withMergeTo(String[] aToPathElements, Object aFrom) withMergeTo(String[] aToPathElements, ImmutablePathTable<String> aFrom) withMergeTo(String aToPath, Object aFrom) withMergeTo(String aToPath, ImmutablePathTable<String> aFrom) withMergeTo(Collection<?> aToPathElements, Object aFrom) withMergeTo(Collection<?> aToPathElements, ImmutablePathTable<String> aFrom) withPut(Collection<?> aPathElements, String aValue) withPutBoolean(Object[] aPathElements, Boolean aValue) withPutBoolean(Object aKey, Boolean aValue) withPutBoolean(String[] aPathElements, Boolean aValue) withPutBoolean(String aKey, Boolean aValue) withPutBoolean(Collection<?> aPathElements, Boolean aValue) withPutByte(Object[] aPathElements, Byte aValue) withPutByte(Object aKey, Byte aValue) withPutByte(String[] aPathElements, Byte aValue) withPutByte(String aKey, Byte aValue) withPutByte(Collection<?> aPathElements, Byte aValue) withPutChar(Object[] aPathElements, Character aValue) withPutChar(Object aKey, Character aValue) withPutChar(String[] aPathElements, Character aValue) withPutChar(String aKey, Character aValue) withPutChar(Collection<?> aPathElements, Character aValue) <C> HttpBodyTablewithPutClass(Object[] aPathElements, Class<C> aValue) <C> HttpBodyTablewithPutClass(Object aKey, Class<C> aValue) <C> HttpBodyTablewithPutClass(String[] aPathElements, Class<C> aValue) <C> HttpBodyTablewithPutClass(String aKey, Class<C> aValue) <C> HttpBodyTablewithPutClass(Collection<?> aPathElements, Class<C> aValue) withPutDirAt(int aIndex, Object aDir) withPutDirAt(int aIndex, ImmutablePathTable<String> aDir) withPutDirAt(Object[] aPathElements, int aIndex, Object aDir) withPutDirAt(Object[] aPathElements, int aIndex, ImmutablePathTable<String> aDir) withPutDirAt(Object aPath, int aIndex, Object aDir) withPutDirAt(Object aPath, int aIndex, ImmutablePathTable<String> aDir) withPutDirAt(String[] aPathElements, int aIndex, Object aDir) withPutDirAt(String[] aPathElements, int aIndex, ImmutablePathTable<String> aDir) withPutDirAt(String aPath, int aIndex, Object aDir) withPutDirAt(String aPath, int aIndex, ImmutablePathTable<String> aDir) withPutDirAt(Collection<?> aPathElements, int aIndex, Object aDir) withPutDirAt(Collection<?> aPathElements, int aIndex, ImmutablePathTable<String> aDir) withPutDouble(Object[] aPathElements, Double aValue) withPutDouble(Object aKey, Double aValue) withPutDouble(String[] aPathElements, Double aValue) withPutDouble(String aKey, Double aValue) withPutDouble(Collection<?> aPathElements, Double aValue) <E extends Enum<E>>
HttpBodyTablewithPutEnum(Object[] aPathElements, E aValue) <E extends Enum<E>>
HttpBodyTablewithPutEnum(Object aKey, E aValue) <E extends Enum<E>>
HttpBodyTablewithPutEnum(String[] aPathElements, E aValue) <E extends Enum<E>>
HttpBodyTablewithPutEnum(String aKey, E aValue) <E extends Enum<E>>
HttpBodyTablewithPutEnum(Collection<?> aPathElements, E aValue) withPutFloat(Object[] aPathElements, Float aValue) withPutFloat(Object aKey, Float aValue) withPutFloat(String[] aPathElements, Float aValue) withPutFloat(String aKey, Float aValue) withPutFloat(Collection<?> aPathElements, Float aValue) withPutInt(Object[] aPathElements, Integer aValue) withPutInt(Object aKey, Integer aValue) withPutInt(String[] aPathElements, Integer aValue) withPutInt(String aKey, Integer aValue) withPutInt(Collection<?> aPathElements, Integer aValue) withPutLong(Object[] aPathElements, Long aValue) withPutLong(Object aKey, Long aValue) withPutLong(String[] aPathElements, Long aValue) withPutLong(String aKey, Long aValue) withPutLong(Collection<?> aPathElements, Long aValue) withPutShort(Object[] aPathElements, Short aValue) withPutShort(Object aKey, Short aValue) withPutShort(String[] aPathElements, Short aValue) withPutShort(String aKey, Short aValue) withPutShort(Collection<?> aPathElements, Short aValue) withPutStatusAlias(String aStatusAlias) Puts a public path's ("status/alias") status alias.withPutStatusAlias(HttpStatusCode aStatusCode) Puts a public path's ("status/alias") status alias.withPutStatusCode(int aStatusCode) Puts a public path's ("status/code") status code.withPutStatusCode(HttpStatusCode aStatusCode) Puts a public path's ("status/code") status code.withPutString(Object[] aPathElements, String aValue) withPutString(Object aKey, String aValue) withPutString(String[] aPathElements, String aValue) withPutString(String aKey, String aValue) withPutString(Collection<?> aPathElements, String aValue) withRemoveFrom(Object aPath) withRemoveFrom(Object... aPathElements) withRemoveFrom(String aPath) withRemoveFrom(String... aPathElements) withRemoveFrom(Collection<?> aPathElements) withRemovePaths(String... aPathElements) Methods inherited from class MapCanonicalTable
fromInstance, fromObject, toInstanceMethods inherited from class MapPathTable
clear, compute, computeIfAbsent, computeIfPresent, containsKey, containsValue, createBackingMap, entrySet, equals, forEach, fromValue, fromValue, get, getAnnotator, getDelimiter, getOrDefault, getType, hashCode, insert, insertBetween, insertFrom, insertTo, isEmpty, keySet, merge, merge, mergeBetween, mergeFrom, mergeTo, put, putAll, putIfAbsent, remove, remove, replace, replace, replaceAll, size, toDataStructure, toString, toType, valuesMethods inherited from interface AnnotatorAccessor
getAnnotatorMethods inherited from interface Containable
sizeMethods inherited from interface DelimiterAccessor
getDelimiterMethods inherited from interface EmptyAccessor
isEmptyMethods inherited from interface ImmutableCanonicalTable
asArray, asArray, asArray, asArray, asBooleanArray, asBooleanArray, asBooleanArray, asBooleanArray, asByteArray, asByteArray, asByteArray, asByteArray, asCharArray, asCharArray, asCharArray, asCharArray, asDoubleArray, asDoubleArray, asDoubleArray, asDoubleArray, asFloatArray, asFloatArray, asFloatArray, asFloatArray, asIntArray, asIntArray, asIntArray, asIntArray, asLongArray, asLongArray, asLongArray, asLongArray, asShortArray, asShortArray, asShortArray, asShortArray, getDir, getDir, getDir, getDir, getDir, getDirAt, getDirAt, getDirAt, getDirAt, getDirs, getDirs, getDirs, getDirs, getDirs, toMap, toPropertiesMethods inherited from interface ImmutableCanonicalTable.MutableCanonicalTable
containsValue, insert, insertBetween, insertFrom, insertTo, put, put, put, put, putAll, putAll, putAll, removeFromMethods inherited from interface ImmutableInterOperableTable
getBoolean, getBoolean, getBoolean, getBoolean, getBoolean, getBooleanOr, getBooleanOr, getBooleanOr, getBooleanOr, getBooleanOr, getByte, getByte, getByte, getByte, getByte, getByteOr, getByteOr, getByteOr, getByteOr, getByteOr, getChar, getChar, getChar, getChar, getChar, getCharOr, getCharOr, getCharOr, getCharOr, getCharOr, getClass, getClass, getClass, getClass, getClass, getClassOr, getClassOr, getClassOr, getClassOr, getClassOr, getDouble, getDouble, getDouble, getDouble, getDouble, getDoubleOr, getDoubleOr, getDoubleOr, getDoubleOr, getDoubleOr, getEnum, getEnum, getEnum, getEnum, getEnum, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getEnumOr, getFloat, getFloat, getFloat, getFloat, getFloat, getFloatOr, getFloatOr, getFloatOr, getFloatOr, getFloatOr, getInt, getInt, getInt, getInt, getInt, getIntOr, getIntOr, getIntOr, getIntOr, getIntOr, getLong, getLong, getLong, getLong, getLong, getLongOr, getLongOr, getLongOr, getLongOr, getLongOr, getShort, getShort, getShort, getShort, getShort, getShortOr, getShortOr, getShortOr, getShortOr, getShortOr, getString, getString, getString, getString, getString, getStringOr, getStringOr, getStringOr, getStringOr, getStringOrMethods inherited from interface ImmutableInterOperableTable.MutableInterOperableTable
containsValue, insert, insertBetween, insertFrom, insertTo, putBoolean, putBoolean, putBoolean, putBoolean, putBoolean, putByte, putByte, putByte, putByte, putByte, putChar, putChar, putChar, putChar, putChar, putClass, putClass, putClass, putClass, putClass, putDouble, putDouble, putDouble, putDouble, putDouble, putEnum, putEnum, putEnum, putEnum, putEnum, putFloat, putFloat, putFloat, putFloat, putFloat, putInt, putInt, putInt, putInt, putInt, putLong, putLong, putLong, putLong, putLong, putShort, putShort, putShort, putShort, putShort, putString, putString, putString, putString, putStringMethods inherited from interface ImmutablePathTable
children, children, children, children, children, children, containsKey, containsKey, containsKey, dirs, dirs, dirs, dirs, dirs, dirs, findPaths, fromExternalPath, get, get, get, getArray, getArray, getArray, getArray, getArray, getArray, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayIndexes, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getArrayOr, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getDirIndexes, getRootPath, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, getValueAt, hasChildren, hasChildren, hasChildren, hasChildren, hasChildren, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasDirAt, hasParentPath, hasPath, hasPath, hasPath, hasPath, hasPath, hasSubDirs, hasSubDirs, hasSubDirs, hasSubDirs, hasValue, hasValue, hasValue, hasValue, hasValue, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, hasValueAt, isArray, isArray, isArray, isArray, isArray, isArray, isChild, isChild, isChild, isChild, isDir, isDir, isDir, isDir, isDir, isEqualTo, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isIndexDir, isLeaf, isLeaf, isLeaf, isLeaf, isLeaf, isRootPath, keySet, keySet, keySet, keySet, keySet, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastArrayIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, lastDirIndex, leaves, leaves, leaves, leaves, leaves, leaves, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextArrayIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, nextDirIndex, paths, paths, paths, paths, paths, paths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, queryPaths, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, sortedKeys, toDataStructure, toDataStructure, toExternalPath, toInstance, toInstance, toLeaf, toMap, toNormalizedPath, toParentPath, toPath, toPath, toPath, toPath, toPathElements, toPathList, toPathStack, toPrintable, toPropertyPath, toType, toType, toType, toType, toType, toType, toType, toTypeMethods inherited from interface ImmutablePathTable.MutablePathTable
add, add, add, add, add, add, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendDirTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, appendValueTo, delete, delete, delete, delete, fromType, fromType, fromType, fromType, fromType, fromType, fromType, fromType, insert, insert, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertBetween, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertFrom, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, insertTo, merge, merge, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeBetween, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, mergeTo, put, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putArray, putValueAt, putValueAt, putValueAt, putValueAt, putValueAt, putValueAt, remove, remove, remove, removeValueAt, removeValueAt, removeValueAt, removeValueAt, removeValueAt, toSourceCode, toSourceCodeMethods inherited from interface ImmutableTable.MutableTable
putMethods inherited from interface Keys.MutableValues
putMethods inherited from interface Map
clear, compute, computeIfAbsent, computeIfPresent, containsKey, containsValue, entrySet, equals, forEach, get, getOrDefault, hashCode, isEmpty, keySet, merge, put, putIfAbsent, remove, remove, replace, replace, replaceAll, size, valuesMethods inherited from interface TypeAccessor
getType
-
Field Details
-
STATUS_CODE_PATH
- See Also:
-
STATUS_ALIAS_PATH
- See Also:
-
STATUS_MESSAGE_PATH
- See Also:
-
STATUS_EXCEPTION_PATH
- See Also:
-
STATUS_TIMESTAMP_PATH
- See Also:
-
-
Constructor Details
-
HttpBodyTable
public HttpBodyTable()Create an emptyHttpBodyTableinstance using the public path delimiter "/" (Delimiter.PATH) for the path declarations. -
HttpBodyTable
Create aHttpBodyTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the public path delimiter "/" (Delimiter.PATH) for the path declarations.- Parameters:
aObj- The object from which the elements are to be added.
-
HttpBodyTable
Create aHttpBodyTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the public path delimiter "/" (Delimiter.PATH) for the path declarations.- Parameters:
aToPath- The sub-path where to insert the object's introspected values to.aObj- The object from which the elements are to be added.
-
HttpBodyTable
Creates aHttpBodyTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the public path delimiter "/" (Delimiter.PATH) for the path declarations.- Parameters:
aObj- The object from which the elements are to be added.aFromPath- The path from where to start adding elements of the provided object.
-
HttpBodyTable
Creates aHttpBodyTableinstance containing the elements as ofImmutablePathTable.MutablePathTable.insert(Object)using the public path delimiter "/" (Delimiter.PATHfor the path declarations.- Parameters:
aToPath- The sub-path where to insert the object's introspected values to.aObj- The object from which the elements are to be added.aFromPath- The path from where to start adding elements of the provided object.
-
-
Method Details
-
retrieveFrom
- Specified by:
retrieveFromin interfaceImmutableCanonicalTable- Specified by:
retrieveFromin interfaceImmutablePathTable<String>- Overrides:
retrieveFromin classMapCanonicalTable
-
retrieveTo
- Specified by:
retrieveToin interfaceImmutableCanonicalTable- Specified by:
retrieveToin interfaceImmutablePathTable<String>- Overrides:
retrieveToin classMapCanonicalTable
-
retrieveBetween
-
withPut
-
getDirAt
-
getDirAt
-
getStatusAlias
Retrieves the public path's ("status/alias") status alias.- Returns:
- The previously set value for the status alias public path.
-
getStatusCode
Retrieves the public path's ("status/code") status code.- Returns:
- The previously set value for the status code public path.
-
getStatusException
Retrieves the public path's ("status/exception") status exception.- Returns:
- The previously set value for the status exception public path.
-
getStatusMessage
Retrieves the public path's ("status/aMessage") status aMessage.- Returns:
- The previously set value for the status aMessage public path.
-
getStatusTimeStamp
Retrieves the public path's ("status/Time-Stamp") status Time-Stamp.- Returns:
- The previously set value for the status Time-Stamp public path.
-
hasStatusAlias
public boolean hasStatusAlias()Determines whether a public path's ("status/alias") status alias exists.- Returns:
- True in case there is a valid value for the status alias default path.
-
hasStatusCode
public boolean hasStatusCode()Determines whether a public path's ("status/code") status code exists.- Returns:
- True in case there is a valid value for the status code default path.
-
hasStatusException
public boolean hasStatusException()Determines whether a public path's ("status/exception") status exception exists.- Returns:
- True in case there is a valid value for the status exception public path.
-
hasStatusMessage
public boolean hasStatusMessage()Determines whether a public path's ("status/aMessage") status aMessage exists.- Returns:
- True in case there is a valid value for the status aMessage public path.
-
hasStatusTimeStamp
public boolean hasStatusTimeStamp()Determines whether a public path's ("status/Time-Stamp") status Time-Stamp in milliseconds exists.- Returns:
- True in case there is a valid value for the status Time-Stamp public path.
-
putDirAt
-
putDirAt
public HttpBodyTable putDirAt(Collection<?> aPathElements, int aIndex, ImmutablePathTable<String> aDir) -
putDirAt
-
putDirAt
-
putDirAt
-
putDirAt
-
putDirAt
-
putDirAt
-
putDirAt
-
putDirAt
-
putDirAt
-
putDirAt
-
putStatusAlias
Puts a public path's ("status/alias") status alias.- Parameters:
aStatusCode- TheHttpStatusCode, which's verbose alias is to be set.- Returns:
- The previously set value for the status alias public path.
-
putStatusAlias
-
putStatusCode
Puts a public path's ("status/code") status code.- Parameters:
aStatusCode- TheHttpStatusCodeto be set.- Returns:
- The previously set value for the status code public path.
-
putStatusCode
Puts a public path's ("status/code") status code.- Parameters:
aStatusCode- The status code value to be set.- Returns:
- The previously set value for the status code public path.
-
putStatusException
-
putStatusException
-
putStatusMessage
-
putStatusTimeStamp
Puts a public path's ("status/Time-Stamp") status Time-Stamp to the current time in milliseconds as ofSystem.currentTimeMillis()- Returns:
- The previously set value for the status Time-Stamp public path.
-
putStatusTimeStamp
Puts a public path's ("status/Time-Stamp") status Time-Stamp in milliseconds.- Parameters:
aStatusTimeStamp- The status Time-Stamp value to be set.- Returns:
- The previously set value for the status Time-Stamp public path.
-
query
-
query
-
query
-
query
-
query
-
queryBetween
public HttpBodyTable queryBetween(Collection<?> aFromPath, Collection<?> aPathQuery, Collection<?> aToPath) -
queryBetween
-
queryBetween
-
queryBetween
-
queryBetween
-
queryBetween
-
queryFrom
-
queryFrom
-
queryFrom
-
queryFrom
-
queryFrom
-
queryFrom
-
queryTo
-
queryTo
-
queryTo
-
queryTo
-
queryTo
-
queryTo
-
removePaths
-
removePaths
-
removeAll
-
removeAll
-
removeAll
-
removeAll
-
removeAll
-
removeAll
-
removeDirAt
-
removeDirAt
-
removeDirAt
-
removeDirAt
-
removeDirAt
-
removeFrom
-
removeFrom
-
removeFrom
-
removeFrom
-
retrieveBetween
-
retrieveBetween
-
retrieveBetween
-
retrieveBetween
-
retrieveFrom
-
retrieveFrom
-
retrieveFrom
-
retrieveFrom
-
retrieveTo
-
retrieveTo
-
retrieveTo
-
retrieveTo
-
withPutStatusAlias
Puts a public path's ("status/alias") status alias.- Parameters:
aStatusCode- TheHttpStatusCode, which's verbose alias is to be set.- Returns:
- The previously set value for the status alias public path.
-
withPutStatusAlias
Puts a public path's ("status/alias") status alias.- Parameters:
aStatusAlias- The status alias value to be set.- Returns:
- The previously set value for the status alias public path.
-
withPutStatusCode
Puts a public path's ("status/code") status code.- Parameters:
aStatusCode- TheHttpStatusCodeto be set.- Returns:
- The previously set value for the status code public path.
-
withPutStatusCode
Puts a public path's ("status/code") status code.- Parameters:
aStatusCode- The status code value to be set.- Returns:
- The previously set value for the status code public path.
-
withPut
-
withPut
-
withPut
-
withPut
-
withPut
-
withPutBoolean
-
withPutBoolean
-
withPutBoolean
-
withPutBoolean
-
withPutBoolean
-
withPutByte
-
withPutByte
-
withPutByte
-
withPutByte
-
withPutByte
-
withPutChar
-
withPutChar
-
withPutChar
-
withPutChar
-
withPutChar
-
withPutClass
-
withPutClass
-
withPutClass
-
withPutClass
-
withPutClass
-
withPutDouble
-
withPutDouble
-
withPutDouble
-
withPutDouble
-
withPutDouble
-
withPutEnum
-
withPutEnum
-
withPutEnum
-
withPutEnum
-
withPutEnum
-
withPutFloat
-
withPutFloat
-
withPutFloat
-
withPutFloat
-
withPutFloat
-
withPutInt
-
withPutInt
-
withPutInt
-
withPutInt
-
withPutInt
-
withPutLong
-
withPutLong
-
withPutLong
-
withPutLong
-
withPutLong
-
withPutShort
-
withPutShort
-
withPutShort
-
withPutShort
-
withPutShort
-
withPutString
-
withPutString
-
withPutString
-
withPutString
-
withPutString
-
withInsert
-
withInsert
-
withInsertBetween
public HttpBodyTable withInsertBetween(Collection<?> aToPathElements, Object aFrom, Collection<?> aFromPathElements) -
withInsertBetween
public HttpBodyTable withInsertBetween(Collection<?> aToPathElements, ImmutablePathTable<String> aFrom, Collection<?> aFromPathElements) -
withInsertBetween
-
withInsertBetween
public HttpBodyTable withInsertBetween(Object aToPath, ImmutablePathTable<String> aFrom, Object aFromPath) -
withInsertBetween
public HttpBodyTable withInsertBetween(Object[] aToPathElements, Object aFrom, Object[] aFromPathElements) -
withInsertBetween
public HttpBodyTable withInsertBetween(Object[] aToPathElements, ImmutablePathTable<String> aFrom, Object[] aFromPathElements) -
withInsertBetween
-
withInsertBetween
public HttpBodyTable withInsertBetween(String aToPath, ImmutablePathTable<String> aFrom, String aFromPath) -
withInsertBetween
public HttpBodyTable withInsertBetween(String[] aToPathElements, Object aFrom, String[] aFromPathElements) -
withInsertBetween
public HttpBodyTable withInsertBetween(String[] aToPathElements, ImmutablePathTable<String> aFrom, String[] aFromPathElements) -
withInsertFrom
-
withInsertFrom
-
withInsertFrom
-
withInsertFrom
-
withInsertFrom
-
withInsertFrom
public HttpBodyTable withInsertFrom(ImmutablePathTable<String> aFrom, Collection<?> aFromPathElements) -
withInsertFrom
-
withInsertFrom
-
withInsertFrom
-
withInsertFrom
-
withInsertTo
-
withInsertTo
-
withInsertTo
-
withInsertTo
-
withInsertTo
-
withInsertTo
-
withInsertTo
-
withInsertTo
-
withInsertTo
-
withInsertTo
-
withMerge
-
withMerge
-
withMergeBetween
public HttpBodyTable withMergeBetween(Collection<?> aToPathElements, Object aFrom, Collection<?> aFromPathElements) -
withMergeBetween
public HttpBodyTable withMergeBetween(Collection<?> aToPathElements, ImmutablePathTable<String> aFrom, Collection<?> aFromPathElements) -
withMergeBetween
-
withMergeBetween
public HttpBodyTable withMergeBetween(Object aToPath, ImmutablePathTable<String> aFrom, Object aFromPath) -
withMergeBetween
public HttpBodyTable withMergeBetween(Object[] aToPathElements, Object aFrom, Object[] aFromPathElements) -
withMergeBetween
public HttpBodyTable withMergeBetween(Object[] aToPathElements, ImmutablePathTable<String> aFrom, Object[] aFromPathElements) -
withMergeBetween
-
withMergeBetween
public HttpBodyTable withMergeBetween(String aToPath, ImmutablePathTable<String> aFrom, String aFromPath) -
withMergeBetween
public HttpBodyTable withMergeBetween(String[] aToPathElements, Object aFrom, String[] aFromPathElements) -
withMergeBetween
public HttpBodyTable withMergeBetween(String[] aToPathElements, ImmutablePathTable<String> aFrom, String[] aFromPathElements) -
withMergeFrom
-
withMergeFrom
-
withMergeFrom
-
withMergeFrom
-
withMergeFrom
-
withMergeFrom
public HttpBodyTable withMergeFrom(ImmutablePathTable<String> aFrom, Collection<?> aFromPathElements) -
withMergeFrom
-
withMergeFrom
-
withMergeFrom
-
withMergeFrom
-
withMergeTo
-
withMergeTo
-
withMergeTo
-
withMergeTo
-
withMergeTo
-
withMergeTo
-
withMergeTo
-
withMergeTo
-
withMergeTo
-
withMergeTo
-
withPutDirAt
-
withPutDirAt
public HttpBodyTable withPutDirAt(Collection<?> aPathElements, int aIndex, ImmutablePathTable<String> aDir) -
withPutDirAt
-
withPutDirAt
-
withPutDirAt
-
withPutDirAt
-
withPutDirAt
-
withPutDirAt
public HttpBodyTable withPutDirAt(Object[] aPathElements, int aIndex, ImmutablePathTable<String> aDir) -
withPutDirAt
-
withPutDirAt
-
withPutDirAt
-
withPutDirAt
public HttpBodyTable withPutDirAt(String[] aPathElements, int aIndex, ImmutablePathTable<String> aDir) -
withRemoveFrom
-
withRemoveFrom
-
withRemoveFrom
-
withRemoveFrom
-
withRemoveFrom
-
withRemovePaths
-