Module org.refcodes.web
Package org.refcodes.web
Interface HttpClientContext.HttpClientContextBuilder
- All Superinterfaces:
BaseUrlAccessor,BaseUrlAccessor.BaseUrlBuilder<HttpClientContext.HttpClientContextBuilder>,BaseUrlAccessor.BaseUrlMutator,BaseUrlAccessor.BaseUrlProperty,org.refcodes.security.TrustStoreDescriptorAccessor,org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorBuilder<HttpClientContext.HttpClientContextBuilder>,org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorMutator,org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorProperty
- All Known Implementing Classes:
HttpClientContextBuilderImpl
- Enclosing interface:
- HttpClientContext
public static interface HttpClientContext.HttpClientContextBuilder extends BaseUrlAccessor.BaseUrlProperty, BaseUrlAccessor.BaseUrlBuilder<HttpClientContext.HttpClientContextBuilder>, org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorProperty, org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorBuilder<HttpClientContext.HttpClientContextBuilder>
The
HttpClientContext.HttpClientContextBuilder interface extends the
HttpClientContext with builder functionality as of the builder
pattern.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.web.BaseUrlAccessor
BaseUrlAccessor.BaseUrlBuilder<B extends BaseUrlAccessor.BaseUrlBuilder<B>>, BaseUrlAccessor.BaseUrlMutator, BaseUrlAccessor.BaseUrlPropertyNested classes/interfaces inherited from interface org.refcodes.security.TrustStoreDescriptorAccessor
org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorBuilder<B extends org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorBuilder<B>>, org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorMutator, org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorProperty -
Method Summary
Methods inherited from interface org.refcodes.web.BaseUrlAccessor
getBaseUrlMethods inherited from interface org.refcodes.web.BaseUrlAccessor.BaseUrlMutator
setBaseUrl, setBaseUrl, setBaseUrl, setBaseUrl, setBaseUrl, setBaseUrl, setBaseUrl, setBaseUrl, setBaseUrl, setBaseUrl, setBaseUrlMethods inherited from interface org.refcodes.web.BaseUrlAccessor.BaseUrlProperty
letBaseUrl, letBaseUrl, letBaseUrl, letBaseUrl, letBaseUrl, letBaseUrl, letBaseUrl, letBaseUrl, letBaseUrl, letBaseUrl, letBaseUrlMethods inherited from interface org.refcodes.security.TrustStoreDescriptorAccessor
getTrustStoreDescriptorMethods inherited from interface org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorMutator
setTrustStoreDescriptorMethods inherited from interface org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorProperty
letTrustStoreDescriptor
-
Method Details
-
withBaseUrl
Sets the baseUrl(protocol, host, port, path) for the base URL (protocol, host, port, path) property.- Specified by:
withBaseUrlin interfaceBaseUrlAccessor.BaseUrlBuilder<HttpClientContext.HttpClientContextBuilder>- Parameters:
aBaseUrl- The base URL (protocol, host, port, path) to be stored by the local address property.- Returns:
- The builder for applying multiple build operations.
-
withBaseUrl
Sets the base URL (protocol, host, port, path) for the base URL (protocol, host, port, path) property.- Specified by:
withBaseUrlin interfaceBaseUrlAccessor.BaseUrlBuilder<HttpClientContext.HttpClientContextBuilder>- Parameters:
aBaseURL- The base URL (protocol, host, port, path) to be stored by the local address property.- Returns:
- The builder for applying multiple build operations.
-
withBaseUrl
default HttpClientContext.HttpClientContextBuilder withBaseUrl(String aBaseUrl) throws MalformedURLExceptionSame asBaseUrlAccessor.BaseUrlBuilder.withBaseUrl(URL)except that aMalformedURLExceptionmay occur when creating theURLinstance from the givenString.- Specified by:
withBaseUrlin interfaceBaseUrlAccessor.BaseUrlBuilder<HttpClientContext.HttpClientContextBuilder>- Parameters:
aBaseUrl- TheStringrepresenting theURL.- Returns:
- The builder for applying multiple build operations.
- Throws:
MalformedURLException- in case theStringcannot be converted to a valid (accepted)URL.
-
withBaseUrl
default HttpClientContext.HttpClientContextBuilder withBaseUrl(String aProtocol, String aHost) throws MalformedURLExceptionSame asBaseUrlAccessor.BaseUrlBuilder.withBaseUrl(URL)except that aMalformedURLExceptionmay occur when creating theURLinstance from the given parameters.- Specified by:
withBaseUrlin interfaceBaseUrlAccessor.BaseUrlBuilder<HttpClientContext.HttpClientContextBuilder>- Parameters:
aProtocol- The protocol (e.g. HTTP or HTTPS) to be used for the baseURL.aHost- The host to which the baseURLis to point to.- Returns:
- The builder for applying multiple build operations.
- Throws:
MalformedURLException- in case the parameters cannot be converted to a valid (accepted)URL.
-
withBaseUrl
default HttpClientContext.HttpClientContextBuilder withBaseUrl(org.refcodes.data.Scheme aScheme, String aHost) throws MalformedURLExceptionSame asBaseUrlAccessor.BaseUrlBuilder.withBaseUrl(URL)except that aMalformedURLExceptionmay occur when creating theURLinstance from the given parameters.- Specified by:
withBaseUrlin interfaceBaseUrlAccessor.BaseUrlBuilder<HttpClientContext.HttpClientContextBuilder>- Parameters:
aScheme- TheScheme(e.g.Scheme.HTTPorScheme.HTTPS) to be used for the baseURL.aHost- The host to which the baseURLis to point to.- Returns:
- The builder for applying multiple build operations.
- Throws:
MalformedURLException- in case the parameters cannot be converted to a valid (accepted)URL.
-
withBaseUrl
default HttpClientContext.HttpClientContextBuilder withBaseUrl(String aProtocol, String aHost, String aPath) throws MalformedURLExceptionSame asBaseUrlAccessor.BaseUrlBuilder.withBaseUrl(URL)except that aMalformedURLExceptionmay occur when creating theURLinstance from the given parameters.- Specified by:
withBaseUrlin interfaceBaseUrlAccessor.BaseUrlBuilder<HttpClientContext.HttpClientContextBuilder>- Parameters:
aProtocol- The protocol (e.g. HTTP or HTTPS) to be used for the baseURL.aHost- The host to which the baseURLis to point to.aPath- The path on the host to which the baseURLis to point to.- Returns:
- The builder for applying multiple build operations.
- Throws:
MalformedURLException- in case the parameters cannot be converted to a valid (accepted)URL.
-
withBaseUrl
default HttpClientContext.HttpClientContextBuilder withBaseUrl(org.refcodes.data.Scheme aScheme, String aHost, String aPath) throws MalformedURLExceptionSame asBaseUrlAccessor.BaseUrlBuilder.withBaseUrl(URL)except that aMalformedURLExceptionmay occur when creating theURLinstance from the given parameters.- Specified by:
withBaseUrlin interfaceBaseUrlAccessor.BaseUrlBuilder<HttpClientContext.HttpClientContextBuilder>- Parameters:
aScheme- TheScheme(e.g.Scheme.HTTPorScheme.HTTPS) to be used for the baseURL.aHost- The host to which the baseURLis to point to.aPath- The path on the host to which the baseURLis to point to.- Returns:
- The builder for applying multiple build operations.
- Throws:
MalformedURLException- in case the parameters cannot be converted to a valid (accepted)URL.
-
withBaseUrl
default HttpClientContext.HttpClientContextBuilder withBaseUrl(String aProtocol, String aHost, int aPort) throws MalformedURLExceptionBuilder method forBaseUrlAccessor.BaseUrlMutator.setBaseUrl(String, String, int).- Specified by:
withBaseUrlin interfaceBaseUrlAccessor.BaseUrlBuilder<HttpClientContext.HttpClientContextBuilder>- Parameters:
aProtocol- The protocol (e.g. HTTP or HTTPS) to be used for the baseURL.aHost- The host to which the baseURLis to point to.aPort- The port to be used when connecting to the host.- Returns:
- The builder for applying multiple build operations.
- Throws:
MalformedURLException- in case the parameters cannot be converted to a valid (accepted)URL.
-
withBaseUrl
default HttpClientContext.HttpClientContextBuilder withBaseUrl(org.refcodes.data.Scheme aScheme, String aHost, int aPort) throws MalformedURLExceptionBuilder method forBaseUrlAccessor.BaseUrlMutator.setBaseUrl(Scheme, String, int).- Specified by:
withBaseUrlin interfaceBaseUrlAccessor.BaseUrlBuilder<HttpClientContext.HttpClientContextBuilder>- Parameters:
aScheme- TheScheme(e.g.Scheme.HTTPorScheme.HTTPS) to be used for the baseURL.aHost- The host to which the baseURLis to point to.aPort- The port to be used when connecting to the host.- Returns:
- The builder for applying multiple build operations.
- Throws:
MalformedURLException- in case the parameters cannot be converted to a valid (accepted)URL.
-
withBaseUrl
default HttpClientContext.HttpClientContextBuilder withBaseUrl(String aProtocol, String aHost, int aPort, String aPath) throws MalformedURLExceptionBuilder method forBaseUrlAccessor.BaseUrlMutator.setBaseUrl(String, String, int, String).- Specified by:
withBaseUrlin interfaceBaseUrlAccessor.BaseUrlBuilder<HttpClientContext.HttpClientContextBuilder>- Parameters:
aProtocol- The protocol (e.g. HTTP or HTTPS) to be used for the baseURL.aHost- The host to which the baseURLis to point to.aPort- The port to be used when connecting to the host.aPath- The path on the host to which the baseURLis to point to.- Returns:
- The builder for applying multiple build operations.
- Throws:
MalformedURLException- in case the parameters cannot be converted to a valid (accepted)URL.
-
withBaseUrl
default HttpClientContext.HttpClientContextBuilder withBaseUrl(org.refcodes.data.Scheme aScheme, String aHost, int aPort, String aPath) throws MalformedURLExceptionBuilder method forBaseUrlAccessor.BaseUrlMutator.setBaseUrl(Scheme, String, int, String).- Specified by:
withBaseUrlin interfaceBaseUrlAccessor.BaseUrlBuilder<HttpClientContext.HttpClientContextBuilder>- Parameters:
aScheme- TheScheme(e.g.Scheme.HTTPorScheme.HTTPS) to be used for the baseURL.aHost- The host to which the baseURLis to point to.aPort- The port to be used when connecting to the host.aPath- The path on the host to which the baseURLis to point to.- Returns:
- The builder for applying multiple build operations.
- Throws:
MalformedURLException- in case the parameters cannot be converted to a valid (accepted)URL.
-
withTrustStoreDescriptor
default HttpClientContext.HttpClientContextBuilder withTrustStoreDescriptor(org.refcodes.security.TrustStoreDescriptor aStoreDescriptor)- Specified by:
withTrustStoreDescriptorin interfaceorg.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorBuilder<HttpClientContext.HttpClientContextBuilder>
-