Module org.refcodes.web
Package org.refcodes.web
Interface HttpClientRequest.HttpClientRequestBuilder
- All Superinterfaces:
HeaderFieldsAccessor<RequestHeaderFields>,HttpBodyAccessor.HttpBodyProvider<BadRequestException>,HttpClientRequest,HttpMethodAccessor,HttpRequest,RedirectDepthAccessor,RedirectDepthAccessor.RedirectDepthBuilder<HttpClientRequest.HttpClientRequestBuilder>,RedirectDepthAccessor.RedirectDepthMutator,RedirectDepthAccessor.RedirectDepthProperty,UrlAccessor
- Enclosing interface:
- HttpClientRequest
public static interface HttpClientRequest.HttpClientRequestBuilder extends HttpClientRequest, RedirectDepthAccessor.RedirectDepthBuilder<HttpClientRequest.HttpClientRequestBuilder>
Builder for the
HttpClientRequest interface.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.web.HeaderFieldsAccessor
HeaderFieldsAccessor.HeaderFieldsBuilder<T extends HeaderFields<?,?>,B extends HeaderFieldsAccessor.HeaderFieldsBuilder<T,B>>, HeaderFieldsAccessor.HeaderFieldsMutator<T extends HeaderFields<?,?>>, HeaderFieldsAccessor.HeaderFieldsProperty<T extends HeaderFields<?,?>>Nested classes/interfaces inherited from interface org.refcodes.web.HttpClientRequest
HttpClientRequest.HttpClientRequestBuilderNested classes/interfaces inherited from interface org.refcodes.web.HttpMethodAccessor
HttpMethodAccessor.HttpMethodBuilder<B extends HttpMethodAccessor.HttpMethodBuilder<B>>, HttpMethodAccessor.HttpMethodMutator, HttpMethodAccessor.HttpMethodPropertyNested classes/interfaces inherited from interface org.refcodes.web.RedirectDepthAccessor
RedirectDepthAccessor.RedirectDepthBuilder<B extends RedirectDepthAccessor.RedirectDepthBuilder<B>>, RedirectDepthAccessor.RedirectDepthMutator, RedirectDepthAccessor.RedirectDepthPropertyNested classes/interfaces inherited from interface org.refcodes.web.UrlAccessor
UrlAccessor.UrlBuilder, UrlAccessor.UrlMutator, UrlAccessor.UrlProperty -
Field Summary
Fields inherited from interface org.refcodes.web.HttpClientRequest
DEFAULT_REDIRECT_DEPTH -
Method Summary
Modifier and Type Method Description default HttpClientRequest.HttpClientRequestBuilderwithRedirectDepth(int aRedirectDepth)Sets the redirect depth for the redirect depth property.default <REQ> HttpClientRequestwithRequest(REQ aRequest)Sets the request for the request property.Methods inherited from interface org.refcodes.web.HeaderFieldsAccessor
getHeaderFieldsMethods inherited from interface org.refcodes.web.HttpClientRequest
getRequest, setRequest, toHttpBodyMethods inherited from interface org.refcodes.web.HttpMethodAccessor
getHttpMethodMethods inherited from interface org.refcodes.web.RedirectDepthAccessor
getRedirectDepthMethods inherited from interface org.refcodes.web.RedirectDepthAccessor.RedirectDepthMutator
setRedirectDepthMethods inherited from interface org.refcodes.web.RedirectDepthAccessor.RedirectDepthProperty
letRedirectDepthMethods inherited from interface org.refcodes.web.UrlAccessor
getUrl
-
Method Details
-
withRequest
Sets the request for the request property.- Type Parameters:
REQ- the generic type- Parameters:
aRequest- The request to be stored by the request property.- Returns:
- The builder for applying multiple build operations.
-
withRedirectDepth
Sets the redirect depth for the redirect depth property.- Specified by:
withRedirectDepthin interfaceRedirectDepthAccessor.RedirectDepthBuilder<HttpClientRequest.HttpClientRequestBuilder>- Parameters:
aRedirectDepth- The redirect depth to be stored by the redirect depth property.- Returns:
- The builder for applying multiple build operations.
-