- All Known Subinterfaces:
HttpClientResponse,HttpInputStreamAccessor.HttpInputStreamProperty,HttpServerRequest
- All Known Implementing Classes:
HttpClientResponseImpl,HttpServerRequestImpl
public interface HttpInputStreamAccessor
Provides an accessor for a HTTP
InputStream body property.-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceHttpInputStreamAccessor.HttpInputStreamBuilder<B extends HttpInputStreamAccessor.HttpInputStreamBuilder<B>>Provides a builder body for a HTTPInputStreamproperty returning the builder for applying multiple build operations.static interfaceHttpInputStreamAccessor.HttpInputStreamMutatorProvides a mutator for aInputStreamproperty.static interfaceHttpInputStreamAccessor.HttpInputStreamPropertyProvides a HTTPInputStreamproperty.static interfaceHttpInputStreamAccessor.HttpInputStreamProvider<EXC extends Exception>A provider interface provides a "toSomething(?)" -
Method Summary
Modifier and Type Method Description InputStreamgetHttpInputStream()Retrieves theInputStreamfrom the HTTPInputStreamproperty.
-
Method Details
-
getHttpInputStream
InputStream getHttpInputStream()Retrieves theInputStreamfrom the HTTPInputStreamproperty.- Returns:
- The
InputStreamstored by theInputStreamproperty.
-