Interface HttpInputStreamAccessor.HttpInputStreamProvider<EXC extends Exception>

Type Parameters:
EXC - The exception type which may be thrown upon converting to the desired type.
Enclosing interface:
HttpInputStreamAccessor

public static interface HttpInputStreamAccessor.HttpInputStreamProvider<EXC extends Exception>
A provider interface provides a "toSomething(?)" method which converts a given instance into something else. The ContentTypeAccessor.ContentTypeProvider converts an implementing instance's state into a ContentType instance.