-
- All Known Subinterfaces:
HttpMethodAccessor.HttpMethodProperty,HttpRequest,HttpRequestBuilder<B>
- All Known Implementing Classes:
AbstractHttpRequest,BasicAuthRequest,HttpClientRequest,HttpServerRequest
public interface HttpMethodAccessorProvides an accessor for a HTTP-Method property.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceHttpMethodAccessor.HttpMethodBuilder<B extends HttpMethodAccessor.HttpMethodBuilder<B>>Provides a builder method for a HTTP-Method property returning the builder for applying multiple build operations.static interfaceHttpMethodAccessor.HttpMethodMutatorProvides a mutator for a HTTP-Method property.static interfaceHttpMethodAccessor.HttpMethodPropertyProvides a HTTP-Method property.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description HttpMethodgetHttpMethod()Retrieves the HTTP-Method from the HTTP-Method property.
-
-
-
Method Detail
-
getHttpMethod
HttpMethod getHttpMethod()
Retrieves the HTTP-Method from the HTTP-Method property.- Returns:
- The HTTP-Method stored by the HTTP-Method property.
-
-