Module org.refcodes.web
Package org.refcodes.web
Interface HttpRequestBuilder<B extends HttpRequestBuilder<B>>
- Type Parameters:
B- the generic type
- All Superinterfaces:
HeaderFieldsAccessor<RequestHeaderFields>,HttpMethodAccessor,HttpRequest,UrlAccessor,UrlAccessor.UrlBuilder,UrlAccessor.UrlMutator
public interface HttpRequestBuilder<B extends HttpRequestBuilder<B>>
extends HttpRequest, UrlAccessor.UrlMutator, UrlAccessor.UrlBuilder
The Interface HttpRequestBuilder.
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.web.HeaderFieldsAccessor
HeaderFieldsAccessor.HeaderFieldsBuilder<T extends HeaderFields<?,?>, B extends HeaderFieldsAccessor.HeaderFieldsBuilder<T, B>>, HeaderFieldsAccessor.HeaderFieldsMutator<T extends HeaderFields<?, ?>>, HeaderFieldsAccessor.HeaderFieldsProperty<T extends HeaderFields<?, ?>> Nested classes/interfaces inherited from interface org.refcodes.web.HttpMethodAccessor
HttpMethodAccessor.HttpMethodBuilder<B extends HttpMethodAccessor.HttpMethodBuilder<B>>, HttpMethodAccessor.HttpMethodMutator, HttpMethodAccessor.HttpMethodPropertyNested classes/interfaces inherited from interface org.refcodes.web.UrlAccessor
UrlAccessor.UrlBuilder, UrlAccessor.UrlMutator, UrlAccessor.UrlProperty -
Method Summary
Modifier and TypeMethodDescriptiondefault BwithAddToHeaderFields(String aField, String aValue) Builder method for theHeaderFieldsAccessor.getHeaderFields()methodAbstractHeaderFields.addTo(String, String).default BwithAddToHeaderFields(String aField, String... aValues) Builder method for theHeaderFieldsAccessor.getHeaderFields()methodHttpFields.addTo(String, String...).default BwithAddToHeaderFields(String aField, List<String> aValues) Builder method for theHeaderFieldsAccessor.getHeaderFields()methodHttpFields.addTo(String, List).default BwithAddToHeaderFields(HeaderField aHeaderField, String... aValues) With add to Header-Fields.default BwithAddToHeaderFields(HeaderField aHeaderField, List<String> aValues) With add to Header-Fields.default BwithAddToQueryFields(String aField, String aValue) Builder method for theUrlAccessor.getUrl()'sUrl.getQueryFields()methodHttpFields.addTo(String, String).default BwithAddToQueryFields(String aField, String... aValues) Builder method for theUrlAccessor.getUrl()'sUrl.getQueryFields()methodHttpFields.addTo(String, String...).default BwithAddToQueryFields(String aField, List<String> aValues) Builder method for theUrlAccessor.getUrl()'sUrl.getQueryFields()methodHttpFields.addTo(String, List).Methods inherited from interface org.refcodes.web.HeaderFieldsAccessor
getHeaderFieldsMethods inherited from interface org.refcodes.web.HttpMethodAccessor
getHttpMethodMethods inherited from interface org.refcodes.web.UrlAccessor
getUrlMethods inherited from interface org.refcodes.web.UrlAccessor.UrlBuilder
withUrlMethods inherited from interface org.refcodes.web.UrlAccessor.UrlMutator
setUrl
-
Method Details
-
withAddToHeaderFields
Builder method for theHeaderFieldsAccessor.getHeaderFields()methodAbstractHeaderFields.addTo(String, String).- Parameters:
aField- The Header-Field (key) of which's list of values a value is to be added.aValue- The value to be added to the list of values associated to the given Header-Field (key).- Returns:
- This
HttpRequestBuilderinstance to continue building up the Header-Fields.
-
withAddToHeaderFields
Builder method for theHeaderFieldsAccessor.getHeaderFields()methodHttpFields.addTo(String, String...).- Parameters:
aField- The Header-Field (key) of which's list of values the values are to be added.aValues- The values to be added to the list of values associated to the given Header-Field (key).- Returns:
- This
HttpRequestBuilderinstance to continue building up the Header-Fields.
-
withAddToHeaderFields
Builder method for theHeaderFieldsAccessor.getHeaderFields()methodHttpFields.addTo(String, List).- Parameters:
aField- The Header-Field (key) of which's list of values the values are to be added.aValues- The values to be added to the list of values associated to the given Header-Field (key).- Returns:
- This
HttpRequestBuilderinstance to continue building up the Header-Fields.
-
withAddToHeaderFields
With add to Header-Fields.- Parameters:
aHeaderField- the Header-FieldaValues- the values- Returns:
- the b
- See Also:
-
withAddToHeaderFields
With add to Header-Fields.- Parameters:
aHeaderField- the Header-FieldaValues- the values- Returns:
- the b
- See Also:
-
withAddToQueryFields
Builder method for theUrlAccessor.getUrl()'sUrl.getQueryFields()methodHttpFields.addTo(String, String).- Parameters:
aField- The Header-Field (key) of which's list of values a value is to be added.aValue- The value to be added to the list of values associated to the given Header-Field (key).- Returns:
- This
HttpRequestBuilderinstance to continue building up the Header-Fields.
-
withAddToQueryFields
Builder method for theUrlAccessor.getUrl()'sUrl.getQueryFields()methodHttpFields.addTo(String, String...).- Parameters:
aField- The Header-Field (key) of which's list of values the values are to be added.aValues- The values to be added to the list of values associated to the given Header-Field (key).- Returns:
- This
HttpRequestBuilderinstance to continue building up the Header-Fields.
-
withAddToQueryFields
Builder method for theUrlAccessor.getUrl()'sUrl.getQueryFields()methodHttpFields.addTo(String, List).- Parameters:
aField- The Header-Field (key) of which's list of values the values are to be added.aValues- The values to be added to the list of values associated to the given Header-Field (key).- Returns:
- This
HttpRequestBuilderinstance to continue building up the Header-Fields.
-