Class HttpServerContextBuilderImpl

java.lang.Object
org.refcodes.web.HttpServerContextBuilderImpl
All Implemented Interfaces:
org.refcodes.io.MaxConnectionsAccessor, org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsBuilder<HttpServerContext.HttpServerContextBuilder>, org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsMutator, org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsProperty, org.refcodes.mixin.PortAccessor, org.refcodes.mixin.PortAccessor.PortBuilder<HttpServerContext.HttpServerContextBuilder>, org.refcodes.mixin.PortAccessor.PortMutator, org.refcodes.mixin.PortAccessor.PortProperty, org.refcodes.security.KeyStoreDescriptorAccessor, org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorBuilder<HttpServerContext.HttpServerContextBuilder>, org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorMutator, org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorProperty, HttpServerContext.HttpServerContextBuilder, SchemeAccessor, SchemeAccessor.SchemeBuilder<HttpServerContext.HttpServerContextBuilder>, SchemeAccessor.SchemeMutator, SchemeAccessor.SchemeProperty

public class HttpServerContextBuilderImpl
extends Object
implements HttpServerContext.HttpServerContextBuilder
The HttpServerContextBuilderImpl implements the HttpServerContext.HttpServerContextBuilder interface and can be used as HttpServerContext for opening an HTTP-Server such as the `HttpRestServer` from the `org.refcodes:refcodes-rest` artifact.
  • Nested Class Summary

    Nested classes/interfaces inherited from interface org.refcodes.security.KeyStoreDescriptorAccessor

    org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorBuilder<B extends org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorBuilder<B>>, org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorMutator, org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorProperty

    Nested classes/interfaces inherited from interface org.refcodes.io.MaxConnectionsAccessor

    org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsBuilder<B extends org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsBuilder<B>>, org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsMutator, org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsProperty

    Nested classes/interfaces inherited from interface org.refcodes.mixin.PortAccessor

    org.refcodes.mixin.PortAccessor.PortBuilder<B extends org.refcodes.mixin.PortAccessor.PortBuilder<B>>, org.refcodes.mixin.PortAccessor.PortMutator, org.refcodes.mixin.PortAccessor.PortProperty

    Nested classes/interfaces inherited from interface org.refcodes.web.SchemeAccessor

    SchemeAccessor.SchemeBuilder<B extends SchemeAccessor.SchemeBuilder<B>>, SchemeAccessor.SchemeMutator, SchemeAccessor.SchemeProperty
  • Constructor Summary

    Constructors
    Constructor Description
    HttpServerContextBuilderImpl​(String aProtocol, int aPort, org.refcodes.security.KeyStoreDescriptor aStoreDescriptor, int aMaxConnections)
    Constructs a HttpClientContext with the given data.
    HttpServerContextBuilderImpl​(org.refcodes.data.Scheme aScheme, int aPort, org.refcodes.security.KeyStoreDescriptor aStoreDescriptor, int aMaxConnections)
    Constructs a HttpClientContext with the given data.
  • Method Summary

    Modifier and Type Method Description
    org.refcodes.security.KeyStoreDescriptor getKeyStoreDescriptor()
    int getMaxConnections()
    int getPort()
    org.refcodes.data.Scheme getScheme()
    Retrieves the UrlScheme from the URL scheme.
    void setKeyStoreDescriptor​(org.refcodes.security.KeyStoreDescriptor aStoreDescriptor)
    void setMaxConnections​(int aMaxConnections)
    void setPort​(int aPort)
    void setProtocol​(String aProtocol)
    Sets the protocol String representation for the scheme property.
    void setScheme​(org.refcodes.data.Scheme aScheme)
    Sets the UrlScheme for the URL scheme.
    String toProtocol()
    Retrieves the protocol representation from the Scheme.

    Methods inherited from class java.lang.Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait

    Methods inherited from interface org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorProperty

    letKeyStoreDescriptor

    Methods inherited from interface org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsProperty

    letMaxConnections

    Methods inherited from interface org.refcodes.mixin.PortAccessor.PortProperty

    letPort

    Methods inherited from interface org.refcodes.web.SchemeAccessor.SchemeProperty

    letProtocol, letScheme
  • Constructor Details

    • HttpServerContextBuilderImpl

      public HttpServerContextBuilderImpl​(org.refcodes.data.Scheme aScheme, int aPort, org.refcodes.security.KeyStoreDescriptor aStoreDescriptor, int aMaxConnections)
      Constructs a HttpClientContext with the given data.
      Parameters:
      aScheme - The Scheme (HTTP or HTTPS) to be used.
      aPort - The TCP port to be used.
      aStoreDescriptor - The descriptor describing the keystore to be used.
      aMaxConnections - The maximum allowed open connections.
    • HttpServerContextBuilderImpl

      public HttpServerContextBuilderImpl​(String aProtocol, int aPort, org.refcodes.security.KeyStoreDescriptor aStoreDescriptor, int aMaxConnections)
      Constructs a HttpClientContext with the given data.
      Parameters:
      aProtocol - The protocol such as the TransportLayerProtocol elements.
      aPort - The TCP port to be used.
      aStoreDescriptor - The descriptor describing the keystore to be used.
      aMaxConnections - The maximum allowed open connections.
  • Method Details

    • getKeyStoreDescriptor

      public org.refcodes.security.KeyStoreDescriptor getKeyStoreDescriptor()
      Specified by:
      getKeyStoreDescriptor in interface org.refcodes.security.KeyStoreDescriptorAccessor
    • getMaxConnections

      public int getMaxConnections()
      Specified by:
      getMaxConnections in interface org.refcodes.io.MaxConnectionsAccessor
    • getPort

      public int getPort()
      Specified by:
      getPort in interface org.refcodes.mixin.PortAccessor
    • getScheme

      public org.refcodes.data.Scheme getScheme()
      Retrieves the UrlScheme from the URL scheme.
      Specified by:
      getScheme in interface SchemeAccessor
      Returns:
      The UrlScheme stored by the URL scheme.
    • setKeyStoreDescriptor

      public void setKeyStoreDescriptor​(org.refcodes.security.KeyStoreDescriptor aStoreDescriptor)
      Specified by:
      setKeyStoreDescriptor in interface org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorMutator
    • setMaxConnections

      public void setMaxConnections​(int aMaxConnections)
      Specified by:
      setMaxConnections in interface org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsMutator
    • setPort

      public void setPort​(int aPort)
      Specified by:
      setPort in interface org.refcodes.mixin.PortAccessor.PortMutator
    • setScheme

      public void setScheme​(org.refcodes.data.Scheme aScheme)
      Sets the UrlScheme for the URL scheme.
      Specified by:
      setScheme in interface SchemeAccessor.SchemeMutator
      Parameters:
      aScheme - The UrlScheme to be stored by the URL scheme.
    • toProtocol

      public String toProtocol()
      Retrieves the protocol representation from the Scheme. In case of a scheme unknown by the Scheme enumeration, then SchemeAccessor.getScheme() might return null whilst SchemeAccessor.toProtocol() still retrieves the unknown scheme's protocol representation (as of SchemeAccessor.SchemeMutator.setProtocol(String)).
      Specified by:
      toProtocol in interface SchemeAccessor
      Returns:
      The protocol representation for the URL.
    • setProtocol

      public void setProtocol​(String aProtocol)
      Sets the protocol String representation for the scheme property. You must provide the scheme's specific part as well. In case of HTTP, provide "http://". In case your provided protocol is unknown by the Scheme enumeration, then the scheme property will not be set, though the SchemeAccessor.toProtocol() still returns your protocol.
      Specified by:
      setProtocol in interface SchemeAccessor.SchemeMutator
      Parameters:
      aProtocol - The UrlScheme's String representation to be stored by the URL scheme.