Interface HttpServerInterceptable
- All Superinterfaces:
PostHttpInterceptable<PostHttpServerInterceptor>,PostHttpServerInterceptable,PreHttpInterceptable<PreHttpServerInterceptor>,PreHttpServerInterceptable
public interface HttpServerInterceptable
extends PreHttpServerInterceptable, PostHttpServerInterceptable
The
HttpServerInterceptable provides base functionality for working
with HttpServerInterceptor instances using the
PreHttpServerInterceptable as well as the
PostHttpServerInterceptable definitions.-
Method Summary
Modifier and TypeMethodDescriptiondefault booleanaddHttpInterceptor(HttpServerInterceptor aInterceptor) Adds the givenHttpServerInterceptorinstance.default booleanhasHttpInterceptor(HttpServerInterceptor aInterceptor) Tests whether the givenHttpServerInterceptorinstance has been added.default booleanremoveHttpInterceptor(HttpServerInterceptor aInterceptor) Removes theHttpServerInterceptorinstance.Methods inherited from interface org.refcodes.web.PostHttpInterceptable
addPostHttpInterceptor, hasPostHttpInterceptor, removePostHttpInterceptorMethods inherited from interface org.refcodes.web.PreHttpInterceptable
addPreHttpInterceptor, hasPreHttpInterceptor, removePreHttpInterceptor
-
Method Details
-
hasHttpInterceptor
Tests whether the givenHttpServerInterceptorinstance has been added.- Parameters:
aInterceptor- TheHttpServerInterceptorinstance for which to test if it has been added.- Returns:
- True in case
PreHttpInterceptable.hasPreHttpInterceptor(PreHttpInterceptor)andPostHttpInterceptable.hasPostHttpInterceptor(PostHttpInterceptor)return true.
-
addHttpInterceptor
Adds the givenHttpServerInterceptorinstance. TheHttpServerInterceptorinstance itself acts as the handle which is used when removing the givenHttpServerInterceptorinstance later.- Parameters:
aInterceptor- TheHttpServerInterceptorinstance which is to be added.- Returns:
- True in case
PreHttpInterceptable.addPreHttpInterceptor(PreHttpInterceptor)orPostHttpInterceptable.addPostHttpInterceptor(PostHttpInterceptor)return true.
-
removeHttpInterceptor
Removes theHttpServerInterceptorinstance. In case theHttpServerInterceptorinstance has not been added before, then false is returned.- Parameters:
aInterceptor- TheHttpServerInterceptorinstance which is to be removed.- Returns:
- True in case
PreHttpInterceptable.removePreHttpInterceptor(PreHttpInterceptor)orPostHttpInterceptable.removePostHttpInterceptor(PostHttpInterceptor)return true.
-