- Functional Interface:
- This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.
An observer being notified by incoming HTTPS requests which might have been
registered via
HttpsConnectionRequestObservable.onConnectionRequest(HttpsConnectionRequestObserver)
possibly using lambda syntax.-
Method Summary
Modifier and TypeMethodDescriptionvoidonHttpsConnectionRequest(InetSocketAddress aLocalAddress, InetSocketAddress aRemoteAddress, SSLParameters aHttpsParams) Invoked upon an incoming HTTPS request.
-
Method Details
-
onHttpsConnectionRequest
void onHttpsConnectionRequest(InetSocketAddress aLocalAddress, InetSocketAddress aRemoteAddress, SSLParameters aHttpsParams) Invoked upon an incoming HTTPS request. TheSSLParameterscan be modified according to the remote address issuing the request.- Parameters:
aLocalAddress- TheInetSocketAddressof the receiver of the request.aRemoteAddress- The remote client'sInetSocketAddress.aHttpsParams- TheSSLParameterswhich may be modified in accordance to the remote address.
-