Class InternalClientErrorException
java.lang.Object
java.lang.Throwable
java.lang.Exception
org.refcodes.exception.AbstractException
org.refcodes.web.WebException
org.refcodes.web.HttpException
org.refcodes.web.HttpStatusException
org.refcodes.web.InternalClientErrorException
- All Implemented Interfaces:
Serializable, ErrorCodeAccessor, Trap, StatusCodeAccessor<HttpStatusCode>, UrlAccessor
Proprietary code and only used inside a REFCODES.ORG client not trespassing
any networking border (the error is generated by the client for the client
locally). This code is used is used when a client signals the business logic
that internal client processing failed even though the response was received
fine.
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from interface ErrorCodeAccessor
ErrorCodeAccessor.ErrorCodeBuilder<B>, ErrorCodeAccessor.ErrorCodeMutator, ErrorCodeAccessor.ErrorCodePropertyNested classes/interfaces inherited from interface StatusCodeAccessor
StatusCodeAccessor.StatusCodeBuilder<SC,B>, StatusCodeAccessor.StatusCodeMutator<SC>, StatusCodeAccessor.StatusCodeProperty<SC> Nested classes/interfaces inherited from interface UrlAccessor
UrlAccessor.UrlBuilder, UrlAccessor.UrlMutator, UrlAccessor.UrlProperty -
Field Summary
Fields inherited from class HttpStatusException
_httpStatusCode -
Constructor Summary
ConstructorsConstructorDescriptionInternalClientErrorException(String aMessage) Instantiates the classInternalClientErrorException.InternalClientErrorException(String aMessage, String aErrorCode) Instantiates the classInternalClientErrorException.InternalClientErrorException(String aMessage, Throwable aCause) Instantiates the classInternalClientErrorException.InternalClientErrorException(String aMessage, Throwable aCause, String aErrorCode) Instantiates the classInternalClientErrorException.Instantiates the classInternalClientErrorException.InternalClientErrorException(Throwable aCause, String aErrorCode) Instantiates the classInternalClientErrorException.InternalClientErrorException(Url aUrl, String aMessage) Instantiates the classInternalClientErrorException.InternalClientErrorException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classInternalClientErrorException.InternalClientErrorException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classInternalClientErrorException.InternalClientErrorException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classInternalClientErrorException.InternalClientErrorException(Url aUrl, Throwable aCause) Instantiates the classInternalClientErrorException.InternalClientErrorException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classInternalClientErrorException. -
Method Summary
Methods inherited from class HttpStatusException
getPatternArguments, getStatusCode, getUrlMethods inherited from class AbstractException
getErrorCode, getMessageMethods inherited from class Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface Trap
toLocalizedMessage, toMessage, toMessage, toMessage, toShortLocalizedMessage, toShortMessage
-
Constructor Details
-
InternalClientErrorException
Instantiates the classInternalClientErrorException.- See Also:
-
InternalClientErrorException
Instantiates the classInternalClientErrorException.- See Also:
-
InternalClientErrorException
Instantiates the classInternalClientErrorException.- See Also:
-
InternalClientErrorException
Instantiates the classInternalClientErrorException.- See Also:
-
InternalClientErrorException
Instantiates the classInternalClientErrorException.- See Also:
-
InternalClientErrorException
Instantiates the classInternalClientErrorException.- See Also:
-
InternalClientErrorException
Instantiates the classInternalClientErrorException.- See Also:
-
InternalClientErrorException
Instantiates the classInternalClientErrorException.- See Also:
-
InternalClientErrorException
Instantiates the classInternalClientErrorException.- See Also:
-
InternalClientErrorException
Instantiates the classInternalClientErrorException.- See Also:
-
InternalClientErrorException
Instantiates the classInternalClientErrorException.- See Also:
-
InternalClientErrorException
Instantiates the classInternalClientErrorException.- See Also:
-