Class InternalClientErrorRuntimeException

All Implemented Interfaces:
Serializable, ErrorCodeAccessor, Trap, StatusCodeAccessor<HttpStatusCode>, UrlAccessor

public class InternalClientErrorRuntimeException extends HttpStatusRuntimeException
Proprietary code and only used inside a REFCODES.ORG client not trespassing any networking border (the error is generated by the client for the client locally). This code is used is used when a client signals the business logic that internal client processing failed even though the response was received fine.
See Also: