-
- All Known Subinterfaces:
IpAddressAccessor.IpAddressProperty,Url,Url.UrlBuilder
- All Known Implementing Classes:
UrlBuilderImpl,UrlImpl
public interface IpAddressAccessorProvides an accessor for a IP-Address property. The IP-Address is represented as an array of ints. This interface provides means to convert it from and to itsStringrepresentation viatoCidrNotation()andIpAddressAccessor.IpAddressMutator.fromCidrNotation(String).
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceIpAddressAccessor.IpAddressBuilder<B extends IpAddressAccessor.IpAddressBuilder<B>>Provides a builder method for a IP-Address property returning the builder for applying multiple build operations.static interfaceIpAddressAccessor.IpAddressMutatorProvides a mutator for a IP-Address property.static interfaceIpAddressAccessor.IpAddressPropertyProvides a IP-Address property.
-
Method Summary
All Methods Instance Methods Abstract Methods Default Methods Modifier and Type Method Description int[]getIpAddress()Retrieves the IP-Address from the IP-Address property.default StringtoCidrNotation()Constructs the IP-AddressStringin CIDR notation from the IP-Address property.
-
-
-
Method Detail
-
getIpAddress
int[] getIpAddress()
Retrieves the IP-Address from the IP-Address property.- Returns:
- The IP-Address stored by the IP-Address property.
-
toCidrNotation
default String toCidrNotation()
Constructs the IP-AddressStringin CIDR notation from the IP-Address property. TheStringis provided as CIDR notation as of "https://en.wikipedia.org/wiki/Classless_Inter-Domain_Routing#CIDR_notation".- Returns:
- The IP-Address converted to a
Stringby the IP-Address property.
-
-