Enum Class LinkRelation

java.lang.Object
java.lang.Enum<LinkRelation>
org.refcodes.web.LinkRelation
All Implemented Interfaces:
Serializable, Comparable<LinkRelation>, Constable, NameAccessor

public enum LinkRelation extends Enum<LinkRelation> implements NameAccessor
Represents a link relation describing the semantic relationship between resources. For example, rel: "next" tells the client that the linked resource is the next item in a sequence.

Enables Discovery: By using standardized or documented rel types, clients can navigate a HATEOAS API without needing hardcoded URLs.

Standardized link relations are defined by the IANA Link Relations Registry, such as self, current or first.