Class OauthToken

java.lang.Object
org.refcodes.web.OauthToken
All Implemented Interfaces:
org.refcodes.mixin.Disposable, org.refcodes.mixin.ValidAccessor

public class OauthToken extends Object implements org.refcodes.mixin.ValidAccessor, org.refcodes.mixin.Disposable
An OAuth-Token contains all relevant information to access a protected resource and refresh the the access token. "If the request for an access token is valid, the authorization server needs to generate an access token (and optional refresh token) and return these to the client, typically along with some additional properties about the authorization." HTTP/1.1 200 OK Content-Type: application/json Cache-Control: no-store Pragma: no-cache { "access_token":"MTQ0NjJkZmQ5OTM2NDE1ZTZjNGZmZjI3", "token_type":"bearer", "expires_in":3600, "refresh_token":"IwOGYzYTlmM2YxOTQ5MGE3YmNmMDFkNTVk", "scope":"create" } See "https://www.oauth.com/oauth2-servers/access-tokens/access-token-response"