-
- All Known Subinterfaces:
OauthTokenAccessor.OauthTokenProperty
public interface OauthTokenAccessorProvides an accessor for a OAuth token property.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceOauthTokenAccessor.OauthTokenBuilder<B extends OauthTokenAccessor.OauthTokenBuilder<B>>Provides a builder method for a OAuth token property returning the builder for applying multiple build operations.static interfaceOauthTokenAccessor.OauthTokenMutatorProvides a mutator for a OAuth token property.static interfaceOauthTokenAccessor.OauthTokenPropertyProvides a OAuth token property.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description OauthTokengetOauthToken()Retrieves the OAuth token from the OAuth token property
-
-
-
Method Detail
-
getOauthToken
OauthToken getOauthToken()
Retrieves the OAuth token from the OAuth token property- Returns:
- The OAuth token stored by the OAuth token property.
-
-