Module org.refcodes.web
Package org.refcodes.web
Interface OauthTokenAccessor.OauthTokenBuilder<B extends OauthTokenAccessor.OauthTokenBuilder<B>>
-
- Type Parameters:
B- The builder to return in order to be able to apply multiple build operations.
- Enclosing interface:
- OauthTokenAccessor
public static interface OauthTokenAccessor.OauthTokenBuilder<B extends OauthTokenAccessor.OauthTokenBuilder<B>>Provides a builder method for a OAuth token property returning the builder for applying multiple build operations.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description BwithOAuthToken(OauthToken aOauthToken)Sets the OAuth token for the OAuth token property
-
-
-
Method Detail
-
withOAuthToken
B withOAuthToken(OauthToken aOauthToken)
Sets the OAuth token for the OAuth token property- Parameters:
aOauthToken- The OAuth token to be stored by the OAuth token property.- Returns:
- The builder for applying multiple build operations.
-
-