- java.lang.Object
-
- org.refcodes.web.OauthTokenImpl
-
- All Implemented Interfaces:
org.refcodes.mixin.Disposable,org.refcodes.mixin.Disposable.Disposedable,org.refcodes.mixin.DisposedAccessor,org.refcodes.mixin.ValidAccessor,OauthToken
public class OauthTokenImpl extends Object implements OauthToken
Implementation of theOauthTokeninterface.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.Disposable
org.refcodes.mixin.Disposable.Disposedable
-
-
Field Summary
Fields Modifier and Type Field Description protected String_accessTokenprotected Integer_expiresInprotected String_notBeforePolicyprotected Integer_refreshExpiresInprotected String_refreshTokenprotected String_scopeprotected String_sessionStateprotected String_tokenType
-
Constructor Summary
Constructors Constructor Description OauthTokenImpl(String aAccessToken, String aRefreshToken, String aTokenType, Integer aExpiresIn, String aScope)Creates a new instance of theOauthTokenImplwith the current time being stored for determining validity of the access token viaisValid()as ofgetExpiresIn().OauthTokenImpl(String aAccessToken, String aRefreshToken, String aTokenType, String aNotBeforePolicy, Integer aExpiresIn, Integer aRefreshExpiresIn, String aScope, String aSessionState)Creates a new instance of theOauthTokenImplwith the current time being stored for determining validity of the access token viaisValid()as ofgetExpiresIn().OauthTokenImpl(HttpBodyMap aOauthToken)Creates a new instance of theOauthTokenImplwith the current time being stored for determining validity of the access token viaisValid()as ofgetExpiresIn().OauthTokenImpl(OauthToken aOauthToken)Creates a new instance of theOauthTokenImplwith the current time being stored for determining validity of the access token viaisValid()as ofgetExpiresIn().
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description voiddispose()protected voidfromHttpBodyMap(HttpBodyMap aOauthToken)Sets the internal fields with the data from theHttpBodyMapas of theOauthFielddefinitions.StringgetAccessToken()Returns the access token.IntegergetExpiresIn()Returns the time in seconds till the access token (OauthToken.getAccessToken()) expires.StringgetNotBeforePolicy()Returns the not-before-policy.IntegergetRefreshExpiresIn()Returns the time in seconds till the refresh token (OauthToken.getRefreshToken()) expires.StringgetRefreshToken()Returns the refresh token.StringgetScope()Returns the OAuth scope.StringgetSessionState()Returns the session state.StringgetTokenType()Returns the token type.booleanisDisposed()booleanisValid()Returns alwaystrueif no "expires in" time (OauthToken.getExpiresIn()) has been set!
-
-
-
Field Detail
-
_accessToken
protected String _accessToken
-
_refreshToken
protected String _refreshToken
-
_tokenType
protected String _tokenType
-
_expiresIn
protected Integer _expiresIn
-
_refreshExpiresIn
protected Integer _refreshExpiresIn
-
_scope
protected String _scope
-
_notBeforePolicy
protected String _notBeforePolicy
-
_sessionState
protected String _sessionState
-
-
Constructor Detail
-
OauthTokenImpl
public OauthTokenImpl(OauthToken aOauthToken)
Creates a new instance of theOauthTokenImplwith the current time being stored for determining validity of the access token viaisValid()as ofgetExpiresIn().- Parameters:
aOauthToken- The OAuth data to use.
-
OauthTokenImpl
public OauthTokenImpl(String aAccessToken, String aRefreshToken, String aTokenType, Integer aExpiresIn, String aScope)
Creates a new instance of theOauthTokenImplwith the current time being stored for determining validity of the access token viaisValid()as ofgetExpiresIn().- Parameters:
aAccessToken- The access tokenaRefreshToken- The refresh tokenaTokenType- The token typeaExpiresIn- The expires-time in secondsaScope- The scope
-
OauthTokenImpl
public OauthTokenImpl(String aAccessToken, String aRefreshToken, String aTokenType, String aNotBeforePolicy, Integer aExpiresIn, Integer aRefreshExpiresIn, String aScope, String aSessionState)
Creates a new instance of theOauthTokenImplwith the current time being stored for determining validity of the access token viaisValid()as ofgetExpiresIn().- Parameters:
aAccessToken- The access tokenaRefreshToken- The refresh tokenaTokenType- The token typeaNotBeforePolicy- The not-before-policy.aExpiresIn- The expires-time in secondsaRefreshExpiresIn- The refresh's expires-time in secondsaScope- The scopeaSessionState- The session state.
-
OauthTokenImpl
public OauthTokenImpl(HttpBodyMap aOauthToken)
Creates a new instance of theOauthTokenImplwith the current time being stored for determining validity of the access token viaisValid()as ofgetExpiresIn().- Parameters:
aOauthToken- TheHttpBodyMapcontaining theOauthTokendata.
-
-
Method Detail
-
dispose
public void dispose()
- Specified by:
disposein interfaceorg.refcodes.mixin.Disposable
-
isDisposed
public boolean isDisposed()
- Specified by:
isDisposedin interfaceorg.refcodes.mixin.DisposedAccessor
-
getAccessToken
public String getAccessToken()
Returns the access token. "The access token string as issued by the authorization server." See "https://www.oauth.com/oauth2-servers/access-tokens/access-token-response"- Specified by:
getAccessTokenin interfaceOauthToken- Returns:
- the access token.
-
getRefreshToken
public String getRefreshToken()
Returns the refresh token. "The access token string as issued by the authorization server." See "https://www.oauth.com/oauth2-servers/access-tokens/access-token-response"- Specified by:
getRefreshTokenin interfaceOauthToken- Returns:
- the refresh token.
-
getScope
public String getScope()
Returns the OAuth scope. "If the scope the user granted is identical to the scope the app requested, this parameter is optional. If the granted scope is different from the requested scope, such as if the user modified the scope, then this parameter is required." See "https://www.oauth.com/oauth2-servers/access-tokens/access-token-response"- Specified by:
getScopein interfaceOauthToken- Returns:
- the OAuth scope.
-
getTokenType
public String getTokenType()
Returns the token type. "The type of token this is, typically just the string bearer" See "https://www.oauth.com/oauth2-servers/access-tokens/access-token-response"- Specified by:
getTokenTypein interfaceOauthToken- Returns:
- the token type.
-
getExpiresIn
public Integer getExpiresIn()
Returns the time in seconds till the access token (OauthToken.getAccessToken()) expires. "If the access token expires, the server should reply with the duration of time the access token is granted for." See "https://www.oauth.com/oauth2-servers/access-tokens/access-token-response"- Specified by:
getExpiresInin interfaceOauthToken- Returns:
- the Expires-In time in seconds
-
getNotBeforePolicy
public String getNotBeforePolicy()
Returns the not-before-policy.- Specified by:
getNotBeforePolicyin interfaceOauthToken- Returns:
- the not-before-policy.
-
getSessionState
public String getSessionState()
Returns the session state.- Specified by:
getSessionStatein interfaceOauthToken- Returns:
- the session state.
-
getRefreshExpiresIn
public Integer getRefreshExpiresIn()
Returns the time in seconds till the refresh token (OauthToken.getRefreshToken()) expires.- Specified by:
getRefreshExpiresInin interfaceOauthToken- Returns:
- the Expires-In time in seconds
-
isValid
public boolean isValid()
Returns alwaystrueif no "expires in" time (OauthToken.getExpiresIn()) has been set!- Specified by:
isValidin interfaceOauthToken- Specified by:
isValidin interfaceorg.refcodes.mixin.ValidAccessor
-
fromHttpBodyMap
protected void fromHttpBodyMap(HttpBodyMap aOauthToken)
Sets the internal fields with the data from theHttpBodyMapas of theOauthFielddefinitions.- Parameters:
aOauthToken- TheHttpBodyMapfrom which to gather the data.
-
-