- java.lang.Object
-
- java.lang.Enum<PortRange>
-
- org.refcodes.web.PortRange
-
- All Implemented Interfaces:
Serializable,Comparable<PortRange>,org.refcodes.mixin.MaxValueAccessor<Integer>,org.refcodes.mixin.MinValueAccessor<Integer>,org.refcodes.struct.Range<Integer>
public enum PortRange extends Enum<PortRange> implements org.refcodes.struct.Range<Integer>
Port range definitions as of RFC 6335 ("https://tools.ietf.org/html/rfc6335")
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.MaxValueAccessor
org.refcodes.mixin.MaxValueAccessor.MaxValueBuilder<V extends Object,B extends org.refcodes.mixin.MaxValueAccessor.MaxValueBuilder<V,B>>, org.refcodes.mixin.MaxValueAccessor.MaxValueMutator<V extends Object>, org.refcodes.mixin.MaxValueAccessor.MaxValueProperty<V extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.MinValueAccessor
org.refcodes.mixin.MinValueAccessor.MinValueBuilder<V extends Object,B extends org.refcodes.mixin.MinValueAccessor.MinValueBuilder<V,B>>, org.refcodes.mixin.MinValueAccessor.MinValueMutator<V extends Object>, org.refcodes.mixin.MinValueAccessor.MinValueProperty<V extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.struct.Range
org.refcodes.struct.Range.RangeBuilder<V extends Number & Comparable<V>>
-
-
Enum Constant Summary
Enum Constants Enum Constant Description DYNAMIC_PORTSLINUX_DYNAMIC_PORTSREGISTERED_PORTSSYSTEM_PORTS
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description IntegergetMaxValue()IntegergetMinValue()static PortRangevalueOf(String name)Returns the enum constant of this type with the specified name.static PortRange[]values()Returns an array containing the constants of this enum type, in the order they are declared.
-
-
-
Method Detail
-
values
public static PortRange[] values()
Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:for (PortRange c : PortRange.values()) System.out.println(c);
- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
public static PortRange valueOf(String name)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
getMinValue
public Integer getMinValue()
- Specified by:
getMinValuein interfaceorg.refcodes.mixin.MinValueAccessor<Integer>
-
-