Module org.refcodes.web
Package org.refcodes.web
Interface PostHttpInterceptable<I extends PostHttpInterceptor<?,?>>
- Type Parameters:
I- The type ofPostHttpInterceptorto be managed.
- All Known Subinterfaces:
HttpClientInterceptable,HttpInterceptable<I>,HttpServerInterceptable,PostHttpClientInterceptable,PostHttpServerInterceptable
public interface PostHttpInterceptable<I extends PostHttpInterceptor<?,?>>
The
PostHttpInterceptable provides base functionality for working
with PostHttpInterceptor instances.-
Method Summary
Modifier and TypeMethodDescriptionbooleanaddPostHttpInterceptor(I aPostInterceptor) Adds the givenPostHttpInterceptorinstance.booleanhasPostHttpInterceptor(I aPostInterceptor) Tests whether the givenPostHttpInterceptorinstance has been added.booleanremovePostHttpInterceptor(I aPostInterceptor) Removes thePostHttpInterceptorinstance.
-
Method Details
-
hasPostHttpInterceptor
Tests whether the givenPostHttpInterceptorinstance has been added.- Parameters:
aPostInterceptor- ThePostHttpInterceptorinstance for which to test if it has been added.- Returns:
- True if the given
PostHttpInterceptorinstance has been added already.
-
addPostHttpInterceptor
Adds the givenPostHttpInterceptorinstance. ThePostHttpInterceptorinstance itself acts as the handle which is used when removing the givenPostHttpInterceptorinstance later.- Parameters:
aPostInterceptor- ThePostHttpInterceptorinstance which is to be added.- Returns:
- True if the
PostHttpInterceptorinstance has been added successfully. If thePostHttpInterceptorinstance has already been added, false is returned.
-
removePostHttpInterceptor
Removes thePostHttpInterceptorinstance. In case thePostHttpInterceptorinstance has not been added before, then false is returned.- Parameters:
aPostInterceptor- ThePostHttpInterceptorinstance which is to be removed.- Returns:
- True if the
PostHttpInterceptorinstance has been removed successfully. If there was none suchPostHttpInterceptorinstance or if thePostHttpInterceptorinstance has already been removed, then false is returned.
-