Module org.refcodes.web
Package org.refcodes.web
Interface PostHttpInterceptor<REQ extends HttpRequest,RES extends HttpResponse>
- All Known Subinterfaces:
HttpClientInterceptor,HttpInterceptor<REQ,,RES> HttpServerInterceptor,PostHttpClientInterceptor,PostHttpServerInterceptor
- Functional Interface:
- This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.
@FunctionalInterface
public interface PostHttpInterceptor<REQ extends HttpRequest,RES extends HttpResponse>
An
PostHttpInterceptor definition for post-processing
HttpRequest as well as HttpResponse instances.-
Method Summary
Modifier and TypeMethodDescriptionvoidpostIntercept(REQ aRequest, RES aResponse) Invoked to post-process aHttpRequestalongside aHttpResponse.
-
Method Details
-
postIntercept
Invoked to post-process aHttpRequestalongside aHttpResponse.- Parameters:
aRequest- TheHttpRequestto post-process.aResponse- TheHttpResponseto post-process.
-