- All Superinterfaces:
PostHttpInterceptor<HttpServerRequest,HttpServerResponse>
- All Known Subinterfaces:
HttpServerInterceptor
- Functional Interface:
- This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.
@FunctionalInterface
public interface PostHttpServerInterceptor
extends PostHttpInterceptor<HttpServerRequest,HttpServerResponse>
An
PostHttpServerInterceptor definition for post-processing
HttpServerRequest as well as HttpServerResponse instances.-
Method Summary
Modifier and TypeMethodDescriptionvoidpostIntercept(HttpServerRequest aRequest, HttpServerResponse aResponse) Invoked to post-process aHttpServerRequestalongside aHttpServerResponse.
-
Method Details
-
postIntercept
Invoked to post-process aHttpServerRequestalongside aHttpServerResponse.- Specified by:
postInterceptin interfacePostHttpInterceptor<HttpServerRequest,HttpServerResponse> - Parameters:
aRequest- TheHttpServerRequestto post-process.aResponse- TheHttpServerResponseto post-process.
-