Interface PreHttpClientInterceptor
- All Superinterfaces:
PreHttpInterceptor<HttpClientRequest, HttpClientResponse>
- All Known Subinterfaces:
HttpClientInterceptor
- Functional Interface:
- This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.
@FunctionalInterface
public interface PreHttpClientInterceptor
extends PreHttpInterceptor<HttpClientRequest, HttpClientResponse>
An
PreHttpClientInterceptor definition for pre-processing
HttpClientRequest as well as HttpClientResponse instances.-
Method Summary
Modifier and TypeMethodDescriptionvoidpreIntercept(HttpClientRequest aRequest, HttpClientResponse aResponse) Invoked to pre-process aHttpClientRequestalongside aHttpClientResponse.
-
Method Details
-
preIntercept
Invoked to pre-process aHttpClientRequestalongside aHttpClientResponse.- Specified by:
preInterceptin interfacePreHttpInterceptor<HttpClientRequest, HttpClientResponse>- Parameters:
aRequest- TheHttpClientRequestto pre-process.aResponse- TheHttpClientResponseto post-process.
-