Module org.refcodes.web
Package org.refcodes.web
Interface PreHttpInterceptable<I extends PreHttpInterceptor<?,?>>
- Type Parameters:
I- The type ofPreHttpInterceptorto be managed.
- All Known Subinterfaces:
HttpClientInterceptable,HttpInterceptable<I>,HttpServerInterceptable,PreHttpClientInterceptable,PreHttpServerInterceptable
public interface PreHttpInterceptable<I extends PreHttpInterceptor<?,?>>
The
PreHttpInterceptable provides base functionality for working with
PreHttpInterceptor instances.-
Method Summary
Modifier and TypeMethodDescriptionbooleanaddPreHttpInterceptor(I aPreInterceptor) Adds the givenPreHttpInterceptorinstance.booleanhasPreHttpInterceptor(I aPreInterceptor) Tests whether the givenPreHttpInterceptorinstance has been added.booleanremovePreHttpInterceptor(I aPreInterceptor) Removes thePreHttpInterceptorinstance.
-
Method Details
-
hasPreHttpInterceptor
Tests whether the givenPreHttpInterceptorinstance has been added.- Parameters:
aPreInterceptor- ThePreHttpInterceptorinstance for which to test if it has been added.- Returns:
- True if the given
PreHttpInterceptorinstance has been added already.
-
addPreHttpInterceptor
Adds the givenPreHttpInterceptorinstance. ThePreHttpInterceptorinstance itself acts as the handle which is used when removing the givenPreHttpInterceptorinstance later.- Parameters:
aPreInterceptor- ThePreHttpInterceptorinstance which is to be added.- Returns:
- True if the
PreHttpInterceptorinstance has been added successfully. If thePreHttpInterceptorinstance has already been added, false is returned.
-
removePreHttpInterceptor
Removes thePreHttpInterceptorinstance. In case thePreHttpInterceptorinstance has not been added before, then false is returned.- Parameters:
aPreInterceptor- ThePreHttpInterceptorinstance which is to be removed.- Returns:
- True if the
PreHttpInterceptorinstance has been removed successfully. If there was none suchPreHttpInterceptorinstance or if thePreHttpInterceptorinstance has already been removed, then false is returned.
-