Interface PreHttpServerInterceptor
- All Superinterfaces:
PreHttpInterceptor<HttpServerRequest, HttpServerResponse>
- All Known Subinterfaces:
HttpServerInterceptor
- Functional Interface:
- This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.
@FunctionalInterface
public interface PreHttpServerInterceptor
extends PreHttpInterceptor<HttpServerRequest, HttpServerResponse>
An
PreHttpServerInterceptor definition for pre-processing
HttpServerRequest as well as HttpServerResponse instances.-
Method Summary
Modifier and TypeMethodDescriptionvoidpreIntercept(HttpServerRequest aRequest, HttpServerResponse aResponse) Invoked to pre-process aHttpServerRequestalongside aHttpServerResponse.
-
Method Details
-
preIntercept
Invoked to pre-process aHttpServerRequestalongside aHttpServerResponse.- Specified by:
preInterceptin interfacePreHttpInterceptor<HttpServerRequest, HttpServerResponse>- Parameters:
aRequest- TheHttpServerRequestto pre-process.aResponse- TheHttpServerResponseto post-process.
-