JavaScript is disabled on your browser.
Description
Nested Class Summary
Enum Constant Summary
Method Summary
Enum Constant Details
HTTP
HTTPS
SOCKS
SOCKS4
SOCKS5
Method Details
values()
valueOf(String)
initialize()
initializeAll()
toProxySettings(EnvironmentVariable, SystemProperty, SystemProperty, Scheme)
Enum Constant Summary
Enum Constants
Method Summary
All Methods Static Methods Instance Methods Concrete Methods
void
Initializes the proxy from the settings of the environment variables if
non according proxy settings are found in the system properties.
static void
Initializes the proxy for all proxy enumeration elements, e.g. calls
initialize() on each element in this enumeration.
protected static void
toProxySettings (org.refcodes.runtime.EnvironmentVariable aFromEnvProxy,
org.refcodes.runtime.SystemProperty aToSysHost,
org.refcodes.runtime.SystemProperty aToSysPort,
org.refcodes.data.Scheme aProtocol)
Returns the enum constant of this class with the specified name.
Returns an array containing the constants of this enum class, in
the order they are declared.
Methods inherited from class java.lang.Enum
clone , compareTo , describeConstable , equals , finalize , getDeclaringClass , hashCode , name , ordinal , toString , valueOf