- All Superinterfaces:
RealmAccessor,RealmAccessor.RealmMutator
- Enclosing interface:
- RealmAccessor
public static interface RealmAccessor.RealmProperty
extends RealmAccessor, RealmAccessor.RealmMutator
Provides a realm property. See RFC 1945 at
"https://tools.ietf.org/html/rfc1945#section-11" and RFC 2617 at
"https://tools.ietf.org/html/rfc2617#page-3".
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.web.RealmAccessor
RealmAccessor.RealmBuilder<B extends RealmAccessor.RealmBuilder<B>>, RealmAccessor.RealmMutator, RealmAccessor.RealmProperty -
Method Summary
Modifier and TypeMethodDescriptiondefault StringThis method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenString(setter) as ofRealmAccessor.RealmMutator.setRealm(String)and returns the very same value (getter).Methods inherited from interface org.refcodes.web.RealmAccessor
getRealmMethods inherited from interface org.refcodes.web.RealmAccessor.RealmMutator
setRealm
-
Method Details
-
letRealm
This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenString(setter) as ofRealmAccessor.RealmMutator.setRealm(String)and returns the very same value (getter).- Parameters:
aRealm- TheStringto set (viaRealmAccessor.RealmMutator.setRealm(String)).- Returns:
- Returns the value passed for it to be used in conclusive processing steps.
-