- All Known Subinterfaces:
RemoteAddressAccessor.RemoteAddressProperty
public interface RemoteAddressAccessor
Provides an accessor for a remote address property.
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceRemoteAddressAccessor.RemoteAddressBuilder<B extends RemoteAddressAccessor.RemoteAddressBuilder<B>>Provides a builder method for a remote address property returning the builder for applying multiple build operations.static interfaceRemoteAddressAccessor.RemoteAddressMutatorProvides a mutator for a remote address property.static interfaceRemoteAddressAccessor.RemoteAddressPropertyProvides a remote address property. -
Method Summary
Modifier and Type Method Description InetSocketAddressgetRemoteAddress()Retrieves the remote address from the remote address property.
-
Method Details
-
getRemoteAddress
InetSocketAddress getRemoteAddress()Retrieves the remote address from the remote address property.- Returns:
- The remote address stored by the remote address property.
-