Module org.refcodes.web
Package org.refcodes.web
Interface RemoteAddressAccessor.RemoteAddressBuilder<B extends RemoteAddressAccessor.RemoteAddressBuilder<B>>
-
- Type Parameters:
B- The builder to return in order to be able to apply multiple build operations.
- Enclosing interface:
- RemoteAddressAccessor
public static interface RemoteAddressAccessor.RemoteAddressBuilder<B extends RemoteAddressAccessor.RemoteAddressBuilder<B>>Provides a builder method for a remote address property returning the builder for applying multiple build operations.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description BwithRemoteAddress(InetSocketAddress aRemoteAddress)Sets the remote address for the remote address property.
-
-
-
Method Detail
-
withRemoteAddress
B withRemoteAddress(InetSocketAddress aRemoteAddress)
Sets the remote address for the remote address property.- Parameters:
aRemoteAddress- The remote address to be stored by the remote address property.- Returns:
- The builder for applying multiple build operations.
-
-