Module org.refcodes.web
Package org.refcodes.web
Interface RemoteAddressAccessor.RemoteAddressMutator
-
- All Known Subinterfaces:
RemoteAddressAccessor.RemoteAddressProperty
- Enclosing interface:
- RemoteAddressAccessor
public static interface RemoteAddressAccessor.RemoteAddressMutatorProvides a mutator for a remote address property.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description voidsetRemoteAddress(InetSocketAddress aRemoteAddress)Sets the remote address for the remote address property.
-
-
-
Method Detail
-
setRemoteAddress
void setRemoteAddress(InetSocketAddress aRemoteAddress)
Sets the remote address for the remote address property.- Parameters:
aRemoteAddress- The remote address to be stored by the remote address property.
-
-