Module org.refcodes.web
Package org.refcodes.web
Interface RemoteAddressAccessor.RemoteAddressProperty
-
- All Superinterfaces:
RemoteAddressAccessor,RemoteAddressAccessor.RemoteAddressMutator
- Enclosing interface:
- RemoteAddressAccessor
public static interface RemoteAddressAccessor.RemoteAddressProperty extends RemoteAddressAccessor, RemoteAddressAccessor.RemoteAddressMutator
Provides a remote address property.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.web.RemoteAddressAccessor
RemoteAddressAccessor.RemoteAddressBuilder<B extends RemoteAddressAccessor.RemoteAddressBuilder<B>>, RemoteAddressAccessor.RemoteAddressMutator, RemoteAddressAccessor.RemoteAddressProperty
-
-
Method Summary
All Methods Instance Methods Default Methods Modifier and Type Method Description default InetSocketAddressletRemoteAddress(InetSocketAddress aRemoteAddress)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenInetSocketAddress(setter) as ofRemoteAddressAccessor.RemoteAddressMutator.setRemoteAddress(InetSocketAddress)and returns the very same value (getter).-
Methods inherited from interface org.refcodes.web.RemoteAddressAccessor
getRemoteAddress
-
Methods inherited from interface org.refcodes.web.RemoteAddressAccessor.RemoteAddressMutator
setRemoteAddress
-
-
-
-
Method Detail
-
letRemoteAddress
default InetSocketAddress letRemoteAddress(InetSocketAddress aRemoteAddress)
This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenInetSocketAddress(setter) as ofRemoteAddressAccessor.RemoteAddressMutator.setRemoteAddress(InetSocketAddress)and returns the very same value (getter).- Parameters:
aRemoteAddress- TheInetSocketAddressto set (viaRemoteAddressAccessor.RemoteAddressMutator.setRemoteAddress(InetSocketAddress)).- Returns:
- Returns the value passed for it to be used in conclusive processing steps.
-
-