Class RequestCookie

All Implemented Interfaces:
KeyAccessor<String>, KeyAccessor.KeyBuilder<String, Relation.RelationBuilder<String,String>>, KeyAccessor.KeyMutator<String>, KeyAccessor.KeyProperty<String>, ValueAccessor<String>, ValueAccessor.ValueBuilder<String, Relation.RelationBuilder<String,String>>, ValueAccessor.ValueMutator<String>, ValueAccessor.ValueProperty<String>, Property, Property.PropertyBuilder, Relation<String,String>, Relation.RelationBuilder<String,String>, Cookie

public class RequestCookie extends PropertyImpl.PropertyBuilderImpl implements Cookie
The RequestCookie represents a request cookies: We use URL encoding / decoding for the cookie value (regarding fromHttpCookie(String) and toHttpCookie()) to make life easier and not fall into the trap of unescaped values.
  • Constructor Details

    • RequestCookie

      public RequestCookie()
      Constructs a RequestCookie.
    • RequestCookie

      public RequestCookie(String aCookieName, String aValue)
      Constructs a RequestCookie with the given cookie name and value.
      Parameters:
      aCookieName - The name of the cookie.
      aValue - The value for the cookie.
    • RequestCookie

      public RequestCookie(String aHttpCookie)
      Constructs a RequestCookie.
      Parameters:
      aHttpCookie - The text as being found in the according HTTP header field.
  • Method Details