-
- All Known Subinterfaces:
HttpServerContext,SchemeAccessor.SchemeProperty
- All Known Implementing Classes:
HttpServerContextBuilder,Url,UrlBuilder
public interface SchemeAccessorProvides an accessor for a URL scheme.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceSchemeAccessor.SchemeBuilder<B extends SchemeAccessor.SchemeBuilder<B>>Provides a builder method for a URL scheme returning the builder for applying multiple build operations.static interfaceSchemeAccessor.SchemeMutatorProvides a mutator for a URL scheme.static interfaceSchemeAccessor.SchemePropertyProvides a URL scheme.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description org.refcodes.data.SchemegetScheme()Retrieves the UrlScheme from the URL scheme.StringtoProtocol()Retrieves the protocol representation from theScheme.
-
-
-
Method Detail
-
getScheme
org.refcodes.data.Scheme getScheme()
Retrieves the UrlScheme from the URL scheme.- Returns:
- The UrlScheme stored by the URL scheme.
-
toProtocol
String toProtocol()
Retrieves the protocol representation from theScheme. In case of a scheme unknown by theSchemeenumeration, thengetScheme()might return null whilsttoProtocol()still retrieves the unknown scheme's protocol representation (as ofSchemeAccessor.SchemeMutator.setProtocol(String)).- Returns:
- The protocol representation for the URL.
-
-