- All Known Subinterfaces:
SchemeAccessor.SchemeProperty
- All Known Implementing Classes:
HttpServerContextBuilder,UrlBuilder
- Enclosing interface:
- SchemeAccessor
public static interface SchemeAccessor.SchemeMutator
Provides a mutator for a URL scheme.
-
Method Summary
Modifier and TypeMethodDescriptionvoidsetProtocol(String aProtocol) Sets the protocolStringrepresentation for the scheme property.voidsetScheme(org.refcodes.data.Scheme aScheme) Sets the UrlScheme for the URL scheme.
-
Method Details
-
setScheme
void setScheme(org.refcodes.data.Scheme aScheme) Sets the UrlScheme for the URL scheme.- Parameters:
aScheme- The UrlScheme to be stored by the URL scheme.
-
setProtocol
Sets the protocolStringrepresentation for the scheme property. You must provide the scheme's specific part as well. In case of HTTP, provide "http://". In case your provided protocol is unknown by theSchemeenumeration, then the scheme property will not be set, though theSchemeAccessor.toProtocol()still returns your protocol.- Parameters:
aProtocol- The UrlScheme'sStringrepresentation to be stored by the URL scheme.
-