- java.lang.Object
-
- org.refcodes.web.UrlBuilderImpl
-
- All Implemented Interfaces:
org.refcodes.mixin.CredentialsAccessor,org.refcodes.mixin.CredentialsAccessor.CredentialsBuilder<Url.UrlBuilder>,org.refcodes.mixin.CredentialsAccessor.CredentialsMutator,org.refcodes.mixin.CredentialsAccessor.CredentialsProperty,org.refcodes.mixin.Dumpable,org.refcodes.mixin.IdentityAccessor,org.refcodes.mixin.IdentityAccessor.IdentityBuilder<Url.UrlBuilder>,org.refcodes.mixin.IdentityAccessor.IdentityMutator,org.refcodes.mixin.IdentityAccessor.IdentityProperty,org.refcodes.mixin.PathAccessor,org.refcodes.mixin.PathAccessor.PathBuilder<Url.UrlBuilder>,org.refcodes.mixin.PathAccessor.PathMutator,org.refcodes.mixin.PathAccessor.PathProperty,org.refcodes.mixin.PortAccessor,org.refcodes.mixin.PortAccessor.PortBuilder<Url.UrlBuilder>,org.refcodes.mixin.PortAccessor.PortMutator,org.refcodes.mixin.PortAccessor.PortProperty,org.refcodes.mixin.SecretAccessor,org.refcodes.mixin.SecretAccessor.SecretBuilder<Url.UrlBuilder>,org.refcodes.mixin.SecretAccessor.SecretMutator,org.refcodes.mixin.SecretAccessor.SecretProperty,FragmentAccessor,FragmentAccessor.FragmentBuilder<Url.UrlBuilder>,FragmentAccessor.FragmentMutator,FragmentAccessor.FragmentProperty,HostAccessor,HostAccessor.HostBuilder<Url.UrlBuilder>,HostAccessor.HostMutator,HostAccessor.HostProperty,IpAddressAccessor,IpAddressAccessor.IpAddressBuilder<Url.UrlBuilder>,IpAddressAccessor.IpAddressMutator,IpAddressAccessor.IpAddressProperty,QueryFieldsAccessor,QueryFieldsAccessor.QueryFieldsBuilder<Url.UrlBuilder>,QueryFieldsAccessor.QueryFieldsMutator,QueryFieldsAccessor.QueryFieldsProperty,SchemeAccessor,SchemeAccessor.SchemeBuilder<Url.UrlBuilder>,SchemeAccessor.SchemeMutator,SchemeAccessor.SchemeProperty,Url,Url.UrlBuilder
public class UrlBuilderImpl extends Object implements Url.UrlBuilder
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.CredentialsAccessor
org.refcodes.mixin.CredentialsAccessor.CredentialsBuilder<B extends org.refcodes.mixin.CredentialsAccessor.CredentialsBuilder<B>>, org.refcodes.mixin.CredentialsAccessor.CredentialsMutator, org.refcodes.mixin.CredentialsAccessor.CredentialsProperty
-
Nested classes/interfaces inherited from interface org.refcodes.web.FragmentAccessor
FragmentAccessor.FragmentBuilder<B extends FragmentAccessor.FragmentBuilder<?>>, FragmentAccessor.FragmentMutator, FragmentAccessor.FragmentProperty
-
Nested classes/interfaces inherited from interface org.refcodes.web.HostAccessor
HostAccessor.HostBuilder<B extends HostAccessor.HostBuilder<?>>, HostAccessor.HostMutator, HostAccessor.HostProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.IdentityAccessor
org.refcodes.mixin.IdentityAccessor.IdentityBuilder<B extends org.refcodes.mixin.IdentityAccessor.IdentityBuilder<B>>, org.refcodes.mixin.IdentityAccessor.IdentityMutator, org.refcodes.mixin.IdentityAccessor.IdentityProperty
-
Nested classes/interfaces inherited from interface org.refcodes.web.IpAddressAccessor
IpAddressAccessor.IpAddressBuilder<B extends IpAddressAccessor.IpAddressBuilder<B>>, IpAddressAccessor.IpAddressMutator, IpAddressAccessor.IpAddressProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.PathAccessor
org.refcodes.mixin.PathAccessor.PathBuilder<B extends org.refcodes.mixin.PathAccessor.PathBuilder<?>>, org.refcodes.mixin.PathAccessor.PathMutator, org.refcodes.mixin.PathAccessor.PathProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.PortAccessor
org.refcodes.mixin.PortAccessor.PortBuilder<B extends org.refcodes.mixin.PortAccessor.PortBuilder<B>>, org.refcodes.mixin.PortAccessor.PortMutator, org.refcodes.mixin.PortAccessor.PortProperty
-
Nested classes/interfaces inherited from interface org.refcodes.web.QueryFieldsAccessor
QueryFieldsAccessor.QueryFieldsBuilder<B extends QueryFieldsAccessor.QueryFieldsBuilder<?>>, QueryFieldsAccessor.QueryFieldsMutator, QueryFieldsAccessor.QueryFieldsProperty
-
Nested classes/interfaces inherited from interface org.refcodes.web.SchemeAccessor
SchemeAccessor.SchemeBuilder<B extends SchemeAccessor.SchemeBuilder<B>>, SchemeAccessor.SchemeMutator, SchemeAccessor.SchemeProperty
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.SecretAccessor
org.refcodes.mixin.SecretAccessor.SecretBuilder<B extends org.refcodes.mixin.SecretAccessor.SecretBuilder<B>>, org.refcodes.mixin.SecretAccessor.SecretMutator, org.refcodes.mixin.SecretAccessor.SecretProperty
-
Nested classes/interfaces inherited from interface org.refcodes.web.Url
Url.UrlBuilder
-
-
Constructor Summary
Constructors Constructor Description UrlBuilderImpl()Default constructor.UrlBuilderImpl(String aUrl)Constructs anUrl.UrlBuilderfrom the provided URLString.UrlBuilderImpl(String aProtocol, String aHost)Constructs anUrl.UrlBuilderwith the common attributes.UrlBuilderImpl(String aProtocol, String aHost, int aPort)Constructs anUrl.UrlBuilderwith the common attributes.UrlBuilderImpl(String aProtocol, String aHost, int aPort, String aPath)Constructs anUrl.UrlBuilderwith the common attributes.UrlBuilderImpl(String aProtocol, String aHost, int aPort, String aPath, FormFields aQueryFields)Constructs anUrl.UrlBuilderwith the common attributes.UrlBuilderImpl(String aProtocol, String aHost, int aPort, String aPath, FormFields aQueryFields, String aFragment)Constructs anUrl.UrlBuilderwith the common attributes.UrlBuilderImpl(String aProtocol, String aHost, String aPath)Constructs anUrl.UrlBuilderwith the common attributes.UrlBuilderImpl(String aProtocol, String aHost, String aPath, FormFields aQueryFields)Constructs anUrl.UrlBuilderwith the common attributes.UrlBuilderImpl(String aProtocol, String aHost, String aPath, FormFields aQueryFields, String aFragment)Constructs anUrl.UrlBuilderwith the common attributes.UrlBuilderImpl(String aUrl, FormFields aQueryFields)Constructs anUrl.UrlBuilderfrom the provided URLString.UrlBuilderImpl(String aUrl, FormFields aQueryFields, String aFragment)Constructs anUrl.UrlBuilderfrom the provided URLString.UrlBuilderImpl(URL aURL)Constructs anUrl.UrlBuilderfrom the providedURLinstance.UrlBuilderImpl(org.refcodes.data.Scheme aScheme, String aHost)Constructs anUrl.UrlBuilderwith the common attributes.UrlBuilderImpl(org.refcodes.data.Scheme aScheme, String aHost, int aPort)Constructs anUrl.UrlBuilderwith the common attributes.UrlBuilderImpl(org.refcodes.data.Scheme aScheme, String aHost, int aPort, String aPath)Constructs anUrl.UrlBuilderwith the common attributes.UrlBuilderImpl(org.refcodes.data.Scheme aScheme, String aHost, int aPort, String aPath, FormFields aQueryFields)Constructs anUrl.UrlBuilderwith the common attributes.UrlBuilderImpl(org.refcodes.data.Scheme aScheme, String aHost, int aPort, String aPath, FormFields aQueryFields, String aFragment)Constructs anUrl.UrlBuilderwith the common attributes.UrlBuilderImpl(org.refcodes.data.Scheme aScheme, String aHost, String aPath)Constructs anUrl.UrlBuilderwith the common attributes.UrlBuilderImpl(org.refcodes.data.Scheme aScheme, String aHost, String aPath, FormFields aQueryFields)Constructs anUrl.UrlBuilderwith the common attributes.UrlBuilderImpl(org.refcodes.data.Scheme aScheme, String aHost, String aPath, FormFields aQueryFields, String aFragment)Constructs anUrl.UrlBuilderwith the common attributes.UrlBuilderImpl(Url aUrl)Creates anUrl.UrlBuilderfrom the providedUrl.UrlBuilderImpl(Url aUrl, String... aPaths)UrlBuilderImpl(Url aUrl, Url aOtherUrl)Constructs a newUrl.UrlBuilderfrom the givenUrlinstances by adding the otherUrl's data to the firstUrl's data.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description StringgetFragment()Retrieves the fragment from the fragment property.StringgetHost()Retrieves the host from the host property.StringgetIdentity()int[]getIpAddress()Retrieves the IP-Address from the IP-Address property.StringgetPath()intgetPort()FormFieldsgetQueryFields()Retrieves the request Query-Fields from the request Query-Fields property.org.refcodes.data.SchemegetScheme()Retrieves the UrlScheme from the URL scheme.StringgetSecret()voidsetFragment(String aFragment)Sets the fragment for the fragment property.voidsetHost(String aHost)Sets the host for the host property.voidsetIdentity(String aIdentity)voidsetIpAddress(int[] aIpAddress)Sets the IP-Address for the IP-Address property.voidsetPath(String aPath)voidsetPort(int aPort)voidsetProtocol(String aProtocol)Sets the protocolStringrepresentation for the scheme property.voidsetQueryFields(FormFields aQueryFields)Sets the request Query-Fields for the request Query-Fields property.voidsetScheme(org.refcodes.data.Scheme aScheme)Sets the UrlScheme for the URL scheme.voidsetSecret(String aSecret)StringtoProtocol()Retrieves the protocol representation from theScheme.StringtoString()-
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface org.refcodes.web.FragmentAccessor.FragmentProperty
letFragment
-
Methods inherited from interface org.refcodes.web.HostAccessor.HostProperty
letHost
-
Methods inherited from interface org.refcodes.web.IpAddressAccessor
toCidrNotation
-
Methods inherited from interface org.refcodes.web.IpAddressAccessor.IpAddressMutator
fromCidrNotation
-
Methods inherited from interface org.refcodes.web.IpAddressAccessor.IpAddressProperty
letIpAddress
-
Methods inherited from interface org.refcodes.web.QueryFieldsAccessor.QueryFieldsProperty
letQueryFields
-
Methods inherited from interface org.refcodes.web.SchemeAccessor.SchemeProperty
letProtocol, letScheme
-
Methods inherited from interface org.refcodes.web.Url.UrlBuilder
addToQueryFields, addToQueryFields, appendToPath, appendToPath, fromUrl, fromURL, withAddToQueryFields, withAddToQueryFields, withAppendToPath, withAppendToPath, withCidrNotation, withFragment, withHost, withIdentity, withIpAddress, withPath, withPort, withProtocol, withQueryFields, withScheme, withSecret
-
-
-
-
Constructor Detail
-
UrlBuilderImpl
public UrlBuilderImpl()
Default constructor. Make sure to set required attributes for a valid URL.
-
UrlBuilderImpl
public UrlBuilderImpl(Url aUrl)
Creates anUrl.UrlBuilderfrom the providedUrl.- Parameters:
aUrl- TheUrlfrom which to construct this instance.
-
UrlBuilderImpl
public UrlBuilderImpl(String aUrl) throws MalformedURLException
Constructs anUrl.UrlBuilderfrom the provided URLString.- Parameters:
aUrl- The URLStringto be parsed. The URL consists of the scheme (protocol), the identify and the secret (optional), the host as well as an optional port and the (optional) path.- Throws:
MalformedURLException- in case the provided URL is considered being malformed.
-
UrlBuilderImpl
public UrlBuilderImpl(String aUrl, FormFields aQueryFields) throws MalformedURLException
Constructs anUrl.UrlBuilderfrom the provided URLString.- Parameters:
aUrl- The URLStringto be parsed. The URL consists of the scheme (protocol), the identify and the secret (optional), the host as well as an optional port and the (optional) path.aQueryFields- The Query-Fields to be used for the HTTP Query-String.- Throws:
MalformedURLException- in case the provided URL is considered being malformed.
-
UrlBuilderImpl
public UrlBuilderImpl(String aUrl, FormFields aQueryFields, String aFragment) throws MalformedURLException
Constructs anUrl.UrlBuilderfrom the provided URLString.- Parameters:
aUrl- The URLStringto be parsed. The URL consists of the scheme (protocol), the identify and the secret (optional), the host as well as an optional port and the (optional) path.aQueryFields- The Query-Fields to be used for the HTTP Query-String.aFragment- The fragment to be set.- Throws:
MalformedURLException- in case the provided URL is considered being malformed.
-
UrlBuilderImpl
public UrlBuilderImpl(URL aURL)
Constructs anUrl.UrlBuilderfrom the providedURLinstance.- Parameters:
aURL- TheURLto be used.
-
UrlBuilderImpl
public UrlBuilderImpl(org.refcodes.data.Scheme aScheme, String aHost)Constructs anUrl.UrlBuilderwith the common attributes.- Parameters:
aScheme- TheScheme(e.g. HTTP or HTTPS) to be used for the destination URL.aHost- The host to which the destination URL is to point to.
-
UrlBuilderImpl
public UrlBuilderImpl(org.refcodes.data.Scheme aScheme, String aHost, int aPort)Constructs anUrl.UrlBuilderwith the common attributes.- Parameters:
aScheme- TheScheme(e.g. HTTP or HTTPS) to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPort- The port to be used when connecting to the host.
-
UrlBuilderImpl
public UrlBuilderImpl(org.refcodes.data.Scheme aScheme, String aHost, int aPort, String aPath)Constructs anUrl.UrlBuilderwith the common attributes.- Parameters:
aScheme- TheScheme(e.g. HTTP or HTTPS) to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPort- The port to be used when connecting to the host.aPath- The path on the host to which the base destination URL is to point to.
-
UrlBuilderImpl
public UrlBuilderImpl(org.refcodes.data.Scheme aScheme, String aHost, int aPort, String aPath, FormFields aQueryFields)Constructs anUrl.UrlBuilderwith the common attributes.- Parameters:
aScheme- TheScheme(e.g. HTTP or HTTPS) to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPort- The port to be used when connecting to the host.aPath- The path on the host to which the base destination URL is to point to.aQueryFields- The Query-Fields to be used for the HTTP Query-String.
-
UrlBuilderImpl
public UrlBuilderImpl(org.refcodes.data.Scheme aScheme, String aHost, int aPort, String aPath, FormFields aQueryFields, String aFragment)Constructs anUrl.UrlBuilderwith the common attributes.- Parameters:
aScheme- TheScheme(e.g. HTTP or HTTPS) to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPort- The port to be used when connecting to the host.aPath- The path on the host to which the base destination URL is to point to.aFragment- The fragment to be set.aQueryFields- The Query-Fields to be used for the HTTP Query-String.
-
UrlBuilderImpl
public UrlBuilderImpl(String aProtocol, String aHost)
Constructs anUrl.UrlBuilderwith the common attributes.- Parameters:
aProtocol- The protocolString(e.g. "http://" or "https://") to be used for the destination URL.aHost- The host to which the destination URL is to point to.
-
UrlBuilderImpl
public UrlBuilderImpl(String aProtocol, String aHost, int aPort)
Constructs anUrl.UrlBuilderwith the common attributes.- Parameters:
aProtocol- The protocolString(e.g. "http://" or "https://") to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPort- The port to be used when connecting to the host.
-
UrlBuilderImpl
public UrlBuilderImpl(String aProtocol, String aHost, int aPort, String aPath)
Constructs anUrl.UrlBuilderwith the common attributes.- Parameters:
aProtocol- The protocolString(e.g. "http://" or "https://") to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPort- The port to be used when connecting to the host.aPath- The path on the host to which the base destination URL is to point to.
-
UrlBuilderImpl
public UrlBuilderImpl(String aProtocol, String aHost, int aPort, String aPath, FormFields aQueryFields)
Constructs anUrl.UrlBuilderwith the common attributes.- Parameters:
aProtocol- The protocolString(e.g. "http://" or "https://") to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPort- The port to be used when connecting to the host.aPath- The path on the host to which the base destination URL is to point to.aQueryFields- The Query-Fields to be used for the HTTP Query-String.
-
UrlBuilderImpl
public UrlBuilderImpl(String aProtocol, String aHost, int aPort, String aPath, FormFields aQueryFields, String aFragment)
Constructs anUrl.UrlBuilderwith the common attributes.- Parameters:
aProtocol- The protocolString(e.g. "http://" or "https://") to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPort- The port to be used when connecting to the host.aPath- The path on the host to which the base destination URL is to point to.aFragment- The fragment to be set.aQueryFields- The Query-Fields to be used for the HTTP Query-String.
-
UrlBuilderImpl
public UrlBuilderImpl(org.refcodes.data.Scheme aScheme, String aHost, String aPath)Constructs anUrl.UrlBuilderwith the common attributes.- Parameters:
aScheme- TheScheme(e.g. HTTP or HTTPS) to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPath- The path on the host to which the base destination URL is to point to.
-
UrlBuilderImpl
public UrlBuilderImpl(org.refcodes.data.Scheme aScheme, String aHost, String aPath, FormFields aQueryFields)Constructs anUrl.UrlBuilderwith the common attributes.- Parameters:
aScheme- TheScheme(e.g. HTTP or HTTPS) to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPath- The path on the host to which the base destination URL is to point to.aQueryFields- The Query-Fields to be used for the HTTP Query-String.
-
UrlBuilderImpl
public UrlBuilderImpl(org.refcodes.data.Scheme aScheme, String aHost, String aPath, FormFields aQueryFields, String aFragment)Constructs anUrl.UrlBuilderwith the common attributes.- Parameters:
aScheme- TheScheme(e.g. HTTP or HTTPS) to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPath- The path on the host to which the base destination URL is to point to.aQueryFields- The Query-Fields to be used for the HTTP Query-String.aFragment- The fragment to be set.
-
UrlBuilderImpl
public UrlBuilderImpl(String aProtocol, String aHost, String aPath)
Constructs anUrl.UrlBuilderwith the common attributes.- Parameters:
aProtocol- The protocolString(e.g. "http://" or "https://") to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPath- The path on the host to which the base destination URL is to point to.
-
UrlBuilderImpl
public UrlBuilderImpl(String aProtocol, String aHost, String aPath, FormFields aQueryFields)
Constructs anUrl.UrlBuilderwith the common attributes.- Parameters:
aProtocol- The protocolString(e.g. "http://" or "https://") to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPath- The path on the host to which the base destination URL is to point to.aQueryFields- The Query-Fields to be used for the HTTP Query-String.
-
UrlBuilderImpl
public UrlBuilderImpl(String aProtocol, String aHost, String aPath, FormFields aQueryFields, String aFragment)
Constructs anUrl.UrlBuilderwith the common attributes.- Parameters:
aProtocol- The protocolString(e.g. "http://" or "https://") to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPath- The path on the host to which the base destination URL is to point to.aQueryFields- The Query-Fields to be used for the HTTP Query-String.aFragment- The fragment to be set.
-
-
Method Detail
-
getScheme
public org.refcodes.data.Scheme getScheme()
Retrieves the UrlScheme from the URL scheme.- Specified by:
getSchemein interfaceSchemeAccessor- Returns:
- The UrlScheme stored by the URL scheme.
-
toProtocol
public String toProtocol()
Retrieves the protocol representation from theScheme. In case of a scheme unknown by theSchemeenumeration, thenSchemeAccessor.getScheme()might return null whilstSchemeAccessor.toProtocol()still retrieves the unknown scheme's protocol representation (as ofSchemeAccessor.SchemeMutator.setProtocol(String)).- Specified by:
toProtocolin interfaceSchemeAccessor- Returns:
- The protocol representation for the URL.
-
setScheme
public void setScheme(org.refcodes.data.Scheme aScheme)
Sets the UrlScheme for the URL scheme.- Specified by:
setSchemein interfaceSchemeAccessor.SchemeMutator- Parameters:
aScheme- The UrlScheme to be stored by the URL scheme.
-
setProtocol
public void setProtocol(String aProtocol)
Sets the protocolStringrepresentation for the scheme property. You must provide the scheme's specific part as well. In case of HTTP, provide "http://". In case your provided protocol is unknown by theSchemeenumeration, then the scheme property will not be set, though theSchemeAccessor.toProtocol()still returns your protocol.- Specified by:
setProtocolin interfaceSchemeAccessor.SchemeMutator- Parameters:
aProtocol- The UrlScheme'sStringrepresentation to be stored by the URL scheme.
-
getHost
public String getHost()
Retrieves the host from the host property.- Specified by:
getHostin interfaceHostAccessor- Returns:
- The host stored by the host property.
-
setHost
public void setHost(String aHost)
Sets the host for the host property.- Specified by:
setHostin interfaceHostAccessor.HostMutator- Parameters:
aHost- The host to be stored by the host property.
-
getIpAddress
public int[] getIpAddress()
Retrieves the IP-Address from the IP-Address property.- Specified by:
getIpAddressin interfaceIpAddressAccessor- Returns:
- The IP-Address stored by the IP-Address property.
-
setIpAddress
public void setIpAddress(int[] aIpAddress)
Sets the IP-Address for the IP-Address property.- Specified by:
setIpAddressin interfaceIpAddressAccessor.IpAddressMutator- Parameters:
aIpAddress- The IP-Address to be stored by the IP-Address property.
-
getPort
public int getPort()
- Specified by:
getPortin interfaceorg.refcodes.mixin.PortAccessor
-
setPort
public void setPort(int aPort)
- Specified by:
setPortin interfaceorg.refcodes.mixin.PortAccessor.PortMutator
-
getPath
public String getPath()
- Specified by:
getPathin interfaceorg.refcodes.mixin.PathAccessor
-
setPath
public void setPath(String aPath)
- Specified by:
setPathin interfaceorg.refcodes.mixin.PathAccessor.PathMutator
-
getQueryFields
public FormFields getQueryFields()
Retrieves the request Query-Fields from the request Query-Fields property.- Specified by:
getQueryFieldsin interfaceQueryFieldsAccessor- Returns:
- The request Query-Fields stored by the request Query-Fields property.
-
setQueryFields
public void setQueryFields(FormFields aQueryFields)
Sets the request Query-Fields for the request Query-Fields property.- Specified by:
setQueryFieldsin interfaceQueryFieldsAccessor.QueryFieldsMutator- Parameters:
aQueryFields- The request Query-Fields to be stored by the form fields property.
-
getFragment
public String getFragment()
Retrieves the fragment from the fragment property.- Specified by:
getFragmentin interfaceFragmentAccessor- Returns:
- The fragment stored by the fragment property.
-
setFragment
public void setFragment(String aFragment)
Sets the fragment for the fragment property.- Specified by:
setFragmentin interfaceFragmentAccessor.FragmentMutator- Parameters:
aFragment- The fragment to be stored by the fragment property.
-
getIdentity
public String getIdentity()
- Specified by:
getIdentityin interfaceorg.refcodes.mixin.IdentityAccessor
-
getSecret
public String getSecret()
- Specified by:
getSecretin interfaceorg.refcodes.mixin.SecretAccessor
-
setIdentity
public void setIdentity(String aIdentity)
- Specified by:
setIdentityin interfaceorg.refcodes.mixin.IdentityAccessor.IdentityMutator
-
setSecret
public void setSecret(String aSecret)
- Specified by:
setSecretin interfaceorg.refcodes.mixin.SecretAccessor.SecretMutator
-
-