java.lang.Object
org.refcodes.web.UrlSugar
Declarative syntactic sugar which may be statically imported in order to
allow declarative definitions for
Url (UrlBuilder) creation
and tweaking: import static org.refcodes.web.UrlSugar.*;-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptiontoUrl()Creates an emptyUrlBuilder, make sure to set required attributes for a valid URL.Constructs anUrlBuilderfrom the provided URLString.Constructs anUrlBuilderwith the common attributes.Constructs anUrlBuilderwith the common attributes.Constructs anUrlBuilderwith the common attributes.toUrl(String aProtocol, String aHost, int aPort, String aPath, FormFields aQueryFields) Constructs anUrlBuilderwith the common attributes.toUrl(String aProtocol, String aHost, int aPort, String aPath, FormFields aQueryFields, String aFragment) Constructs anUrlBuilderwith the common attributes.Constructs anUrlBuilderwith the common attributes.toUrl(String aProtocol, String aHost, String aPath, FormFields aQueryFields) Constructs anUrlBuilderwith the common attributes.Constructs anUrlBuilderwith the common attributes.Constructs anUrlBuilderfrom the providedURLinstance.Constructs anUrlBuilderwith the common attributes.Constructs anUrlBuilderwith the common attributes.Constructs anUrlBuilderwith the common attributes.toUrl(org.refcodes.data.Scheme aScheme, String aHost, int aPort, String aPath, FormFields aQueryFields) Constructs anUrlBuilderwith the common attributes.toUrl(org.refcodes.data.Scheme aScheme, String aHost, int aPort, String aPath, FormFields aQueryFields, String aFragment) Constructs anUrlBuilderwith the common attributes.Constructs anUrlBuilderwith the common attributes.toUrl(org.refcodes.data.Scheme aScheme, String aHost, String aPath, FormFields aQueryFields) Constructs anUrlBuilderwith the common attributes.toUrl(org.refcodes.data.Scheme aScheme, String aHost, String aPath, FormFields aQueryFields, String aFragment) Constructs anUrlBuilderwith the common attributes.
-
Constructor Details
-
UrlSugar
public UrlSugar()
-
-
Method Details
-
toUrl
Creates an emptyUrlBuilder, make sure to set required attributes for a valid URL.- Returns:
- The accordingly constructed
UrlBuilderinstance.
-
toUrl
Constructs anUrlBuilderfrom the provided URLString.- Parameters:
aUrl- The URLStringto be parsed.- Returns:
- The accordingly constructed
UrlBuilderinstance. - Throws:
MalformedURLException- in case the provided URL is considered being malformed.
-
toUrl
Constructs anUrlBuilderfrom the providedURLinstance.- Parameters:
aURL- TheURLto be used.- Returns:
- The accordingly constructed
UrlBuilderinstance.
-
toUrl
Constructs anUrlBuilderwith the common attributes.- Parameters:
aScheme- TheScheme(e.g. HTTP or HTTPS) to be used for the destination URL.aHost- The host to which the destination URL is to point to.- Returns:
- The accordingly constructed
UrlBuilderinstance.
-
toUrl
Constructs anUrlBuilderwith the common attributes.- Parameters:
aScheme- TheScheme(e.g. HTTP or HTTPS) to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPort- The port to be used when connecting to the host.- Returns:
- The accordingly constructed
UrlBuilderinstance.
-
toUrl
Constructs anUrlBuilderwith the common attributes.- Parameters:
aScheme- TheScheme(e.g. HTTP or HTTPS) to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPort- The port to be used when connecting to the host.aPath- The path on the host to which the base destination URL is to point to.- Returns:
- The accordingly constructed
UrlBuilderinstance.
-
toUrl
public UrlBuilder toUrl(org.refcodes.data.Scheme aScheme, String aHost, int aPort, String aPath, FormFields aQueryFields) Constructs anUrlBuilderwith the common attributes.- Parameters:
aScheme- TheScheme(e.g. HTTP or HTTPS) to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPort- The port to be used when connecting to the host.aPath- The path on the host to which the base destination URL is to point to.aQueryFields- The Query-Fields to be used for the HTTP Query-String.- Returns:
- The accordingly constructed
UrlBuilderinstance.
-
toUrl
public UrlBuilder toUrl(org.refcodes.data.Scheme aScheme, String aHost, int aPort, String aPath, FormFields aQueryFields, String aFragment) Constructs anUrlBuilderwith the common attributes.- Parameters:
aScheme- TheScheme(e.g. HTTP or HTTPS) to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPort- The port to be used when connecting to the host.aPath- The path on the host to which the base destination URL is to point to.aQueryFields- The Query-Fields to be used for the HTTP Query-String.aFragment- The fragment to be set.- Returns:
- The accordingly constructed
UrlBuilderinstance.
-
toUrl
Constructs anUrlBuilderwith the common attributes.- Parameters:
aProtocol- The protocolString(e.g. "http://" or "https://") to be used for the destination URL.aHost- The host to which the destination URL is to point to.- Returns:
- The accordingly constructed
UrlBuilderinstance.
-
toUrl
Constructs anUrlBuilderwith the common attributes.- Parameters:
aProtocol- The protocolString(e.g. "http://" or "https://") to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPort- The port to be used when connecting to the host.- Returns:
- The accordingly constructed
UrlBuilderinstance.
-
toUrl
Constructs anUrlBuilderwith the common attributes.- Parameters:
aProtocol- The protocolString(e.g. "http://" or "https://") to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPort- The port to be used when connecting to the host.aPath- The path on the host to which the base destination URL is to point to.- Returns:
- The accordingly constructed
UrlBuilderinstance.
-
toUrl
public UrlBuilder toUrl(String aProtocol, String aHost, int aPort, String aPath, FormFields aQueryFields) Constructs anUrlBuilderwith the common attributes.- Parameters:
aProtocol- The protocolString(e.g. "http://" or "https://") to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPort- The port to be used when connecting to the host.aPath- The path on the host to which the base destination URL is to point to.aQueryFields- The Query-Fields to be used for the HTTP Query-String.- Returns:
- The accordingly constructed
UrlBuilderinstance.
-
toUrl
public UrlBuilder toUrl(String aProtocol, String aHost, int aPort, String aPath, FormFields aQueryFields, String aFragment) Constructs anUrlBuilderwith the common attributes.- Parameters:
aProtocol- The protocolString(e.g. "http://" or "https://") to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPort- The port to be used when connecting to the host.aPath- The path on the host to which the base destination URL is to point to.aQueryFields- The Query-Fields to be used for the HTTP Query-String.aFragment- The fragment to be set.- Returns:
- The accordingly constructed
UrlBuilderinstance.
-
toUrl
Constructs anUrlBuilderwith the common attributes.- Parameters:
aScheme- TheScheme(e.g. HTTP or HTTPS) to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPath- The path on the host to which the base destination URL is to point to.- Returns:
- The accordingly constructed
UrlBuilderinstance.
-
toUrl
public UrlBuilder toUrl(org.refcodes.data.Scheme aScheme, String aHost, String aPath, FormFields aQueryFields) Constructs anUrlBuilderwith the common attributes.- Parameters:
aScheme- TheScheme(e.g. HTTP or HTTPS) to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPath- The path on the host to which the base destination URL is to point to.aQueryFields- The Query-Fields to be used for the HTTP Query-String.- Returns:
- The accordingly constructed
UrlBuilderinstance.
-
toUrl
public UrlBuilder toUrl(org.refcodes.data.Scheme aScheme, String aHost, String aPath, FormFields aQueryFields, String aFragment) Constructs anUrlBuilderwith the common attributes.- Parameters:
aScheme- TheScheme(e.g. HTTP or HTTPS) to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPath- The path on the host to which the base destination URL is to point to.aQueryFields- The Query-Fields to be used for the HTTP Query-String.aFragment- The fragment to be set.- Returns:
- The accordingly constructed
UrlBuilderinstance.
-
toUrl
Constructs anUrlBuilderwith the common attributes.- Parameters:
aProtocol- The protocolString(e.g. "http://" or "https://") to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPath- The path on the host to which the base destination URL is to point to.- Returns:
- The accordingly constructed
UrlBuilderinstance.
-
toUrl
Constructs anUrlBuilderwith the common attributes.- Parameters:
aProtocol- The protocolString(e.g. "http://" or "https://") to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPath- The path on the host to which the base destination URL is to point to.aQueryFields- The Query-Fields to be used for the HTTP Query-String.- Returns:
- The accordingly constructed
UrlBuilderinstance.
-
toUrl
public UrlBuilder toUrl(String aProtocol, String aHost, String aPath, FormFields aQueryFields, String aFragment) Constructs anUrlBuilderwith the common attributes.- Parameters:
aProtocol- The protocolString(e.g. "http://" or "https://") to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPath- The path on the host to which the base destination URL is to point to.aQueryFields- The Query-Fields to be used for the HTTP Query-String.aFragment- The fragment to be set.- Returns:
- The accordingly constructed
UrlBuilderinstance.
-