-
- All Known Subinterfaces:
UserAgentAccessor.UserAgentProperty
public interface UserAgentAccessorProvides an accessor for a user agent property.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceUserAgentAccessor.UserAgentBuilder<B extends UserAgentAccessor.UserAgentBuilder<B>>Provides a builder method for a user agent property returning the builder for applying multiple build operations.static interfaceUserAgentAccessor.UserAgentMutatorProvides a mutator for a user agent property.static interfaceUserAgentAccessor.UserAgentPropertyProvides a user agent property.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description StringgetUserAgent()Retrieves the user agent from the user agent property.
-
-
-
Method Detail
-
getUserAgent
String getUserAgent()
Retrieves the user agent from the user agent property.- Returns:
- The user agent stored by the user agent property.
-
-