Uses of Class
org.refcodes.web.AbstractHeaderFields
-
Uses of AbstractHeaderFields in org.refcodes.web
Subclasses of AbstractHeaderFields in org.refcodes.webModifier and TypeClassDescriptionclassTheRequestHeaderFieldsreflect the structure of a HTTP-Header and may be used to represent a HTTP-Header.classTheResponseHeaderFieldsreflect the structure of a HTTP header and may be used to represent a HTTP header.