Uses of Class
org.refcodes.web.BasicAuthCredentials
-
Uses of BasicAuthCredentials in org.refcodes.web
Subclasses of BasicAuthCredentials in org.refcodes.webModifier and TypeClassDescriptionclassTheBasicAuthCredentialsBuildercompares the secret (getSecret()) case sensitive but the username (getIdentity()) case insensitive within theequals(Object)method.Classes in org.refcodes.web that implement interfaces with type arguments of type BasicAuthCredentialsModifier and TypeClassDescriptionclassTheBasicAuthCredentialsdefines a type for representing a Basic-Authentication credentials Header-Field.Methods in org.refcodes.web that return BasicAuthCredentialsModifier and TypeMethodDescriptionBasicAuthCredentialsAccessor.getBasicAuthCredentials()Retrieves theBasicAuthCredentialsfrom the Basic-Authentication credentials property (or null if there are none such credentials).BasicAuthRequest.getBasicAuthCredentials()Retrieves theBasicAuthCredentialsfrom the Basic-Authentication credentials property (or null if there are none such credentials).default BasicAuthCredentialsHeaderFields.getBasicAuthCredentials()Retrieves theBasicAuthCredentialsfrom the request (or null if there are none such credentials).default BasicAuthCredentialsBasicAuthCredentialsAccessor.BasicAuthCredentialsProperty.letBasicAuthCredentials(String aUserName, String aSecret) This method stores and passes through the given arguments, which is very useful for builder APIs:Sets theBasicAuthCredentialsfrom the user name and the secret for the Basic-Authentication credentials property.default BasicAuthCredentialsBasicAuthCredentialsAccessor.BasicAuthCredentialsProperty.letBasicAuthCredentials(BasicAuthCredentials aBasicAuthCredentials) This method stores and passes through the given argument, which is very useful for builder APIs:Sets theBasicAuthCredentialsfor the Basic-Authentication credentials property.default BasicAuthCredentialsHeaderFields.putBasicAuthCredentials(String aUserName, String aSecret) Sets theBasicAuthCredentialsfrom the user name and the secret for the Basic-Authentication credentials property.default BasicAuthCredentialsHeaderFields.putBasicAuthCredentials(BasicAuthCredentials aBasicAuthCredentials) Sets theBasicAuthCredentials(user name and secret) for HTTP Basic-Authentication.default BasicAuthCredentialsHeaderFields.removeBasicAuthCredentials()Removes theBasicAuthCredentials(user name and secret) for HTTP Basic-Authentication.BasicAuthCredentials.withHttpAuthorization(String aHttpAuthorization) Initializes thisAuthTypeCredentialsinstance from theHeaderField.AUTHORIZATIONHeader-Fields's value.Methods in org.refcodes.web with parameters of type BasicAuthCredentialsModifier and TypeMethodDescriptiondefault BasicAuthCredentialsBasicAuthCredentialsAccessor.BasicAuthCredentialsProperty.letBasicAuthCredentials(BasicAuthCredentials aBasicAuthCredentials) This method stores and passes through the given argument, which is very useful for builder APIs:Sets theBasicAuthCredentialsfor the Basic-Authentication credentials property.BasicAuthObserver.onBasicAuthRequest(InetSocketAddress aLocalAddress, InetSocketAddress aRemoteAddress, HttpMethod aHttpMethod, String aLocator, BasicAuthCredentials aCredentials, String aRealm) Invoked upon an incoming HTTP Basic-Authentication requests.default BasicAuthCredentialsHeaderFields.putBasicAuthCredentials(BasicAuthCredentials aBasicAuthCredentials) Sets theBasicAuthCredentials(user name and secret) for HTTP Basic-Authentication.voidBasicAuthCredentialsAccessor.BasicAuthCredentialsMutator.setBasicAuthCredentials(BasicAuthCredentials aBasicAuthCredentials) Sets theBasicAuthCredentialsfor the Basic-Authentication credentials property.BasicAuthCredentialsAccessor.BasicAuthCredentialsBuilder.withBasicAuthCredentials(BasicAuthCredentials aBasicAuthCredentials) Sets theBasicAuthCredentialsfor the Basic-Authentication credentials property.default BHeaderFields.withBasicAuthCredentials(BasicAuthCredentials aBasicAuthCredentials) Sets theBasicAuthCredentials(user name and secret) for HTTP Basic-Authentication.Constructors in org.refcodes.web with parameters of type BasicAuthCredentialsModifierConstructorDescriptionBasicAuthRequest(HttpMethod aHttpMethod, Url aUrl, BasicAuthCredentials aCredentials) Constructs aBasicAuthRequestinstance with required attributes.