Uses of Enum Class
org.refcodes.web.BasicAuthResponse
-
Uses of BasicAuthResponse in org.refcodes.web
Methods in org.refcodes.web that return BasicAuthResponseModifier and TypeMethodDescriptionBasicAuthObserver.onBasicAuthRequest(InetSocketAddress aLocalAddress, InetSocketAddress aRemoteAddress, HttpMethod aHttpMethod, String aLocator, BasicAuthCredentials aCredentials, String aRealm) Invoked upon an incoming HTTP Basic-Authentication requests.static BasicAuthResponseReturns the enum constant of this class with the specified name.static BasicAuthResponse[]BasicAuthResponse.values()Returns an array containing the constants of this enum class, in the order they are declared.