Uses of Enum Class
org.refcodes.web.ContentEncoding
-
Uses of ContentEncoding in org.refcodes.web
Methods in org.refcodes.web that return ContentEncodingModifier and TypeMethodDescriptionstatic ContentEncodingContentEncoding.fromHttpEncoding(String aHttpEncoding) Returns thatContentEncodingrepresented by the given HTTP header's encoding.default ContentEncodingHeaderFields.getContentEncoding()Gets the Content-Encoding entity-Header-FieldHeaderField.CONTENT_ENCODING: "...default ContentEncodingHeaderFields.putContentEncoding(ContentEncoding aEncoding) Sets the Content-Encoding entity-Header-FieldHeaderField.CONTENT_ENCODING: "...default ContentEncodingHeaderFields.removeContentEncoding()Removes the Content-Encoding entity-Header-FieldHeaderField.CONTENT_ENCODING: "...static ContentEncodingReturns the enum constant of this class with the specified name.static ContentEncoding[]ContentEncoding.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in org.refcodes.web that return types with arguments of type ContentEncodingModifier and TypeMethodDescriptiondefault List<ContentEncoding>HeaderFields.getAcceptEncodings()Gets the the Content-Encoding entity-Header-FieldHeaderField.CONTENT_ENCODING: "...default List<ContentEncoding>HeaderFields.putAcceptEncodings(List<ContentEncoding> aEncodings) Sets the the Content-Encoding entity-Header-FieldHeaderField.CONTENT_ENCODING: "...default List<ContentEncoding>HeaderFields.putAcceptEncodings(ContentEncoding... aEncodings) Sets the the Content-Encoding entity-Header-FieldHeaderField.CONTENT_ENCODING: "...default List<ContentEncoding>HeaderFields.removeAcceptEncodings()Removes the the Content-Encoding entity-Header-FieldHeaderField.CONTENT_ENCODING: "...Methods in org.refcodes.web with parameters of type ContentEncodingModifier and TypeMethodDescriptiondefault List<ContentEncoding>HeaderFields.putAcceptEncodings(ContentEncoding... aEncodings) Sets the the Content-Encoding entity-Header-FieldHeaderField.CONTENT_ENCODING: "...default ContentEncodingHeaderFields.putContentEncoding(ContentEncoding aEncoding) Sets the Content-Encoding entity-Header-FieldHeaderField.CONTENT_ENCODING: "...default BHeaderFields.withAcceptEncodings(ContentEncoding... aEncodings) Sets the the Content-Encoding entity-Header-FieldHeaderField.CONTENT_ENCODING: "...default BHeaderFields.withContentEncoding(ContentEncoding aEncoding) Sets the Content-Encoding entity-Header-FieldHeaderField.CONTENT_ENCODING: "...Method parameters in org.refcodes.web with type arguments of type ContentEncodingModifier and TypeMethodDescriptiondefault List<ContentEncoding>HeaderFields.putAcceptEncodings(List<ContentEncoding> aEncodings) Sets the the Content-Encoding entity-Header-FieldHeaderField.CONTENT_ENCODING: "...default BHeaderFields.withAcceptEncodings(List<ContentEncoding> aEncodings) Sets the the Content-Encoding entity-Header-FieldHeaderField.CONTENT_ENCODING: "...