Uses of Interface
org.refcodes.web.Cookie
-
Uses of Cookie in org.refcodes.web
Classes in org.refcodes.web with type parameters of type CookieModifier and TypeClassDescriptionclassAbstractHeaderFields<C extends Cookie, T extends HeaderFields<C,T>> Abstract implementation of theHeaderFieldstype.interfaceHeaderFields<C extends Cookie, B extends HeaderFields<C,B>> TheHeaderFieldsreflect the structure of a HTTP header and may be used to represent a HTTP header.Classes in org.refcodes.web that implement CookieModifier and TypeClassDescriptionclassTheRequestCookierepresents a request cookies: We use URL encoding / decoding for the cookie value (regardingRequestCookie.fromHttpCookie(String)andRequestCookie.toHttpCookie()) to make life easier and not fall into the trap of unescaped values.classAs of "HTTP cookies explained - NCZOnline": "...Methods in org.refcodes.web that return CookieModifier and TypeMethodDescriptionCookie.withHttpCookie(String aHttpCookie) Sets the cookie according to the provided HTTP cookie text viaCookie.fromHttpCookie(String).Constructors in org.refcodes.web with parameters of type Cookie