Uses of Enum Class
org.refcodes.web.CookieAttribute
-
Uses of CookieAttribute in org.refcodes.web
Methods in org.refcodes.web that return CookieAttributeModifier and TypeMethodDescriptionstatic CookieAttributeFrom key.static CookieAttributeReturns the enum constant of this class with the specified name.static CookieAttribute[]CookieAttribute.values()Returns an array containing the constants of this enum class, in the order they are declared.