Uses of Class
org.refcodes.web.FormFields
-
Uses of FormFields in org.refcodes.web
Fields in org.refcodes.web declared as FormFieldsMethods in org.refcodes.web that return FormFieldsModifier and TypeMethodDescriptionFormFieldsAccessor.getFormFields()Retrieves the request Form-Fields from the request Form-Fields property.QueryFieldsAccessor.getQueryFields()Retrieves the request Query-Fields from the request Query-Fields property.Url.getQueryFields()Retrieves the request Query-Fields from the request Query-Fields property.default FormFieldsFormFieldsAccessor.FormFieldsProperty.letFormFields(FormFields aFormFields) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenFormFields(setter) as ofFormFieldsAccessor.FormFieldsMutator.setFormFields(FormFields)and returns the very same value (getter).default FormFieldsQueryFieldsAccessor.QueryFieldsProperty.letQueryFields(FormFields aQueryFields) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenFormFields(setter) as ofQueryFieldsAccessor.QueryFieldsMutator.setQueryFields(FormFields)and returns the very same value (getter).Methods in org.refcodes.web with parameters of type FormFieldsModifier and TypeMethodDescriptiondefault FormFieldsFormFieldsAccessor.FormFieldsProperty.letFormFields(FormFields aFormFields) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenFormFields(setter) as ofFormFieldsAccessor.FormFieldsMutator.setFormFields(FormFields)and returns the very same value (getter).default FormFieldsQueryFieldsAccessor.QueryFieldsProperty.letQueryFields(FormFields aQueryFields) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenFormFields(setter) as ofQueryFieldsAccessor.QueryFieldsMutator.setQueryFields(FormFields)and returns the very same value (getter).voidFormFieldsAccessor.FormFieldsMutator.setFormFields(FormFields aFormFields) Sets the request Form-Fields for the request Form-Fields property.voidQueryFieldsAccessor.QueryFieldsMutator.setQueryFields(FormFields aQueryFields) Sets the request Query-Fields for the request Query-Fields property.voidUrlBuilder.setQueryFields(FormFields aQueryFields) Sets the request Query-Fields for the request Query-Fields property.UrlSugar.toUrl(String aProtocol, String aHost, int aPort, String aPath, FormFields aQueryFields) Constructs anUrlBuilderwith the common attributes.UrlSugar.toUrl(String aProtocol, String aHost, int aPort, String aPath, FormFields aQueryFields, String aFragment) Constructs anUrlBuilderwith the common attributes.UrlSugar.toUrl(String aProtocol, String aHost, String aPath, FormFields aQueryFields) Constructs anUrlBuilderwith the common attributes.UrlSugar.toUrl(String aProtocol, String aHost, String aPath, FormFields aQueryFields, String aFragment) Constructs anUrlBuilderwith the common attributes.UrlSugar.toUrl(org.refcodes.data.Scheme aScheme, String aHost, int aPort, String aPath, FormFields aQueryFields) Constructs anUrlBuilderwith the common attributes.UrlSugar.toUrl(org.refcodes.data.Scheme aScheme, String aHost, int aPort, String aPath, FormFields aQueryFields, String aFragment) Constructs anUrlBuilderwith the common attributes.UrlSugar.toUrl(org.refcodes.data.Scheme aScheme, String aHost, String aPath, FormFields aQueryFields) Constructs anUrlBuilderwith the common attributes.UrlSugar.toUrl(org.refcodes.data.Scheme aScheme, String aHost, String aPath, FormFields aQueryFields, String aFragment) Constructs anUrlBuilderwith the common attributes.FormFieldsAccessor.FormFieldsBuilder.withFormFields(FormFields aFormFields) Sets the request Form-Fields to use and returns this builder as of the Builder-Pattern.QueryFieldsAccessor.QueryFieldsBuilder.withQueryFields(FormFields aQueryFields) Sets the request Query-Fields to use and returns this builder as of the Builder-Pattern.UrlBuilder.withQueryFields(FormFields aQueryFields) Sets the request Query-Fields to use and returns this builder as of the Builder-Pattern.Constructors in org.refcodes.web with parameters of type FormFieldsModifierConstructorDescriptionUrl(String aProtocol, String aHost, int aPort, String aPath, FormFields aQueryFields) Constructs anUrlwith the common attributes.Url(String aProtocol, String aHost, int aPort, String aPath, FormFields aQueryFields, String aFragment) Constructs anUrlwith the common attributes.Url(String aProtocol, String aHost, String aPath, FormFields aQueryFields) Constructs anUrlwith the common attributes.Constructs anUrlwith the common attributes.Url(String aUrl, FormFields aQueryFields) Url(String aUrl, FormFields aQueryFields, String aFragment) Url(org.refcodes.data.Scheme aScheme, String aHost, int aPort, String aPath, FormFields aQueryFields) Constructs anUrlwith the common attributes.Url(org.refcodes.data.Scheme aScheme, String aHost, int aPort, String aPath, FormFields aQueryFields, String aFragment) Constructs anUrlwith the common attributes.Url(org.refcodes.data.Scheme aScheme, String aHost, String aPath, FormFields aQueryFields) Constructs anUrlwith the common attributes.Url(org.refcodes.data.Scheme aScheme, String aHost, String aPath, FormFields aQueryFields, String aFragment) Constructs anUrlwith the common attributes.UrlBuilder(String aProtocol, String aHost, int aPort, String aPath, FormFields aQueryFields) UrlBuilder(String aProtocol, String aHost, int aPort, String aPath, FormFields aQueryFields, String aFragment) UrlBuilder(String aProtocol, String aHost, String aPath, FormFields aQueryFields) UrlBuilder(String aProtocol, String aHost, String aPath, FormFields aQueryFields, String aFragment) UrlBuilder(String aUrl, FormFields aQueryFields) UrlBuilder(String aUrl, FormFields aQueryFields, String aFragment) UrlBuilder(org.refcodes.data.Scheme aScheme, String aHost, int aPort, String aPath, FormFields aQueryFields) UrlBuilder(org.refcodes.data.Scheme aScheme, String aHost, int aPort, String aPath, FormFields aQueryFields, String aFragment) UrlBuilder(org.refcodes.data.Scheme aScheme, String aHost, String aPath, FormFields aQueryFields) UrlBuilder(org.refcodes.data.Scheme aScheme, String aHost, String aPath, FormFields aQueryFields, String aFragment)