Uses of Class
org.refcodes.web.HttpBodyMap
-
Uses of HttpBodyMap in org.refcodes.web
Methods in org.refcodes.web that return HttpBodyMapModifier and TypeMethodDescriptionHttpBodyMap.getDirAt(int aIndex) HttpServerRequest.getRequest()Retrieves theHttpBodyMaprepresenting the request body.HttpClientResponse.getResponse()Retrieves theHttpBodyMaprepresenting the response body.HttpBodyMap.putDirAt(Collection<?> aPathElements, int aIndex, Object aDir) HttpBodyMap.putDirAt(Collection<?> aPathElements, int aIndex, org.refcodes.struct.PathMap<String> aDir) HttpBodyMap.query(Collection<?> aQueryElements) HttpBodyMap.queryBetween(Object[] aFromPath, Object[] aPathQuery, Object[] aToPath) HttpBodyMap.queryBetween(Object aFromPath, Object aPathQuery, Object aToPath) HttpBodyMap.queryBetween(String[] aFromPath, String[] aPathQuery, String[] aToPath) HttpBodyMap.queryBetween(String aFromPath, String aPathQuery, String aToPath) HttpBodyMap.queryBetween(String aFromPath, Pattern aRegExp, String aToPath) HttpBodyMap.queryBetween(Collection<?> aFromPath, Collection<?> aPathQuery, Collection<?> aToPath) HttpBodyMap.queryFrom(Collection<?> aPathQuery, Collection<?> aFromPath) HttpBodyMap.queryTo(Collection<?> aPathQuery, String aToPath) HttpBodyMap.removeAll(Collection<?> aPathQueryElements) HttpBodyMap.removeDirAt(int aIndex) HttpBodyMap.removeDirAt(Object[] aPathElements, int aIndex) HttpBodyMap.removeDirAt(Object aPath, int aIndex) HttpBodyMap.removeDirAt(String[] aPathElements, int aIndex) HttpBodyMap.removeDirAt(String aPath, int aIndex) HttpBodyMap.removeFrom(Object aPath) HttpBodyMap.removeFrom(Object... aPathElements) HttpBodyMap.removeFrom(String aPath) HttpBodyMap.removeFrom(String... aPathElements) HttpBodyMap.removePaths(String... aPaths) HttpBodyMap.removePaths(Collection<?> aPaths) HttpBodyMap.retrieveBetween(Object[] aFromPath, Object[] aToPath) HttpBodyMap.retrieveBetween(Object aFromPath, Object aToPath) HttpBodyMap.retrieveBetween(String[] aFromPath, String[] aToPath) HttpBodyMap.retrieveBetween(String aFromPath, String aToPath) HttpBodyMap.retrieveBetween(Collection<?> aFromPath, Collection<?> aToPath) HttpBodyMap.retrieveFrom(Object aParentPath) HttpBodyMap.retrieveFrom(Object... aPathElements) HttpBodyMap.retrieveFrom(String aFromPath) HttpBodyMap.retrieveFrom(String... aPathElements) HttpBodyMap.retrieveFrom(Collection<?> aPathElements) HttpBodyMap.retrieveTo(Object aToPath) HttpBodyMap.retrieveTo(Object... aToPathElements) HttpBodyMap.retrieveTo(String aToPath) HttpBodyMap.retrieveTo(String... aToPathElements) HttpBodyMap.retrieveTo(Collection<?> aToPathElements) HttpBodyMap.withInsert(Object aObj) HttpBodyMap.withInsert(org.refcodes.struct.PathMap<String> aFrom) HttpBodyMap.withInsertBetween(Object[] aToPathElements, Object aFrom, Object[] aFromPathElements) HttpBodyMap.withInsertBetween(Object[] aToPathElements, org.refcodes.struct.PathMap<String> aFrom, Object[] aFromPathElements) HttpBodyMap.withInsertBetween(Object aToPath, Object aFrom, Object aFromPath) HttpBodyMap.withInsertBetween(Object aToPath, org.refcodes.struct.PathMap<String> aFrom, Object aFromPath) HttpBodyMap.withInsertBetween(String[] aToPathElements, Object aFrom, String[] aFromPathElements) HttpBodyMap.withInsertBetween(String[] aToPathElements, org.refcodes.struct.PathMap<String> aFrom, String[] aFromPathElements) HttpBodyMap.withInsertBetween(String aToPath, Object aFrom, String aFromPath) HttpBodyMap.withInsertBetween(String aToPath, org.refcodes.struct.PathMap<String> aFrom, String aFromPath) HttpBodyMap.withInsertBetween(Collection<?> aToPathElements, Object aFrom, Collection<?> aFromPathElements) HttpBodyMap.withInsertBetween(Collection<?> aToPathElements, org.refcodes.struct.PathMap<String> aFrom, Collection<?> aFromPathElements) HttpBodyMap.withInsertFrom(Object aFrom, Object aFromPath) HttpBodyMap.withInsertFrom(Object aFrom, Object... aFromPathElements) HttpBodyMap.withInsertFrom(Object aFrom, String aFromPath) HttpBodyMap.withInsertFrom(Object aFrom, String... aFromPathElements) HttpBodyMap.withInsertFrom(Object aFrom, Collection<?> aFromPathElements) HttpBodyMap.withInsertFrom(org.refcodes.struct.PathMap<String> aFrom, Object aFromPath) HttpBodyMap.withInsertFrom(org.refcodes.struct.PathMap<String> aFrom, Object... aFromPathElements) HttpBodyMap.withInsertFrom(org.refcodes.struct.PathMap<String> aFrom, String aFromPath) HttpBodyMap.withInsertFrom(org.refcodes.struct.PathMap<String> aFrom, String... aFromPathElements) HttpBodyMap.withInsertFrom(org.refcodes.struct.PathMap<String> aFrom, Collection<?> aFromPathElements) HttpBodyMap.withInsertTo(Object[] aToPathElements, Object aFrom) HttpBodyMap.withInsertTo(Object[] aToPathElements, org.refcodes.struct.PathMap<String> aFrom) HttpBodyMap.withInsertTo(Object aToPath, Object aFrom) HttpBodyMap.withInsertTo(Object aToPath, org.refcodes.struct.PathMap<String> aFrom) HttpBodyMap.withInsertTo(String[] aToPathElements, Object aFrom) HttpBodyMap.withInsertTo(String[] aToPathElements, org.refcodes.struct.PathMap<String> aFrom) HttpBodyMap.withInsertTo(String aToPath, Object aFrom) HttpBodyMap.withInsertTo(String aToPath, org.refcodes.struct.PathMap<String> aFrom) HttpBodyMap.withInsertTo(Collection<?> aToPathElements, Object aFrom) HttpBodyMap.withInsertTo(Collection<?> aToPathElements, org.refcodes.struct.PathMap<String> aFrom) HttpBodyMap.withMergeBetween(Object[] aToPathElements, Object aFrom, Object[] aFromPathElements) HttpBodyMap.withMergeBetween(Object[] aToPathElements, org.refcodes.struct.PathMap<String> aFrom, Object[] aFromPathElements) HttpBodyMap.withMergeBetween(Object aToPath, Object aFrom, Object aFromPath) HttpBodyMap.withMergeBetween(Object aToPath, org.refcodes.struct.PathMap<String> aFrom, Object aFromPath) HttpBodyMap.withMergeBetween(String[] aToPathElements, Object aFrom, String[] aFromPathElements) HttpBodyMap.withMergeBetween(String[] aToPathElements, org.refcodes.struct.PathMap<String> aFrom, String[] aFromPathElements) HttpBodyMap.withMergeBetween(String aToPath, Object aFrom, String aFromPath) HttpBodyMap.withMergeBetween(String aToPath, org.refcodes.struct.PathMap<String> aFrom, String aFromPath) HttpBodyMap.withMergeBetween(Collection<?> aToPathElements, Object aFrom, Collection<?> aFromPathElements) HttpBodyMap.withMergeBetween(Collection<?> aToPathElements, org.refcodes.struct.PathMap<String> aFrom, Collection<?> aFromPathElements) HttpBodyMap.withMergeFrom(Object aFrom, Object aFromPath) HttpBodyMap.withMergeFrom(Object aFrom, Object... aFromPathElements) HttpBodyMap.withMergeFrom(Object aFrom, String aFromPath) HttpBodyMap.withMergeFrom(Object aFrom, String... aFromPathElements) HttpBodyMap.withMergeFrom(Object aFrom, Collection<?> aFromPathElements) HttpBodyMap.withMergeFrom(org.refcodes.struct.PathMap<String> aFrom, Object aFromPath) HttpBodyMap.withMergeFrom(org.refcodes.struct.PathMap<String> aFrom, Object... aFromPathElements) HttpBodyMap.withMergeFrom(org.refcodes.struct.PathMap<String> aFrom, String aFromPath) HttpBodyMap.withMergeFrom(org.refcodes.struct.PathMap<String> aFrom, String... aFromPathElements) HttpBodyMap.withMergeFrom(org.refcodes.struct.PathMap<String> aFrom, Collection<?> aFromPathElements) HttpBodyMap.withMergeTo(Object[] aToPathElements, Object aFrom) HttpBodyMap.withMergeTo(Object[] aToPathElements, org.refcodes.struct.PathMap<String> aFrom) HttpBodyMap.withMergeTo(Object aToPath, Object aFrom) HttpBodyMap.withMergeTo(Object aToPath, org.refcodes.struct.PathMap<String> aFrom) HttpBodyMap.withMergeTo(String[] aToPathElements, Object aFrom) HttpBodyMap.withMergeTo(String[] aToPathElements, org.refcodes.struct.PathMap<String> aFrom) HttpBodyMap.withMergeTo(String aToPath, Object aFrom) HttpBodyMap.withMergeTo(String aToPath, org.refcodes.struct.PathMap<String> aFrom) HttpBodyMap.withMergeTo(Collection<?> aToPathElements, Object aFrom) HttpBodyMap.withMergeTo(Collection<?> aToPathElements, org.refcodes.struct.PathMap<String> aFrom) HttpBodyMap.withPut(Collection<?> aPathElements, String aValue) HttpBodyMap.withPut(org.refcodes.struct.Property aProperty) HttpBodyMap.withPutBoolean(Object[] aPathElements, Boolean aValue) HttpBodyMap.withPutBoolean(Object aKey, Boolean aValue) HttpBodyMap.withPutBoolean(String[] aPathElements, Boolean aValue) HttpBodyMap.withPutBoolean(String aKey, Boolean aValue) HttpBodyMap.withPutBoolean(Collection<?> aPathElements, Boolean aValue) HttpBodyMap.withPutByte(Object[] aPathElements, Byte aValue) HttpBodyMap.withPutByte(Object aKey, Byte aValue) HttpBodyMap.withPutByte(String[] aPathElements, Byte aValue) HttpBodyMap.withPutByte(String aKey, Byte aValue) HttpBodyMap.withPutByte(Collection<?> aPathElements, Byte aValue) HttpBodyMap.withPutChar(Object[] aPathElements, Character aValue) HttpBodyMap.withPutChar(Object aKey, Character aValue) HttpBodyMap.withPutChar(String[] aPathElements, Character aValue) HttpBodyMap.withPutChar(String aKey, Character aValue) HttpBodyMap.withPutChar(Collection<?> aPathElements, Character aValue) <C> HttpBodyMapHttpBodyMap.withPutClass(Object[] aPathElements, Class<C> aValue) <C> HttpBodyMapHttpBodyMap.withPutClass(Object aKey, Class<C> aValue) <C> HttpBodyMapHttpBodyMap.withPutClass(String[] aPathElements, Class<C> aValue) <C> HttpBodyMapHttpBodyMap.withPutClass(String aKey, Class<C> aValue) <C> HttpBodyMapHttpBodyMap.withPutClass(Collection<?> aPathElements, Class<C> aValue) HttpBodyMap.withPutDirAt(int aIndex, Object aDir) HttpBodyMap.withPutDirAt(int aIndex, org.refcodes.struct.PathMap<String> aDir) HttpBodyMap.withPutDirAt(Object[] aPathElements, int aIndex, Object aDir) HttpBodyMap.withPutDirAt(Object[] aPathElements, int aIndex, org.refcodes.struct.PathMap<String> aDir) HttpBodyMap.withPutDirAt(Object aPath, int aIndex, Object aDir) HttpBodyMap.withPutDirAt(Object aPath, int aIndex, org.refcodes.struct.PathMap<String> aDir) HttpBodyMap.withPutDirAt(String[] aPathElements, int aIndex, Object aDir) HttpBodyMap.withPutDirAt(String[] aPathElements, int aIndex, org.refcodes.struct.PathMap<String> aDir) HttpBodyMap.withPutDirAt(String aPath, int aIndex, Object aDir) HttpBodyMap.withPutDirAt(String aPath, int aIndex, org.refcodes.struct.PathMap<String> aDir) HttpBodyMap.withPutDirAt(Collection<?> aPathElements, int aIndex, Object aDir) HttpBodyMap.withPutDirAt(Collection<?> aPathElements, int aIndex, org.refcodes.struct.PathMap<String> aDir) HttpBodyMap.withPutDouble(Object[] aPathElements, Double aValue) HttpBodyMap.withPutDouble(Object aKey, Double aValue) HttpBodyMap.withPutDouble(String[] aPathElements, Double aValue) HttpBodyMap.withPutDouble(String aKey, Double aValue) HttpBodyMap.withPutDouble(Collection<?> aPathElements, Double aValue) <E extends Enum<E>>
HttpBodyMapHttpBodyMap.withPutEnum(Object[] aPathElements, E aValue) <E extends Enum<E>>
HttpBodyMapHttpBodyMap.withPutEnum(Object aKey, E aValue) <E extends Enum<E>>
HttpBodyMapHttpBodyMap.withPutEnum(String[] aPathElements, E aValue) <E extends Enum<E>>
HttpBodyMapHttpBodyMap.withPutEnum(String aKey, E aValue) <E extends Enum<E>>
HttpBodyMapHttpBodyMap.withPutEnum(Collection<?> aPathElements, E aValue) HttpBodyMap.withPutFloat(Object[] aPathElements, Float aValue) HttpBodyMap.withPutFloat(Object aKey, Float aValue) HttpBodyMap.withPutFloat(String[] aPathElements, Float aValue) HttpBodyMap.withPutFloat(String aKey, Float aValue) HttpBodyMap.withPutFloat(Collection<?> aPathElements, Float aValue) HttpBodyMap.withPutInt(Object[] aPathElements, Integer aValue) HttpBodyMap.withPutInt(Object aKey, Integer aValue) HttpBodyMap.withPutInt(String[] aPathElements, Integer aValue) HttpBodyMap.withPutInt(String aKey, Integer aValue) HttpBodyMap.withPutInt(Collection<?> aPathElements, Integer aValue) HttpBodyMap.withPutLong(Object[] aPathElements, Long aValue) HttpBodyMap.withPutLong(Object aKey, Long aValue) HttpBodyMap.withPutLong(String[] aPathElements, Long aValue) HttpBodyMap.withPutLong(String aKey, Long aValue) HttpBodyMap.withPutLong(Collection<?> aPathElements, Long aValue) HttpBodyMap.withPutShort(Object[] aPathElements, Short aValue) HttpBodyMap.withPutShort(Object aKey, Short aValue) HttpBodyMap.withPutShort(String[] aPathElements, Short aValue) HttpBodyMap.withPutShort(String aKey, Short aValue) HttpBodyMap.withPutShort(Collection<?> aPathElements, Short aValue) HttpBodyMap.withPutStatusAlias(String aStatusAlias) Puts a public path's ("status/alias") status alias.HttpBodyMap.withPutStatusAlias(HttpStatusCode aStatusCode) Puts a public path's ("status/alias") status alias.HttpBodyMap.withPutStatusCode(int aStatusCode) Puts a public path's ("status/code") status code.HttpBodyMap.withPutStatusCode(HttpStatusCode aStatusCode) Puts a public path's ("status/code") status code.HttpBodyMap.withPutString(Object[] aPathElements, String aValue) HttpBodyMap.withPutString(Object aKey, String aValue) HttpBodyMap.withPutString(String[] aPathElements, String aValue) HttpBodyMap.withPutString(String aKey, String aValue) HttpBodyMap.withPutString(Collection<?> aPathElements, String aValue) HttpBodyMap.withRemoveFrom(Object aPath) HttpBodyMap.withRemoveFrom(Object... aPathElements) HttpBodyMap.withRemoveFrom(String aPath) HttpBodyMap.withRemoveFrom(String... aPathElements) HttpBodyMap.withRemoveFrom(Collection<?> aPathElements) HttpBodyMap.withRemovePaths(String... aPathElements) Methods in org.refcodes.web with parameters of type HttpBodyMapModifier and TypeMethodDescriptionprotected voidOauthToken.fromHttpBodyMap(HttpBodyMap aOauthToken) Sets the internal fields with the data from theHttpBodyMapas of theOauthFielddefinitions.Constructors in org.refcodes.web with parameters of type HttpBodyMapModifierConstructorDescriptionOauthToken(HttpBodyMap aOauthToken) Creates a new instance of theOauthTokenwith the current time being stored for determining validity of the access token viaOauthToken.isValid()as ofOauthToken.getExpiresIn().