Uses of Enum Class
org.refcodes.web.HttpMethod
-
Uses of HttpMethod in org.refcodes.web
Fields in org.refcodes.web declared as HttpMethodMethods in org.refcodes.web that return HttpMethodModifier and TypeMethodDescriptionstatic HttpMethodHttpMethod.fromHttpMethod(String aHttpMethod) From http method.AbstractHttpRequest.getHttpMethod()Retrieves the HTTP-Method from the HTTP-Method property.BasicAuthRequest.getHttpMethod()Retrieves the HTTP-Method from the HTTP-Method property.HttpMethodAccessor.getHttpMethod()Retrieves the HTTP-Method from the HTTP-Method property.default HttpMethodHttpMethodAccessor.HttpMethodProperty.letHttpMethod(HttpMethod aHttpMethod) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenHttpMethod(setter) as ofHttpMethodAccessor.HttpMethodMutator.setHttpMethod(HttpMethod)and returns the very same value (getter).static HttpMethodReturns the enum constant of this class with the specified name.static HttpMethod[]HttpMethod.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in org.refcodes.web that return types with arguments of type HttpMethodModifier and TypeMethodDescriptiondefault List<HttpMethod> HeaderFields.getAllowMethods()Gets the Allow entity-Header-FieldHeaderField.ALLOW: "...default List<HttpMethod> HeaderFields.putAllowMethods(List<HttpMethod> aHttpMethods) Sets the Allow entity-Header-FieldHeaderField.ALLOW: "...default List<HttpMethod> HeaderFields.putAllowMethods(HttpMethod... aHttpMethods) Sets the Allow entity-Header-FieldHeaderField.ALLOW: "...default List<HttpMethod> HeaderFields.removeAllowMethods()Removes the Allow entity-Header-FieldHeaderField.ALLOW: "...Methods in org.refcodes.web with parameters of type HttpMethodModifier and TypeMethodDescriptiondefault HttpMethodHttpMethodAccessor.HttpMethodProperty.letHttpMethod(HttpMethod aHttpMethod) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenHttpMethod(setter) as ofHttpMethodAccessor.HttpMethodMutator.setHttpMethod(HttpMethod)and returns the very same value (getter).BasicAuthObserver.onBasicAuthRequest(InetSocketAddress aLocalAddress, InetSocketAddress aRemoteAddress, HttpMethod aHttpMethod, String aLocator, BasicAuthCredentials aCredentials, String aRealm) Invoked upon an incoming HTTP Basic-Authentication requests.default List<HttpMethod> HeaderFields.putAllowMethods(HttpMethod... aHttpMethods) Sets the Allow entity-Header-FieldHeaderField.ALLOW: "...voidHttpMethodAccessor.HttpMethodMutator.setHttpMethod(HttpMethod aHttpMethod) Sets the HTTP-Method for the HTTP-Method property.default BHeaderFields.withAllowMethods(HttpMethod... aHttpMethods) Sets the Allow entity-Header-FieldHeaderField.ALLOW: "...HttpMethodAccessor.HttpMethodBuilder.withHttpMethod(HttpMethod aHttpMethod) Sets the HTTP-Method for the HTTP-Method property.Method parameters in org.refcodes.web with type arguments of type HttpMethodModifier and TypeMethodDescriptiondefault List<HttpMethod> HeaderFields.putAllowMethods(List<HttpMethod> aHttpMethods) Sets the Allow entity-Header-FieldHeaderField.ALLOW: "...default BHeaderFields.withAllowMethods(List<HttpMethod> aHttpMethods) Sets the Allow entity-Header-FieldHeaderField.ALLOW: "...Constructors in org.refcodes.web with parameters of type HttpMethodModifierConstructorDescriptionAbstractHttpRequest(HttpMethod aHttpMethod, Url aUrl) Constructs aHttpRequestwith all required attributes.AbstractHttpRequest(HttpMethod aHttpMethod, Url aUrl, RequestHeaderFields aHeaderFields) Constructs aHttpRequestwith all required attributes.BasicAuthRequest(HttpMethod aHttpMethod, Url aUrl, BasicAuthCredentials aCredentials) Constructs aBasicAuthRequestinstance with required attributes.HttpClientRequest(HttpMethod aHttpMethod, Url aUrl, int aRedirectDepth, MediaTypeFactoryLookup aMediaTypeFactoryLookup) Instantiates a new http client request impl.HttpClientRequest(HttpMethod aHttpMethod, Url aUrl, Object aRequest, int aRedirectDepth, MediaTypeFactoryLookup aMediaTypeFactoryLookup) Instantiates a new http client request impl.HttpClientRequest(HttpMethod aHttpMethod, Url aUrl, Object aRequest, MediaTypeFactoryLookup aMediaTypeFactoryLookup) Instantiates a new http client request impl.HttpClientRequest(HttpMethod aHttpMethod, Url aUrl, MediaTypeFactoryLookup aMediaTypeFactoryLookup) Instantiates a new http client request impl.HttpClientRequest(HttpMethod aHttpMethod, Url aUrl, RequestHeaderFields aHeaderFields, Object aRequest, int aRedirectDepth, MediaTypeFactoryLookup aMediaTypeFactoryLookup) Instantiates a new http client request impl.HttpClientRequest(HttpMethod aHttpMethod, Url aUrl, RequestHeaderFields aHeaderFields, Object aRequest, MediaTypeFactoryLookup aMediaTypeFactoryLookup) Instantiates a new http client request impl.HttpServerRequest(HttpMethod aHttpMethod, Url aUrl, RequestHeaderFields aHeaderFields, InputStream aHttpInputStream, MediaTypeFactoryLookup aMediaTypeFactoryLookup) Constructs aHttpServerRequestwith all required attributes.