Uses of Class
org.refcodes.web.HttpResponseException
-
Uses of HttpResponseException in org.refcodes.web
Subclasses of HttpResponseException in org.refcodes.webModifier and TypeClassDescriptionclassProprietary code and only used inside a REFCODES.ORG client not trespassing any networking border (the error is generated by the client for the client locally).classProprietary code and only used inside a REFCODES.ORG client not trespassing any networking border (the error is generated by the client for the client locally).