Uses of Class
org.refcodes.web.HttpResponseRuntimeException
-
-
Uses of HttpResponseRuntimeException in org.refcodes.web
Subclasses of HttpResponseRuntimeException in org.refcodes.web Modifier and Type Class Description classBadInvocationRuntimeExceptionProprietary code and only used inside a REFCODES.ORG client not trespassing any networking border (the error is generated by the client for the client locally).classBadResponseRuntimeExceptionProprietary code and only used inside a REFCODES.ORG client not trespassing any networking border (the error is generated by the client for the client locally).
-