Uses of Enum Class
org.refcodes.web.HttpStatusCode
-
Uses of HttpStatusCode in org.refcodes.web
Subclasses with type arguments of type HttpStatusCode in org.refcodes.webModifier and TypeClassDescriptionenumThe org.apache.commons.httpclient.HttpStatus constants as enumeration.Fields in org.refcodes.web declared as HttpStatusCodeModifier and TypeFieldDescriptionprotected HttpStatusCodeAbstractHttpResponse._httpStatusCodeprotected HttpStatusCodeHttpStatusException._httpStatusCodeMethods in org.refcodes.web that return HttpStatusCodeModifier and TypeMethodDescriptionAbstractHttpResponse.getHttpStatusCode()Retrieves the HTTP Status-Code from the HTTP Status-Code property.HttpStatusCodeAccessor.getHttpStatusCode()Retrieves the HTTP Status-Code from the HTTP Status-Code property.HttpStatusException.getHttpStatusCode()Retrieves the HTTP Status-Code from the HTTP Status-Code property.HttpBodyTable.getStatusCode()Retrieves the public path's ("status/code") status code.default HttpStatusCodeHttpStatusCodeAccessor.HttpStatusCodeProperty.letHttpStatusCode(HttpStatusCode aHttpStatusCode) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenHttpStatusCode(setter) as ofHttpStatusCodeAccessor.HttpStatusCodeMutator.setHttpStatusCode(HttpStatusCode)and returns the very same value (getter).static HttpStatusCodeHttpStatusCode.toHttpStatusCode(int aHttpStatusCode) Determines the HTTP success code from the given value by evaluating theHttpStatusCode.getStatusCode()property.static HttpStatusCodeHttpStatusCode.toHttpStatusCode(StatusCodeAccessor<Integer> aHttpStatusCode) Determines the HTTP success code from the given HTTP Status-Code property by evaluating theHttpStatusCode.getStatusCode()property.static HttpStatusCodeReturns the enum constant of this class with the specified name.static HttpStatusCode[]HttpStatusCode.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in org.refcodes.web with parameters of type HttpStatusCodeModifier and TypeMethodDescriptiondefault HttpStatusCodeHttpStatusCodeAccessor.HttpStatusCodeProperty.letHttpStatusCode(HttpStatusCode aHttpStatusCode) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenHttpStatusCode(setter) as ofHttpStatusCodeAccessor.HttpStatusCodeMutator.setHttpStatusCode(HttpStatusCode)and returns the very same value (getter).HttpBodyTable.putStatusAlias(HttpStatusCode aStatusCode) Puts a public path's ("status/alias") status alias.HttpBodyTable.putStatusCode(HttpStatusCode aStatusCode) Puts a public path's ("status/code") status code.voidHttpServerResponse.setHttpStatusCode(HttpStatusCode aStatusCode) Sets the HTTP Status-Code for the HTTP Status-Code property.voidHttpStatusCodeAccessor.HttpStatusCodeMutator.setHttpStatusCode(HttpStatusCode aStatusCode) Sets the HTTP Status-Code for the HTTP Status-Code property.HttpServerResponse.withHttpStatusCode(HttpStatusCode aStatusCode) Sets the HTTP Status-Code for the HTTP Status-Code property.HttpStatusCodeAccessor.HttpStatusCodeBuilder.withHttpStatusCode(HttpStatusCode aStatusCode) Sets the HTTP Status-Code for the HTTP Status-Code property.HttpBodyTable.withPutStatusAlias(HttpStatusCode aStatusCode) Puts a public path's ("status/alias") status alias.HttpBodyTable.withPutStatusCode(HttpStatusCode aStatusCode) Puts a public path's ("status/code") status code.Constructors in org.refcodes.web with parameters of type HttpStatusCodeModifierConstructorDescriptionAbstractHttpResponse(HttpStatusCode aHttpStatusCode) Constructs aHttpResponsewith all required attributes.AbstractHttpResponse(HttpStatusCode aHttpStatusCode, ResponseHeaderFields aHeaderFields) Constructs aHttpResponsewith all required attributes.HttpClientResponse(Url aUrl, HttpStatusCode aHttpStatusCode, ResponseHeaderFields aHeaderFields, InputStream aHttpInputStream, MediaTypeFactoryLookup aMediaTypeFactoryLookup) Instantiates the classHttpClientResponse.HttpResponseException(HttpStatusCode aStatusCode, String aMessage) Instantiates the classHttpResponseException.HttpResponseException(HttpStatusCode aStatusCode, String aMessage, String aErrorCode) Instantiates the classHttpResponseException.HttpResponseException(HttpStatusCode aStatusCode, String aMessage, Throwable aCause) Instantiates the classHttpResponseException.HttpResponseException(HttpStatusCode aStatusCode, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classHttpResponseException.HttpResponseException(HttpStatusCode aStatusCode, Throwable aCause) Instantiates the classHttpResponseException.HttpResponseException(HttpStatusCode aStatusCode, Throwable aCause, String aErrorCode) Instantiates the classHttpResponseException.HttpResponseException(HttpStatusCode aStatusCode, Url aUrl, String aMessage) Instantiates the classHttpResponseException.HttpResponseException(HttpStatusCode aStatusCode, Url aUrl, String aMessage, String aErrorCode) Instantiates the classHttpResponseException.HttpResponseException(HttpStatusCode aStatusCode, Url aUrl, String aMessage, Throwable aCause) Instantiates the classHttpResponseException.HttpResponseException(HttpStatusCode aStatusCode, Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classHttpResponseException.HttpResponseException(HttpStatusCode aStatusCode, Url aUrl, Throwable aCause) Instantiates the classHttpResponseException.HttpResponseException(HttpStatusCode aStatusCode, Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classHttpResponseException.HttpServerResponse(HttpStatusCode aHttpStatusCode, MediaTypeFactoryLookup aMediaTypeFactoryLookup) Instantiates the classHttpServerResponse.HttpStatusException(HttpStatusCode aStatusCode, String aMessage) Instantiates the classHttpStatusException.HttpStatusException(HttpStatusCode aStatusCode, String aMessage, String aErrorCode) Instantiates the classHttpStatusException.HttpStatusException(HttpStatusCode aStatusCode, String aMessage, Throwable aCause) Instantiates the classHttpStatusException.HttpStatusException(HttpStatusCode aStatusCode, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classHttpStatusException.HttpStatusException(HttpStatusCode aStatusCode, Throwable aCause) Instantiates the classHttpStatusException.HttpStatusException(HttpStatusCode aStatusCode, Throwable aCause, String aErrorCode) Instantiates the classHttpStatusException.HttpStatusException(HttpStatusCode aStatusCode, Url aUrl, String aMessage) Instantiates the classHttpStatusException.HttpStatusException(HttpStatusCode aStatusCode, Url aUrl, String aMessage, String aErrorCode) Instantiates the classHttpStatusException.HttpStatusException(HttpStatusCode aStatusCode, Url aUrl, String aMessage, Throwable aCause) Instantiates the classHttpStatusException.HttpStatusException(HttpStatusCode aStatusCode, Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classHttpStatusException.HttpStatusException(HttpStatusCode aStatusCode, Url aUrl, Throwable aCause) Instantiates the classHttpStatusException.HttpStatusException(HttpStatusCode aStatusCode, Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classHttpStatusException.