Uses of Class
org.refcodes.web.IpAddress
-
-
Uses of IpAddress in org.refcodes.web
Methods in org.refcodes.web that return IpAddress Modifier and Type Method Description static IpAddressIpAddress. valueOf(String name)Returns the enum constant of this type with the specified name.static IpAddress[]IpAddress. values()Returns an array containing the constants of this enum type, in the order they are declared.
-