Uses of Enum Class
org.refcodes.web.LinkRelation
-
Uses of LinkRelation in org.refcodes.web
Subclasses with type arguments of type LinkRelation in org.refcodes.webModifier and TypeClassDescriptionenumRepresents a link relation describing the semantic relationship between resources.Methods in org.refcodes.web that return LinkRelationModifier and TypeMethodDescriptionstatic LinkRelationLinkRelation.fromString(String aName) Determine theLinkRelationrepresented by the given name.static LinkRelationReturns the enum constant of this class with the specified name.static LinkRelation[]LinkRelation.values()Returns an array containing the constants of this enum class, in the order they are declared.