Uses of Class
org.refcodes.web.OauthToken
-
Uses of OauthToken in org.refcodes.web
Methods in org.refcodes.web that return OauthTokenModifier and TypeMethodDescriptionOauthTokenAccessor.getOauthToken()Retrieves the OAuth token from the OAuth token propertydefault OauthTokenOauthTokenAccessor.OauthTokenProperty.letOauthToken(OauthToken aOauthToken) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenOauthToken(setter) as ofOauthTokenAccessor.OauthTokenMutator.setOauthToken(OauthToken)and returns the very same value (getter).Methods in org.refcodes.web with parameters of type OauthTokenModifier and TypeMethodDescriptiondefault OauthTokenOauthTokenAccessor.OauthTokenProperty.letOauthToken(OauthToken aOauthToken) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenOauthToken(setter) as ofOauthTokenAccessor.OauthTokenMutator.setOauthToken(OauthToken)and returns the very same value (getter).voidOauthTokenAccessor.OauthTokenMutator.setOauthToken(OauthToken aOauthToken) Sets the OAuth token for the OAuth token property.OauthTokenAccessor.OauthTokenBuilder.withOAuthToken(OauthToken aOauthToken) Sets the OAuth token for the OAuth token propertyConstructors in org.refcodes.web with parameters of type OauthTokenModifierConstructorDescriptionOauthToken(OauthToken aOauthToken) Creates a new instance of theOauthTokenwith the current time being stored for determining validity of the access token viaisValid()as ofgetExpiresIn().