Uses of Class
org.refcodes.web.PortNotFoundRuntimeException
-
-
Uses of PortNotFoundRuntimeException in org.refcodes.web
Subclasses of PortNotFoundRuntimeException in org.refcodes.web Modifier and Type Class Description classPortAlreadyBoundRuntimeExceptionThrown in case the given portPortAlreadyBoundRuntimeException.getPort()is already in use.Methods in org.refcodes.web that throw PortNotFoundRuntimeException Modifier and Type Method Description IntegerPortManager. bindAnyPort()Any free port in the range as defined byPortRange.DYNAMIC_PORTSis bound (reserved) and returned.IntegerPortManagerImpl. bindAnyPort()Any free port in the range as defined byPortRange.DYNAMIC_PORTSis bound (reserved) and returned.default IntegerPortManager. bindNextPort(int aBeginPortIndex)The first free port in the range of the given Port-Number and thePortRange.DYNAMIC_PORTSmax port number (as ofPortRange.getMaxValue()) bound (reserved) and returned.IntegerPortManager. bindNextPort(int aBeginPortIndex, int aEndPortIndex)The first free port in the range of the given begin Port-Number index and the given end Port-Number index is bound (reserved) and returned.IntegerPortManagerImpl. bindNextPort(int aBeginPortIndex, int aEndPortIndex)The first free port in the range of the given begin Port-Number index and the given end Port-Number index is bound (reserved) and returned.
-