Uses of Class
org.refcodes.web.PortRange
-
-
Uses of PortRange in org.refcodes.web
Methods in org.refcodes.web that return PortRange Modifier and Type Method Description static PortRangePortRange. valueOf(String name)Returns the enum constant of this type with the specified name.static PortRange[]PortRange. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in org.refcodes.web with parameters of type PortRange Modifier and Type Method Description default IntegerPortManager. bindNextPort(PortRange aPortRange)The first free port in the range of the given begin Port-Number index and the given end Port-Number index is bound (reserved) and returned.
-