JavaScript is disabled on your browser.
Skip navigation links
Module
Class
Use
Tree
Index
Search
Help
org.refcodes.web
org.refcodes.web
Proxy
Uses of Enum Class
org.refcodes.web.Proxy
Uses of
Proxy
in
org.refcodes.web
Subclasses with type arguments of type
Proxy
in
org.refcodes.web
Modifier and Type
Class
Description
enum
Proxy
The Enum Proxy.
Methods in
org.refcodes.web
that return
Proxy
Modifier and Type
Method
Description
static
Proxy
Proxy.
valueOf
(
String
name)
Returns the enum constant of this class with the specified name.
static
Proxy
[]
Proxy.
values
()
Returns an array containing the constants of this enum class, in the order they are declared.