Uses of Class
org.refcodes.web.RequestCookie
-
Uses of RequestCookie in org.refcodes.web
Subclasses with type arguments of type RequestCookie in org.refcodes.webModifier and TypeClassDescriptionclassTheRequestHeaderFieldsreflect the structure of a HTTP-Header and may be used to represent a HTTP-Header.Methods in org.refcodes.web that return RequestCookieModifier and TypeMethodDescriptionAdds an individual server-side cookie to be sent to the client to thisResponseHeaderFieldsinstance.protected RequestCookieRequestHeaderFields.createCookie(String aHttpCookie) protected RequestCookieRequestHeaderFields.createCookie(String aCookieName, String aValue) Creates a plainCookiewith the given name and value.RequestCookie.withHttpCookie(String aCookie) Sets the cookie according to the provided HTTP cookie text viaCookie.fromHttpCookie(String).