Uses of Class
org.refcodes.web.ResponseCookie
-
Uses of ResponseCookie in org.refcodes.web
Subclasses with type arguments of type ResponseCookie in org.refcodes.webModifier and TypeClassDescriptionclassTheResponseHeaderFieldsreflect the structure of a HTTP header and may be used to represent a HTTP header.Classes in org.refcodes.web that implement interfaces with type arguments of type ResponseCookieModifier and TypeClassDescriptionclassAs of "HTTP cookies explained - NCZOnline": "...classAs of "HTTP cookies explained - NCZOnline": "...Methods in org.refcodes.web that return ResponseCookieModifier and TypeMethodDescriptionAdds an individual server-side cookie to be sent to the client to thisResponseHeaderFieldsinstance.protected ResponseCookieResponseHeaderFields.createCookie(String aHttpCookie) protected ResponseCookieResponseHeaderFields.createCookie(String aCookieName, String aValue) Creates a plainCookiewith the given name and value.ResponseCookie.withDomain(String aDomain) Sets the domain for this cookie.ResponseCookie.withExpiresAfter(TimeUnit aTimeUnit, long aTime) Builder method for the methodResponseCookie.setExpiresAfter(TimeUnit, long).ResponseCookie.withExpiresDate(Date aExpiresDate) Sets the expiration date of this cookie and returns this instance as of the Builder-Pattern.ResponseCookie.withHttpCookie(String aCookie) Sets the cookie according to the provided HTTP cookie text viaCookie.fromHttpCookie(String).ResponseCookie.withHttpOnly(boolean isHttpOnly) Sets whether it be an HTTP only cookie.ResponseCookie.withMaxAge(int aMaxAge) Builder method forResponseCookie.setMaxAge(int).Sets the path of the cookie.ResponseCookie.withSecure(boolean isSecure) Sets whether it be a secure HTTP cookie.ResponseCookie.withVersion(String aVersion) Builder method forResponseCookie.setVersion(String).Methods in org.refcodes.web with parameters of type ResponseCookieModifier and TypeMethodDescriptionResponseHeaderFields.withAddCookie(ResponseCookie aCookie) Builder method for theHeaderFields.addCookie(Cookie)method.