Uses of Enum Class
org.refcodes.web.TransportLayerProtocol
-
Uses of TransportLayerProtocol in org.refcodes.web
Subclasses with type arguments of type TransportLayerProtocol in org.refcodes.webModifier and TypeClassDescriptionenumTransport Layer Security Protocols (TLS-Protocols) known by the herein contained libraries.Methods in org.refcodes.web that return TransportLayerProtocolModifier and TypeMethodDescriptionstatic TransportLayerProtocolReturns the enum constant of this class with the specified name.static TransportLayerProtocol[]TransportLayerProtocol.values()Returns an array containing the constants of this enum class, in the order they are declared.