Uses of Class
org.refcodes.web.Url
-
Uses of Url in org.refcodes.web
Subclasses of Url in org.refcodes.webModifier and TypeClassDescriptionclassTheUrlBuilderextends an immutableUrlwith mutable functionality.Fields in org.refcodes.web declared as UrlMethods in org.refcodes.web that return UrlModifier and TypeMethodDescriptionBaseUrlAccessor.getBaseUrl()Retrieves the base URL (protocol, host, port, locator) from the base URL (protocol, host, port, locator) property.AbstractHttpRequest.getUrl()BasicAuthRequest.getUrl()HttpClientResponse.getUrl()HttpStatusException.getUrl()UrlAccessor.getUrl()default UrlBaseUrlAccessor.BaseUrlProperty.letBaseUrl(String aProtocol, String aHost) This method stores and passes through (being produced to anURL) the given arguments, which is very useful for builder APIs.default UrlBaseUrlAccessor.BaseUrlProperty.letBaseUrl(String aProtocol, String aHost, int aPort) This method stores and passes through (being produced to anURL) the given arguments, which is very useful for builder APIs.default UrlBaseUrlAccessor.BaseUrlProperty.letBaseUrl(String aProtocol, String aHost, int aPort, String aPath) This method stores and passes through (being produced to anURL) the given arguments, which is very useful for builder APIs.default UrlBaseUrlAccessor.BaseUrlProperty.letBaseUrl(String aProtocol, String aHost, String aPath) This method stores and passes through (being produced to anURL) the given arguments, which is very useful for builder APIs.default UrlBaseUrlAccessor.BaseUrlProperty.letBaseUrl(Scheme aScheme, String aHost) This method stores and passes through (being produced to anUrl) the given arguments, which is very useful for builder APIs.default UrlBaseUrlAccessor.BaseUrlProperty.letBaseUrl(Scheme aScheme, String aHost, int aPort) This method stores and passes through (being produced to anUrl) the given arguments, which is very useful for builder APIs.default UrlBaseUrlAccessor.BaseUrlProperty.letBaseUrl(Scheme aScheme, String aHost, int aPort, String aPath) This method stores and passes through (being produced to anURL) the given arguments, which is very useful for builder APIs.default UrlBaseUrlAccessor.BaseUrlProperty.letBaseUrl(Scheme aScheme, String aHost, String aPath) This method stores and passes through (being produced to anUrl) the given arguments, which is very useful for builder APIs.default UrlBaseUrlAccessor.BaseUrlProperty.letBaseUrl(Url aBaseUrl) This method stores and passes through the given argument, which is very useful for builder APIs.default UrlThis method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenUrl(setter) as ofUrlAccessor.UrlMutator.setUrl(Url)and returns the very same value (getter).Methods in org.refcodes.web with parameters of type UrlModifier and TypeMethodDescriptiondefault UrlBaseUrlAccessor.BaseUrlProperty.letBaseUrl(Url aBaseUrl) This method stores and passes through the given argument, which is very useful for builder APIs.default UrlThis method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenUrl(setter) as ofUrlAccessor.UrlMutator.setUrl(Url)and returns the very same value (getter).voidBaseUrlAccessor.BaseUrlMutator.setBaseUrl(Url aBaseUrl) Sets the baseUrl(protocol, host, port, path) for the base URL (protocol, host, port, path) property.voidSets the Url for theUrlproperty.BaseUrlAccessor.BaseUrlBuilder.withBaseUrl(Url aBaseUrl) Sets the baseUrl(protocol, host, port, path) for the base URL (protocol, host, port, path) property.Sets the Url for theUrlproperty.Constructors in org.refcodes.web with parameters of type UrlModifierConstructorDescriptionAbstractHttpRequest(HttpMethod aHttpMethod, Url aUrl) Constructs aHttpRequestwith all required attributes.AbstractHttpRequest(HttpMethod aHttpMethod, Url aUrl, RequestHeaderFields aHeaderFields) Constructs aHttpRequestwith all required attributes.BadGatewayException(Url aUrl, String aMessage) Instantiates the classBadGatewayException.BadGatewayException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classBadGatewayException.BadGatewayException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classBadGatewayException.BadGatewayException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classBadGatewayException.BadGatewayException(Url aUrl, Throwable aCause) Instantiates the classBadGatewayException.BadGatewayException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classBadGatewayException.BadInvocationException(Url aUrl, String aMessage) Instantiates the classBadInvocationException.BadInvocationException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classBadInvocationException.BadInvocationException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classBadInvocationException.BadInvocationException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classBadInvocationException.BadInvocationException(Url aUrl, Throwable aCause) Instantiates the classBadInvocationException.BadInvocationException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classBadInvocationException.BadRequestException(Url aUrl, String aMessage) Instantiates the classBadRequestException.BadRequestException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classBadRequestException.BadRequestException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classBadRequestException.BadRequestException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classBadRequestException.BadRequestException(Url aUrl, Throwable aCause) Instantiates the classBadRequestException.BadRequestException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classBadRequestException.BadResponseException(Url aUrl, String aMessage) Instantiates the classBadResponseException.BadResponseException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classBadResponseException.BadResponseException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classBadResponseException.BadResponseException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classBadResponseException.BadResponseException(Url aUrl, Throwable aCause) Instantiates the classBadResponseException.BadResponseException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classBadResponseException.BasicAuthFailureException(Url aUrl, String aMessage) Instantiates the classBasicAuthFailureException.BasicAuthFailureException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classBasicAuthFailureException.BasicAuthFailureException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classBasicAuthFailureException.BasicAuthFailureException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classBasicAuthFailureException.BasicAuthFailureException(Url aUrl, Throwable aCause) Instantiates the classBasicAuthFailureException.BasicAuthFailureException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classBasicAuthFailureException.BasicAuthRequest(HttpMethod aHttpMethod, Url aUrl, BasicAuthCredentials aCredentials) Constructs aBasicAuthRequestinstance with required attributes.BasicAuthRequiredException(Url aUrl, String aMessage) Instantiates the classBasicAuthRequiredException.BasicAuthRequiredException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classBasicAuthRequiredException.BasicAuthRequiredException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classBasicAuthRequiredException.BasicAuthRequiredException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classBasicAuthRequiredException.BasicAuthRequiredException(Url aUrl, Throwable aCause) Instantiates the classBasicAuthRequiredException.BasicAuthRequiredException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classBasicAuthRequiredException.ConflictException(Url aUrl, String aMessage) Instantiates the classConflictException.ConflictException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classConflictException.ConflictException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classConflictException.ConflictException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classConflictException.ConflictException(Url aUrl, Throwable aCause) Instantiates the classConflictException.ConflictException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classConflictException.ExpectationFailedException(Url aUrl, String aMessage) Instantiates the classExpectationFailedException.ExpectationFailedException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classExpectationFailedException.ExpectationFailedException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classExpectationFailedException.ExpectationFailedException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classExpectationFailedException.ExpectationFailedException(Url aUrl, Throwable aCause) Instantiates the classExpectationFailedException.ExpectationFailedException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classExpectationFailedException.FailedDependencyException(Url aUrl, String aMessage) Instantiates the classFailedDependencyException.FailedDependencyException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classFailedDependencyException.FailedDependencyException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classFailedDependencyException.FailedDependencyException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classFailedDependencyException.FailedDependencyException(Url aUrl, Throwable aCause) Instantiates the classFailedDependencyException.FailedDependencyException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classFailedDependencyException.ForbiddenException(Url aUrl, String aMessage) Instantiates the classForbiddenException.ForbiddenException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classForbiddenException.ForbiddenException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classForbiddenException.ForbiddenException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classForbiddenException.ForbiddenException(Url aUrl, Throwable aCause) Instantiates the classForbiddenException.ForbiddenException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classForbiddenException.GatewayTimeoutException(Url aUrl, String aMessage) Instantiates the classGatewayTimeoutException.GatewayTimeoutException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classGatewayTimeoutException.GatewayTimeoutException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classGatewayTimeoutException.GatewayTimeoutException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classGatewayTimeoutException.GatewayTimeoutException(Url aUrl, Throwable aCause) Instantiates the classGatewayTimeoutException.GatewayTimeoutException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classGatewayTimeoutException.GoneException(Url aUrl, String aMessage) Instantiates the classGoneException.GoneException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classGoneException.GoneException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classGoneException.GoneException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classGoneException.GoneException(Url aUrl, Throwable aCause) Instantiates the classGoneException.GoneException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classGoneException.HttpClientRequest(HttpMethod aHttpMethod, Url aUrl, int aRedirectDepth, MediaTypeFactoryLookup aMediaTypeFactoryLookup) Instantiates a new http client request impl.HttpClientRequest(HttpMethod aHttpMethod, Url aUrl, Object aRequest, int aRedirectDepth, MediaTypeFactoryLookup aMediaTypeFactoryLookup) Instantiates a new http client request impl.HttpClientRequest(HttpMethod aHttpMethod, Url aUrl, Object aRequest, MediaTypeFactoryLookup aMediaTypeFactoryLookup) Instantiates a new http client request impl.HttpClientRequest(HttpMethod aHttpMethod, Url aUrl, MediaTypeFactoryLookup aMediaTypeFactoryLookup) Instantiates a new http client request impl.HttpClientRequest(HttpMethod aHttpMethod, Url aUrl, RequestHeaderFields aHeaderFields, Object aRequest, int aRedirectDepth, MediaTypeFactoryLookup aMediaTypeFactoryLookup) Instantiates the classHttpClientRequest.HttpClientRequest(HttpMethod aHttpMethod, Url aUrl, RequestHeaderFields aHeaderFields, Object aRequest, MediaTypeFactoryLookup aMediaTypeFactoryLookup) Instantiates a new http client request impl.HttpClientResponse(Url aUrl, HttpStatusCode aHttpStatusCode, ResponseHeaderFields aHeaderFields, InputStream aHttpInputStream, MediaTypeFactoryLookup aMediaTypeFactoryLookup) Instantiates the classHttpClientResponse.HttpClientResponse(Url aUrl, ResponseHeaderFields aHeaderFields, MediaTypeFactoryLookup aMediaTypeFactoryLookup) Constructs aHttpClientResponsewith all available attributes.HttpResponseException(HttpStatusCode aStatusCode, Url aUrl, String aMessage) Instantiates the classHttpResponseException.HttpResponseException(HttpStatusCode aStatusCode, Url aUrl, String aMessage, String aErrorCode) Instantiates the classHttpResponseException.HttpResponseException(HttpStatusCode aStatusCode, Url aUrl, String aMessage, Throwable aCause) Instantiates the classHttpResponseException.HttpResponseException(HttpStatusCode aStatusCode, Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classHttpResponseException.HttpResponseException(HttpStatusCode aStatusCode, Url aUrl, Throwable aCause) Instantiates the classHttpResponseException.HttpResponseException(HttpStatusCode aStatusCode, Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classHttpResponseException.HttpServerRequest(HttpMethod aHttpMethod, Url aUrl, RequestHeaderFields aHeaderFields, InputStream aHttpInputStream, MediaTypeFactoryLookup aMediaTypeFactoryLookup) Instantiates the classHttpServerRequest.HttpStatusException(HttpStatusCode aStatusCode, Url aUrl, String aMessage) Instantiates the classHttpStatusException.HttpStatusException(HttpStatusCode aStatusCode, Url aUrl, String aMessage, String aErrorCode) Instantiates the classHttpStatusException.HttpStatusException(HttpStatusCode aStatusCode, Url aUrl, String aMessage, Throwable aCause) Instantiates the classHttpStatusException.HttpStatusException(HttpStatusCode aStatusCode, Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classHttpStatusException.HttpStatusException(HttpStatusCode aStatusCode, Url aUrl, Throwable aCause) Instantiates the classHttpStatusException.HttpStatusException(HttpStatusCode aStatusCode, Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classHttpStatusException.HttpVersionNotSupportedException(Url aUrl, String aMessage) Instantiates the classHttpVersionNotSupportedException.HttpVersionNotSupportedException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classHttpVersionNotSupportedException.HttpVersionNotSupportedException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classHttpVersionNotSupportedException.HttpVersionNotSupportedException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classHttpVersionNotSupportedException.HttpVersionNotSupportedException(Url aUrl, Throwable aCause) Instantiates the classHttpVersionNotSupportedException.HttpVersionNotSupportedException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classHttpVersionNotSupportedException.InsufficientSpaceOnResourceException(Url aUrl, String aMessage) Instantiates the classInsufficientSpaceOnResourceException.InsufficientSpaceOnResourceException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classInsufficientSpaceOnResourceException.InsufficientSpaceOnResourceException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classInsufficientSpaceOnResourceException.InsufficientSpaceOnResourceException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classInsufficientSpaceOnResourceException.InsufficientSpaceOnResourceException(Url aUrl, Throwable aCause) Instantiates the classInsufficientSpaceOnResourceException.InsufficientSpaceOnResourceException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classInsufficientSpaceOnResourceException.InsufficientStorageException(Url aUrl, String aMessage) Instantiates the classInsufficientStorageException.InsufficientStorageException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classInsufficientStorageException.InsufficientStorageException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classInsufficientStorageException.InsufficientStorageException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classInsufficientStorageException.InsufficientStorageException(Url aUrl, Throwable aCause) Instantiates the classInsufficientStorageException.InsufficientStorageException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classInsufficientStorageException.InternalClientErrorException(Url aUrl, String aMessage) Instantiates the classInternalClientErrorException.InternalClientErrorException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classInternalClientErrorException.InternalClientErrorException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classInternalClientErrorException.InternalClientErrorException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classInternalClientErrorException.InternalClientErrorException(Url aUrl, Throwable aCause) Instantiates the classInternalClientErrorException.InternalClientErrorException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classInternalClientErrorException.InternalServerErrorException(Url aUrl, String aMessage) Instantiates the classInternalServerErrorException.InternalServerErrorException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classInternalServerErrorException.InternalServerErrorException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classInternalServerErrorException.InternalServerErrorException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classInternalServerErrorException.InternalServerErrorException(Url aUrl, Throwable aCause) Instantiates the classInternalServerErrorException.InternalServerErrorException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classInternalServerErrorException.LengthRequiredException(Url aUrl, String aMessage) Instantiates the classLengthRequiredException.LengthRequiredException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classLengthRequiredException.LengthRequiredException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classLengthRequiredException.LengthRequiredException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classLengthRequiredException.LengthRequiredException(Url aUrl, Throwable aCause) Instantiates the classLengthRequiredException.LengthRequiredException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classLengthRequiredException.LockedException(Url aUrl, String aMessage) Instantiates the classLockedException.LockedException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classLockedException.LockedException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classLockedException.LockedException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classLockedException.LockedException(Url aUrl, Throwable aCause) Instantiates the classLockedException.LockedException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classLockedException.MethodFailureException(Url aUrl, String aMessage) Instantiates the classMethodFailureException.MethodFailureException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classMethodFailureException.MethodFailureException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classMethodFailureException.MethodFailureException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classMethodFailureException.MethodFailureException(Url aUrl, Throwable aCause) Instantiates the classMethodFailureException.MethodFailureException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classMethodFailureException.MethodNotAllowedException(Url aUrl, String aMessage) Instantiates the classMethodNotAllowedException.MethodNotAllowedException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classMethodNotAllowedException.MethodNotAllowedException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classMethodNotAllowedException.MethodNotAllowedException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classMethodNotAllowedException.MethodNotAllowedException(Url aUrl, Throwable aCause) Instantiates the classMethodNotAllowedException.MethodNotAllowedException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classMethodNotAllowedException.MovedPermanentlyException(Url aUrl, String aMessage) Instantiates the classMovedPermanentlyException.MovedPermanentlyException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classMovedPermanentlyException.MovedPermanentlyException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classMovedPermanentlyException.MovedPermanentlyException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classMovedPermanentlyException.MovedPermanentlyException(Url aUrl, Throwable aCause) Instantiates the classMovedPermanentlyException.MovedPermanentlyException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classMovedPermanentlyException.MovedTemporarilyException(Url aUrl, String aMessage) Instantiates the classMovedTemporarilyException.MovedTemporarilyException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classMovedTemporarilyException.MovedTemporarilyException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classMovedTemporarilyException.MovedTemporarilyException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classMovedTemporarilyException.MovedTemporarilyException(Url aUrl, Throwable aCause) Instantiates the classMovedTemporarilyException.MovedTemporarilyException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classMovedTemporarilyException.MultipleChoicesException(Url aUrl, String aMessage) Instantiates the classMultipleChoicesException.MultipleChoicesException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classMultipleChoicesException.MultipleChoicesException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classMultipleChoicesException.MultipleChoicesException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classMultipleChoicesException.MultipleChoicesException(Url aUrl, Throwable aCause) Instantiates the classMultipleChoicesException.MultipleChoicesException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classMultipleChoicesException.MultiStatusException(Url aUrl, String aMessage) Instantiates the classMultiStatusException.MultiStatusException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classMultiStatusException.MultiStatusException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classMultiStatusException.MultiStatusException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classMultiStatusException.MultiStatusException(Url aUrl, Throwable aCause) Instantiates the classMultiStatusException.MultiStatusException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classMultiStatusException.NoContentException(Url aUrl, String aMessage) Instantiates the classNoContentException.NoContentException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classNoContentException.NoContentException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classNoContentException.NoContentException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classNoContentException.NoContentException(Url aUrl, Throwable aCause) Instantiates the classNoContentException.NoContentException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classNoContentException.NonAuthoritativeInformationException(Url aUrl, String aMessage) Instantiates the classNonAuthoritativeInformationException.NonAuthoritativeInformationException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classNonAuthoritativeInformationException.NonAuthoritativeInformationException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classNonAuthoritativeInformationException.NonAuthoritativeInformationException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classNonAuthoritativeInformationException.NonAuthoritativeInformationException(Url aUrl, Throwable aCause) Instantiates the classNonAuthoritativeInformationException.NonAuthoritativeInformationException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classNonAuthoritativeInformationException.NotAcceptableException(Url aUrl, String aMessage) Instantiates the classNotAcceptableException.NotAcceptableException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classNotAcceptableException.NotAcceptableException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classNotAcceptableException.NotAcceptableException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classNotAcceptableException.NotAcceptableException(Url aUrl, Throwable aCause) Instantiates the classNotAcceptableException.NotAcceptableException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classNotAcceptableException.NotFoundException(Url aUrl, String aMessage) Instantiates the classNotFoundException.NotFoundException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classNotFoundException.NotFoundException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classNotFoundException.NotFoundException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classNotFoundException.NotFoundException(Url aUrl, Throwable aCause) Instantiates the classNotFoundException.NotFoundException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classNotFoundException.NotImplementedException(Url aUrl, String aMessage) Instantiates the classNotImplementedException.NotImplementedException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classNotImplementedException.NotImplementedException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classNotImplementedException.NotImplementedException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classNotImplementedException.NotImplementedException(Url aUrl, Throwable aCause) Instantiates the classNotImplementedException.NotImplementedException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classNotImplementedException.NotModifiedException(Url aUrl, String aMessage) Instantiates the classNotModifiedException.NotModifiedException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classNotModifiedException.NotModifiedException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classNotModifiedException.NotModifiedException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classNotModifiedException.NotModifiedException(Url aUrl, Throwable aCause) Instantiates the classNotModifiedException.NotModifiedException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classNotModifiedException.PartialContentException(Url aUrl, String aMessage) Instantiates the classPartialContentException.PartialContentException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classPartialContentException.PartialContentException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classPartialContentException.PartialContentException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classPartialContentException.PartialContentException(Url aUrl, Throwable aCause) Instantiates the classPartialContentException.PartialContentException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classPartialContentException.PaymentRequiredException(Url aUrl, String aMessage) Instantiates the classPaymentRequiredException.PaymentRequiredException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classPaymentRequiredException.PaymentRequiredException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classPaymentRequiredException.PaymentRequiredException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classPaymentRequiredException.PaymentRequiredException(Url aUrl, Throwable aCause) Instantiates the classPaymentRequiredException.PaymentRequiredException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classPaymentRequiredException.PermanentRedirectException(Url aUrl, String aMessage) Instantiates the classPermanentRedirectException.PermanentRedirectException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classPermanentRedirectException.PermanentRedirectException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classPermanentRedirectException.PermanentRedirectException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classPermanentRedirectException.PermanentRedirectException(Url aUrl, Throwable aCause) Instantiates the classPermanentRedirectException.PermanentRedirectException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classPermanentRedirectException.PreconditionFailedException(Url aUrl, String aMessage) Instantiates the classPreconditionFailedException.PreconditionFailedException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classPreconditionFailedException.PreconditionFailedException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classPreconditionFailedException.PreconditionFailedException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classPreconditionFailedException.PreconditionFailedException(Url aUrl, Throwable aCause) Instantiates the classPreconditionFailedException.PreconditionFailedException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classPreconditionFailedException.ProxyAuthenticationRequiredException(Url aUrl, String aMessage) Instantiates the classProxyAuthenticationRequiredException.ProxyAuthenticationRequiredException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classProxyAuthenticationRequiredException.ProxyAuthenticationRequiredException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classProxyAuthenticationRequiredException.ProxyAuthenticationRequiredException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classProxyAuthenticationRequiredException.ProxyAuthenticationRequiredException(Url aUrl, Throwable aCause) Instantiates the classProxyAuthenticationRequiredException.ProxyAuthenticationRequiredException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classProxyAuthenticationRequiredException.ReauthenticationRequiredException(Url aUrl, String aMessage) Instantiates the classReauthenticationRequiredException.ReauthenticationRequiredException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classReauthenticationRequiredException.ReauthenticationRequiredException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classReauthenticationRequiredException.ReauthenticationRequiredException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classReauthenticationRequiredException.ReauthenticationRequiredException(Url aUrl, Throwable aCause) Instantiates the classReauthenticationRequiredException.ReauthenticationRequiredException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classReauthenticationRequiredException.RequestedRangeNotSatisfiableException(Url aUrl, String aMessage) Instantiates the classRequestedRangeNotSatisfiableException.RequestedRangeNotSatisfiableException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classRequestedRangeNotSatisfiableException.RequestedRangeNotSatisfiableException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classRequestedRangeNotSatisfiableException.RequestedRangeNotSatisfiableException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classRequestedRangeNotSatisfiableException.RequestedRangeNotSatisfiableException(Url aUrl, Throwable aCause) Instantiates the classRequestedRangeNotSatisfiableException.RequestedRangeNotSatisfiableException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classRequestedRangeNotSatisfiableException.RequestTimeoutException(Url aUrl, String aMessage) Instantiates the classRequestTimeoutException.RequestTimeoutException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classRequestTimeoutException.RequestTimeoutException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classRequestTimeoutException.RequestTimeoutException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classRequestTimeoutException.RequestTimeoutException(Url aUrl, Throwable aCause) Instantiates the classRequestTimeoutException.RequestTimeoutException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classRequestTimeoutException.RequestTooLongException(Url aUrl, String aMessage) Instantiates the classRequestTooLongException.RequestTooLongException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classRequestTooLongException.RequestTooLongException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classRequestTooLongException.RequestTooLongException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classRequestTooLongException.RequestTooLongException(Url aUrl, Throwable aCause) Instantiates the classRequestTooLongException.RequestTooLongException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classRequestTooLongException.RequestUriTooLongException(Url aUrl, String aMessage) Instantiates the classRequestUriTooLongException.RequestUriTooLongException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classRequestUriTooLongException.RequestUriTooLongException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classRequestUriTooLongException.RequestUriTooLongException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classRequestUriTooLongException.RequestUriTooLongException(Url aUrl, Throwable aCause) Instantiates the classRequestUriTooLongException.RequestUriTooLongException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classRequestUriTooLongException.ResetContentException(Url aUrl, String aMessage) Instantiates the classResetContentException.ResetContentException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classResetContentException.ResetContentException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classResetContentException.ResetContentException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classResetContentException.ResetContentException(Url aUrl, Throwable aCause) Instantiates the classResetContentException.ResetContentException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classResetContentException.SeeOtherException(Url aUrl, String aMessage) Instantiates the classSeeOtherException.SeeOtherException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classSeeOtherException.SeeOtherException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classSeeOtherException.SeeOtherException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classSeeOtherException.SeeOtherException(Url aUrl, Throwable aCause) Instantiates the classSeeOtherException.SeeOtherException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classSeeOtherException.ServiceUnavailableException(Url aUrl, String aMessage) Instantiates the classServiceUnavailableException.ServiceUnavailableException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classServiceUnavailableException.ServiceUnavailableException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classServiceUnavailableException.ServiceUnavailableException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classServiceUnavailableException.ServiceUnavailableException(Url aUrl, Throwable aCause) Instantiates the classServiceUnavailableException.ServiceUnavailableException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classServiceUnavailableException.TemporaryRedirectException(Url aUrl, String aMessage) Instantiates the classTemporaryRedirectException.TemporaryRedirectException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classTemporaryRedirectException.TemporaryRedirectException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classTemporaryRedirectException.TemporaryRedirectException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classTemporaryRedirectException.TemporaryRedirectException(Url aUrl, Throwable aCause) Instantiates the classTemporaryRedirectException.TemporaryRedirectException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classTemporaryRedirectException.UnassignedStatusCodeException(int aHttpStatusCode, Url aUrl, String aMessage) Instantiates the classUnassignedStatusCodeException.UnassignedStatusCodeException(int aHttpStatusCode, Url aUrl, String aMessage, String aErrorCode) Instantiates the classUnassignedStatusCodeException.UnassignedStatusCodeException(int aHttpStatusCode, Url aUrl, String aMessage, Throwable aCause) Instantiates the classUnassignedStatusCodeException.UnassignedStatusCodeException(int aHttpStatusCode, Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classUnassignedStatusCodeException.UnassignedStatusCodeException(int aHttpStatusCode, Url aUrl, Throwable aCause) Instantiates the classUnassignedStatusCodeException.UnassignedStatusCodeException(int aHttpStatusCode, Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classUnassignedStatusCodeException.UnauthorizedException(Url aUrl, String aMessage) Instantiates the classUnauthorizedException.UnauthorizedException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classUnauthorizedException.UnauthorizedException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classUnauthorizedException.UnauthorizedException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classUnauthorizedException.UnauthorizedException(Url aUrl, Throwable aCause) Instantiates the classUnauthorizedException.UnauthorizedException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classUnauthorizedException.UnavailableForLegalReasonsException(Url aUrl, String aMessage) Instantiates the classUnavailableForLegalReasonsException.UnavailableForLegalReasonsException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classUnavailableForLegalReasonsException.UnavailableForLegalReasonsException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classUnavailableForLegalReasonsException.UnavailableForLegalReasonsException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classUnavailableForLegalReasonsException.UnavailableForLegalReasonsException(Url aUrl, Throwable aCause) Instantiates the classUnavailableForLegalReasonsException.UnavailableForLegalReasonsException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classUnavailableForLegalReasonsException.UnprocessableEntityException(Url aUrl, String aMessage) Instantiates the classUnprocessableEntityException.UnprocessableEntityException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classUnprocessableEntityException.UnprocessableEntityException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classUnprocessableEntityException.UnprocessableEntityException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classUnprocessableEntityException.UnprocessableEntityException(Url aUrl, Throwable aCause) Instantiates the classUnprocessableEntityException.UnprocessableEntityException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classUnprocessableEntityException.UnsupportedMediaTypeException(Url aUrl, String aMessage) Instantiates the classUnsupportedMediaTypeException.UnsupportedMediaTypeException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classUnsupportedMediaTypeException.UnsupportedMediaTypeException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classUnsupportedMediaTypeException.UnsupportedMediaTypeException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classUnsupportedMediaTypeException.UnsupportedMediaTypeException(Url aUrl, Throwable aCause) Instantiates the classUnsupportedMediaTypeException.UnsupportedMediaTypeException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classUnsupportedMediaTypeException.UrlBuilder(Url aUrl) Instantiates the classUrlBuilder.UrlBuilder(Url aUrl, String... aPaths) Instantiates the classUrlBuilder.UrlBuilder(Url aUrl, Url aOtherUrl) Instantiates the classUrlBuilder.UseProxyException(Url aUrl, String aMessage) Instantiates the classUseProxyException.UseProxyException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classUseProxyException.UseProxyException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classUseProxyException.UseProxyException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classUseProxyException.UseProxyException(Url aUrl, Throwable aCause) Instantiates the classUseProxyException.UseProxyException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classUseProxyException.VersionNotSupportedException(Url aUrl, String aMessage) Instantiates the classVersionNotSupportedException.VersionNotSupportedException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classVersionNotSupportedException.VersionNotSupportedException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classVersionNotSupportedException.VersionNotSupportedException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classVersionNotSupportedException.VersionNotSupportedException(Url aUrl, Throwable aCause) Instantiates the classVersionNotSupportedException.VersionNotSupportedException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classVersionNotSupportedException.