Provides an accessor for a
AuthType property.
Provides a builder method for a
AuthType property returning the
builder for applying multiple build operations.
Provides a mutator for a
AuthType property.
The Interface AuthTypeCredentials.
The Class BadRequestException.
Proprietary code and only used inside a REFCODES.ORG client not trespassing
any networking border (the error is generated by the client for the client
locally).
Provides an accessor for a base locator property.
Provides a builder method for a base locator property returning the
builder for applying multiple build operations.
Provides a mutator for a base locator property.
Provides an accessor for a base URL (protocol, host, port, locator) property.
Provides a builder method for a base URL (protocol, host, port, path)
property returning the builder for applying multiple build operations.
Provides a mutator for a base URL (protocol, host, port, locator)
property.
Provides a base URL (protocol, host, port, path) property.
The
BasicAuthCredentials defines a type for representing a
Basic-Authentication credentials Header-Field.
Provides a builder method for a
BasicAuthCredentials property
returning the builder for applying multiple build operations.
An observable which notifies the registered
BasicAuthObserver on
incoming HTTP Basic-Authentication requests.
The enumeration for a Basic-Auth response.
The
BasicCredentials describes the attributes required by a
Basic-Auth authentication over HTTP(S).
The
BearerAuthCredentials defines a type for representing a
Bearer-Authentication credentials Header-Field.
Provides a builder method for a
BearerAuthCredentials property
returning the builder for applying multiple build operations.
Provides an accessor for a Content-Type property.
Provides a builder method for a Content-Type property returning the
builder for applying multiple build operations.
Provides a mutator for a Content-Type property.
A provider interface provides a "toSomething(?)"
The
Cookie represents a HTTP cookie.
The Enum CookieAttribute.
The Class ForbiddenException.
The
FormFields represent the URL's Query-String by the notation
originally used by the GET request of the ancient web forms (see
"https://en.wikipedia.org/wiki/Query_string#Web_forms").
Provides an accessor for a request Form-Fields property.
Provides a mutator for a request Form-Fields property.
Provides a mutator for a request Form-Fields property.
Provides an accessor for a fragment property.
Provides a mutator for an fragment property.
Provides a mutator for a fragment property.
Provides a fragment property.
Provides a builder method for a
HeaderField property returning
the builder for applying multiple build operations.
The
HeaderFields reflect the structure of a HTTP header and may be
used to represent a HTTP header.
Provides an accessor for an Header-Fields property.
Provides a mutator for an Header-Fields property.
Provides a mutator for an Header-Fields property.
Provides an accessor for a host property.
Provides a mutator for an host property.
Provides a mutator for a host property.
Provides a host property.
Provides an accessor for a HTTP body property.
Provides a builder body for a HTTP body property returning the builder
for applying multiple build operations.
Provides a mutator for a HTTP body property.
A provider interface provides a "toSomething(?)"
The
HttpBodyMap type is a "dynamic" type in terms of it's structure
being represented by paths'.
This context describes all information required to open a client (HTTP or
HTTPS).
Base exception HTTP related problems.
Various key/value "collections" we run across when we develop HTTP based
applications may have more then one value for one key.
Provides an accessor for a HTTP
InputStream body property.
Provides a builder body for a HTTP
InputStream property returning
the builder for applying multiple build operations.
The
HttpMediaType converts an implementing instance's state into an
HTTP media type as used in HTTP Header-Fields.
Provides an accessor for a HTTP Media-Type property.
Provides a builder body for a HTTP Media-Type property returning the
builder for applying multiple build operations.
Provides a mutator for a HTTP Media-Type property.
A provider interface provides a "toSomething(?)"
Provides an accessor for a HTTP-Method property.
Provides a builder method for a HTTP-Method property returning the
builder for applying multiple build operations.
Provides a mutator for a HTTP-Method property.
Defines a HTTP-Request, being the
HttpMethod, the Header-Fields and
the locator representing, though without the request body.
The Interface HttpRequestBuilder.
Defines a
HttpResponse being the response Header-Fields and the
response body.
Thrown by a HTTP-Response handling system in case of some unexpected
response.
Thrown by a HTTP-Response handling system in case of some unexpected
response.
The Class HttpRuntimeException.
This context describes all information required to open a server (HTTP or
HTTPS) and bind a port.
The org.apache.commons.httpclient.HttpStatus constants as enumeration.
Provides access to a HTTP Status-Code property including all known HTTP HTTP
Status-Codes (success as well as error codes) as of
HttpStatusCode.
Provides a builder method for a HTTP Status-Code property returning the
builder for applying multiple build operations.
Base HTTP exception, thrown in case of HTTP status code related exceptions
(e.g. as of a HTTP response was of an erroneous status).
Only the Success 2xx codes as of (from) the
HttpStatusCode
enumeration.
Provides access to a HTTP success code property including just the 2xx HTTP
success codes as of
HttpSuccessCode excluding all HTTP error codes.
Provides a builder method for a HTTP success code property returning the
builder for applying multiple build operations.
Some simple load balancing strategies.
Provides a builder method for a load balancing strategy property
returning the builder for applying multiple build operations.
Provides an accessor for a local address property.
Provides a builder method for a local address property returning the
builder for applying multiple build operations.
Provides a mutator for a local address property.
The
MediaType is the Media-Sub-Type part of a HTTP Media-Type.
Provides an accessor for a Media-Type property.
Provides a builder method for a Media-Type property returning the builder
for applying multiple build operations.
Provides a mutator for a Media-Type property.
The Interface MediaTypeFactoryLookup.
Known or in this scope used
MediaType parameters.
Provides an accessor for a Media-Types property.
Provides a builder method for a Media-Types property returning the
builder for applying multiple build operations.
Provides a mutator for a Media-Types property.
An OAuth-Token contains all relevant information to access a protected
resource and refresh the the access token.
Provides an accessor for a OAuth token property.
Provides a builder method for a OAuth token property returning the
builder for applying multiple build operations.
Provides a mutator for a OAuth token property.
Provides an accessor for a request Query-Fields property.
Provides a mutator for a request Query-Fields property.
Provides a mutator for a request Query-Fields property.
Provides a request Query-Fields property.
Provides an accessor for a realm property.
Provides a builder method for a realm property returning the builder for
applying multiple build operations.
Provides a mutator for a realm property.
Provides an accessor for a redirect depth property.
Provides a builder method for a redirect depth property returning the
builder for applying multiple build operations.
Provides a mutator for a redirect depth property.
Provides a redirect depth property.
Provides an accessor for a remote address property.
Provides a builder method for a remote address property returning the
builder for applying multiple build operations.
Provides a mutator for a remote address property.
The
RequestHeaderFields reflect the structure of a HTTP-Header and
may be used to represent a HTTP-Header.
Provides an accessor for an request Header-Fields property.
Provides a mutator for an request Header-Fields property.
Provides a mutator for an request Header-Fields property.
As of "HTTP cookies explained - NCZOnline": "...
The
ResponseHeaderFields reflect the structure of a HTTP header and
may be used to represent a HTTP header.
Provides an accessor for an response Header-Fields property.
Provides a mutator for an response Header-Fields property.
Provides a mutator for an response Header-Fields property.
Provides an accessor for a URL scheme.
Provides a builder method for a URL scheme returning the builder for
applying multiple build operations.
Provides a mutator for a URL scheme.
The Interface TokenCredentials.
The
TopLevelType is the top-level part of a HTTP Media-Type.
Provides an accessor for a Media-Top-Level-Type property.
Provides a builder method for a Media-Top-Level-Type property returning
the builder for applying multiple build operations.
Provides a mutator for a Media-Top-Level-Type property.
Transport Layer Security Protocols (TLS-Protocols) known by the herein
contained libraries.
The Class UnauthorizedException.
The Class UnauthorizedRuntimeException.
The
Url class represents an immutable URL: An URL looks something
like this:
"scheme://[identity[:secret]@]host[:port][/path][?
Provides an accessor for a
Url property..
Provides a builder method for a
Url property returning the
builder for applying multiple build operations.
Provides a mutator for a
Url property.
The
UrlBuilder extends an immutable
Url with mutable
functionality.
Provides an accessor for a user agent property.
Provides a builder method for a user agent property returning the builder
for applying multiple build operations.
Provides a mutator for a user agent property.
Provides an accessor for a virtual host property.
Provides a mutator for an virtual host property.
Provides a mutator for a virtual host property.
The base exception for networking related issues.
The base runtime exception for networking related issues.