Class BadResponseException
java.lang.Object
java.lang.Throwable
java.lang.Exception
org.refcodes.exception.AbstractException
org.refcodes.web.WebException
org.refcodes.web.HttpException
org.refcodes.web.HttpStatusException
org.refcodes.web.HttpResponseException
org.refcodes.web.BadResponseException
- All Implemented Interfaces:
Serializable,org.refcodes.exception.ErrorCodeAccessor,org.refcodes.exception.Trap,org.refcodes.mixin.StatusCodeAccessor<HttpStatusCode>,UrlAccessor
Proprietary code and only used inside a REFCODES.ORG client not trespassing
any networking border (the error is generated by the client for the client
locally). This code is used when a client signals a bad response being
received by a server, e.g. the response cannot be processed by the client and
does not meet the client's expectations.
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.exception.ErrorCodeAccessor
org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B extends org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B>>, org.refcodes.exception.ErrorCodeAccessor.ErrorCodeMutator, org.refcodes.exception.ErrorCodeAccessor.ErrorCodePropertyNested classes/interfaces inherited from interface org.refcodes.mixin.StatusCodeAccessor
org.refcodes.mixin.StatusCodeAccessor.StatusCodeBuilder<SC,B extends org.refcodes.mixin.StatusCodeAccessor.StatusCodeBuilder<SC, B>>, org.refcodes.mixin.StatusCodeAccessor.StatusCodeMutator<SC>, org.refcodes.mixin.StatusCodeAccessor.StatusCodeProperty<SC> Nested classes/interfaces inherited from interface org.refcodes.web.UrlAccessor
UrlAccessor.UrlBuilder, UrlAccessor.UrlMutator, UrlAccessor.UrlProperty -
Field Summary
Fields inherited from class org.refcodes.web.HttpStatusException
_httpStatusCode -
Constructor Summary
ConstructorsConstructorDescriptionBadResponseException(String aMessage) Instantiates the classBadResponseException.BadResponseException(String aMessage, String aErrorCode) Instantiates the classBadResponseException.BadResponseException(String aMessage, Throwable aCause) Instantiates the classBadResponseException.BadResponseException(String aMessage, Throwable aCause, String aErrorCode) Instantiates the classBadResponseException.BadResponseException(Throwable aCause) Instantiates the classBadResponseException.BadResponseException(Throwable aCause, String aErrorCode) Instantiates the classBadResponseException.BadResponseException(Url aUrl, String aMessage) Instantiates the classBadResponseException.BadResponseException(Url aUrl, String aMessage, String aErrorCode) Instantiates the classBadResponseException.BadResponseException(Url aUrl, String aMessage, Throwable aCause) Instantiates the classBadResponseException.BadResponseException(Url aUrl, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classBadResponseException.BadResponseException(Url aUrl, Throwable aCause) Instantiates the classBadResponseException.BadResponseException(Url aUrl, Throwable aCause, String aErrorCode) Instantiates the classBadResponseException. -
Method Summary
Methods inherited from class org.refcodes.web.HttpStatusException
getPatternArguments, getStatusCode, getUrlMethods inherited from class org.refcodes.exception.AbstractException
getErrorCode, getMessageMethods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.exception.Trap
toLocalizedMessage, toMessage, toMessage, toMessage, toShortLocalizedMessage, toShortMessage
-
Constructor Details
-
BadResponseException
Instantiates the classBadResponseException.- See Also:
-
BadResponseException
Instantiates the classBadResponseException.- See Also:
-
BadResponseException
Instantiates the classBadResponseException.- See Also:
-
BadResponseException
-
BadResponseException
Instantiates the classBadResponseException.- See Also:
-
BadResponseException
Instantiates the classBadResponseException.- See Also:
-
BadResponseException
Instantiates the classBadResponseException.- See Also:
-
BadResponseException
Instantiates the classBadResponseException.- See Also:
-
BadResponseException
Instantiates the classBadResponseException.- See Also:
-
BadResponseException
Instantiates the classBadResponseException.- See Also:
-
BadResponseException
Instantiates the classBadResponseException.- See Also:
-
BadResponseException
Instantiates the classBadResponseException.- See Also:
-