java.lang.Object
java.lang.Throwable
java.lang.Exception
org.refcodes.exception.AbstractException
org.refcodes.web.WebException
org.refcodes.web.HttpException
org.refcodes.web.HttpStatusException
org.refcodes.web.HttpResponseException
org.refcodes.web.BadResponseException
- All Implemented Interfaces:
Serializable,org.refcodes.exception.ErrorCodeAccessor,org.refcodes.exception.Trap,org.refcodes.mixin.StatusCodeAccessor<HttpStatusCode>
Proprietary code and only used inside a REFCODES.ORG client not trespassing
any networking border (the error is generated by the client for the client
locally). This code is used when a client signals a bad response being
received by a server, e.g. the response cannot be processed by the client and
does not meet the client's expectations.
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.exception.ErrorCodeAccessor
org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B extends org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B>>, org.refcodes.exception.ErrorCodeAccessor.ErrorCodeMutator, org.refcodes.exception.ErrorCodeAccessor.ErrorCodePropertyNested classes/interfaces inherited from interface org.refcodes.mixin.StatusCodeAccessor
org.refcodes.mixin.StatusCodeAccessor.StatusCodeBuilder<SC extends Object,B extends org.refcodes.mixin.StatusCodeAccessor.StatusCodeBuilder<SC, B>>, org.refcodes.mixin.StatusCodeAccessor.StatusCodeMutator<SC extends Object>, org.refcodes.mixin.StatusCodeAccessor.StatusCodeProperty<SC extends Object> -
Constructor Summary
ConstructorsConstructorDescriptionBadResponseException(String aMessage) Instantiates a new bad response exception.BadResponseException(String aMessage, String aErrorCode) Instantiates a new bad response exception.BadResponseException(String aMessage, Throwable aCause) Instantiates a new bad response exception.BadResponseException(String aMessage, Throwable aCause, String aErrorCode) Instantiates a new bad response exception.BadResponseException(Throwable aCause) Instantiates a new bad response exception.BadResponseException(Throwable aCause, String aErrorCode) Instantiates a new bad response exception. -
Method Summary
Methods inherited from class org.refcodes.web.HttpStatusException
getStatusCodeMethods inherited from class org.refcodes.exception.AbstractException
getErrorCodeMethods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.exception.Trap
toLocalizedMessage, toMessage, toShortLocalizedMessage, toShortMessage
-
Constructor Details
-
BadResponseException
Instantiates a new bad response exception.- Parameters:
aMessage- The aMessage describing this exception.aErrorCode- The error code identifying this exception.
-
BadResponseException
Instantiates a new bad response exception. -
BadResponseException
Instantiates a new bad response exception. -
BadResponseException
Instantiates a new bad response exception.- Parameters:
aMessage- The aMessage describing this exception.
-
BadResponseException
Instantiates a new bad response exception. -
BadResponseException
Instantiates a new bad response exception.
-