java.lang.Object
java.lang.Throwable
java.lang.Exception
java.lang.RuntimeException
org.refcodes.exception.AbstractRuntimeException
org.refcodes.web.WebRuntimeException
org.refcodes.web.HttpRuntimeException
org.refcodes.web.HttpStatusRuntimeException
org.refcodes.web.HttpResponseRuntimeException
org.refcodes.web.BadResponseRuntimeException
- All Implemented Interfaces:
Serializable,org.refcodes.exception.ErrorCodeAccessor,org.refcodes.exception.Trap,org.refcodes.mixin.StatusCodeAccessor<HttpStatusCode>
Proprietary code and only used inside a REFCODES.ORG client not trespassing
any networking border (the error is generated by the client for the client
locally). This code is used when a client signals a bad response being
received by a server, e.g. the response cannot be processed by the client and
does not meet the client's expectations.
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.exception.ErrorCodeAccessor
org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B extends org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B>>, org.refcodes.exception.ErrorCodeAccessor.ErrorCodeMutator, org.refcodes.exception.ErrorCodeAccessor.ErrorCodePropertyNested classes/interfaces inherited from interface org.refcodes.mixin.StatusCodeAccessor
org.refcodes.mixin.StatusCodeAccessor.StatusCodeBuilder<SC extends Object,B extends org.refcodes.mixin.StatusCodeAccessor.StatusCodeBuilder<SC, B>>, org.refcodes.mixin.StatusCodeAccessor.StatusCodeMutator<SC extends Object>, org.refcodes.mixin.StatusCodeAccessor.StatusCodeProperty<SC extends Object> -
Constructor Summary
ConstructorsConstructorDescriptionBadResponseRuntimeException(String aMessage) Instantiates a new bad response runtime exception.BadResponseRuntimeException(String aMessage, String aErrorCode) Instantiates a new bad response runtime exception.BadResponseRuntimeException(String aMessage, Throwable aCause) Instantiates a new bad response runtime exception.BadResponseRuntimeException(String aMessage, Throwable aCause, String aErrorCode) Instantiates a new bad response runtime exception.BadResponseRuntimeException(Throwable aCause) Instantiates a new bad response runtime exception.BadResponseRuntimeException(Throwable aCause, String aErrorCode) Instantiates a new bad response runtime exception. -
Method Summary
Methods inherited from class org.refcodes.web.HttpStatusRuntimeException
getStatusCodeMethods inherited from class org.refcodes.exception.AbstractRuntimeException
getErrorCodeMethods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.exception.Trap
toLocalizedMessage, toMessage, toShortLocalizedMessage, toShortMessage
-
Constructor Details
-
BadResponseRuntimeException
Instantiates a new bad response runtime exception.- Parameters:
aMessage- The aMessage describing this exception.aErrorCode- The error code identifying this exception.
-
BadResponseRuntimeException
Instantiates a new bad response runtime exception. -
BadResponseRuntimeException
Instantiates a new bad response runtime exception. -
BadResponseRuntimeException
Instantiates a new bad response runtime exception.- Parameters:
aMessage- The aMessage describing this exception.
-
BadResponseRuntimeException
Instantiates a new bad response runtime exception. -
BadResponseRuntimeException
Instantiates a new bad response runtime exception.
-