- All Known Subinterfaces:
BaseUrlAccessor.BaseUrlProperty,HttpClientContext,HttpClientContext.HttpClientContextBuilder
- All Known Implementing Classes:
HttpClientContextBuilderImpl
public interface BaseUrlAccessor
Provides an accessor for a base URL (protocol, host, port, locator) property.
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceBaseUrlAccessor.BaseUrlBuilder<B extends BaseUrlAccessor.BaseUrlBuilder<B>>Provides a builder method for a base URL (protocol, host, port, path) property returning the builder for applying multiple build operations.static interfaceBaseUrlAccessor.BaseUrlMutatorProvides a mutator for a base URL (protocol, host, port, locator) property.static interfaceBaseUrlAccessor.BaseUrlPropertyProvides a base URL (protocol, host, port, path) property. -
Method Summary
Modifier and Type Method Description UrlgetBaseUrl()Retrieves the base URL (protocol, host, port, locator) from the base URL (protocol, host, port, locator) property.
-
Method Details
-
getBaseUrl
Url getBaseUrl()Retrieves the base URL (protocol, host, port, locator) from the base URL (protocol, host, port, locator) property.- Returns:
- The base URL (protocol, host, port, locator) stored by the base URL (protocol, host, port, locator) property.
-