Module org.refcodes.web
Package org.refcodes.web
Interface BasicAuthCredentialsAccessor.BasicAuthCredentialsBuilder<B extends BasicAuthCredentialsAccessor.BasicAuthCredentialsBuilder<B>>
- Type Parameters:
B- The builder to return in order to be able to apply multiple build operations.
- Enclosing interface:
- BasicAuthCredentialsAccessor
public static interface BasicAuthCredentialsAccessor.BasicAuthCredentialsBuilder<B extends BasicAuthCredentialsAccessor.BasicAuthCredentialsBuilder<B>>
Provides a builder method for a
BasicAuthCredentials property
returning the builder for applying multiple build operations.-
Method Summary
Modifier and Type Method Description BwithBasicAuthCredentials(String aUserName, String aSecret)Sets theBasicAuthCredentialsfrom the user name and the secret for the Basic-Authentication credentials property.BwithBasicAuthCredentials(BasicAuthCredentials aBasicAuthCredentials)Sets theBasicAuthCredentialsfor the Basic-Authentication credentials property.
-
Method Details
-
withBasicAuthCredentials
Sets theBasicAuthCredentialsfor the Basic-Authentication credentials property.- Parameters:
aBasicAuthCredentials- TheBasicAuthCredentialsto be stored by theBasicAuthCredentialsproperty.- Returns:
- The builder for applying multiple build operations.
-
withBasicAuthCredentials
Sets theBasicAuthCredentialsfrom the user name and the secret for the Basic-Authentication credentials property.- Parameters:
aUserName- The user name to be stored by theBasicAuthCredentialsproperty.aSecret- The password to be stored by theBasicAuthCredentialsproperty.- Returns:
- The builder for applying multiple build operations.
-