Module org.refcodes.web
Package org.refcodes.web
Interface BasicAuthCredentialsAccessor.BasicAuthCredentialsMutator
-
- All Known Subinterfaces:
BasicAuthCredentialsAccessor.BasicAuthCredentialsProperty
- Enclosing interface:
- BasicAuthCredentialsAccessor
public static interface BasicAuthCredentialsAccessor.BasicAuthCredentialsMutatorProvides a mutator for aBasicAuthCredentialsproperty.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Default Methods Modifier and Type Method Description default voidsetBasicAuthCredentials(String aUserName, String aSecret)Sets theBasicAuthCredentialsfrom the user name and the secret for the Basic-Authentication credentials property.voidsetBasicAuthCredentials(BasicAuthCredentials aBasicAuthCredentials)Sets theBasicAuthCredentialsfor the Basic-Authentication credentials property.
-
-
-
Method Detail
-
setBasicAuthCredentials
void setBasicAuthCredentials(BasicAuthCredentials aBasicAuthCredentials)
Sets theBasicAuthCredentialsfor the Basic-Authentication credentials property.- Parameters:
aBasicAuthCredentials- TheBasicAuthCredentialsto be stored by theBasicAuthCredentialsproperty.
-
setBasicAuthCredentials
default void setBasicAuthCredentials(String aUserName, String aSecret)
Sets theBasicAuthCredentialsfrom the user name and the secret for the Basic-Authentication credentials property.- Parameters:
aUserName- The user name to be stored by theBasicAuthCredentialsproperty.aSecret- The password to be stored by theBasicAuthCredentialsproperty.
-
-