Interface BasicAuthCredentialsAccessor.BasicAuthCredentialsProperty

    • Method Detail

      • letBasicAuthCredentials

        default BasicAuthCredentials letBasicAuthCredentials​(BasicAuthCredentials aBasicAuthCredentials)
        This method stores and passes through the given argument, which is very useful for builder APIs:Sets the BasicAuthCredentials for the Basic-Authentication credentials property.
        Parameters:
        aBasicAuthCredentials - The BasicAuthCredentials to be stored by the BasicAuthCredentials property.
        Returns:
        Returns the value passed for it to be used in conclusive processing steps.
      • letBasicAuthCredentials

        default BasicAuthCredentials letBasicAuthCredentials​(String aUserName,
                                                             String aSecret)
        This method stores and passes through the given arguments, which is very useful for builder APIs:Sets the BasicAuthCredentials from the user name and the secret for the Basic-Authentication credentials property.
        Parameters:
        aUserName - The user name to be stored by the BasicAuthCredentials property.
        aSecret - The password to be stored by the BasicAuthCredentials property.
        Returns:
        Returns the values passed (combined to an instance of BasicAuthCredentials) for it to be used in conclusive processing steps.