Module org.refcodes.web
Package org.refcodes.web
Interface BasicAuthCredentialsAccessor.BasicAuthCredentialsProperty
-
- All Superinterfaces:
BasicAuthCredentialsAccessor,BasicAuthCredentialsAccessor.BasicAuthCredentialsMutator
- Enclosing interface:
- BasicAuthCredentialsAccessor
public static interface BasicAuthCredentialsAccessor.BasicAuthCredentialsProperty extends BasicAuthCredentialsAccessor, BasicAuthCredentialsAccessor.BasicAuthCredentialsMutator
Provides aBasicAuthCredentialsproperty.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.web.BasicAuthCredentialsAccessor
BasicAuthCredentialsAccessor.BasicAuthCredentialsBuilder<B extends BasicAuthCredentialsAccessor.BasicAuthCredentialsBuilder<B>>, BasicAuthCredentialsAccessor.BasicAuthCredentialsMutator, BasicAuthCredentialsAccessor.BasicAuthCredentialsProperty
-
-
Method Summary
All Methods Instance Methods Default Methods Modifier and Type Method Description default BasicAuthCredentialsletBasicAuthCredentials(String aUserName, String aSecret)This method stores and passes through the given arguments, which is very useful for builder APIs:Sets theBasicAuthCredentialsfrom the user name and the secret for the Basic-Authentication credentials property.default BasicAuthCredentialsletBasicAuthCredentials(BasicAuthCredentials aBasicAuthCredentials)This method stores and passes through the given argument, which is very useful for builder APIs:Sets theBasicAuthCredentialsfor the Basic-Authentication credentials property.-
Methods inherited from interface org.refcodes.web.BasicAuthCredentialsAccessor
getBasicAuthCredentials
-
Methods inherited from interface org.refcodes.web.BasicAuthCredentialsAccessor.BasicAuthCredentialsMutator
setBasicAuthCredentials, setBasicAuthCredentials
-
-
-
-
Method Detail
-
letBasicAuthCredentials
default BasicAuthCredentials letBasicAuthCredentials(BasicAuthCredentials aBasicAuthCredentials)
This method stores and passes through the given argument, which is very useful for builder APIs:Sets theBasicAuthCredentialsfor the Basic-Authentication credentials property.- Parameters:
aBasicAuthCredentials- TheBasicAuthCredentialsto be stored by theBasicAuthCredentialsproperty.- Returns:
- Returns the value passed for it to be used in conclusive processing steps.
-
letBasicAuthCredentials
default BasicAuthCredentials letBasicAuthCredentials(String aUserName, String aSecret)
This method stores and passes through the given arguments, which is very useful for builder APIs:Sets theBasicAuthCredentialsfrom the user name and the secret for the Basic-Authentication credentials property.- Parameters:
aUserName- The user name to be stored by theBasicAuthCredentialsproperty.aSecret- The password to be stored by theBasicAuthCredentialsproperty.- Returns:
- Returns the values passed (combined to an instance of
BasicAuthCredentials) for it to be used in conclusive processing steps.
-
-