- java.lang.Object
-
- org.refcodes.web.BearerAuthCredentials
-
- All Implemented Interfaces:
org.refcodes.mixin.TokenAccessor,org.refcodes.mixin.Validatable<TokenCredentials>,AuthTypeAccessor,AuthTypeCredentials<BearerAuthCredentials,TokenCredentials>,TokenCredentials
public class BearerAuthCredentials extends Object implements TokenCredentials, AuthTypeCredentials<BearerAuthCredentials,TokenCredentials>
TheBearerAuthCredentialsdefines a type for representing a Bearer-Authentication credentials Header-Field. Parse the Header-Field viafromHttpAuthorization(String)and feed it with the header'sHeaderField.AUTHORIZATIONfield's value. To create the according Header-Field's value from theBearerAuthCredentialstype, calltoHttpAuthorization().
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.web.AuthTypeAccessor
AuthTypeAccessor.AuthTypeBuilder<B extends AuthTypeAccessor.AuthTypeBuilder<B>>, AuthTypeAccessor.AuthTypeMutator, AuthTypeAccessor.AuthTypeProperty
-
-
Field Summary
Fields Modifier and Type Field Description static charDELIMITER_AUTH_TYPE
-
Constructor Summary
Constructors Constructor Description BearerAuthCredentials()Instantiates a new bearer auth credentials impl.BearerAuthCredentials(String aToken)Instantiates a new bearer auth credentials impl.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description booleanequals(Object obj)voidfromHttpAuthorization(String aHttpAuthorization)Initializes thisAuthTypeCredentialsinstance from theHeaderField.AUTHORIZATIONHeader-Fields's value.AuthTypegetAuthType()Retrieves theAuthTypefrom the Authorization-Type property (or null if there are none such credentials).StringgetToken()inthashCode()StringtoHttpAuthorization()Creates aHeaderField.AUTHORIZATIONHTTP Header-Field value from theAuthTypeCredentialsinstance.StringtoString()voidvalidate(String aToken)Validates the provided user-name and secret with thisBearerAuthCredentialsviaTokenCredentials.isValid(String).voidvalidate(TokenCredentials aCredentials)Validates the providedTokenCredentialswith thisBearerAuthCredentialsviaTokenCredentials.isValid(TokenCredentials).BearerAuthCredentialswithHttpAuthorization(String aHttpAuthorization)Initializes thisAuthTypeCredentialsinstance from theHeaderField.AUTHORIZATIONHeader-Fields's value.-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface org.refcodes.web.TokenCredentials
isValid, isValid
-
-
-
-
Field Detail
-
DELIMITER_AUTH_TYPE
public static final char DELIMITER_AUTH_TYPE
- See Also:
- Constant Field Values
-
-
Constructor Detail
-
BearerAuthCredentials
public BearerAuthCredentials()
Instantiates a new bearer auth credentials impl.
-
BearerAuthCredentials
public BearerAuthCredentials(String aToken)
Instantiates a new bearer auth credentials impl.- Parameters:
aToken- the secret
-
-
Method Detail
-
validate
public void validate(TokenCredentials aCredentials) throws ForbiddenException
Validates the providedTokenCredentialswith thisBearerAuthCredentialsviaTokenCredentials.isValid(TokenCredentials). In case the providedTokenCredentialsare not valid, then aForbiddenExceptionis thrown.- Specified by:
validatein interfaceAuthTypeCredentials<BearerAuthCredentials,TokenCredentials>- Parameters:
aCredentials- TheTokenCredentialsto be verified.- Throws:
ForbiddenException- thrown in case the providedTokenCredentialsdo not match.
-
validate
public void validate(String aToken) throws ForbiddenException
Validates the provided user-name and secret with thisBearerAuthCredentialsviaTokenCredentials.isValid(String). In case the provided credentials are not valid, then aForbiddenExceptionis thrown.- Parameters:
aToken- The secret part to be tested if it fits with the thisTokenCredentialsinstance.- Throws:
ForbiddenException- thrown in case the providedTokenCredentialsdo not match.
-
withHttpAuthorization
public BearerAuthCredentials withHttpAuthorization(String aHttpAuthorization) throws IllegalArgumentException
Initializes thisAuthTypeCredentialsinstance from theHeaderField.AUTHORIZATIONHeader-Fields's value.- Specified by:
withHttpAuthorizationin interfaceAuthTypeCredentials<BearerAuthCredentials,TokenCredentials>- Parameters:
aHttpAuthorization- TheHeaderField.AUTHORIZATIONheader field's value- Returns:
- the t
- Throws:
IllegalArgumentException- The value does not conform the the HTTP Authorization Header-Field's Basic-Authentication format.
-
getAuthType
public AuthType getAuthType()
Retrieves theAuthTypefrom the Authorization-Type property (or null if there are none such credentials).- Specified by:
getAuthTypein interfaceAuthTypeAccessor- Returns:
- The
AuthTypestored by the Basic-Authentication credentials property (or null if there are none such credentials).
-
getToken
public String getToken()
- Specified by:
getTokenin interfaceorg.refcodes.mixin.TokenAccessor
-
fromHttpAuthorization
public void fromHttpAuthorization(String aHttpAuthorization)
Initializes thisAuthTypeCredentialsinstance from theHeaderField.AUTHORIZATIONHeader-Fields's value.- Specified by:
fromHttpAuthorizationin interfaceAuthTypeCredentials<BearerAuthCredentials,TokenCredentials>- Parameters:
aHttpAuthorization- TheHeaderField.AUTHORIZATIONheader field's value
-
toHttpAuthorization
public String toHttpAuthorization()
Creates aHeaderField.AUTHORIZATIONHTTP Header-Field value from theAuthTypeCredentialsinstance.- Specified by:
toHttpAuthorizationin interfaceAuthTypeCredentials<BearerAuthCredentials,TokenCredentials>- Returns:
- The according HTTP Header-Field's value.
-
-