All Implemented Interfaces:
Serializable , Comparable <ContentEncoding >, java.lang.constant.Constable, org.refcodes.mixin.NameAccessor
public enum ContentEncoding
extends Enum <ContentEncoding >
implements org.refcodes.mixin.NameAccessor
See Also:
"https://developer.mozilla.org/de/docs/Web/HTTP/Headers/Content-Encoding"
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.mixin.NameAccessor
org.refcodes.mixin.NameAccessor.NameBuilder<B extends org.refcodes.mixin.NameAccessor.NameBuilder<B>>, org.refcodes.mixin.NameAccessor.NameMutator, org.refcodes.mixin.NameAccessor.NameProperty
Method Summary
All Methods Static Methods Instance Methods Concrete Methods
Methods inherited from class java.lang.Enum
clone , compareTo , describeConstable , equals , finalize , getDeclaringClass , hashCode , name , ordinal , toString , valueOf
Method Details
values
Returns an array containing the constants of this enum type, in
the order they are declared.
Returns:
an array containing the constants of this enum type, in the order they are declared
valueOf
Returns the enum constant of this type with the specified name.
The string must match exactly an identifier used to declare an
enum constant in this type. (Extraneous whitespace characters are
not permitted.)
Parameters:
name - the name of the enum constant to be returned.
Returns:
the enum constant with the specified name
Throws:
IllegalArgumentException - if this enum type has no constant with the specified name
NullPointerException - if the argument is null
getName
Gets the name.
Specified by:
getName in interface org.refcodes.mixin.NameAccessor
Returns:
the name
fromHttpEncoding
Returns that
ContentEncoding represented by the given HTTP
header's encoding.
Parameters:
aHttpEncoding - The HTTP header encoding for which to determine the
ContentEncoding .
Returns:
The determined ContentEncoding or null if none was
determinable.