Class HttpClientRequest

    • Constructor Detail

      • HttpClientRequest

        public HttpClientRequest​(HttpMethod aHttpMethod,
                                 Url aUrl,
                                 MediaTypeFactoryLookup aMediaTypeFactoryLookup)
        Instantiates a new http client request impl.
        Parameters:
        aHttpMethod - the http method
        aUrl - The Url from which to take the URL specific data.
        aMediaTypeFactoryLookup - the media type factory lookup
      • HttpClientRequest

        public HttpClientRequest​(HttpMethod aHttpMethod,
                                 Url aUrl,
                                 Object aRequest,
                                 MediaTypeFactoryLookup aMediaTypeFactoryLookup)
        Instantiates a new http client request impl.
        Parameters:
        aHttpMethod - the http method
        aUrl - The Url from which to take the URL specific data.
        aRequest - the request
        aMediaTypeFactoryLookup - the media type factory lookup
      • HttpClientRequest

        public HttpClientRequest​(HttpMethod aHttpMethod,
                                 Url aUrl,
                                 RequestHeaderFields aHeaderFields,
                                 Object aRequest,
                                 MediaTypeFactoryLookup aMediaTypeFactoryLookup)
        Instantiates a new http client request impl.
        Parameters:
        aHttpMethod - the http method
        aUrl - The Url from which to take the URL specific data.
        aHeaderFields - the Header-Fields
        aRequest - the request
        aMediaTypeFactoryLookup - the media type factory lookup
      • HttpClientRequest

        public HttpClientRequest​(HttpMethod aHttpMethod,
                                 Url aUrl,
                                 int aRedirectDepth,
                                 MediaTypeFactoryLookup aMediaTypeFactoryLookup)
        Instantiates a new http client request impl.
        Parameters:
        aHttpMethod - the http method
        aUrl - The Url from which to take the URL specific data.
        aRedirectDepth - The redirect depth provides the count of HTTP-Request and HTTP-Response cycles where the response represents a redirect as of HttpStatusCode.isRedirectStatus(). A value of -1 represents a nearly infinite HTTP-Request and HTTP-Response cycle (infinite might mean a maximum of 256 cycle).
        aMediaTypeFactoryLookup - the media type factory lookup
      • HttpClientRequest

        public HttpClientRequest​(HttpMethod aHttpMethod,
                                 Url aUrl,
                                 Object aRequest,
                                 int aRedirectDepth,
                                 MediaTypeFactoryLookup aMediaTypeFactoryLookup)
        Instantiates a new http client request impl.
        Parameters:
        aHttpMethod - the http method
        aUrl - The Url from which to take the URL specific data.
        aRequest - the request
        aRedirectDepth - The redirect depth provides the count of HTTP-Request and HTTP-Response cycles where the response represents a redirect as of HttpStatusCode.isRedirectStatus(). A value of -1 represents a nearly infinite HTTP-Request and HTTP-Response cycle (infinite might mean a maximum of 256 cycle).
        aMediaTypeFactoryLookup - the media type factory lookup
      • HttpClientRequest

        public HttpClientRequest​(HttpMethod aHttpMethod,
                                 Url aUrl,
                                 RequestHeaderFields aHeaderFields,
                                 Object aRequest,
                                 int aRedirectDepth,
                                 MediaTypeFactoryLookup aMediaTypeFactoryLookup)
        Instantiates a new http client request impl.
        Parameters:
        aHttpMethod - the http method
        aUrl - The Url from which to take the URL specific data.
        aHeaderFields - the Header-Fields
        aRequest - the request
        aRedirectDepth - The redirect depth provides the count of HTTP-Request and HTTP-Response cycles where the response represents a redirect as of HttpStatusCode.isRedirectStatus(). A value of -1 keeps a redirect depth as used by default by underlying implementations.
        aMediaTypeFactoryLookup - the media type factory lookup