Interface HttpFields<B extends HttpFields<B>>

Type Parameters:
B - The generic type of the builder to be returned upon invoking builder methods.
All Superinterfaces:
Map<String,List<String>>
All Known Subinterfaces:
HeaderFields<C,B>
All Known Implementing Classes:
AbstractHeaderFields, AbstractHttpFields, FormFields, RequestHeaderFields, ResponseHeaderFields

public interface HttpFields<B extends HttpFields<B>> extends Map<String,List<String>>
Various key/value "collections" we run across when we develop HTTP based applications may have more then one value for one key. Such "collections" in this package are the HeaderFields as well as the FormFields. This interface represents this kind of data structure providing some common convenience methods.