Module org.refcodes.web
Package org.refcodes.web
Interface HttpInputStreamAccessor.HttpInputStreamProperty
-
- All Superinterfaces:
HttpInputStreamAccessor,HttpInputStreamAccessor.HttpInputStreamMutator
- Enclosing interface:
- HttpInputStreamAccessor
public static interface HttpInputStreamAccessor.HttpInputStreamProperty extends HttpInputStreamAccessor, HttpInputStreamAccessor.HttpInputStreamMutator
Provides a HTTPInputStreamproperty.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.web.HttpInputStreamAccessor
HttpInputStreamAccessor.HttpInputStreamBuilder<B extends HttpInputStreamAccessor.HttpInputStreamBuilder<B>>, HttpInputStreamAccessor.HttpInputStreamMutator, HttpInputStreamAccessor.HttpInputStreamProperty, HttpInputStreamAccessor.HttpInputStreamProvider<EXC extends Exception>
-
-
Method Summary
All Methods Instance Methods Default Methods Modifier and Type Method Description default InputStreamletHttpInputStream(InputStream aInputStream)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenInputStream(setter) as ofHttpInputStreamAccessor.HttpInputStreamMutator.setHttpInputStream(InputStream)and returns the very same value (getter).-
Methods inherited from interface org.refcodes.web.HttpInputStreamAccessor
getHttpInputStream
-
Methods inherited from interface org.refcodes.web.HttpInputStreamAccessor.HttpInputStreamMutator
setHttpInputStream
-
-
-
-
Method Detail
-
letHttpInputStream
default InputStream letHttpInputStream(InputStream aInputStream)
This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenInputStream(setter) as ofHttpInputStreamAccessor.HttpInputStreamMutator.setHttpInputStream(InputStream)and returns the very same value (getter).- Parameters:
aInputStream- TheInputStreamto set (viaHttpInputStreamAccessor.HttpInputStreamMutator.setHttpInputStream(InputStream)).- Returns:
- Returns the value passed for it to be used in conclusive processing steps.
-
-