java.lang.Object
org.refcodes.web.HttpServerContextBuilder
- All Implemented Interfaces:
org.refcodes.io.MaxConnectionsAccessor,org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsBuilder<HttpServerContextBuilder>,org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsMutator,org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsProperty,org.refcodes.mixin.PortAccessor,org.refcodes.mixin.PortAccessor.PortBuilder<HttpServerContextBuilder>,org.refcodes.mixin.PortAccessor.PortMutator,org.refcodes.mixin.PortAccessor.PortProperty,org.refcodes.security.KeyStoreDescriptorAccessor,org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorBuilder<HttpServerContextBuilder>,org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorMutator,org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorProperty,HttpServerContext,SchemeAccessor,SchemeAccessor.SchemeBuilder<HttpServerContextBuilder>,SchemeAccessor.SchemeMutator,SchemeAccessor.SchemeProperty
public class HttpServerContextBuilder
extends Object
implements HttpServerContext, SchemeAccessor.SchemeProperty, SchemeAccessor.SchemeBuilder<HttpServerContextBuilder>, org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorProperty, org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorBuilder<HttpServerContextBuilder>, org.refcodes.mixin.PortAccessor.PortProperty, org.refcodes.mixin.PortAccessor.PortBuilder<HttpServerContextBuilder>, org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsProperty, org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsBuilder<HttpServerContextBuilder>
The
HttpServerContextBuilder implements the HttpServerContext
interface extending it with builder functionality..-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.security.KeyStoreDescriptorAccessor
org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorBuilder<B extends org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorBuilder<B>>, org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorMutator, org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorPropertyNested classes/interfaces inherited from interface org.refcodes.io.MaxConnectionsAccessor
org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsBuilder<B extends org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsBuilder<B>>, org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsMutator, org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsPropertyNested classes/interfaces inherited from interface org.refcodes.mixin.PortAccessor
org.refcodes.mixin.PortAccessor.PortBuilder<B extends org.refcodes.mixin.PortAccessor.PortBuilder<B>>, org.refcodes.mixin.PortAccessor.PortMutator, org.refcodes.mixin.PortAccessor.PortPropertyNested classes/interfaces inherited from interface org.refcodes.web.SchemeAccessor
SchemeAccessor.SchemeBuilder<B extends SchemeAccessor.SchemeBuilder<B>>, SchemeAccessor.SchemeMutator, SchemeAccessor.SchemeProperty -
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final intstatic final org.refcodes.data.Scheme -
Constructor Summary
ConstructorsConstructorDescriptionConstructs aHttpClientContextwith a default schemeScheme.HTTPfor port 8080.HttpServerContextBuilder(int aPort) Constructs aHttpClientContextwith a default scheme.HttpServerContextBuilder(String aProtocol, int aPort) Constructs aHttpClientContextwith a default scheme.HttpServerContextBuilder(String aProtocol, int aPort, org.refcodes.security.KeyStoreDescriptor aKeyStoreDescriptor, int aMaxConnections) Constructs aHttpClientContextwith the given data.HttpServerContextBuilder(org.refcodes.data.Scheme aScheme, int aPort) Constructs aHttpClientContextwith a default scheme.HttpServerContextBuilder(org.refcodes.data.Scheme aScheme, int aPort, org.refcodes.security.KeyStoreDescriptor aKeyStoreDescriptor, int aMaxConnections) Constructs aHttpClientContextwith the given data. -
Method Summary
Modifier and TypeMethodDescriptionorg.refcodes.security.KeyStoreDescriptorintintgetPort()org.refcodes.data.SchemeRetrieves the UrlScheme from the URL scheme.voidsetKeyStoreDescriptor(org.refcodes.security.KeyStoreDescriptor aKeyStoreDescriptor) voidsetMaxConnections(int aMaxConnections) voidsetPort(int aPort) voidsetProtocol(String aProtocol) Sets the protocolStringrepresentation for the scheme property.voidsetScheme(org.refcodes.data.Scheme aScheme) Sets the UrlScheme for the URL scheme.Retrieves the protocol representation from theScheme.withKeyStoreDescriptor(org.refcodes.security.KeyStoreDescriptor aKeyStoreDescriptor) withMaxConnections(int aMaxConnections) withPort(int aPort) withProtocol(String aProtocol) Sets the protocol for the URL scheme.withScheme(org.refcodes.data.Scheme aScheme) Sets the UrlScheme for the URL scheme.Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorProperty
letKeyStoreDescriptorMethods inherited from interface org.refcodes.io.MaxConnectionsAccessor.MaxConnectionsProperty
letMaxConnectionsMethods inherited from interface org.refcodes.mixin.PortAccessor.PortProperty
letPortMethods inherited from interface org.refcodes.web.SchemeAccessor.SchemeProperty
letProtocol, letScheme
-
Field Details
-
DEFAULT_SCHEME
public static final org.refcodes.data.Scheme DEFAULT_SCHEME -
DEFAULT_PORT
public static final int DEFAULT_PORT- See Also:
-
-
Constructor Details
-
HttpServerContextBuilder
public HttpServerContextBuilder()Constructs aHttpClientContextwith a default schemeScheme.HTTPfor port 8080. -
HttpServerContextBuilder
public HttpServerContextBuilder(int aPort) Constructs aHttpClientContextwith a default scheme.- Parameters:
aPort- The TCP port to be used.
-
HttpServerContextBuilder
public HttpServerContextBuilder(org.refcodes.data.Scheme aScheme, int aPort) Constructs aHttpClientContextwith a default scheme.- Parameters:
aScheme- TheScheme(HTTP or HTTPS) to be used.aPort- The TCP port to be used.
-
HttpServerContextBuilder
Constructs aHttpClientContextwith a default scheme.- Parameters:
aProtocol- The protocol such as theTransportLayerProtocolaPort- The TCP port to be used.
-
HttpServerContextBuilder
public HttpServerContextBuilder(org.refcodes.data.Scheme aScheme, int aPort, org.refcodes.security.KeyStoreDescriptor aKeyStoreDescriptor, int aMaxConnections) Constructs aHttpClientContextwith the given data.- Parameters:
aScheme- TheScheme(HTTP or HTTPS) to be used.aPort- The TCP port to be used.aKeyStoreDescriptor- The descriptor describing the keystore to be used.aMaxConnections- The maximum allowed open connections.
-
HttpServerContextBuilder
public HttpServerContextBuilder(String aProtocol, int aPort, org.refcodes.security.KeyStoreDescriptor aKeyStoreDescriptor, int aMaxConnections) Constructs aHttpClientContextwith the given data.- Parameters:
aProtocol- The protocol such as theTransportLayerProtocolelements.aPort- The TCP port to be used.aKeyStoreDescriptor- The descriptor describing the keystore to be used.aMaxConnections- The maximum allowed open connections.
-
-
Method Details
-
getKeyStoreDescriptor
public org.refcodes.security.KeyStoreDescriptor getKeyStoreDescriptor()- Specified by:
getKeyStoreDescriptorin interfaceorg.refcodes.security.KeyStoreDescriptorAccessor
-
getMaxConnections
public int getMaxConnections()- Specified by:
getMaxConnectionsin interfaceorg.refcodes.io.MaxConnectionsAccessor
-
getPort
public int getPort()- Specified by:
getPortin interfaceorg.refcodes.mixin.PortAccessor
-
getScheme
public org.refcodes.data.Scheme getScheme()Retrieves the UrlScheme from the URL scheme.- Specified by:
getSchemein interfaceSchemeAccessor- Returns:
- The UrlScheme stored by the URL scheme.
-
setKeyStoreDescriptor
public void setKeyStoreDescriptor(org.refcodes.security.KeyStoreDescriptor aKeyStoreDescriptor) - Specified by:
setKeyStoreDescriptorin interfaceorg.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorMutator
-
setMaxConnections
public void setMaxConnections(int aMaxConnections) - Specified by:
setMaxConnectionsin interfaceorg.refcodes.io.MaxConnectionsAccessor.MaxConnectionsMutator
-
setPort
public void setPort(int aPort) - Specified by:
setPortin interfaceorg.refcodes.mixin.PortAccessor.PortMutator
-
setScheme
public void setScheme(org.refcodes.data.Scheme aScheme) Sets the UrlScheme for the URL scheme.- Specified by:
setSchemein interfaceSchemeAccessor.SchemeMutator- Parameters:
aScheme- The UrlScheme to be stored by the URL scheme.
-
toProtocol
Retrieves the protocol representation from theScheme. In case of a scheme unknown by theSchemeenumeration, thenSchemeAccessor.getScheme()might return null whilstSchemeAccessor.toProtocol()still retrieves the unknown scheme's protocol representation (as ofSchemeAccessor.SchemeMutator.setProtocol(String)).- Specified by:
toProtocolin interfaceSchemeAccessor- Returns:
- The protocol representation for the URL.
-
setProtocol
Sets the protocolStringrepresentation for the scheme property. You must provide the scheme's specific part as well. In case of HTTP, provide "http://". In case your provided protocol is unknown by theSchemeenumeration, then the scheme property will not be set, though theSchemeAccessor.toProtocol()still returns your protocol.- Specified by:
setProtocolin interfaceSchemeAccessor.SchemeMutator- Parameters:
aProtocol- The UrlScheme'sStringrepresentation to be stored by the URL scheme.
-
withKeyStoreDescriptor
public HttpServerContextBuilder withKeyStoreDescriptor(org.refcodes.security.KeyStoreDescriptor aKeyStoreDescriptor) - Specified by:
withKeyStoreDescriptorin interfaceorg.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorBuilder<HttpServerContextBuilder>
-
withMaxConnections
- Specified by:
withMaxConnectionsin interfaceorg.refcodes.io.MaxConnectionsAccessor.MaxConnectionsBuilder<HttpServerContextBuilder>
-
withPort
- Specified by:
withPortin interfaceorg.refcodes.mixin.PortAccessor.PortBuilder<HttpServerContextBuilder>
-
withProtocol
Sets the protocol for the URL scheme.- Specified by:
withProtocolin interfaceSchemeAccessor.SchemeBuilder<HttpServerContextBuilder>- Parameters:
aProtocol- The protocol to be stored by the URL scheme.- Returns:
- The builder for applying multiple build operations.
-
withScheme
Sets the UrlScheme for the URL scheme.- Specified by:
withSchemein interfaceSchemeAccessor.SchemeBuilder<HttpServerContextBuilder>- Parameters:
aScheme- The UrlScheme to be stored by the URL scheme.- Returns:
- The builder for applying multiple build operations.
-