Class InternalClientErrorException

java.lang.Object
java.lang.Throwable
java.lang.Exception
org.refcodes.exception.AbstractException
All Implemented Interfaces:
Serializable, org.refcodes.exception.ErrorCodeAccessor, org.refcodes.exception.Trap, org.refcodes.mixin.StatusCodeAccessor<HttpStatusCode>, UrlAccessor

public class InternalClientErrorException extends HttpStatusException
Proprietary code and only used inside a REFCODES.ORG client not trespassing any networking border (the error is generated by the client for the client locally). This code is used is used when a client signals the business logic that internal client processing failed even though the response was received fine.
See Also: