java.lang.Object
java.lang.Throwable
java.lang.Exception
org.refcodes.exception.AbstractException
org.refcodes.web.WebException
org.refcodes.web.HttpException
org.refcodes.web.HttpStatusException
org.refcodes.web.InternalClientErrorException
- All Implemented Interfaces:
Serializable,org.refcodes.exception.ErrorCodeAccessor,org.refcodes.exception.Trap,org.refcodes.mixin.StatusCodeAccessor<HttpStatusCode>
Proprietary code and only used inside a REFCODES.ORG client not trespassing
any networking border (the error is generated by the client for the client
locally). This code is used is used when a client signals the business logic
that internal client processing failed even though the response was received
fine.
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.exception.ErrorCodeAccessor
org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B extends org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B>>, org.refcodes.exception.ErrorCodeAccessor.ErrorCodeMutator, org.refcodes.exception.ErrorCodeAccessor.ErrorCodePropertyNested classes/interfaces inherited from interface org.refcodes.mixin.StatusCodeAccessor
org.refcodes.mixin.StatusCodeAccessor.StatusCodeBuilder<SC extends Object,B extends org.refcodes.mixin.StatusCodeAccessor.StatusCodeBuilder<SC, B>>, org.refcodes.mixin.StatusCodeAccessor.StatusCodeMutator<SC extends Object>, org.refcodes.mixin.StatusCodeAccessor.StatusCodeProperty<SC extends Object> -
Constructor Summary
ConstructorsConstructorDescriptionInternalClientErrorException(String aMessage) Instantiates a new internal client error exception.InternalClientErrorException(String aMessage, String aErrorCode) Instantiates a new internal client error exception.InternalClientErrorException(String aMessage, Throwable aCause) Instantiates a new internal client error exception.InternalClientErrorException(String aMessage, Throwable aCause, String aErrorCode) Instantiates a new internal client error exception.Instantiates a new internal client error exception.InternalClientErrorException(Throwable aCause, String aErrorCode) Instantiates a new internal client error exception. -
Method Summary
Methods inherited from class org.refcodes.web.HttpStatusException
getStatusCodeMethods inherited from class org.refcodes.exception.AbstractException
getErrorCodeMethods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.exception.Trap
toLocalizedMessage, toMessage, toShortLocalizedMessage, toShortMessage
-
Constructor Details
-
InternalClientErrorException
Instantiates a new internal client error exception.- Parameters:
aMessage- The aMessage describing this exception.aErrorCode- The error code identifying this exception.
-
InternalClientErrorException
Instantiates a new internal client error exception. -
InternalClientErrorException
Instantiates a new internal client error exception. -
InternalClientErrorException
Instantiates a new internal client error exception.- Parameters:
aMessage- The aMessage describing this exception.
-
InternalClientErrorException
Instantiates a new internal client error exception. -
InternalClientErrorException
Instantiates a new internal client error exception.
-