Enum PortRange

java.lang.Object
java.lang.Enum<PortRange>
org.refcodes.web.PortRange
All Implemented Interfaces:
Serializable, Comparable<PortRange>, java.lang.constant.Constable, org.refcodes.mixin.MaxValueAccessor<Integer>, org.refcodes.mixin.MinValueAccessor<Integer>, org.refcodes.struct.Range<Integer>

public enum PortRange
extends Enum<PortRange>
implements org.refcodes.struct.Range<Integer>
Port range definitions as of RFC 6335 ("https://tools.ietf.org/html/rfc6335")
  • Nested Class Summary

    Nested classes/interfaces inherited from class java.lang.Enum

    Enum.EnumDesc<E extends Enum<E>>

    Nested classes/interfaces inherited from interface org.refcodes.mixin.MaxValueAccessor

    org.refcodes.mixin.MaxValueAccessor.MaxValueBuilder<V extends Object,​B extends org.refcodes.mixin.MaxValueAccessor.MaxValueBuilder<V,​B>>, org.refcodes.mixin.MaxValueAccessor.MaxValueMutator<V extends Object>, org.refcodes.mixin.MaxValueAccessor.MaxValueProperty<V extends Object>

    Nested classes/interfaces inherited from interface org.refcodes.mixin.MinValueAccessor

    org.refcodes.mixin.MinValueAccessor.MinValueBuilder<V extends Object,​B extends org.refcodes.mixin.MinValueAccessor.MinValueBuilder<V,​B>>, org.refcodes.mixin.MinValueAccessor.MinValueMutator<V extends Object>, org.refcodes.mixin.MinValueAccessor.MinValueProperty<V extends Object>

    Nested classes/interfaces inherited from interface org.refcodes.struct.Range

    org.refcodes.struct.Range.RangeBuilder<V extends Number & Comparable<V>>
  • Enum Constant Summary

    Enum Constants
    Enum Constant Description
    DYNAMIC_PORTS  
    LINUX_DYNAMIC_PORTS  
    REGISTERED_PORTS  
    SYSTEM_PORTS  
  • Method Summary

    Modifier and Type Method Description
    Integer getMaxValue()
    Integer getMinValue()
    static PortRange valueOf​(String name)
    Returns the enum constant of this type with the specified name.
    static PortRange[] values()
    Returns an array containing the constants of this enum type, in the order they are declared.

    Methods inherited from class java.lang.Object

    getClass, notify, notifyAll, wait, wait, wait

    Methods inherited from interface org.refcodes.struct.Range

    isMember
  • Enum Constant Details

    • SYSTEM_PORTS

      public static final PortRange SYSTEM_PORTS
    • REGISTERED_PORTS

      public static final PortRange REGISTERED_PORTS
    • DYNAMIC_PORTS

      public static final PortRange DYNAMIC_PORTS
    • LINUX_DYNAMIC_PORTS

      public static final PortRange LINUX_DYNAMIC_PORTS
  • Method Details

    • values

      public static PortRange[] values()
      Returns an array containing the constants of this enum type, in the order they are declared.
      Returns:
      an array containing the constants of this enum type, in the order they are declared
    • valueOf

      public static PortRange valueOf​(String name)
      Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum type has no constant with the specified name
      NullPointerException - if the argument is null
    • getMinValue

      public Integer getMinValue()
      Specified by:
      getMinValue in interface org.refcodes.mixin.MinValueAccessor<Integer>
    • getMaxValue

      public Integer getMaxValue()
      Specified by:
      getMaxValue in interface org.refcodes.mixin.MaxValueAccessor<Integer>