Interface PreHttpInterceptor<REQ extends HttpRequest,RES extends HttpResponse>

All Known Subinterfaces:
HttpClientInterceptor, HttpInterceptor<REQ,RES>, HttpServerInterceptor, PreHttpClientInterceptor, PreHttpServerInterceptor
Functional Interface:
This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.

@FunctionalInterface public interface PreHttpInterceptor<REQ extends HttpRequest,RES extends HttpResponse>
An PreHttpInterceptor definition for pre-processing HttpRequest as well as HttpResponse instances.