Module org.refcodes.web
Package org.refcodes.web
Interface PreHttpInterceptor<REQ extends HttpRequest,RES extends HttpResponse>
- All Known Subinterfaces:
HttpClientInterceptor,HttpInterceptor<REQ,,RES> HttpServerInterceptor,PreHttpClientInterceptor,PreHttpServerInterceptor
- Functional Interface:
- This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.
@FunctionalInterface
public interface PreHttpInterceptor<REQ extends HttpRequest,RES extends HttpResponse>
-
Method Summary
Modifier and TypeMethodDescriptionvoidpreIntercept(REQ aRequest, RES aResponse) Invoked to pre-process aHttpRequestalongside aHttpResponse.
-
Method Details
-
preIntercept
Invoked to pre-process aHttpRequestalongside aHttpResponse.- Parameters:
aRequest- TheHttpRequestto pre-process.aResponse- TheHttpResponseto pre-process.
-