- All Implemented Interfaces:
org.refcodes.mixin.KeyAccessor<String>,org.refcodes.mixin.KeyAccessor.KeyBuilder<String,,org.refcodes.struct.Relation.RelationBuilder<String, String>> org.refcodes.mixin.KeyAccessor.KeyMutator<String>,org.refcodes.mixin.KeyAccessor.KeyProperty<String>,org.refcodes.mixin.ValueAccessor<String>,org.refcodes.mixin.ValueAccessor.ValueBuilder<String,,org.refcodes.struct.Relation.RelationBuilder<String, String>> org.refcodes.mixin.ValueAccessor.ValueMutator<String>,org.refcodes.mixin.ValueAccessor.ValueProperty<String>,org.refcodes.struct.Property,org.refcodes.struct.Property.PropertyBuilder,org.refcodes.struct.Relation<String,,String> org.refcodes.struct.Relation.RelationBuilder<String,,String> Cookie
public class RequestCookie
extends org.refcodes.struct.PropertyImpl.PropertyBuilderImpl
implements Cookie
The
RequestCookie represents a request cookies: We use URL encoding /
decoding for the cookie value (regarding fromHttpCookie(String) and
toHttpCookie()) to make life easier and not fall into the trap of
unescaped values.-
Nested Class Summary
Nested classes/interfaces inherited from class org.refcodes.struct.PropertyImpl
org.refcodes.struct.PropertyImpl.PropertyBuilderImplNested classes/interfaces inherited from class org.refcodes.struct.RelationImpl
org.refcodes.struct.RelationImpl.RelationBuilderImpl<K,V> Nested classes/interfaces inherited from interface org.refcodes.mixin.KeyAccessor
org.refcodes.mixin.KeyAccessor.KeyBuilder<K,B extends org.refcodes.mixin.KeyAccessor.KeyBuilder<K, B>>, org.refcodes.mixin.KeyAccessor.KeyMutator<K>, org.refcodes.mixin.KeyAccessor.KeyProperty<K> Nested classes/interfaces inherited from interface org.refcodes.struct.Property
org.refcodes.struct.Property.PropertyBuilderNested classes/interfaces inherited from interface org.refcodes.struct.Relation
org.refcodes.struct.Relation.RelationBuilder<K,V> Nested classes/interfaces inherited from interface org.refcodes.mixin.ValueAccessor
org.refcodes.mixin.ValueAccessor.ValueBuilder<V,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V, B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V>, org.refcodes.mixin.ValueAccessor.ValueProperty<V> -
Field Summary
Fields inherited from class org.refcodes.struct.RelationImpl
_key, _value -
Constructor Summary
ConstructorsConstructorDescriptionConstructs aRequestCookie.RequestCookie(String aHttpCookie) Constructs aRequestCookie.RequestCookie(String aCookieName, String aValue) Constructs aRequestCookiewith the given cookie name and value. -
Method Summary
Modifier and TypeMethodDescriptionvoidfromHttpCookie(String aHttpCookie) Sets the cookie according to the provided HTTP cookie text.Returns the cookie to be assigned to a cookie Header-Field.toString()withHttpCookie(String aCookie) Sets the cookie according to the provided HTTP cookie text viaCookie.fromHttpCookie(String).Methods inherited from class org.refcodes.struct.PropertyImpl.PropertyBuilderImpl
setKey, setValueMethods inherited from class org.refcodes.struct.RelationImpl
getKey, getValueMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.mixin.KeyAccessor
getKeyMethods inherited from interface org.refcodes.mixin.KeyAccessor.KeyMutator
setKeyMethods inherited from interface org.refcodes.mixin.KeyAccessor.KeyProperty
letKeyMethods inherited from interface org.refcodes.struct.Property
toPropertyMethods inherited from interface org.refcodes.struct.Property.PropertyBuilder
withKey, withValueMethods inherited from interface org.refcodes.mixin.ValueAccessor
getValue, getValueOrMethods inherited from interface org.refcodes.mixin.ValueAccessor.ValueMutator
setValueMethods inherited from interface org.refcodes.mixin.ValueAccessor.ValueProperty
letValue
-
Constructor Details
-
RequestCookie
public RequestCookie()Constructs aRequestCookie. -
RequestCookie
Constructs aRequestCookiewith the given cookie name and value.- Parameters:
aCookieName- The name of the cookie.aValue- The value for the cookie.
-
RequestCookie
Constructs aRequestCookie.- Parameters:
aHttpCookie- The text as being found in the according HTTP header field.
-
-
Method Details
-
withHttpCookie
Sets the cookie according to the provided HTTP cookie text viaCookie.fromHttpCookie(String).- Specified by:
withHttpCookiein interfaceCookie- Parameters:
aCookie- The HTTP cookie text.- Returns:
- A
Cookieinstance as of the Builder-Pattern.
-
fromHttpCookie
Sets the cookie according to the provided HTTP cookie text.- Specified by:
fromHttpCookiein interfaceCookie- Parameters:
aHttpCookie- The HTTP cookie text.
-
toHttpCookie
Returns the cookie to be assigned to a cookie Header-Field.- Specified by:
toHttpCookiein interfaceCookie- Returns:
- The cookie value for a Header-Field.
-
toString
- Overrides:
toStringin classorg.refcodes.struct.PropertyImpl.PropertyBuilderImpl
-