-
- All Implemented Interfaces:
org.refcodes.mixin.KeyAccessor<String>,org.refcodes.mixin.KeyAccessor.KeyBuilder<String,org.refcodes.struct.Relation.RelationBuilder<String,String>>,org.refcodes.mixin.KeyAccessor.KeyMutator<String>,org.refcodes.mixin.KeyAccessor.KeyProperty<String>,org.refcodes.mixin.ValueAccessor<String>,org.refcodes.mixin.ValueAccessor.ValueBuilder<String,org.refcodes.struct.Relation.RelationBuilder<String,String>>,org.refcodes.mixin.ValueAccessor.ValueMutator<String>,org.refcodes.mixin.ValueAccessor.ValueProperty<String>,org.refcodes.struct.Property,org.refcodes.struct.Property.PropertyBuilder,org.refcodes.struct.Relation<String,String>,org.refcodes.struct.Relation.RelationBuilder<String,String>,Cookie
public class RequestCookie extends org.refcodes.struct.PropertyImpl.PropertyBuilderImpl implements Cookie
TheRequestCookierepresents a request cookies: We use URL encoding / decoding for the cookie value (regardingfromHttpCookie(String)andtoHttpCookie()) to make life easier and not fall into the trap of unescaped values.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from class org.refcodes.struct.PropertyImpl
org.refcodes.struct.PropertyImpl.PropertyBuilderImpl
-
Nested classes/interfaces inherited from class org.refcodes.struct.RelationImpl
org.refcodes.struct.RelationImpl.RelationBuilderImpl<K extends Object,V extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.KeyAccessor
org.refcodes.mixin.KeyAccessor.KeyBuilder<K extends Object,B extends org.refcodes.mixin.KeyAccessor.KeyBuilder<K,B>>, org.refcodes.mixin.KeyAccessor.KeyMutator<K extends Object>, org.refcodes.mixin.KeyAccessor.KeyProperty<K extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.struct.Property
org.refcodes.struct.Property.PropertyBuilder
-
Nested classes/interfaces inherited from interface org.refcodes.struct.Relation
org.refcodes.struct.Relation.RelationBuilder<K extends Object,V extends Object>
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.ValueAccessor
org.refcodes.mixin.ValueAccessor.ValueBuilder<V extends Object,B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V,B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V extends Object>, org.refcodes.mixin.ValueAccessor.ValueProperty<V extends Object>
-
-
Constructor Summary
Constructors Constructor Description RequestCookie()Constructs aRequestCookie.RequestCookie(String aHttpCookie)Constructs aRequestCookie.RequestCookie(String aCookieName, String aValue)Constructs aRequestCookiewith the given cookie name and value.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description voidfromHttpCookie(String aHttpCookie)Sets the cookie according to the provided HTTP cookie text.StringtoHttpCookie()Returns the cookie to be assigned to a cookie Header-Field.StringtoString()RequestCookiewithHttpCookie(String aCookie)Sets the cookie according to the provided HTTP cookie text viaCookie.fromHttpCookie(String).
-
-
-
Constructor Detail
-
RequestCookie
public RequestCookie()
Constructs aRequestCookie.
-
RequestCookie
public RequestCookie(String aCookieName, String aValue)
Constructs aRequestCookiewith the given cookie name and value.- Parameters:
aCookieName- The name of the cookie.aValue- The value for the cookie.
-
RequestCookie
public RequestCookie(String aHttpCookie)
Constructs aRequestCookie.- Parameters:
aHttpCookie- The text as being found in the according HTTP header field.
-
-
Method Detail
-
withHttpCookie
public RequestCookie withHttpCookie(String aCookie)
Sets the cookie according to the provided HTTP cookie text viaCookie.fromHttpCookie(String).- Specified by:
withHttpCookiein interfaceCookie- Parameters:
aCookie- The HTTP cookie text.- Returns:
- A
Cookieinstance as of the Builder-Pattern.
-
fromHttpCookie
public void fromHttpCookie(String aHttpCookie)
Sets the cookie according to the provided HTTP cookie text.- Specified by:
fromHttpCookiein interfaceCookie- Parameters:
aHttpCookie- The HTTP cookie text.
-
toHttpCookie
public String toHttpCookie()
Returns the cookie to be assigned to a cookie Header-Field.- Specified by:
toHttpCookiein interfaceCookie- Returns:
- The cookie value for a Header-Field.
-
toString
public String toString()
- Overrides:
toStringin classorg.refcodes.struct.PropertyImpl.PropertyBuilderImpl
-
-