Interface RequestCookie

  • All Superinterfaces:
    Cookie, org.refcodes.mixin.KeyAccessor<String>, org.refcodes.mixin.KeyAccessor.KeyBuilder<String,​org.refcodes.struct.Relation.RelationBuilder<String,​String>>, org.refcodes.mixin.KeyAccessor.KeyMutator<String>, org.refcodes.mixin.KeyAccessor.KeyProperty<String>, org.refcodes.struct.Property, org.refcodes.struct.Property.PropertyBuilder, org.refcodes.struct.Relation<String,​String>, org.refcodes.struct.Relation.RelationBuilder<String,​String>, org.refcodes.mixin.ValueAccessor<String>, org.refcodes.mixin.ValueAccessor.ValueBuilder<String,​org.refcodes.struct.Relation.RelationBuilder<String,​String>>, org.refcodes.mixin.ValueAccessor.ValueMutator<String>, org.refcodes.mixin.ValueAccessor.ValueProperty<String>
    All Known Implementing Classes:
    RequestCookieImpl

    public interface RequestCookie
    extends Cookie
    The RequestCookie represents a builder for a building request cookies. We use URL encoding / decoding for the cookie value (regarding fromHttpCookie(String) and toHttpCookie()) to make life easier and not fall into the trap of unescaped values.
    • Nested Class Summary

      • Nested classes/interfaces inherited from interface org.refcodes.mixin.KeyAccessor

        org.refcodes.mixin.KeyAccessor.KeyBuilder<K extends Object,​B extends org.refcodes.mixin.KeyAccessor.KeyBuilder<K,​B>>, org.refcodes.mixin.KeyAccessor.KeyMutator<K extends Object>, org.refcodes.mixin.KeyAccessor.KeyProperty<K extends Object>
      • Nested classes/interfaces inherited from interface org.refcodes.struct.Property

        org.refcodes.struct.Property.PropertyBuilder
      • Nested classes/interfaces inherited from interface org.refcodes.struct.Relation

        org.refcodes.struct.Relation.RelationBuilder<K extends Object,​V extends Object>
      • Nested classes/interfaces inherited from interface org.refcodes.mixin.ValueAccessor

        org.refcodes.mixin.ValueAccessor.ValueBuilder<V extends Object,​B extends org.refcodes.mixin.ValueAccessor.ValueBuilder<V,​B>>, org.refcodes.mixin.ValueAccessor.ValueMutator<V extends Object>, org.refcodes.mixin.ValueAccessor.ValueProperty<V extends Object>
    • Method Summary

      All Methods Instance Methods Default Methods 
      Modifier and Type Method Description
      default void fromHttpCookie​(String aHttpCookie)
      Sets the cookie according to the provided HTTP cookie text.
      default String toHttpCookie()
      Returns the cookie to be assigned to a cookie Header-Field.
      default RequestCookie withHttpCookie​(String aCookie)
      Sets the cookie according to the provided HTTP cookie text via Cookie.fromHttpCookie(String).
      • Methods inherited from interface org.refcodes.mixin.KeyAccessor

        getKey
      • Methods inherited from interface org.refcodes.mixin.KeyAccessor.KeyMutator

        setKey
      • Methods inherited from interface org.refcodes.mixin.KeyAccessor.KeyProperty

        letKey
      • Methods inherited from interface org.refcodes.struct.Property

        toProperty
      • Methods inherited from interface org.refcodes.struct.Property.PropertyBuilder

        withKey, withValue
      • Methods inherited from interface org.refcodes.mixin.ValueAccessor

        getValue, getValueOr
      • Methods inherited from interface org.refcodes.mixin.ValueAccessor.ValueMutator

        setValue
      • Methods inherited from interface org.refcodes.mixin.ValueAccessor.ValueProperty

        letValue
    • Method Detail

      • fromHttpCookie

        default void fromHttpCookie​(String aHttpCookie)
        Sets the cookie according to the provided HTTP cookie text.
        Specified by:
        fromHttpCookie in interface Cookie
        Parameters:
        aHttpCookie - The HTTP cookie text.
      • toHttpCookie

        default String toHttpCookie()
        Returns the cookie to be assigned to a cookie Header-Field.
        Specified by:
        toHttpCookie in interface Cookie
        Returns:
        The cookie value for a Header-Field.