- java.lang.Object
-
- java.util.AbstractMap<K,V>
-
- java.util.HashMap<String,List<String>>
-
- org.refcodes.web.AbstractHttpFields<T>
-
- org.refcodes.web.AbstractHeaderFields<RequestCookie,RequestHeaderFields>
-
- org.refcodes.web.RequestHeaderFields
-
- All Implemented Interfaces:
Serializable,Cloneable,Map<String,List<String>>,HeaderFields<RequestCookie,RequestHeaderFields>,HttpFields<RequestHeaderFields>
public class RequestHeaderFields extends AbstractHeaderFields<RequestCookie,RequestHeaderFields> implements HeaderFields<RequestCookie,RequestHeaderFields>
TheRequestHeaderFieldsreflect the structure of a HTTP-Header and may be used to represent a HTTP-Header.- See Also:
- Serialized Form
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from class java.util.AbstractMap
AbstractMap.SimpleEntry<K extends Object,V extends Object>, AbstractMap.SimpleImmutableEntry<K extends Object,V extends Object>
-
-
Field Summary
-
Fields inherited from interface org.refcodes.web.HeaderFields
BASIC_REALM
-
-
Constructor Summary
Constructors Constructor Description RequestHeaderFields()Instantiates a new request Header-Fields impl.RequestHeaderFields(Map<String,List<String>> aFromHeaderFields)Instantiates a new request Header-Fields impl.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description RequestCookieaddCookie(String aHttpCookie)Adds an individual server-side cookie to be sent to the client to thisResponseHeaderFieldsinstance.protected RequestCookiecreateCookie(String aHttpCookie)protected RequestCookiecreateCookie(String aCookieName, String aValue)Creates a plainCookiewith the given name and value.protected StringgetCookieFieldName()The Header-Field name for theCookieelements.-
Methods inherited from class org.refcodes.web.AbstractHeaderFields
addCookie, addCookie, addTo, entrySet, get, getAllCookies, isCommaSeparatedHeaderField, keySet, put, putAll, toHeaderField, toHeaderFields
-
Methods inherited from class org.refcodes.web.AbstractHttpFields
copyHttpFields
-
Methods inherited from class java.util.HashMap
clear, clone, compute, computeIfAbsent, computeIfPresent, containsKey, containsValue, forEach, getOrDefault, isEmpty, merge, putIfAbsent, remove, remove, replace, replace, replaceAll, size, values
-
Methods inherited from class java.util.AbstractMap
equals, hashCode, toString
-
Methods inherited from class java.lang.Object
finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface org.refcodes.web.HeaderFields
addCookie, addCookie, addTo, addTo, addTo, get, getAcceptCharsets, getAcceptEncodings, getAcceptLanguages, getAcceptTypes, getAllCookies, getAllowMethods, getAuthenticate, getAuthorization, getBasicAuth, getBasicAuthCredentials, getBearerAuthCredentials, getContentEncoding, getContentLength, getContentType, getCookies, getFirst, getFirstCookie, getHost, getRequestId, getSessionId, getUnknownAcceptTypes, getUnknownContentTypes, getUserAgent, put, put, put, putAcceptCharsets, putAcceptCharsets, putAcceptEncodings, putAcceptEncodings, putAcceptLanguages, putAcceptLanguages, putAcceptTypes, putAcceptTypes, putAllowMethods, putAllowMethods, putAuthenticate, putAuthorization, putAuthorization, putAuthorization, putBasicAuthCredentials, putBasicAuthCredentials, putBasicAuthRequired, putBearerAuthCredentials, putBearerAuthCredentials, putContentEncoding, putContentLength, putContentType, putContentType, putHost, putRequestId, putSessionId, putUserAgent, remove, removeAcceptCharsets, removeAcceptEncodings, removeAcceptLanguages, removeAcceptTypes, removeAllowMethods, removeAuthenticate, removeAuthorization, removeBasicAuthCredentials, removeBasicAuthenticate, removeBearerAuthCredentials, removeContentEncoding, removeContentLength, removeContentType, removeHost, removeRequestId, removeSessionId, removeUserAgent, toBasicAuthRealm, toHeaderFields, toHttpCookies, withAcceptCharsets, withAcceptCharsets, withAcceptEncodings, withAcceptEncodings, withAcceptLanguages, withAcceptLanguages, withAcceptTypes, withAcceptTypes, withAddCookie, withAddCookie, withAddTo, withAddTo, withAddTo, withAllowMethods, withAllowMethods, withAuthenticate, withAuthorization, withAuthorization, withAuthorization, withBasicAuthCredentials, withBasicAuthCredentials, withBasicAuthRequired, withBearerAuthCredentials, withBearerAuthCredentials, withContentEncoding, withContentLength, withContentType, withContentType, withHost, withPut, withPut, withPut, withRequestId, withSessionId, withUserAgent
-
Methods inherited from interface org.refcodes.web.HttpFields
addTo, addTo, addTo, addTo, addTo, addTo, getFirst, getFirst, put, put, put, put, toField, toField, withAddTo, withAddTo, withAddTo, withAddTo, withAddTo, withAddTo, withPut, withPut, withPut, withPut, withPut, withPut
-
Methods inherited from interface java.util.Map
clear, compute, computeIfAbsent, computeIfPresent, containsKey, containsValue, entrySet, equals, forEach, get, getOrDefault, hashCode, isEmpty, keySet, merge, put, putAll, putIfAbsent, remove, remove, replace, replace, replaceAll, size, values
-
-
-
-
Method Detail
-
addCookie
public RequestCookie addCookie(String aHttpCookie)
Adds an individual server-side cookie to be sent to the client to thisResponseHeaderFieldsinstance. The server-side cookies are retrieved from theHeaderField.SET_COOKIEHeader-Field. WITH THE METHODHeaderFields.getAllCookies()andHeaderFields.getCookies(String)as well asHeaderFields.getFirstCookie(String)ONLY THE COOKIES SENT BY THE CLIENT CAN BE RETRIEVED (E.G. COOKIES RESIDING IN THE HEADER FIELDHeaderField.COOKIE). COOKIES SET VIAHeaderFields.addCookie(String, String)ORHeaderFields.withAddCookie(String, String)CANNOT BE RETRIEVED, AS THE COOKIES BEING SET SERVER-SIDE ARE PUT IN THEHeaderField.SET_COOKIEHeader-Field.- Specified by:
addCookiein interfaceHeaderFields<RequestCookie,RequestHeaderFields>- Parameters:
aHttpCookie- The HTTP-CookieStringto be paresd as a cookie.- Returns:
- The resulting cookie builder being added which can be modified
affecting(!) this
ResponseHeaderFieldsinstance!
-
getCookieFieldName
protected String getCookieFieldName()
The Header-Field name for theCookieelements. The Header-Field name differs from the context, e.g. when setting aCookieserver-side or when retrieving aCookieclient-side.- Specified by:
getCookieFieldNamein classAbstractHeaderFields<RequestCookie,RequestHeaderFields>- Returns:
- The Header-Field where the
Cookieelements are stored.
-
createCookie
protected RequestCookie createCookie(String aCookieName, String aValue)
Creates a plainCookiewith the given name and value.- Specified by:
createCookiein classAbstractHeaderFields<RequestCookie,RequestHeaderFields>- Parameters:
aCookieName- The name of theCookie.aValue- The value for theCookie- Returns:
- The
Cookiewith the given name and value.
-
createCookie
protected RequestCookie createCookie(String aHttpCookie)
- Specified by:
createCookiein classAbstractHeaderFields<RequestCookie,RequestHeaderFields>- Parameters:
aHttpCookie- The text of the Header-Field for the cookie to be created.- Returns:
- The
Cookiewith the given cookie properties.
-
-