-
- All Superinterfaces:
org.refcodes.mixin.TokenAccessor,org.refcodes.mixin.Validatable<TokenCredentials>
- All Known Implementing Classes:
BearerAuthCredentials
public interface TokenCredentials extends org.refcodes.mixin.TokenAccessor, org.refcodes.mixin.Validatable<TokenCredentials>
The Interface TokenCredentials.
-
-
Method Summary
All Methods Instance Methods Default Methods Modifier and Type Method Description default booleanisValid(String aToken)Validates the provided user-name and secret against thisTokenCredentialsuser-name and secret.default booleanisValid(TokenCredentials aCredentials)Validates the providedTokenCredentialsagainst thisTokenCredentialsuser-name and secret.
-
-
-
Method Detail
-
isValid
default boolean isValid(TokenCredentials aCredentials)
Validates the providedTokenCredentialsagainst thisTokenCredentialsuser-name and secret. If thisTokenCredentialsinstance's user-name or password are null, then false is returned.- Specified by:
isValidin interfaceorg.refcodes.mixin.Validatable<TokenCredentials>- Parameters:
aCredentials- TheTokenCredentialsto be tested if them fit with the thisTokenCredentialsinstance.- Returns:
- True if the
TokenCredentialsmatch with the thisTokenCredentialsinstance and thisBasicAuthCredentialsinstance's user-name and secret are not null.
-
isValid
default boolean isValid(String aToken)
Validates the provided user-name and secret against thisTokenCredentialsuser-name and secret. If thisTokenCredentialsinstance's user-name or password are null, then false is returned.- Parameters:
aToken- the token- Returns:
- True if the user-name and secret match with the this
TokenCredentialsinstance and thisBasicAuthCredentialsinstance's user-name and secret are not null.
-
-