- java.lang.Object
-
- org.refcodes.web.UrlSugar
-
public class UrlSugar extends Object
Declarative syntactic sugar which may be statically imported in order to allow declarative definitions forUrl(Url.UrlBuilder) creation and tweaking:import static org.refcodes.web.UrlSugar.*;
-
-
Constructor Summary
Constructors Constructor Description UrlSugar()
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description Url.UrlBuildertoUrl()Creates an emptyUrl.UrlBuilder, make sure to set required attributes for a valid URL.Url.UrlBuildertoUrl(String aUrl)Constructs anUrl.UrlBuilderfrom the provided URLString.Url.UrlBuildertoUrl(String aProtocol, String aHost)Constructs anUrl.UrlBuilderwith the common attributes.Url.UrlBuildertoUrl(String aProtocol, String aHost, int aPort)Constructs anUrl.UrlBuilderwith the common attributes.Url.UrlBuildertoUrl(String aProtocol, String aHost, int aPort, String aPath)Constructs anUrl.UrlBuilderwith the common attributes.Url.UrlBuildertoUrl(String aProtocol, String aHost, int aPort, String aPath, FormFields aQueryFields)Constructs anUrl.UrlBuilderwith the common attributes.Url.UrlBuildertoUrl(String aProtocol, String aHost, int aPort, String aPath, FormFields aQueryFields, String aFragment)Constructs anUrl.UrlBuilderwith the common attributes.Url.UrlBuildertoUrl(String aProtocol, String aHost, String aPath)Constructs anUrl.UrlBuilderwith the common attributes.Url.UrlBuildertoUrl(String aProtocol, String aHost, String aPath, FormFields aQueryFields)Constructs anUrl.UrlBuilderwith the common attributes.Url.UrlBuildertoUrl(String aProtocol, String aHost, String aPath, FormFields aQueryFields, String aFragment)Constructs anUrl.UrlBuilderwith the common attributes.Url.UrlBuildertoUrl(URL aURL)Constructs anUrl.UrlBuilderfrom the providedURLinstance.Url.UrlBuildertoUrl(org.refcodes.data.Scheme aScheme, String aHost)Constructs anUrl.UrlBuilderwith the common attributes.Url.UrlBuildertoUrl(org.refcodes.data.Scheme aScheme, String aHost, int aPort)Constructs anUrl.UrlBuilderwith the common attributes.Url.UrlBuildertoUrl(org.refcodes.data.Scheme aScheme, String aHost, int aPort, String aPath)Constructs anUrl.UrlBuilderwith the common attributes.Url.UrlBuildertoUrl(org.refcodes.data.Scheme aScheme, String aHost, int aPort, String aPath, FormFields aQueryFields)Constructs anUrl.UrlBuilderwith the common attributes.Url.UrlBuildertoUrl(org.refcodes.data.Scheme aScheme, String aHost, int aPort, String aPath, FormFields aQueryFields, String aFragment)Constructs anUrl.UrlBuilderwith the common attributes.Url.UrlBuildertoUrl(org.refcodes.data.Scheme aScheme, String aHost, String aPath)Constructs anUrl.UrlBuilderwith the common attributes.Url.UrlBuildertoUrl(org.refcodes.data.Scheme aScheme, String aHost, String aPath, FormFields aQueryFields)Constructs anUrl.UrlBuilderwith the common attributes.Url.UrlBuildertoUrl(org.refcodes.data.Scheme aScheme, String aHost, String aPath, FormFields aQueryFields, String aFragment)Constructs anUrl.UrlBuilderwith the common attributes.
-
-
-
Method Detail
-
toUrl
public Url.UrlBuilder toUrl()
Creates an emptyUrl.UrlBuilder, make sure to set required attributes for a valid URL.- Returns:
- The accordingly constructed
Url.UrlBuilderinstance.
-
toUrl
public Url.UrlBuilder toUrl(String aUrl) throws MalformedURLException
Constructs anUrl.UrlBuilderfrom the provided URLString.- Parameters:
aUrl- The URLStringto be parsed.- Returns:
- The accordingly constructed
Url.UrlBuilderinstance. - Throws:
MalformedURLException- in case the provided URL is considered being malformed.
-
toUrl
public Url.UrlBuilder toUrl(URL aURL)
Constructs anUrl.UrlBuilderfrom the providedURLinstance.- Parameters:
aURL- TheURLto be used.- Returns:
- The accordingly constructed
Url.UrlBuilderinstance.
-
toUrl
public Url.UrlBuilder toUrl(org.refcodes.data.Scheme aScheme, String aHost)
Constructs anUrl.UrlBuilderwith the common attributes.- Parameters:
aScheme- TheScheme(e.g. HTTP or HTTPS) to be used for the destination URL.aHost- The host to which the destination URL is to point to.- Returns:
- The accordingly constructed
Url.UrlBuilderinstance.
-
toUrl
public Url.UrlBuilder toUrl(org.refcodes.data.Scheme aScheme, String aHost, int aPort)
Constructs anUrl.UrlBuilderwith the common attributes.- Parameters:
aScheme- TheScheme(e.g. HTTP or HTTPS) to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPort- The port to be used when connecting to the host.- Returns:
- The accordingly constructed
Url.UrlBuilderinstance.
-
toUrl
public Url.UrlBuilder toUrl(org.refcodes.data.Scheme aScheme, String aHost, int aPort, String aPath)
Constructs anUrl.UrlBuilderwith the common attributes.- Parameters:
aScheme- TheScheme(e.g. HTTP or HTTPS) to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPort- The port to be used when connecting to the host.aPath- The path on the host to which the base destination URL is to point to.- Returns:
- The accordingly constructed
Url.UrlBuilderinstance.
-
toUrl
public Url.UrlBuilder toUrl(org.refcodes.data.Scheme aScheme, String aHost, int aPort, String aPath, FormFields aQueryFields)
Constructs anUrl.UrlBuilderwith the common attributes.- Parameters:
aScheme- TheScheme(e.g. HTTP or HTTPS) to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPort- The port to be used when connecting to the host.aPath- The path on the host to which the base destination URL is to point to.aQueryFields- The Query-Fields to be used for the HTTP Query-String.- Returns:
- The accordingly constructed
Url.UrlBuilderinstance.
-
toUrl
public Url.UrlBuilder toUrl(org.refcodes.data.Scheme aScheme, String aHost, int aPort, String aPath, FormFields aQueryFields, String aFragment)
Constructs anUrl.UrlBuilderwith the common attributes.- Parameters:
aScheme- TheScheme(e.g. HTTP or HTTPS) to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPort- The port to be used when connecting to the host.aPath- The path on the host to which the base destination URL is to point to.aQueryFields- The Query-Fields to be used for the HTTP Query-String.aFragment- The fragment to be set.- Returns:
- The accordingly constructed
Url.UrlBuilderinstance.
-
toUrl
public Url.UrlBuilder toUrl(String aProtocol, String aHost)
Constructs anUrl.UrlBuilderwith the common attributes.- Parameters:
aProtocol- The protocolString(e.g. "http://" or "https://") to be used for the destination URL.aHost- The host to which the destination URL is to point to.- Returns:
- The accordingly constructed
Url.UrlBuilderinstance.
-
toUrl
public Url.UrlBuilder toUrl(String aProtocol, String aHost, int aPort)
Constructs anUrl.UrlBuilderwith the common attributes.- Parameters:
aProtocol- The protocolString(e.g. "http://" or "https://") to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPort- The port to be used when connecting to the host.- Returns:
- The accordingly constructed
Url.UrlBuilderinstance.
-
toUrl
public Url.UrlBuilder toUrl(String aProtocol, String aHost, int aPort, String aPath)
Constructs anUrl.UrlBuilderwith the common attributes.- Parameters:
aProtocol- The protocolString(e.g. "http://" or "https://") to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPort- The port to be used when connecting to the host.aPath- The path on the host to which the base destination URL is to point to.- Returns:
- The accordingly constructed
Url.UrlBuilderinstance.
-
toUrl
public Url.UrlBuilder toUrl(String aProtocol, String aHost, int aPort, String aPath, FormFields aQueryFields)
Constructs anUrl.UrlBuilderwith the common attributes.- Parameters:
aProtocol- The protocolString(e.g. "http://" or "https://") to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPort- The port to be used when connecting to the host.aPath- The path on the host to which the base destination URL is to point to.aQueryFields- The Query-Fields to be used for the HTTP Query-String.- Returns:
- The accordingly constructed
Url.UrlBuilderinstance.
-
toUrl
public Url.UrlBuilder toUrl(String aProtocol, String aHost, int aPort, String aPath, FormFields aQueryFields, String aFragment)
Constructs anUrl.UrlBuilderwith the common attributes.- Parameters:
aProtocol- The protocolString(e.g. "http://" or "https://") to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPort- The port to be used when connecting to the host.aPath- The path on the host to which the base destination URL is to point to.aQueryFields- The Query-Fields to be used for the HTTP Query-String.aFragment- The fragment to be set.- Returns:
- The accordingly constructed
Url.UrlBuilderinstance.
-
toUrl
public Url.UrlBuilder toUrl(org.refcodes.data.Scheme aScheme, String aHost, String aPath)
Constructs anUrl.UrlBuilderwith the common attributes.- Parameters:
aScheme- TheScheme(e.g. HTTP or HTTPS) to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPath- The path on the host to which the base destination URL is to point to.- Returns:
- The accordingly constructed
Url.UrlBuilderinstance.
-
toUrl
public Url.UrlBuilder toUrl(org.refcodes.data.Scheme aScheme, String aHost, String aPath, FormFields aQueryFields)
Constructs anUrl.UrlBuilderwith the common attributes.- Parameters:
aScheme- TheScheme(e.g. HTTP or HTTPS) to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPath- The path on the host to which the base destination URL is to point to.aQueryFields- The Query-Fields to be used for the HTTP Query-String.- Returns:
- The accordingly constructed
Url.UrlBuilderinstance.
-
toUrl
public Url.UrlBuilder toUrl(org.refcodes.data.Scheme aScheme, String aHost, String aPath, FormFields aQueryFields, String aFragment)
Constructs anUrl.UrlBuilderwith the common attributes.- Parameters:
aScheme- TheScheme(e.g. HTTP or HTTPS) to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPath- The path on the host to which the base destination URL is to point to.aQueryFields- The Query-Fields to be used for the HTTP Query-String.aFragment- The fragment to be set.- Returns:
- The accordingly constructed
Url.UrlBuilderinstance.
-
toUrl
public Url.UrlBuilder toUrl(String aProtocol, String aHost, String aPath)
Constructs anUrl.UrlBuilderwith the common attributes.- Parameters:
aProtocol- The protocolString(e.g. "http://" or "https://") to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPath- The path on the host to which the base destination URL is to point to.- Returns:
- The accordingly constructed
Url.UrlBuilderinstance.
-
toUrl
public Url.UrlBuilder toUrl(String aProtocol, String aHost, String aPath, FormFields aQueryFields)
Constructs anUrl.UrlBuilderwith the common attributes.- Parameters:
aProtocol- The protocolString(e.g. "http://" or "https://") to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPath- The path on the host to which the base destination URL is to point to.aQueryFields- The Query-Fields to be used for the HTTP Query-String.- Returns:
- The accordingly constructed
Url.UrlBuilderinstance.
-
toUrl
public Url.UrlBuilder toUrl(String aProtocol, String aHost, String aPath, FormFields aQueryFields, String aFragment)
Constructs anUrl.UrlBuilderwith the common attributes.- Parameters:
aProtocol- The protocolString(e.g. "http://" or "https://") to be used for the destination URL.aHost- The host to which the destination URL is to point to.aPath- The path on the host to which the base destination URL is to point to.aQueryFields- The Query-Fields to be used for the HTTP Query-String.aFragment- The fragment to be set.- Returns:
- The accordingly constructed
Url.UrlBuilderinstance.
-
-