Uses of Class
org.refcodes.web.AbstractHttpFields
-
-
Uses of AbstractHttpFields in org.refcodes.web
Subclasses of AbstractHttpFields in org.refcodes.web Modifier and Type Class Description classAbstractHeaderFields<C extends Cookie,T extends HeaderFields<C,T>>Abstract implementation of theHeaderFieldstype.classFormFieldsTheFormFieldsrepresent the URL's Query-String by the notation originally used by the GET request of the ancient web forms (see "https://en.wikipedia.org/wiki/Query_string#Web_forms").classRequestHeaderFieldsTheRequestHeaderFieldsreflect the structure of a HTTP-Header and may be used to represent a HTTP-Header.classResponseHeaderFieldsTheResponseHeaderFieldsreflect the structure of a HTTP header and may be used to represent a HTTP header.
-