Uses of Interface
org.refcodes.web.BasicAuthCredentials
-
-
Uses of BasicAuthCredentials in org.refcodes.web
Subinterfaces of BasicAuthCredentials in org.refcodes.web Modifier and Type Interface Description static interfaceBasicAuthCredentials.BasicAuthCredentialsBuilderBuilder type for theBasicAuthCredentialstype.Classes in org.refcodes.web that implement BasicAuthCredentials Modifier and Type Class Description classBasicAuthCredentialsBuilderImplThis implementation of theBasicAuthCredentials.BasicAuthCredentialsBuilderinterface compares the secret (BasicAuthCredentialsImpl.getSecret()) case sensitive but the username (BasicAuthCredentialsImpl.getIdentity()) case insensitive with theBasicAuthCredentialsImpl.equals(Object)method.classBasicAuthCredentialsImplThis implementation of theBasicAuthCredentialsinterface compares the secret (BasicAuthCredentialsImpl.getSecret()) case sensitive but the username (BasicAuthCredentialsImpl.getIdentity()) case insensitive with theBasicAuthCredentialsImpl.equals(Object)method.Methods in org.refcodes.web that return BasicAuthCredentials Modifier and Type Method Description BasicAuthCredentialsBasicAuthCredentialsAccessor. getBasicAuthCredentials()Retrieves theBasicAuthCredentialsfrom the Basic-Authentication credentials property (or null if there are none such credentials).BasicAuthCredentialsBasicAuthRequestImpl. getBasicAuthCredentials()Retrieves theBasicAuthCredentialsfrom the Basic-Authentication credentials property (or null if there are none such credentials).default BasicAuthCredentialsHeaderFields. getBasicAuthCredentials()Retrieves theBasicAuthCredentialsfrom the request (or null if there are none such credentials).default BasicAuthCredentialsBasicAuthCredentialsAccessor.BasicAuthCredentialsProperty. letBasicAuthCredentials(String aUserName, String aSecret)This method stores and passes through the given arguments, which is very useful for builder APIs:Sets theBasicAuthCredentialsfrom the user name and the secret for the Basic-Authentication credentials property.default BasicAuthCredentialsBasicAuthCredentialsAccessor.BasicAuthCredentialsProperty. letBasicAuthCredentials(BasicAuthCredentials aBasicAuthCredentials)This method stores and passes through the given argument, which is very useful for builder APIs:Sets theBasicAuthCredentialsfor the Basic-Authentication credentials property.default BasicAuthCredentialsHeaderFields. putBasicAuthCredentials(String aUserName, String aSecret)Sets theBasicAuthCredentialsfrom the user name and the secret for the Basic-Authentication credentials property.default BasicAuthCredentialsHeaderFields. putBasicAuthCredentials(BasicAuthCredentials aBasicAuthCredentials)Sets theBasicAuthCredentials(user name and secret) for HTTP Basic-Authentication.default BasicAuthCredentialsHeaderFields. removeBasicAuthCredentials()Removes theBasicAuthCredentials(user name and secret) for HTTP Basic-Authentication.default BasicAuthCredentialsBasicAuthCredentials. withHttpAuthorization(String aHttpAuthorization)Initializes thisAuthTypeCredentialsinstance from theHeaderField.AUTHORIZATIONHeader-Fields's value.Methods in org.refcodes.web with parameters of type BasicAuthCredentials Modifier and Type Method Description default BasicAuthCredentialsBasicAuthCredentialsAccessor.BasicAuthCredentialsProperty. letBasicAuthCredentials(BasicAuthCredentials aBasicAuthCredentials)This method stores and passes through the given argument, which is very useful for builder APIs:Sets theBasicAuthCredentialsfor the Basic-Authentication credentials property.BasicAuthResponseBasicAuthObserver. onBasicAuthRequest(InetSocketAddress aLocalAddress, InetSocketAddress aRemoteAddress, HttpMethod aHttpMethod, String aLocator, BasicAuthCredentials aCredentials, String aRealm)Invoked upon an incoming HTTP Basic-Authentication requests.default BasicAuthCredentialsHeaderFields. putBasicAuthCredentials(BasicAuthCredentials aBasicAuthCredentials)Sets theBasicAuthCredentials(user name and secret) for HTTP Basic-Authentication.voidBasicAuthCredentialsAccessor.BasicAuthCredentialsMutator. setBasicAuthCredentials(BasicAuthCredentials aBasicAuthCredentials)Sets theBasicAuthCredentialsfor the Basic-Authentication credentials property.BBasicAuthCredentialsAccessor.BasicAuthCredentialsBuilder. withBasicAuthCredentials(BasicAuthCredentials aBasicAuthCredentials)Sets theBasicAuthCredentialsfor the Basic-Authentication credentials property.default BHeaderFields. withBasicAuthCredentials(BasicAuthCredentials aBasicAuthCredentials)Sets theBasicAuthCredentials(user name and secret) for HTTP Basic-Authentication.Constructors in org.refcodes.web with parameters of type BasicAuthCredentials Constructor Description BasicAuthRequestImpl(HttpMethod aHttpMethod, Url aUrl, BasicAuthCredentials aCredentials)Constructs aBasicAuthRequestinstance with required attributes.
-