Uses of Class
org.refcodes.web.ContentEncoding
-
-
Uses of ContentEncoding in org.refcodes.web
Methods in org.refcodes.web that return ContentEncoding Modifier and Type Method Description static ContentEncodingContentEncoding. fromHttpEncoding(String aHttpEncoding)Returns thatContentEncodingrepresented by the given HTTP header's encoding.default ContentEncodingHeaderFields. getContentEncoding()Gets the Content-Encoding entity-Header-FieldHeaderField.CONTENT_ENCODING: "...default ContentEncodingHeaderFields. putContentEncoding(ContentEncoding aEncoding)Sets the Content-Encoding entity-Header-FieldHeaderField.CONTENT_ENCODING: "...default ContentEncodingHeaderFields. removeContentEncoding()Removes the Content-Encoding entity-Header-FieldHeaderField.CONTENT_ENCODING: "...static ContentEncodingContentEncoding. valueOf(String name)Returns the enum constant of this type with the specified name.static ContentEncoding[]ContentEncoding. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in org.refcodes.web that return types with arguments of type ContentEncoding Modifier and Type Method Description default List<ContentEncoding>HeaderFields. getAcceptEncodings()Gets the the Content-Encoding entity-Header-FieldHeaderField.CONTENT_ENCODING: "...default List<ContentEncoding>HeaderFields. putAcceptEncodings(List<ContentEncoding> aEncodings)Sets the the Content-Encoding entity-Header-FieldHeaderField.CONTENT_ENCODING: "...default List<ContentEncoding>HeaderFields. putAcceptEncodings(ContentEncoding... aEncodings)Sets the the Content-Encoding entity-Header-FieldHeaderField.CONTENT_ENCODING: "...default List<ContentEncoding>HeaderFields. removeAcceptEncodings()Removes the the Content-Encoding entity-Header-FieldHeaderField.CONTENT_ENCODING: "...Methods in org.refcodes.web with parameters of type ContentEncoding Modifier and Type Method Description default List<ContentEncoding>HeaderFields. putAcceptEncodings(ContentEncoding... aEncodings)Sets the the Content-Encoding entity-Header-FieldHeaderField.CONTENT_ENCODING: "...default ContentEncodingHeaderFields. putContentEncoding(ContentEncoding aEncoding)Sets the Content-Encoding entity-Header-FieldHeaderField.CONTENT_ENCODING: "...default BHeaderFields. withAcceptEncodings(ContentEncoding... aEncodings)Sets the the Content-Encoding entity-Header-FieldHeaderField.CONTENT_ENCODING: "...default BHeaderFields. withContentEncoding(ContentEncoding aEncoding)Sets the Content-Encoding entity-Header-FieldHeaderField.CONTENT_ENCODING: "...Method parameters in org.refcodes.web with type arguments of type ContentEncoding Modifier and Type Method Description default List<ContentEncoding>HeaderFields. putAcceptEncodings(List<ContentEncoding> aEncodings)Sets the the Content-Encoding entity-Header-FieldHeaderField.CONTENT_ENCODING: "...default BHeaderFields. withAcceptEncodings(List<ContentEncoding> aEncodings)Sets the the Content-Encoding entity-Header-FieldHeaderField.CONTENT_ENCODING: "...
-