Uses of Interface
org.refcodes.web.Cookie
-
-
Uses of Cookie in org.refcodes.web
Classes in org.refcodes.web with type parameters of type Cookie Modifier and Type Class Description classAbstractHeaderFields<C extends Cookie,T extends HeaderFields<C,T>>Abstract implementation of theHeaderFieldstype.interfaceHeaderFields<C extends Cookie,B extends HeaderFields<C,B>>TheHeaderFieldsreflect the structure of a HTTP header and may be used to represent a HTTP header.Classes in org.refcodes.web that implement Cookie Modifier and Type Class Description classRequestCookieTheRequestCookierepresents a request cookies: We use URL encoding / decoding for the cookie value (regardingRequestCookie.fromHttpCookie(String)andRequestCookie.toHttpCookie()) to make life easier and not fall into the trap of unescaped values.classResponseCookieAs of "HTTP cookies explained - NCZOnline": "...Methods in org.refcodes.web that return Cookie Modifier and Type Method Description CookieCookie. withHttpCookie(String aHttpCookie)Sets the cookie according to the provided HTTP cookie text viafromHttpCookie(String).Constructors in org.refcodes.web with parameters of type Cookie Constructor Description ResponseCookie(Cookie aCookie)Constructs aResponseCookie.
-