Uses of Class
org.refcodes.web.CookieAttribute
-
-
Uses of CookieAttribute in org.refcodes.web
Methods in org.refcodes.web that return CookieAttribute Modifier and Type Method Description static CookieAttributeCookieAttribute. fromKey(String aKey)From key.static CookieAttributeCookieAttribute. valueOf(String name)Returns the enum constant of this type with the specified name.static CookieAttribute[]CookieAttribute. values()Returns an array containing the constants of this enum type, in the order they are declared.
-