Uses of Interface
org.refcodes.web.FormFields
-
-
Uses of FormFields in org.refcodes.web
Classes in org.refcodes.web that implement FormFields Modifier and Type Class Description classFormFieldsImplThe Class FormFieldsImpl.Methods in org.refcodes.web that return FormFields Modifier and Type Method Description FormFieldsFormFieldsAccessor. getFormFields()Retrieves the request Form-Fields from the request Form-Fields property.FormFieldsQueryFieldsAccessor. getQueryFields()Retrieves the request Query-Fields from the request Query-Fields property.FormFieldsUrlBuilderImpl. getQueryFields()Retrieves the request Query-Fields from the request Query-Fields property.FormFieldsUrlImpl. getQueryFields()Retrieves the request Query-Fields from the request Query-Fields property.default FormFieldsFormFieldsAccessor.FormFieldsProperty. letFormFields(FormFields aFormFields)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenFormFields(setter) as ofFormFieldsAccessor.FormFieldsMutator.setFormFields(FormFields)and returns the very same value (getter).default FormFieldsQueryFieldsAccessor.QueryFieldsProperty. letQueryFields(FormFields aQueryFields)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenFormFields(setter) as ofQueryFieldsAccessor.QueryFieldsMutator.setQueryFields(FormFields)and returns the very same value (getter).static FormFieldsFormFields. toFormFields()Creates a newFormFieldsinstance.static FormFieldsFormFields. toFormFields(String aFormFields)Creates a newFormFieldsinstance.Methods in org.refcodes.web with parameters of type FormFields Modifier and Type Method Description default FormFieldsFormFieldsAccessor.FormFieldsProperty. letFormFields(FormFields aFormFields)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenFormFields(setter) as ofFormFieldsAccessor.FormFieldsMutator.setFormFields(FormFields)and returns the very same value (getter).default FormFieldsQueryFieldsAccessor.QueryFieldsProperty. letQueryFields(FormFields aQueryFields)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenFormFields(setter) as ofQueryFieldsAccessor.QueryFieldsMutator.setQueryFields(FormFields)and returns the very same value (getter).voidFormFieldsAccessor.FormFieldsMutator. setFormFields(FormFields aFormFields)Sets the request Form-Fields for the request Form-Fields property.voidQueryFieldsAccessor.QueryFieldsMutator. setQueryFields(FormFields aQueryFields)Sets the request Query-Fields for the request Query-Fields property.voidUrlBuilderImpl. setQueryFields(FormFields aQueryFields)Sets the request Query-Fields for the request Query-Fields property.Url.UrlBuilderUrlSugar. toUrl(String aProtocol, String aHost, int aPort, String aPath, FormFields aQueryFields)Constructs anUrl.UrlBuilderwith the common attributes.Url.UrlBuilderUrlSugar. toUrl(String aProtocol, String aHost, int aPort, String aPath, FormFields aQueryFields, String aFragment)Constructs anUrl.UrlBuilderwith the common attributes.Url.UrlBuilderUrlSugar. toUrl(String aProtocol, String aHost, String aPath, FormFields aQueryFields)Constructs anUrl.UrlBuilderwith the common attributes.Url.UrlBuilderUrlSugar. toUrl(String aProtocol, String aHost, String aPath, FormFields aQueryFields, String aFragment)Constructs anUrl.UrlBuilderwith the common attributes.Url.UrlBuilderUrlSugar. toUrl(org.refcodes.data.Scheme aScheme, String aHost, int aPort, String aPath, FormFields aQueryFields)Constructs anUrl.UrlBuilderwith the common attributes.Url.UrlBuilderUrlSugar. toUrl(org.refcodes.data.Scheme aScheme, String aHost, int aPort, String aPath, FormFields aQueryFields, String aFragment)Constructs anUrl.UrlBuilderwith the common attributes.Url.UrlBuilderUrlSugar. toUrl(org.refcodes.data.Scheme aScheme, String aHost, String aPath, FormFields aQueryFields)Constructs anUrl.UrlBuilderwith the common attributes.Url.UrlBuilderUrlSugar. toUrl(org.refcodes.data.Scheme aScheme, String aHost, String aPath, FormFields aQueryFields, String aFragment)Constructs anUrl.UrlBuilderwith the common attributes.BFormFieldsAccessor.FormFieldsBuilder. withFormFields(FormFields aFormFields)Sets the request Form-Fields to use and returns this builder as of the Builder-Pattern.BQueryFieldsAccessor.QueryFieldsBuilder. withQueryFields(FormFields aQueryFields)Sets the request Query-Fields to use and returns this builder as of the Builder-Pattern.default Url.UrlBuilderUrl.UrlBuilder. withQueryFields(FormFields aQueryFields)Sets the request Query-Fields to use and returns this builder as of the Builder-Pattern.Constructors in org.refcodes.web with parameters of type FormFields Constructor Description UrlBuilderImpl(String aProtocol, String aHost, int aPort, String aPath, FormFields aQueryFields)Constructs anUrl.UrlBuilderwith the common attributes.UrlBuilderImpl(String aProtocol, String aHost, int aPort, String aPath, FormFields aQueryFields, String aFragment)Constructs anUrl.UrlBuilderwith the common attributes.UrlBuilderImpl(String aProtocol, String aHost, String aPath, FormFields aQueryFields)Constructs anUrl.UrlBuilderwith the common attributes.UrlBuilderImpl(String aProtocol, String aHost, String aPath, FormFields aQueryFields, String aFragment)Constructs anUrl.UrlBuilderwith the common attributes.UrlBuilderImpl(String aUrl, FormFields aQueryFields)Constructs anUrl.UrlBuilderfrom the provided URLString.UrlBuilderImpl(String aUrl, FormFields aQueryFields, String aFragment)Constructs anUrl.UrlBuilderfrom the provided URLString.UrlBuilderImpl(org.refcodes.data.Scheme aScheme, String aHost, int aPort, String aPath, FormFields aQueryFields)Constructs anUrl.UrlBuilderwith the common attributes.UrlBuilderImpl(org.refcodes.data.Scheme aScheme, String aHost, int aPort, String aPath, FormFields aQueryFields, String aFragment)Constructs anUrl.UrlBuilderwith the common attributes.UrlBuilderImpl(org.refcodes.data.Scheme aScheme, String aHost, String aPath, FormFields aQueryFields)Constructs anUrl.UrlBuilderwith the common attributes.UrlBuilderImpl(org.refcodes.data.Scheme aScheme, String aHost, String aPath, FormFields aQueryFields, String aFragment)Constructs anUrl.UrlBuilderwith the common attributes.UrlImpl(String aProtocol, String aHost, int aPort, String aPath, FormFields aQueryFields)Constructs anUrlwith the common attributes.UrlImpl(String aProtocol, String aHost, int aPort, String aPath, FormFields aQueryFields, String aFragment)Constructs anUrlwith the common attributes.UrlImpl(String aProtocol, String aHost, String aPath, FormFields aQueryFields)Constructs anUrlwith the common attributes.UrlImpl(String aProtocol, String aHost, String aPath, FormFields aQueryFields, String aFragment)Constructs anUrlwith the common attributes.UrlImpl(String aUrl, FormFields aQueryFields)UrlImpl(String aUrl, FormFields aQueryFields, String aFragment)UrlImpl(org.refcodes.data.Scheme aScheme, String aHost, int aPort, String aPath, FormFields aQueryFields)Constructs anUrlwith the common attributes.UrlImpl(org.refcodes.data.Scheme aScheme, String aHost, int aPort, String aPath, FormFields aQueryFields, String aFragment)Constructs anUrlwith the common attributes.UrlImpl(org.refcodes.data.Scheme aScheme, String aHost, String aPath, FormFields aQueryFields)Constructs anUrlwith the common attributes.UrlImpl(org.refcodes.data.Scheme aScheme, String aHost, String aPath, FormFields aQueryFields, String aFragment)Constructs anUrlwith the common attributes.
-