-
Methods in org.refcodes.web with parameters of type FormFields
| Modifier and Type |
Method |
Description |
default FormFields |
FormFieldsAccessor.FormFieldsProperty.letFormFields(FormFields aFormFields) |
|
default FormFields |
QueryFieldsAccessor.QueryFieldsProperty.letQueryFields(FormFields aQueryFields) |
|
void |
FormFieldsAccessor.FormFieldsMutator.setFormFields(FormFields aFormFields) |
Sets the request Form-Fields for the request Form-Fields property.
|
void |
QueryFieldsAccessor.QueryFieldsMutator.setQueryFields(FormFields aQueryFields) |
Sets the request Query-Fields for the request Query-Fields property.
|
void |
UrlBuilderImpl.setQueryFields(FormFields aQueryFields) |
Sets the request Query-Fields for the request Query-Fields property.
|
Url.UrlBuilder |
UrlSugar.toUrl(String aProtocol,
String aHost,
int aPort,
String aPath,
FormFields aQueryFields) |
|
Url.UrlBuilder |
UrlSugar.toUrl(String aProtocol,
String aHost,
int aPort,
String aPath,
FormFields aQueryFields,
String aFragment) |
|
Url.UrlBuilder |
UrlSugar.toUrl(String aProtocol,
String aHost,
String aPath,
FormFields aQueryFields) |
|
Url.UrlBuilder |
UrlSugar.toUrl(String aProtocol,
String aHost,
String aPath,
FormFields aQueryFields,
String aFragment) |
|
Url.UrlBuilder |
UrlSugar.toUrl(org.refcodes.data.Scheme aScheme,
String aHost,
int aPort,
String aPath,
FormFields aQueryFields) |
|
Url.UrlBuilder |
UrlSugar.toUrl(org.refcodes.data.Scheme aScheme,
String aHost,
int aPort,
String aPath,
FormFields aQueryFields,
String aFragment) |
|
Url.UrlBuilder |
UrlSugar.toUrl(org.refcodes.data.Scheme aScheme,
String aHost,
String aPath,
FormFields aQueryFields) |
|
Url.UrlBuilder |
UrlSugar.toUrl(org.refcodes.data.Scheme aScheme,
String aHost,
String aPath,
FormFields aQueryFields,
String aFragment) |
|
B |
FormFieldsAccessor.FormFieldsBuilder.withFormFields(FormFields aFormFields) |
Sets the request Form-Fields to use and returns this builder as of
the Builder-Pattern.
|
B |
QueryFieldsAccessor.QueryFieldsBuilder.withQueryFields(FormFields aQueryFields) |
Sets the request Query-Fields to use and returns this builder as of
the Builder-Pattern.
|
default Url.UrlBuilder |
Url.UrlBuilder.withQueryFields(FormFields aQueryFields) |
Sets the request Query-Fields to use and returns this builder as of
the Builder-Pattern.
|
Constructors in org.refcodes.web with parameters of type FormFields
| Constructor |
Description |
UrlBuilderImpl(String aProtocol,
String aHost,
int aPort,
String aPath,
FormFields aQueryFields) |
|
UrlBuilderImpl(String aProtocol,
String aHost,
int aPort,
String aPath,
FormFields aQueryFields,
String aFragment) |
|
UrlBuilderImpl(String aProtocol,
String aHost,
String aPath,
FormFields aQueryFields) |
|
UrlBuilderImpl(String aProtocol,
String aHost,
String aPath,
FormFields aQueryFields,
String aFragment) |
|
UrlBuilderImpl(String aUrl,
FormFields aQueryFields) |
|
UrlBuilderImpl(String aUrl,
FormFields aQueryFields,
String aFragment) |
|
UrlBuilderImpl(org.refcodes.data.Scheme aScheme,
String aHost,
int aPort,
String aPath,
FormFields aQueryFields) |
|
UrlBuilderImpl(org.refcodes.data.Scheme aScheme,
String aHost,
int aPort,
String aPath,
FormFields aQueryFields,
String aFragment) |
|
UrlBuilderImpl(org.refcodes.data.Scheme aScheme,
String aHost,
String aPath,
FormFields aQueryFields) |
|
UrlBuilderImpl(org.refcodes.data.Scheme aScheme,
String aHost,
String aPath,
FormFields aQueryFields,
String aFragment) |
|
UrlImpl(String aProtocol,
String aHost,
int aPort,
String aPath,
FormFields aQueryFields) |
Constructs an Url with the common attributes.
|
UrlImpl(String aProtocol,
String aHost,
int aPort,
String aPath,
FormFields aQueryFields,
String aFragment) |
Constructs an Url with the common attributes.
|
UrlImpl(String aProtocol,
String aHost,
String aPath,
FormFields aQueryFields) |
Constructs an Url with the common attributes.
|
UrlImpl(String aProtocol,
String aHost,
String aPath,
FormFields aQueryFields,
String aFragment) |
Constructs an Url with the common attributes.
|
UrlImpl(String aUrl,
FormFields aQueryFields) |
Constructs an Url from the provided URL String.
|
UrlImpl(String aUrl,
FormFields aQueryFields,
String aFragment) |
Constructs an Url from the provided URL String.
|
UrlImpl(org.refcodes.data.Scheme aScheme,
String aHost,
int aPort,
String aPath,
FormFields aQueryFields) |
Constructs an Url with the common attributes.
|
UrlImpl(org.refcodes.data.Scheme aScheme,
String aHost,
int aPort,
String aPath,
FormFields aQueryFields,
String aFragment) |
Constructs an Url with the common attributes.
|
UrlImpl(org.refcodes.data.Scheme aScheme,
String aHost,
String aPath,
FormFields aQueryFields) |
Constructs an Url with the common attributes.
|
UrlImpl(org.refcodes.data.Scheme aScheme,
String aHost,
String aPath,
FormFields aQueryFields,
String aFragment) |
Constructs an Url with the common attributes.
|