Uses of Interface
org.refcodes.web.HttpFields
-
-
Uses of HttpFields in org.refcodes.web
Classes in org.refcodes.web with type parameters of type HttpFields Modifier and Type Class Description classAbstractHttpFields<T extends HttpFields<T>>Abstract implementation of theHeaderFieldstype.interfaceHttpFields<B extends HttpFields<B>>Various key/value "collections" we run across when we develop HTTP based applications may have more then one value for one key.Subinterfaces of HttpFields in org.refcodes.web Modifier and Type Interface Description interfaceHeaderFields<C extends Cookie,B extends HeaderFields<C,B>>TheHeaderFieldsreflect the structure of a HTTP header and may be used to represent a HTTP header.Classes in org.refcodes.web that implement HttpFields Modifier and Type Class Description classAbstractHeaderFields<C extends Cookie,T extends HeaderFields<C,T>>Abstract implementation of theHeaderFieldstype.classAbstractHttpFields<T extends HttpFields<T>>Abstract implementation of theHeaderFieldstype.classFormFieldsTheFormFieldsrepresent the URL's Query-String by the notation originally used by the GET request of the ancient web forms (see "https://en.wikipedia.org/wiki/Query_string#Web_forms").classRequestHeaderFieldsTheRequestHeaderFieldsreflect the structure of a HTTP-Header and may be used to represent a HTTP-Header.classResponseHeaderFieldsTheResponseHeaderFieldsreflect the structure of a HTTP header and may be used to represent a HTTP header.Methods in org.refcodes.web with parameters of type HttpFields Modifier and Type Method Description protected static voidAbstractHttpFields. copyHttpFields(Map<String,List<String>> aFromFields, HttpFields<?> aToFields)Copies the provided "from" fields into the provided "to" fields.
-