Uses of Class
org.refcodes.web.HttpMethod
-
-
Uses of HttpMethod in org.refcodes.web
Fields in org.refcodes.web declared as HttpMethod Modifier and Type Field Description protected HttpMethodAbstractHttpRequest. _httpMethodMethods in org.refcodes.web that return HttpMethod Modifier and Type Method Description static HttpMethodHttpMethod. fromHttpMethod(String aHttpMethod)From http method.HttpMethodAbstractHttpRequest. getHttpMethod()Retrieves the HTTP-Method from the HTTP-Method property.HttpMethodBasicAuthRequestImpl. getHttpMethod()Retrieves the HTTP-Method from the HTTP-Method property.HttpMethodHttpMethodAccessor. getHttpMethod()Retrieves the HTTP-Method from the HTTP-Method property.default HttpMethodHttpMethodAccessor.HttpMethodProperty. letHttpMethod(HttpMethod aHttpMethod)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenHttpMethod(setter) as ofHttpMethodAccessor.HttpMethodMutator.setHttpMethod(HttpMethod)and returns the very same value (getter).static HttpMethodHttpMethod. valueOf(String name)Returns the enum constant of this type with the specified name.static HttpMethod[]HttpMethod. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in org.refcodes.web that return types with arguments of type HttpMethod Modifier and Type Method Description default List<HttpMethod>HeaderFields. getAllowMethods()Gets the Allow entity-Header-FieldHeaderField.ALLOW: "...default List<HttpMethod>HeaderFields. putAllowMethods(List<HttpMethod> aHttpMethods)Sets the Allow entity-Header-FieldHeaderField.ALLOW: "...default List<HttpMethod>HeaderFields. putAllowMethods(HttpMethod... aHttpMethods)Sets the Allow entity-Header-FieldHeaderField.ALLOW: "...default List<HttpMethod>HeaderFields. removeAllowMethods()Removes the Allow entity-Header-FieldHeaderField.ALLOW: "...Methods in org.refcodes.web with parameters of type HttpMethod Modifier and Type Method Description default HttpMethodHttpMethodAccessor.HttpMethodProperty. letHttpMethod(HttpMethod aHttpMethod)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenHttpMethod(setter) as ofHttpMethodAccessor.HttpMethodMutator.setHttpMethod(HttpMethod)and returns the very same value (getter).BasicAuthResponseBasicAuthObserver. onBasicAuthRequest(InetSocketAddress aLocalAddress, InetSocketAddress aRemoteAddress, HttpMethod aHttpMethod, String aLocator, BasicAuthCredentials aCredentials, String aRealm)Invoked upon an incoming HTTP Basic-Authentication requests.default List<HttpMethod>HeaderFields. putAllowMethods(HttpMethod... aHttpMethods)Sets the Allow entity-Header-FieldHeaderField.ALLOW: "...voidHttpMethodAccessor.HttpMethodMutator. setHttpMethod(HttpMethod aHttpMethod)Sets the HTTP-Method for the HTTP-Method property.default BHeaderFields. withAllowMethods(HttpMethod... aHttpMethods)Sets the Allow entity-Header-FieldHeaderField.ALLOW: "...BHttpMethodAccessor.HttpMethodBuilder. withHttpMethod(HttpMethod aHttpMethod)Sets the HTTP-Method for the HTTP-Method property.Method parameters in org.refcodes.web with type arguments of type HttpMethod Modifier and Type Method Description default List<HttpMethod>HeaderFields. putAllowMethods(List<HttpMethod> aHttpMethods)Sets the Allow entity-Header-FieldHeaderField.ALLOW: "...default BHeaderFields. withAllowMethods(List<HttpMethod> aHttpMethods)Sets the Allow entity-Header-FieldHeaderField.ALLOW: "...Constructors in org.refcodes.web with parameters of type HttpMethod Constructor Description AbstractHttpRequest(HttpMethod aHttpMethod, Url aUrl)Constructs aHttpRequestwith all required attributes.AbstractHttpRequest(HttpMethod aHttpMethod, Url aUrl, RequestHeaderFields aHeaderFields)Constructs aHttpRequestwith all required attributes.BasicAuthRequestImpl(HttpMethod aHttpMethod, Url aUrl, BasicAuthCredentials aCredentials)Constructs aBasicAuthRequestinstance with required attributes.HttpClientRequestImpl(HttpMethod aHttpMethod, Url aUrl, int aRedirectDepth, MediaTypeFactoryLookup aMediaTypeFactoryLookup)Instantiates a new http client request impl.HttpClientRequestImpl(HttpMethod aHttpMethod, Url aUrl, Object aRequest, int aRedirectDepth, MediaTypeFactoryLookup aMediaTypeFactoryLookup)Instantiates a new http client request impl.HttpClientRequestImpl(HttpMethod aHttpMethod, Url aUrl, Object aRequest, MediaTypeFactoryLookup aMediaTypeFactoryLookup)Instantiates a new http client request impl.HttpClientRequestImpl(HttpMethod aHttpMethod, Url aUrl, MediaTypeFactoryLookup aMediaTypeFactoryLookup)Instantiates a new http client request impl.HttpClientRequestImpl(HttpMethod aHttpMethod, Url aUrl, RequestHeaderFields aHeaderFields, Object aRequest, int aRedirectDepth, MediaTypeFactoryLookup aMediaTypeFactoryLookup)Instantiates a new http client request impl.HttpClientRequestImpl(HttpMethod aHttpMethod, Url aUrl, RequestHeaderFields aHeaderFields, Object aRequest, MediaTypeFactoryLookup aMediaTypeFactoryLookup)Instantiates a new http client request impl.HttpServerRequestImpl(HttpMethod aHttpMethod, Url aUrl, RequestHeaderFields aHeaderFields, InputStream aHttpInputStream, MediaTypeFactoryLookup aMediaTypeFactoryLookup)Constructs aHttpServerRequestwith all required attributes.
-