Uses of Class
org.refcodes.web.HttpResponseException
-
-
Uses of HttpResponseException in org.refcodes.web
Subclasses of HttpResponseException in org.refcodes.web Modifier and Type Class Description classBadInvocationExceptionProprietary code and only used inside a REFCODES.ORG client not trespassing any networking border (the error is generated by the client for the client locally).classBadResponseExceptionProprietary code and only used inside a REFCODES.ORG client not trespassing any networking border (the error is generated by the client for the client locally).
-