Uses of Class
org.refcodes.web.HttpStatusCode
-
-
Uses of HttpStatusCode in org.refcodes.web
Fields in org.refcodes.web declared as HttpStatusCode Modifier and Type Field Description protected HttpStatusCodeHttpResponseImpl. _httpStatusCodeMethods in org.refcodes.web that return HttpStatusCode Modifier and Type Method Description HttpStatusCodeHttpResponseImpl. getHttpStatusCode()Retrieves the HTTP Status-Code from the HTTP Status-Code property.HttpStatusCodeHttpStatusCodeAccessor. getHttpStatusCode()Retrieves the HTTP Status-Code from the HTTP Status-Code property.HttpStatusCodeHttpBodyMap. getStatusCode()Retrieves the public path's ("status/code") status code.HttpStatusCodeHttpStatusException. getStatusCode()HttpStatusCodeHttpStatusRuntimeException. getStatusCode()default HttpStatusCodeHttpStatusCodeAccessor.HttpStatusCodeProperty. letHttpStatusCode(HttpStatusCode aHttpStatusCode)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenHttpStatusCode(setter) as ofHttpStatusCodeAccessor.HttpStatusCodeMutator.setHttpStatusCode(HttpStatusCode)and returns the very same value (getter).static HttpStatusCodeHttpStatusCode. toHttpStatusCode(int aHttpStatusCode)Determines the HTTP success code from the given value by evaluating thegetStatusCode()property.static HttpStatusCodeHttpStatusCode. toHttpStatusCode(org.refcodes.mixin.StatusCodeAccessor<Integer> aHttpStatusCode)Determines the HTTP success code from the given HTTP Status-Code property by evaluating thegetStatusCode()property.static HttpStatusCodeHttpStatusCode. valueOf(String name)Returns the enum constant of this type with the specified name.static HttpStatusCode[]HttpStatusCode. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in org.refcodes.web with parameters of type HttpStatusCode Modifier and Type Method Description default HttpStatusCodeHttpStatusCodeAccessor.HttpStatusCodeProperty. letHttpStatusCode(HttpStatusCode aHttpStatusCode)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenHttpStatusCode(setter) as ofHttpStatusCodeAccessor.HttpStatusCodeMutator.setHttpStatusCode(HttpStatusCode)and returns the very same value (getter).StringHttpBodyMap. putStatusAlias(HttpStatusCode aStatusCode)Puts a public path's ("status/alias") status alias.StringHttpBodyMap. putStatusCode(HttpStatusCode aStatusCode)Puts a public path's ("status/code") status code.voidHttpServerResponseImpl. setHttpStatusCode(HttpStatusCode aStatusCode)Sets the HTTP Status-Code for the HTTP Status-Code property.voidHttpStatusCodeAccessor.HttpStatusCodeMutator. setHttpStatusCode(HttpStatusCode aStatusCode)Sets the HTTP Status-Code for the HTTP Status-Code property.default HttpServerResponseHttpServerResponse. withHttpStatusCode(HttpStatusCode aStatusCode)Sets the HTTP Status-Code for the HTTP Status-Code property.BHttpStatusCodeAccessor.HttpStatusCodeBuilder. withHttpStatusCode(HttpStatusCode aStatusCode)Sets the HTTP Status-Code for the HTTP Status-Code property.HttpBodyMapHttpBodyMap. withPutStatusAlias(HttpStatusCode aStatusCode)Puts a public path's ("status/alias") status alias.HttpBodyMapHttpBodyMap. withPutStatusCode(HttpStatusCode aStatusCode)Puts a public path's ("status/code") status code.Constructors in org.refcodes.web with parameters of type HttpStatusCode Constructor Description HttpClientResponseImpl(Url aUrl, HttpStatusCode aHttpStatusCode, ResponseHeaderFields aHeaderFields, InputStream aHttpInputStream, MediaTypeFactoryLookup aMediaTypeFactoryLookup)Constructs aHttpClientResponsewith all required attributes.HttpResponseException(HttpStatusCode aStatusCode, String message)Instantiates a new http response exception.HttpResponseException(HttpStatusCode aStatusCode, String aMessage, String aErrorCode)Instantiates a new http response exception.HttpResponseException(HttpStatusCode aStatusCode, String message, Throwable cause)Instantiates a new http response exception.HttpResponseException(HttpStatusCode aStatusCode, String aMessage, Throwable aCause, String aErrorCode)Instantiates a new http response exception.HttpResponseException(HttpStatusCode aStatusCode, Throwable cause)Instantiates a new http response exception.HttpResponseException(HttpStatusCode aStatusCode, Throwable aCause, String aErrorCode)Instantiates a new http response exception.HttpResponseImpl(HttpStatusCode aHttpStatusCode)Constructs aHttpResponsewith all required attributes.HttpResponseImpl(HttpStatusCode aHttpStatusCode, ResponseHeaderFields aHeaderFields)Constructs aHttpResponsewith all required attributes.HttpResponseRuntimeException(HttpStatusCode aStatusCode, String message)Instantiates a new http response runtime exception.HttpResponseRuntimeException(HttpStatusCode aStatusCode, String aMessage, String aErrorCode)Instantiates a new http response runtime exception.HttpResponseRuntimeException(HttpStatusCode aStatusCode, String message, Throwable cause)Instantiates a new http response runtime exception.HttpResponseRuntimeException(HttpStatusCode aStatusCode, String aMessage, Throwable aCause, String aErrorCode)Instantiates a new http response runtime exception.HttpResponseRuntimeException(HttpStatusCode aStatusCode, Throwable cause)Instantiates a new http response runtime exception.HttpResponseRuntimeException(HttpStatusCode aStatusCode, Throwable aCause, String aErrorCode)Instantiates a new http response runtime exception.HttpServerResponseImpl(HttpStatusCode aHttpStatusCode, MediaTypeFactoryLookup aMediaTypeFactoryLookup)Instantiates a new http server response impl.HttpStatusException(HttpStatusCode aStatusCode, String message)Instantiates a new http status exception.HttpStatusException(HttpStatusCode aStatusCode, String aMessage, String aErrorCode)Instantiates a new http status exception.HttpStatusException(HttpStatusCode aStatusCode, String message, Throwable cause)Instantiates a new http status exception.HttpStatusException(HttpStatusCode aStatusCode, String aMessage, Throwable aCause, String aErrorCode)Instantiates a new http status exception.HttpStatusException(HttpStatusCode aStatusCode, Throwable cause)Instantiates a new http status exception.HttpStatusException(HttpStatusCode aStatusCode, Throwable aCause, String aErrorCode)Instantiates a new http status exception.HttpStatusRuntimeException(HttpStatusCode aStatusCode, String message)Instantiates a new http status runtime exception.HttpStatusRuntimeException(HttpStatusCode aStatusCode, String aMessage, String aErrorCode)Instantiates a new http status runtime exception.HttpStatusRuntimeException(HttpStatusCode aStatusCode, String message, Throwable cause)Instantiates a new http status runtime exception.HttpStatusRuntimeException(HttpStatusCode aStatusCode, String aMessage, Throwable aCause, String aErrorCode)Instantiates a new http status runtime exception.HttpStatusRuntimeException(HttpStatusCode aStatusCode, Throwable cause)Instantiates a new http status runtime exception.HttpStatusRuntimeException(HttpStatusCode aStatusCode, Throwable aCause, String aErrorCode)Instantiates a new http status runtime exception.
-