Uses of Enum Class
org.refcodes.web.OauthField
-
Uses of OauthField in org.refcodes.web
Methods in org.refcodes.web that return OauthFieldModifier and TypeMethodDescriptionstatic OauthFieldOauthField.fromHeaderField(HeaderField aHeaderField) Resolves theOauthFieldfrom theHeaderField.static OauthFieldResolves theOauthFieldfrom theHttpBodyMappath.static OauthFieldReturns the enum constant of this class with the specified name.static OauthField[]OauthField.values()Returns an array containing the constants of this enum class, in the order they are declared.