Uses of Class
org.refcodes.web.OauthField
-
-
Uses of OauthField in org.refcodes.web
Methods in org.refcodes.web that return OauthField Modifier and Type Method Description static OauthFieldOauthField. fromHeaderField(HeaderField aHeaderField)Resolves theOauthFieldfrom theHeaderField.static OauthFieldOauthField. fromPath(String aPath)Resolves theOauthFieldfrom theHttpBodyMappath.static OauthFieldOauthField. valueOf(String name)Returns the enum constant of this type with the specified name.static OauthField[]OauthField. values()Returns an array containing the constants of this enum type, in the order they are declared.
-