JavaScript is disabled on your browser.
Skip navigation links
Module
Package
Class
Use
Tree
Index
Help
SEARCH
Uses of Enum Class
org.refcodes.web.Proxy
Uses of
Proxy
in
org.refcodes.web
Methods in
org.refcodes.web
that return
Proxy
Modifier and Type
Method
Description
static
Proxy
Proxy.
valueOf
(
String
name)
Returns the enum constant of this class with the specified name.
static
Proxy
[]
Proxy.
values
()
Returns an array containing the constants of this enum class, in the order they are declared.