Uses of Class
org.refcodes.web.TransportLayerProtocol
-
-
Uses of TransportLayerProtocol in org.refcodes.web
Methods in org.refcodes.web that return TransportLayerProtocol Modifier and Type Method Description static TransportLayerProtocolTransportLayerProtocol. valueOf(String name)Returns the enum constant of this type with the specified name.static TransportLayerProtocol[]TransportLayerProtocol. values()Returns an array containing the constants of this enum type, in the order they are declared.
-