| AbstractHeaderFields |
|
| AbstractHttpFields |
|
| AuthType |
The Enum AuthType.
|
| AuthTypeAccessor |
Provides an accessor for a AuthType property.
|
| AuthTypeAccessor.AuthTypeBuilder |
Provides a builder method for a AuthType property returning the
builder for applying multiple build operations.
|
| AuthTypeAccessor.AuthTypeMutator |
Provides a mutator for a AuthType property.
|
| AuthTypeCredentials |
The Interface AuthTypeCredentials.
|
| BadRequestException |
The Class BadRequestException.
|
| BadResponseException |
Proprietary code and only used inside a REFCODES.ORG client not trespassing
any networking border (the error is generated by the client for the client
locally).
|
| BaseLocatorAccessor |
Provides an accessor for a base locator property.
|
| BaseLocatorAccessor.BaseLocatorBuilder |
Provides a builder method for a base locator property returning the
builder for applying multiple build operations.
|
| BaseLocatorAccessor.BaseLocatorMutator |
Provides a mutator for a base locator property.
|
| BaseUrlAccessor |
Provides an accessor for a base URL (protocol, host, port, locator) property.
|
| BaseUrlAccessor.BaseUrlBuilder |
Provides a builder method for a base URL (protocol, host, port, path)
property returning the builder for applying multiple build operations.
|
| BaseUrlAccessor.BaseUrlMutator |
Provides a mutator for a base URL (protocol, host, port, locator)
property.
|
| BaseUrlAccessor.BaseUrlProperty |
Provides a base URL (protocol, host, port, path) property.
|
| BasicAuthCredentials |
This interface defines a type for representing a Basic-Authentication
credentials Header-Field.
|
| BasicAuthCredentials.BasicAuthCredentialsBuilder |
|
| BasicAuthCredentialsAccessor |
|
| BasicAuthCredentialsAccessor.BasicAuthCredentialsBuilder |
Provides a builder method for a BasicAuthCredentials property
returning the builder for applying multiple build operations.
|
| BasicAuthCredentialsAccessor.BasicAuthCredentialsMutator |
|
| BasicAuthCredentialsImpl |
|
| BasicAuthObservable |
An observable which notifies the registered BasicAuthObserver on
incoming HTTP Basic-Authentication requests.
|
| BasicAuthObserver |
|
| BasicAuthRequest |
|
| BasicAuthResponse |
The enumeration for a Basic-Auth response.
|
| BasicCredentials |
The Interface BasicCredentials.
|
| BearerAuthCredentials |
This interface defines a type for representing a Bearer-Authentication
credentials Header-Field.
|
| BearerAuthCredentialsAccessor |
|
| BearerAuthCredentialsAccessor.BearerAuthCredentialsBuilder |
Provides a builder method for a BearerAuthCredentials property
returning the builder for applying multiple build operations.
|
| BearerAuthCredentialsAccessor.BearerAuthCredentialsMutator |
|
| ContentEncoding |
|
| ContentType |
|
| ContentTypeAccessor |
Provides an accessor for a Content-Type property.
|
| ContentTypeAccessor.ContentTypeBuilder |
Provides a builder method for a Content-Type property returning the
builder for applying multiple build operations.
|
| ContentTypeAccessor.ContentTypeMutator |
Provides a mutator for a Content-Type property.
|
| ContentTypeAccessor.ContentTypeProvider |
A provider interface provides a "toSomething(?)"
|
| Cookie |
The Cookie represents a HTTP cookie.
|
| CookieAttribute |
The Enum CookieAttribute.
|
| ForbiddenException |
The Class ForbiddenException.
|
| FormFields |
The FormFields represent the URL's Query-String by the notation
originally used by the GET request of the ancient web forms (see
"https://en.wikipedia.org/wiki/Query_string#Web_forms").
|
| FormFieldsAccessor |
Provides an accessor for a request Form-Fields property.
|
| FormFieldsAccessor.FormFieldsBuilder |
Provides a mutator for a request Form-Fields property.
|
| FormFieldsAccessor.FormFieldsMutator |
Provides a mutator for a request Form-Fields property.
|
| FragmentAccessor |
Provides an accessor for a fragment property.
|
| FragmentAccessor.FragmentBuilder |
Provides a mutator for an fragment property.
|
| FragmentAccessor.FragmentMutator |
Provides a mutator for a fragment property.
|
| FragmentAccessor.FragmentProperty |
Provides a fragment property.
|
| GrantType |
The Enum GrantType.
|
| HeaderField |
The Enum HeaderField.
|
| HeaderFieldAccessor |
|
| HeaderFieldAccessor.HeaderFieldBuilder |
Provides a builder method for a HeaderField property returning
the builder for applying multiple build operations.
|
| HeaderFieldAccessor.HeaderFieldMutator |
|
| HeaderFields |
The HeaderFields reflect the structure of a HTTP header and may be
used to represent a HTTP header.
|
| HeaderFieldsAccessor |
Provides an accessor for an Header-Fields property.
|
| HeaderFieldsAccessor.HeaderFieldsBuilder |
Provides a mutator for an Header-Fields property.
|
| HeaderFieldsAccessor.HeaderFieldsMutator |
Provides a mutator for an Header-Fields property.
|
| HostAccessor |
Provides an accessor for a host property.
|
| HostAccessor.HostBuilder |
Provides a mutator for an host property.
|
| HostAccessor.HostMutator |
Provides a mutator for a host property.
|
| HostAccessor.HostProperty |
Provides a host property.
|
| HttpBodyAccessor |
Provides an accessor for a HTTP body property.
|
| HttpBodyAccessor.HttpBodyBuilder |
Provides a builder body for a HTTP body property returning the builder
for applying multiple build operations.
|
| HttpBodyAccessor.HttpBodyMutator |
Provides a mutator for a HTTP body property.
|
| HttpBodyAccessor.HttpBodyProvider |
A provider interface provides a "toSomething(?)"
|
| HttpBodyMap |
The HttpBodyMap type is a "dynamic" type in terms of it's structure
being represented by paths'.
|
| HttpClientContext.HttpClientContextBuilder |
|
| HttpClientRequest |
|
| HttpClientRequest.HttpClientRequestBuilder |
|
| HttpClientResponse |
|
| HttpException |
Base exception HTTP related problems.
|
| HttpFields |
Various key/value "collections" we run across when we develop HTTP based
applications may have more then one value for one key.
|
| HttpInputStreamAccessor |
Provides an accessor for a HTTP InputStream body property.
|
| HttpInputStreamAccessor.HttpInputStreamBuilder |
Provides a builder body for a HTTP InputStream property returning
the builder for applying multiple build operations.
|
| HttpInputStreamAccessor.HttpInputStreamMutator |
|
| HttpMediaType |
The HttpMediaType converts an implementing instance's state into an
HTTP media type as used in HTTP Header-Fields.
|
| HttpMediaTypeAccessor |
Provides an accessor for a HTTP Media-Type property.
|
| HttpMediaTypeAccessor.HttpMediaTypeBuilder |
Provides a builder body for a HTTP Media-Type property returning the
builder for applying multiple build operations.
|
| HttpMediaTypeAccessor.HttpMediaTypeMutator |
Provides a mutator for a HTTP Media-Type property.
|
| HttpMediaTypeAccessor.HttpMediaTypeProvider |
A provider interface provides a "toSomething(?)"
|
| HttpMethod |
The Enum HttpMethod.
|
| HttpMethodAccessor |
Provides an accessor for a HTTP-Method property.
|
| HttpMethodAccessor.HttpMethodBuilder |
Provides a builder method for a HTTP-Method property returning the
builder for applying multiple build operations.
|
| HttpMethodAccessor.HttpMethodMutator |
Provides a mutator for a HTTP-Method property.
|
| HttpRequest |
Defines a HTTP-Request, being the HttpMethod, the Header-Fields and
the locator representing, though without the request body.
|
| HttpRequestBuilder |
The Interface HttpRequestBuilder.
|
| HttpRequestImpl |
|
| HttpResponse |
Defines a HttpResponse being the response Header-Fields and the
response body.
|
| HttpResponseException |
Thrown by a HTTP-Response handling system in case of some unexpected
response.
|
| HttpResponseImpl |
|
| HttpResponseRuntimeException |
Thrown by a HTTP-Response handling system in case of some unexpected
response.
|
| HttpRuntimeException |
The Class HttpRuntimeException.
|
| HttpsConnectionRequestObservable |
|
| HttpsConnectionRequestObserver |
|
| HttpServerContext.HttpServerContextBuilder |
|
| HttpServerRequest |
|
| HttpServerResponse |
|
| HttpStatusCode |
The org.apache.commons.httpclient.HttpStatus constants as enumeration.
|
| HttpStatusCodeAccessor |
Provides access to a HTTP Status-Code property including all known HTTP HTTP
Status-Codes (success as well as error codes) as of HttpStatusCode.
|
| HttpStatusCodeAccessor.HttpStatusCodeBuilder |
Provides a builder method for a HTTP Status-Code property returning the
builder for applying multiple build operations.
|
| HttpStatusCodeAccessor.HttpStatusCodeMutator |
|
| HttpStatusCodeAccessor.HttpStatusCodeProperty |
|
| HttpStatusException |
Base exception for HTTP status code related exceptions.
|
| HttpStatusRuntimeException |
The Class HttpStatusRuntimeException.
|
| HttpSuccessCode |
Only the Success 2xx codes as of (from) the HttpStatusCode
enumeration.
|
| HttpSuccessCodeAccessor |
Provides access to a HTTP success code property including just the 2xx HTTP
success codes as of HttpSuccessCode excluding all HTTP error codes.
|
| HttpSuccessCodeAccessor.HttpSuccessCodeBuilder |
Provides a builder method for a HTTP success code property returning the
builder for applying multiple build operations.
|
| HttpSuccessCodeAccessor.HttpSuccessCodeMutator |
|
| IpAddress |
Metrics of an IP-Address as of IPv4 or IPv6.
|
| IpAddressAccessor |
Provides an accessor for a IP-Address property.
|
| IpAddressAccessor.IpAddressBuilder |
Provides a builder method for a IP-Address property returning the builder
for applying multiple build operations.
|
| IpAddressAccessor.IpAddressMutator |
Provides a mutator for a IP-Address property.
|
| IpAddressAccessor.IpAddressProperty |
Provides a IP-Address property.
|
| LoadBalancingStrategy |
Some simple load balancing strategies.
|
| LoadBalancingStrategyAccessor |
|
| LoadBalancingStrategyAccessor.LoadBalancingStrategyBuilder |
Provides a builder method for a load balancing strategy property
returning the builder for applying multiple build operations.
|
| LoadBalancingStrategyAccessor.LoadBalancingStrategyMutator |
|
| LocalAddressAccessor |
Provides an accessor for a local address property.
|
| LocalAddressAccessor.LocalAddressBuilder |
Provides a builder method for a local address property returning the
builder for applying multiple build operations.
|
| LocalAddressAccessor.LocalAddressMutator |
Provides a mutator for a local address property.
|
| MediaType |
The MediaType is the Media-Sub-Type part of a HTTP Media-Type.
|
| MediaTypeAccessor |
Provides an accessor for a Media-Type property.
|
| MediaTypeAccessor.MediaTypeBuilder |
Provides a builder method for a Media-Type property returning the builder
for applying multiple build operations.
|
| MediaTypeAccessor.MediaTypeMutator |
Provides a mutator for a Media-Type property.
|
| MediaTypeFactory |
|
| MediaTypeFactoryLookup |
The Interface MediaTypeFactoryLookup.
|
| MediaTypeParameter |
Known or in this scope used MediaType parameters.
|
| MediaTypesAccessor |
Provides an accessor for a Media-Types property.
|
| MediaTypesAccessor.MediaTypesBuilder |
Provides a builder method for a Media-Types property returning the
builder for applying multiple build operations.
|
| MediaTypesAccessor.MediaTypesMutator |
Provides a mutator for a Media-Types property.
|
| NetException |
The base exception for networking related issues.
|
| NetRuntimeException |
The base runtime exception for networking related issues.
|
| OauthField |
The Enum OauthField.
|
| OauthToken |
An OAuth-Token contains all relevant information to access a protected
resource and refresh the the access token.
|
| OauthTokenAccessor |
Provides an accessor for a OAuth token property.
|
| OauthTokenAccessor.OauthTokenBuilder |
Provides a builder method for a OAuth token property returning the
builder for applying multiple build operations.
|
| OauthTokenAccessor.OauthTokenMutator |
Provides a mutator for a OAuth token property.
|
| PortAlreadyBoundException |
|
| PortManager |
When implemented as singleton, then resources battling for dynamically
assigned ports my use this functionality to get and block a port until it is
freed again.
|
| PortManagerImpl |
|
| PortNotFoundException |
Thrown in case no port can be determined.
|
| PortNotFoundRuntimeException |
Thrown in case no port can be determined.
|
| PortRange |
Port range definitions as of RFC 6335 ("https://tools.ietf.org/html/rfc6335")
|
| Proxy |
The Enum Proxy.
|
| QueryFieldsAccessor |
Provides an accessor for a request Query-Fields property.
|
| QueryFieldsAccessor.QueryFieldsBuilder |
Provides a mutator for a request Query-Fields property.
|
| QueryFieldsAccessor.QueryFieldsMutator |
Provides a mutator for a request Query-Fields property.
|
| QueryFieldsAccessor.QueryFieldsProperty |
Provides a request Query-Fields property.
|
| RealmAccessor |
Provides an accessor for a realm property.
|
| RealmAccessor.RealmBuilder |
Provides a builder method for a realm property returning the builder for
applying multiple build operations.
|
| RealmAccessor.RealmMutator |
Provides a mutator for a realm property.
|
| RedirectDepthAccessor |
Provides an accessor for a redirect depth property.
|
| RedirectDepthAccessor.RedirectDepthBuilder |
Provides a builder method for a redirect depth property returning the
builder for applying multiple build operations.
|
| RedirectDepthAccessor.RedirectDepthMutator |
Provides a mutator for a redirect depth property.
|
| RedirectDepthAccessor.RedirectDepthProperty |
Provides a redirect depth property.
|
| RemoteAddressAccessor |
Provides an accessor for a remote address property.
|
| RemoteAddressAccessor.RemoteAddressBuilder |
Provides a builder method for a remote address property returning the
builder for applying multiple build operations.
|
| RemoteAddressAccessor.RemoteAddressMutator |
Provides a mutator for a remote address property.
|
| RequestCookie |
The RequestCookie represents a builder for a building request
cookies.
|
| RequestHeaderFields |
The RequestHeaderFields reflect the structure of a HTTP header and
may be used to represent a HTTP header.
|
| RequestHeaderFieldsAccessor |
Provides an accessor for an request Header-Fields property.
|
| RequestHeaderFieldsAccessor.RequestHeaderFieldsBuilder |
Provides a mutator for an request Header-Fields property.
|
| RequestHeaderFieldsAccessor.RequestHeaderFieldsMutator |
Provides a mutator for an request Header-Fields property.
|
| ResponseCookie |
The ResponseCookie represents a builder for building response
cookies.
|
| ResponseHeaderFields |
The ResponseHeaderFields reflect the structure of a HTTP header and
may be used to represent a HTTP header.
|
| ResponseHeaderFieldsAccessor |
Provides an accessor for an response Header-Fields property.
|
| ResponseHeaderFieldsAccessor.ResponseHeaderFieldsBuilder |
Provides a mutator for an response Header-Fields property.
|
| ResponseHeaderFieldsAccessor.ResponseHeaderFieldsMutator |
Provides a mutator for an response Header-Fields property.
|
| SchemeAccessor |
Provides an accessor for a URL scheme.
|
| SchemeAccessor.SchemeBuilder |
Provides a builder method for a URL scheme returning the builder for
applying multiple build operations.
|
| SchemeAccessor.SchemeMutator |
Provides a mutator for a URL scheme.
|
| SchemeAccessor.SchemeProperty |
Provides a URL scheme.
|
| TokenCredentials |
The Interface TokenCredentials.
|
| TokenType |
The Enum TokenType.
|
| TopLevelType |
The TopLevelType is the top-level part of a HTTP Media-Type.
|
| TopLevelTypeAccessor |
Provides an accessor for a Media-Top-Level-Type property.
|
| TopLevelTypeAccessor.TopLevelTypeBuilder |
Provides a builder method for a Media-Top-Level-Type property returning
the builder for applying multiple build operations.
|
| TopLevelTypeAccessor.TopLevelTypeMutator |
Provides a mutator for a Media-Top-Level-Type property.
|
| TransportLayerProtocol |
Transport Layer Security Protocols (TLS-Protocols) known by the herin
contained libraries.
|
| UnauthorizedException |
The Class UnauthorizedException.
|
| UnauthorizedRuntimeException |
The Class UnauthorizedRuntimeException.
|
| Url |
An URL looks something like this:
"scheme://[identity[:secret]@]host[:port][/path][?
|
| Url.UrlBuilder |
|
| UrlAccessor |
Provides an accessor for a Url property..
|
| UrlAccessor.UrlBuilder |
Provides a builder method for a Url property returning the
builder for applying multiple build operations.
|
| UrlAccessor.UrlMutator |
Provides a mutator for a Url property.
|
| UserAgentAccessor |
Provides an accessor for a user agent property.
|
| UserAgentAccessor.UserAgentBuilder |
Provides a builder method for a user agent property returning the builder
for applying multiple build operations.
|
| UserAgentAccessor.UserAgentMutator |
Provides a mutator for a user agent property.
|
| VirtualHostAccessor |
Provides an accessor for a virtual host property.
|
| VirtualHostAccessor.VirtualHostBuilder |
Provides a mutator for an virtual host property.
|
| VirtualHostAccessor.VirtualHostMutator |
Provides a mutator for a virtual host property.
|